/*
! tailwindcss v3.4.4 | MIT License | https://tailwindcss.com
*/

/*
1. Prevent padding and border from affecting element width. (https://github.com/mozdevs/cssremedy/issues/4)
2. Allow adding a border to an element by just adding a border-width. (https://github.com/tailwindcss/tailwindcss/pull/116)
*/

*,
::before,
::after {
  box-sizing: border-box;
  /* 1 */
  border-width: 0;
  /* 2 */
  border-style: solid;
  /* 2 */
  border-color: #e5e7eb;
  /* 2 */
}

::before,
::after {
  --tw-content: '';
}

/*
1. Use a consistent sensible line-height in all browsers.
2. Prevent adjustments of font size after orientation changes in iOS.
3. Use a more readable tab size.
4. Use the user's configured `sans` font-family by default.
5. Use the user's configured `sans` font-feature-settings by default.
6. Use the user's configured `sans` font-variation-settings by default.
7. Disable tap highlights on iOS
*/

html,
:host {
  line-height: 1.5;
  /* 1 */
  -webkit-text-size-adjust: 100%;
  /* 2 */
  -moz-tab-size: 4;
  /* 3 */
  -o-tab-size: 4;
     tab-size: 4;
  /* 3 */
  font-family: ui-sans-serif, system-ui, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol", "Noto Color Emoji";
  /* 4 */
  font-feature-settings: normal;
  /* 5 */
  font-variation-settings: normal;
  /* 6 */
  -webkit-tap-highlight-color: transparent;
  /* 7 */
}

/*
1. Remove the margin in all browsers.
2. Inherit line-height from `html` so users can set them as a class directly on the `html` element.
*/

body {
  margin: 0;
  /* 1 */
  line-height: inherit;
  /* 2 */
}

/*
1. Add the correct height in Firefox.
2. Correct the inheritance of border color in Firefox. (https://bugzilla.mozilla.org/show_bug.cgi?id=190655)
3. Ensure horizontal rules are visible by default.
*/

hr {
  height: 0;
  /* 1 */
  color: inherit;
  /* 2 */
  border-top-width: 1px;
  /* 3 */
}

/*
Add the correct text decoration in Chrome, Edge, and Safari.
*/

abbr:where([title]) {
  -webkit-text-decoration: underline dotted;
          text-decoration: underline dotted;
}

/*
Remove the default font size and weight for headings.
*/

h1,
h2,
h3,
h4,
h5,
h6 {
  font-size: inherit;
  font-weight: inherit;
}

/*
Reset links to optimize for opt-in styling instead of opt-out.
*/

a {
  color: inherit;
  text-decoration: inherit;
}

/*
Add the correct font weight in Edge and Safari.
*/

b,
strong {
  font-weight: bolder;
}

/*
1. Use the user's configured `mono` font-family by default.
2. Use the user's configured `mono` font-feature-settings by default.
3. Use the user's configured `mono` font-variation-settings by default.
4. Correct the odd `em` font sizing in all browsers.
*/

code,
kbd,
samp,
pre {
  font-family: ui-monospace, SFMono-Regular, Menlo, Monaco, Consolas, "Liberation Mono", "Courier New", monospace;
  /* 1 */
  font-feature-settings: normal;
  /* 2 */
  font-variation-settings: normal;
  /* 3 */
  font-size: 1em;
  /* 4 */
}

/*
Add the correct font size in all browsers.
*/

small {
  font-size: 80%;
}

/*
Prevent `sub` and `sup` elements from affecting the line height in all browsers.
*/

sub,
sup {
  font-size: 75%;
  line-height: 0;
  position: relative;
  vertical-align: baseline;
}

sub {
  bottom: -0.25em;
}

sup {
  top: -0.5em;
}

/*
1. Remove text indentation from table contents in Chrome and Safari. (https://bugs.chromium.org/p/chromium/issues/detail?id=999088, https://bugs.webkit.org/show_bug.cgi?id=201297)
2. Correct table border color inheritance in all Chrome and Safari. (https://bugs.chromium.org/p/chromium/issues/detail?id=935729, https://bugs.webkit.org/show_bug.cgi?id=195016)
3. Remove gaps between table borders by default.
*/

table {
  text-indent: 0;
  /* 1 */
  border-color: inherit;
  /* 2 */
  border-collapse: collapse;
  /* 3 */
}

/*
1. Change the font styles in all browsers.
2. Remove the margin in Firefox and Safari.
3. Remove default padding in all browsers.
*/

button,
input,
optgroup,
select,
textarea {
  font-family: inherit;
  /* 1 */
  font-feature-settings: inherit;
  /* 1 */
  font-variation-settings: inherit;
  /* 1 */
  font-size: 100%;
  /* 1 */
  font-weight: inherit;
  /* 1 */
  line-height: inherit;
  /* 1 */
  letter-spacing: inherit;
  /* 1 */
  color: inherit;
  /* 1 */
  margin: 0;
  /* 2 */
  padding: 0;
  /* 3 */
}

/*
Remove the inheritance of text transform in Edge and Firefox.
*/

button,
select {
  text-transform: none;
}

/*
1. Correct the inability to style clickable types in iOS and Safari.
2. Remove default button styles.
*/

button,
input:where([type='button']),
input:where([type='reset']),
input:where([type='submit']) {
  -webkit-appearance: button;
  /* 1 */
  background-color: transparent;
  /* 2 */
  background-image: none;
  /* 2 */
}

/*
Use the modern Firefox focus style for all focusable elements.
*/

:-moz-focusring {
  outline: auto;
}

/*
Remove the additional `:invalid` styles in Firefox. (https://github.com/mozilla/gecko-dev/blob/2f9eacd9d3d995c937b4251a5557d95d494c9be1/layout/style/res/forms.css#L728-L737)
*/

:-moz-ui-invalid {
  box-shadow: none;
}

/*
Add the correct vertical alignment in Chrome and Firefox.
*/

progress {
  vertical-align: baseline;
}

/*
Correct the cursor style of increment and decrement buttons in Safari.
*/

::-webkit-inner-spin-button,
::-webkit-outer-spin-button {
  height: auto;
}

/*
1. Correct the odd appearance in Chrome and Safari.
2. Correct the outline style in Safari.
*/

[type='search'] {
  -webkit-appearance: textfield;
  /* 1 */
  outline-offset: -2px;
  /* 2 */
}

/*
Remove the inner padding in Chrome and Safari on macOS.
*/

::-webkit-search-decoration {
  -webkit-appearance: none;
}

/*
1. Correct the inability to style clickable types in iOS and Safari.
2. Change font properties to `inherit` in Safari.
*/

::-webkit-file-upload-button {
  -webkit-appearance: button;
  /* 1 */
  font: inherit;
  /* 2 */
}

/*
Add the correct display in Chrome and Safari.
*/

summary {
  display: list-item;
}

/*
Removes the default spacing and border for appropriate elements.
*/

blockquote,
dl,
dd,
h1,
h2,
h3,
h4,
h5,
h6,
hr,
figure,
p,
pre {
  margin: 0;
}

fieldset {
  margin: 0;
  padding: 0;
}

legend {
  padding: 0;
}

ol,
ul,
menu {
  list-style: none;
  margin: 0;
  padding: 0;
}

/*
Reset default styling for dialogs.
*/

dialog {
  padding: 0;
}

/*
Prevent resizing textareas horizontally by default.
*/

textarea {
  resize: vertical;
}

/*
1. Reset the default placeholder opacity in Firefox. (https://github.com/tailwindlabs/tailwindcss/issues/3300)
2. Set the default placeholder color to the user's configured gray 400 color.
*/

input::-moz-placeholder, textarea::-moz-placeholder {
  opacity: 1;
  /* 1 */
  color: #9ca3af;
  /* 2 */
}

input::placeholder,
textarea::placeholder {
  opacity: 1;
  /* 1 */
  color: #9ca3af;
  /* 2 */
}

/*
Set the default cursor for buttons.
*/

button,
[role="button"] {
  cursor: pointer;
}

/*
Make sure disabled buttons don't get the pointer cursor.
*/

:disabled {
  cursor: default;
}

/*
1. Make replaced elements `display: block` by default. (https://github.com/mozdevs/cssremedy/issues/14)
2. Add `vertical-align: middle` to align replaced elements more sensibly by default. (https://github.com/jensimmons/cssremedy/issues/14#issuecomment-634934210)
   This can trigger a poorly considered lint error in some tools but is included by design.
*/

img,
svg,
video,
canvas,
audio,
iframe,
embed,
object {
  display: block;
  /* 1 */
  vertical-align: middle;
  /* 2 */
}

/*
Constrain images and videos to the parent width and preserve their intrinsic aspect ratio. (https://github.com/mozdevs/cssremedy/issues/14)
*/

img,
video {
  max-width: 100%;
  height: auto;
}

/* Make elements with the HTML hidden attribute stay hidden by default */

[hidden] {
  display: none;
}

[type='text'],[type='email'],[type='url'],[type='password'],[type='number'],[type='date'],[type='datetime-local'],[type='month'],[type='search'],[type='tel'],[type='time'],[type='week'],[multiple],textarea,select {
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  background-color: #fff;
  border-color: #6b7280;
  border-width: 1px;
  border-radius: 0px;
  padding-top: 0.5rem;
  padding-right: 0.75rem;
  padding-bottom: 0.5rem;
  padding-left: 0.75rem;
  font-size: 1rem;
  line-height: 1.5rem;
  --tw-shadow: 0 0 #0000;
}

[type='text']:focus, [type='email']:focus, [type='url']:focus, [type='password']:focus, [type='number']:focus, [type='date']:focus, [type='datetime-local']:focus, [type='month']:focus, [type='search']:focus, [type='tel']:focus, [type='time']:focus, [type='week']:focus, [multiple]:focus, textarea:focus, select:focus {
  outline: 2px solid transparent;
  outline-offset: 2px;
  --tw-ring-inset: var(--tw-empty,/*!*/ /*!*/);
  --tw-ring-offset-width: 0px;
  --tw-ring-offset-color: #fff;
  --tw-ring-color: #2563eb;
  --tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);
  --tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);
  box-shadow: var(--tw-ring-offset-shadow), var(--tw-ring-shadow), var(--tw-shadow);
  border-color: #2563eb;
}

input::-moz-placeholder, textarea::-moz-placeholder {
  color: #6b7280;
  opacity: 1;
}

input::placeholder,textarea::placeholder {
  color: #6b7280;
  opacity: 1;
}

::-webkit-datetime-edit-fields-wrapper {
  padding: 0;
}

::-webkit-date-and-time-value {
  min-height: 1.5em;
}

::-webkit-datetime-edit,::-webkit-datetime-edit-year-field,::-webkit-datetime-edit-month-field,::-webkit-datetime-edit-day-field,::-webkit-datetime-edit-hour-field,::-webkit-datetime-edit-minute-field,::-webkit-datetime-edit-second-field,::-webkit-datetime-edit-millisecond-field,::-webkit-datetime-edit-meridiem-field {
  padding-top: 0;
  padding-bottom: 0;
}

select {
  background-image: url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 20 20'%3e%3cpath stroke='%236b7280' stroke-linecap='round' stroke-linejoin='round' stroke-width='1.5' d='M6 8l4 4 4-4'/%3e%3c/svg%3e");
  background-position: right 0.5rem center;
  background-repeat: no-repeat;
  background-size: 1.5em 1.5em;
  padding-right: 2.5rem;
  -webkit-print-color-adjust: exact;
          color-adjust: exact;
}

[multiple] {
  background-image: initial;
  background-position: initial;
  background-repeat: unset;
  background-size: initial;
  padding-right: 0.75rem;
  -webkit-print-color-adjust: unset;
          color-adjust: unset;
}

[type='checkbox'],[type='radio'] {
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  padding: 0;
  -webkit-print-color-adjust: exact;
          color-adjust: exact;
  display: inline-block;
  vertical-align: middle;
  background-origin: border-box;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
  flex-shrink: 0;
  height: 1rem;
  width: 1rem;
  color: #2563eb;
  background-color: #fff;
  border-color: #6b7280;
  border-width: 1px;
  --tw-shadow: 0 0 #0000;
}

[type='checkbox'] {
  border-radius: 0px;
}

[type='radio'] {
  border-radius: 100%;
}

[type='checkbox']:focus,[type='radio']:focus {
  outline: 2px solid transparent;
  outline-offset: 2px;
  --tw-ring-inset: var(--tw-empty,/*!*/ /*!*/);
  --tw-ring-offset-width: 2px;
  --tw-ring-offset-color: #fff;
  --tw-ring-color: #2563eb;
  --tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);
  --tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);
  box-shadow: var(--tw-ring-offset-shadow), var(--tw-ring-shadow), var(--tw-shadow);
}

[type='checkbox']:checked,[type='radio']:checked {
  border-color: transparent;
  background-color: currentColor;
  background-size: 100% 100%;
  background-position: center;
  background-repeat: no-repeat;
}

[type='checkbox']:checked {
  background-image: url("data:image/svg+xml,%3csvg viewBox='0 0 16 16' fill='white' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M12.207 4.793a1 1 0 010 1.414l-5 5a1 1 0 01-1.414 0l-2-2a1 1 0 011.414-1.414L6.5 9.086l4.293-4.293a1 1 0 011.414 0z'/%3e%3c/svg%3e");
}

[type='radio']:checked {
  background-image: url("data:image/svg+xml,%3csvg viewBox='0 0 16 16' fill='white' xmlns='http://www.w3.org/2000/svg'%3e%3ccircle cx='8' cy='8' r='3'/%3e%3c/svg%3e");
}

[type='checkbox']:checked:hover,[type='checkbox']:checked:focus,[type='radio']:checked:hover,[type='radio']:checked:focus {
  border-color: transparent;
  background-color: currentColor;
}

[type='checkbox']:indeterminate {
  background-image: url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath stroke='white' stroke-linecap='round' stroke-linejoin='round' stroke-width='2' d='M4 8h8'/%3e%3c/svg%3e");
  border-color: transparent;
  background-color: currentColor;
  background-size: 100% 100%;
  background-position: center;
  background-repeat: no-repeat;
}

[type='checkbox']:indeterminate:hover,[type='checkbox']:indeterminate:focus {
  border-color: transparent;
  background-color: currentColor;
}

[type='file'] {
  background: unset;
  border-color: inherit;
  border-width: 0;
  border-radius: 0;
  padding: 0;
  font-size: unset;
  line-height: inherit;
}

[type='file']:focus {
  outline: 1px auto -webkit-focus-ring-color;
}

:root,
[data-theme] {
  background-color: var(--fallback-b1,oklch(var(--b1)/1));
  color: var(--fallback-bc,oklch(var(--bc)/1));
}

@supports not (color: oklch(0% 0 0)) {
  :root {
    color-scheme: light;
    --fallback-p: #491eff;
    --fallback-pc: #d4dbff;
    --fallback-s: #ff41c7;
    --fallback-sc: #fff9fc;
    --fallback-a: #00cfbd;
    --fallback-ac: #00100d;
    --fallback-n: #2b3440;
    --fallback-nc: #d7dde4;
    --fallback-b1: #ffffff;
    --fallback-b2: #e5e6e6;
    --fallback-b3: #e5e6e6;
    --fallback-bc: #1f2937;
    --fallback-in: #00b3f0;
    --fallback-inc: #000000;
    --fallback-su: #00ca92;
    --fallback-suc: #000000;
    --fallback-wa: #ffc22d;
    --fallback-wac: #000000;
    --fallback-er: #ff6f70;
    --fallback-erc: #000000;
  }

  @media (prefers-color-scheme: dark) {
    :root {
      color-scheme: dark;
      --fallback-p: #7582ff;
      --fallback-pc: #050617;
      --fallback-s: #ff71cf;
      --fallback-sc: #190211;
      --fallback-a: #00c7b5;
      --fallback-ac: #000e0c;
      --fallback-n: #2a323c;
      --fallback-nc: #a6adbb;
      --fallback-b1: #1d232a;
      --fallback-b2: #191e24;
      --fallback-b3: #15191e;
      --fallback-bc: #a6adbb;
      --fallback-in: #00b3f0;
      --fallback-inc: #000000;
      --fallback-su: #00ca92;
      --fallback-suc: #000000;
      --fallback-wa: #ffc22d;
      --fallback-wac: #000000;
      --fallback-er: #ff6f70;
      --fallback-erc: #000000;
    }
  }
}

html {
  -webkit-tap-highlight-color: transparent;
}

* {
  scrollbar-color: currentColor transparent;
}

:root {
  color-scheme: light;
  --in: 72.06% 0.191 231.6;
  --su: 64.8% 0.150 160;
  --wa: 84.71% 0.199 83.87;
  --er: 71.76% 0.221 22.18;
  --pc: 89.824% 0.06192 275.75;
  --ac: 15.352% 0.0368 183.61;
  --inc: 0% 0 0;
  --suc: 0% 0 0;
  --wac: 0% 0 0;
  --erc: 0% 0 0;
  --rounded-box: 1rem;
  --rounded-btn: 0.5rem;
  --rounded-badge: 1.9rem;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  --tab-radius: 0.5rem;
  --p: 49.12% 0.3096 275.75;
  --s: 69.71% 0.329 342.55;
  --sc: 98.71% 0.0106 342.55;
  --a: 76.76% 0.184 183.61;
  --n: 32.1785% 0.02476 255.701624;
  --nc: 89.4994% 0.011585 252.096176;
  --b1: 100% 0 0;
  --b2: 96.1151% 0 0;
  --b3: 92.4169% 0.00108 197.137559;
  --bc: 27.8078% 0.029596 256.847952;
}

@media (prefers-color-scheme: dark) {
  :root {
    color-scheme: dark;
    --in: 72.06% 0.191 231.6;
    --su: 64.8% 0.150 160;
    --wa: 84.71% 0.199 83.87;
    --er: 71.76% 0.221 22.18;
    --pc: 13.138% 0.0392 275.75;
    --sc: 14.96% 0.052 342.55;
    --ac: 14.902% 0.0334 183.61;
    --inc: 0% 0 0;
    --suc: 0% 0 0;
    --wac: 0% 0 0;
    --erc: 0% 0 0;
    --rounded-box: 1rem;
    --rounded-btn: 0.5rem;
    --rounded-badge: 1.9rem;
    --animation-btn: 0.25s;
    --animation-input: .2s;
    --btn-focus-scale: 0.95;
    --border-btn: 1px;
    --tab-border: 1px;
    --tab-radius: 0.5rem;
    --p: 65.69% 0.196 275.75;
    --s: 74.8% 0.26 342.55;
    --a: 74.51% 0.167 183.61;
    --n: 31.3815% 0.021108 254.139175;
    --nc: 74.6477% 0.0216 264.435964;
    --b1: 25.3267% 0.015896 252.417568;
    --b2: 23.2607% 0.013807 253.100675;
    --b3: 21.1484% 0.01165 254.087939;
    --bc: 74.6477% 0.0216 264.435964;
  }
}

[data-theme=light] {
  color-scheme: light;
  --in: 72.06% 0.191 231.6;
  --su: 64.8% 0.150 160;
  --wa: 84.71% 0.199 83.87;
  --er: 71.76% 0.221 22.18;
  --pc: 89.824% 0.06192 275.75;
  --ac: 15.352% 0.0368 183.61;
  --inc: 0% 0 0;
  --suc: 0% 0 0;
  --wac: 0% 0 0;
  --erc: 0% 0 0;
  --rounded-box: 1rem;
  --rounded-btn: 0.5rem;
  --rounded-badge: 1.9rem;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  --tab-radius: 0.5rem;
  --p: 49.12% 0.3096 275.75;
  --s: 69.71% 0.329 342.55;
  --sc: 98.71% 0.0106 342.55;
  --a: 76.76% 0.184 183.61;
  --n: 32.1785% 0.02476 255.701624;
  --nc: 89.4994% 0.011585 252.096176;
  --b1: 100% 0 0;
  --b2: 96.1151% 0 0;
  --b3: 92.4169% 0.00108 197.137559;
  --bc: 27.8078% 0.029596 256.847952;
}

[data-theme=dark] {
  color-scheme: dark;
  --in: 72.06% 0.191 231.6;
  --su: 64.8% 0.150 160;
  --wa: 84.71% 0.199 83.87;
  --er: 71.76% 0.221 22.18;
  --pc: 13.138% 0.0392 275.75;
  --sc: 14.96% 0.052 342.55;
  --ac: 14.902% 0.0334 183.61;
  --inc: 0% 0 0;
  --suc: 0% 0 0;
  --wac: 0% 0 0;
  --erc: 0% 0 0;
  --rounded-box: 1rem;
  --rounded-btn: 0.5rem;
  --rounded-badge: 1.9rem;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  --tab-radius: 0.5rem;
  --p: 65.69% 0.196 275.75;
  --s: 74.8% 0.26 342.55;
  --a: 74.51% 0.167 183.61;
  --n: 31.3815% 0.021108 254.139175;
  --nc: 74.6477% 0.0216 264.435964;
  --b1: 25.3267% 0.015896 252.417568;
  --b2: 23.2607% 0.013807 253.100675;
  --b3: 21.1484% 0.01165 254.087939;
  --bc: 74.6477% 0.0216 264.435964;
}

[data-theme=cupcake] {
  color-scheme: light;
  --in: 72.06% 0.191 231.6;
  --su: 64.8% 0.150 160;
  --wa: 84.71% 0.199 83.87;
  --er: 71.76% 0.221 22.18;
  --pc: 15.2344% 0.017892 200.026556;
  --sc: 15.787% 0.020249 356.29965;
  --ac: 15.8762% 0.029206 78.618794;
  --nc: 84.7148% 0.013247 313.189598;
  --inc: 0% 0 0;
  --suc: 0% 0 0;
  --wac: 0% 0 0;
  --erc: 0% 0 0;
  --rounded-box: 1rem;
  --rounded-badge: 1.9rem;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --p: 76.172% 0.089459 200.026556;
  --s: 78.9351% 0.101246 356.29965;
  --a: 79.3811% 0.146032 78.618794;
  --n: 23.5742% 0.066235 313.189598;
  --b1: 97.7882% 0.00418 56.375637;
  --b2: 93.9822% 0.007638 61.449292;
  --b3: 91.5861% 0.006811 53.440502;
  --bc: 23.5742% 0.066235 313.189598;
  --rounded-btn: 1.9rem;
  --tab-border: 2px;
  --tab-radius: 0.7rem;
}

[data-theme=bumblebee] {
  color-scheme: light;
  --b2: 93% 0 0;
  --b3: 86% 0 0;
  --in: 72.06% 0.191 231.6;
  --su: 64.8% 0.150 160;
  --wa: 84.71% 0.199 83.87;
  --er: 71.76% 0.221 22.18;
  --bc: 20% 0 0;
  --ac: 16.254% 0.0314 56.52;
  --nc: 82.55% 0.015 281.99;
  --inc: 0% 0 0;
  --suc: 0% 0 0;
  --wac: 0% 0 0;
  --erc: 0% 0 0;
  --rounded-box: 1rem;
  --rounded-btn: 0.5rem;
  --rounded-badge: 1.9rem;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  --tab-radius: 0.5rem;
  --p: 89.51% 0.2132 96.61;
  --pc: 38.92% 0.046 96.61;
  --s: 80.39% 0.194 70.76;
  --sc: 39.38% 0.068 70.76;
  --a: 81.27% 0.157 56.52;
  --n: 12.75% 0.075 281.99;
  --b1: 100% 0 0;
}

[data-theme=emerald] {
  color-scheme: light;
  --b2: 93% 0 0;
  --b3: 86% 0 0;
  --in: 72.06% 0.191 231.6;
  --su: 64.8% 0.150 160;
  --wa: 84.71% 0.199 83.87;
  --er: 71.76% 0.221 22.18;
  --inc: 0% 0 0;
  --suc: 0% 0 0;
  --wac: 0% 0 0;
  --erc: 0% 0 0;
  --rounded-box: 1rem;
  --rounded-btn: 0.5rem;
  --rounded-badge: 1.9rem;
  --border-btn: 1px;
  --tab-border: 1px;
  --tab-radius: 0.5rem;
  --p: 76.6626% 0.135433 153.450024;
  --pc: 33.3872% 0.040618 162.240129;
  --s: 61.3028% 0.202368 261.294233;
  --sc: 100% 0 0;
  --a: 72.7725% 0.149783 33.200363;
  --ac: 0% 0 0;
  --n: 35.5192% 0.032071 262.988584;
  --nc: 98.4625% 0.001706 247.838921;
  --b1: 100% 0 0;
  --bc: 35.5192% 0.032071 262.988584;
  --animation-btn: 0;
  --animation-input: 0;
  --btn-focus-scale: 1;
}

[data-theme=corporate] {
  color-scheme: light;
  --b2: 93% 0 0;
  --b3: 86% 0 0;
  --in: 72.06% 0.191 231.6;
  --su: 64.8% 0.150 160;
  --wa: 84.71% 0.199 83.87;
  --er: 71.76% 0.221 22.18;
  --pc: 12.078% 0.0456 269.1;
  --sc: 13.0739% 0.010951 256.688055;
  --ac: 15.3934% 0.022799 163.57888;
  --inc: 0% 0 0;
  --suc: 0% 0 0;
  --wac: 0% 0 0;
  --erc: 0% 0 0;
  --border-btn: 1px;
  --tab-border: 1px;
  --p: 60.39% 0.228 269.1;
  --s: 65.3694% 0.054756 256.688055;
  --a: 76.9669% 0.113994 163.57888;
  --n: 22.3899% 0.031305 278.07229;
  --nc: 95.8796% 0.008588 247.915135;
  --b1: 100% 0 0;
  --bc: 22.3899% 0.031305 278.07229;
  --rounded-box: 0.25rem;
  --rounded-btn: .125rem;
  --rounded-badge: .125rem;
  --tab-radius: 0.25rem;
  --animation-btn: 0;
  --animation-input: 0;
  --btn-focus-scale: 1;
}

[data-theme=synthwave] {
  color-scheme: dark;
  --b2: 20.2941% 0.076211 287.835609;
  --b3: 18.7665% 0.070475 287.835609;
  --pc: 14.4421% 0.031903 342.009383;
  --sc: 15.6543% 0.02362 227.382405;
  --ac: 17.608% 0.0412 93.72;
  --rounded-box: 1rem;
  --rounded-btn: 0.5rem;
  --rounded-badge: 1.9rem;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  --tab-radius: 0.5rem;
  --p: 72.2105% 0.159514 342.009383;
  --s: 78.2714% 0.118101 227.382405;
  --a: 88.04% 0.206 93.72;
  --n: 25.5554% 0.103537 286.507967;
  --nc: 97.9365% 0.00819 301.358346;
  --b1: 21.8216% 0.081948 287.835609;
  --bc: 97.9365% 0.00819 301.358346;
  --in: 76.5197% 0.12273 231.831603;
  --inc: 23.5017% 0.096418 290.329844;
  --su: 86.0572% 0.115038 178.624677;
  --suc: 23.5017% 0.096418 290.329844;
  --wa: 85.531% 0.122117 93.722227;
  --wac: 23.5017% 0.096418 290.329844;
  --er: 73.7005% 0.121339 32.639257;
  --erc: 23.5017% 0.096418 290.329844;
}

[data-theme=retro] {
  color-scheme: light;
  --inc: 90.923% 0.043042 262.880917;
  --suc: 12.541% 0.033982 149.213788;
  --wac: 13.3168% 0.031484 58.31834;
  --erc: 13.144% 0.0398 27.33;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  --p: 76.8664% 0.104092 22.664655;
  --pc: 26.5104% 0.006243 0.522862;
  --s: 80.7415% 0.052534 159.094608;
  --sc: 26.5104% 0.006243 0.522862;
  --a: 70.3919% 0.125455 52.953428;
  --ac: 26.5104% 0.006243 0.522862;
  --n: 28.4181% 0.009519 355.534017;
  --nc: 92.5604% 0.025113 89.217311;
  --b1: 91.6374% 0.034554 90.51575;
  --b2: 88.2722% 0.049418 91.774344;
  --b3: 84.133% 0.065952 90.856665;
  --bc: 26.5104% 0.006243 0.522862;
  --in: 54.615% 0.215208 262.880917;
  --su: 62.7052% 0.169912 149.213788;
  --wa: 66.584% 0.157422 58.31834;
  --er: 65.72% 0.199 27.33;
  --rounded-box: 0.4rem;
  --rounded-btn: 0.4rem;
  --rounded-badge: 0.4rem;
  --tab-radius: 0.4rem;
}

[data-theme=cyberpunk] {
  color-scheme: light;
  --b2: 87.8943% 0.16647 104.32;
  --b3: 81.2786% 0.15394 104.32;
  --in: 72.06% 0.191 231.6;
  --su: 64.8% 0.150 160;
  --wa: 84.71% 0.199 83.87;
  --er: 71.76% 0.221 22.18;
  --bc: 18.902% 0.0358 104.32;
  --pc: 14.844% 0.0418 6.35;
  --sc: 16.666% 0.0368 204.72;
  --ac: 14.372% 0.04352 310.43;
  --inc: 0% 0 0;
  --suc: 0% 0 0;
  --wac: 0% 0 0;
  --erc: 0% 0 0;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  font-family: ui-monospace,SFMono-Regular,Menlo,Monaco,Consolas,Liberation Mono,Courier New,monospace;
  --p: 74.22% 0.209 6.35;
  --s: 83.33% 0.184 204.72;
  --a: 71.86% 0.2176 310.43;
  --n: 23.04% 0.065 269.31;
  --nc: 94.51% 0.179 104.32;
  --b1: 94.51% 0.179 104.32;
  --rounded-box: 0;
  --rounded-btn: 0;
  --rounded-badge: 0;
  --tab-radius: 0;
}

[data-theme=valentine] {
  color-scheme: light;
  --b2: 88.0567% 0.024834 337.06289;
  --b3: 81.4288% 0.022964 337.06289;
  --pc: 13.7239% 0.030755 15.066527;
  --sc: 14.3942% 0.029258 293.189609;
  --ac: 14.2537% 0.014961 197.828857;
  --inc: 90.923% 0.043042 262.880917;
  --suc: 12.541% 0.033982 149.213788;
  --wac: 13.3168% 0.031484 58.31834;
  --erc: 14.614% 0.0414 27.33;
  --rounded-box: 1rem;
  --rounded-badge: 1.9rem;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  --p: 68.6197% 0.153774 15.066527;
  --s: 71.971% 0.14629 293.189609;
  --a: 71.2685% 0.074804 197.828857;
  --n: 54.6053% 0.143342 358.004839;
  --nc: 90.2701% 0.037202 336.955191;
  --b1: 94.6846% 0.026703 337.06289;
  --bc: 37.3085% 0.081131 4.606426;
  --in: 54.615% 0.215208 262.880917;
  --su: 62.7052% 0.169912 149.213788;
  --wa: 66.584% 0.157422 58.31834;
  --er: 73.07% 0.207 27.33;
  --rounded-btn: 1.9rem;
  --tab-radius: 0.7rem;
}

[data-theme=halloween] {
  color-scheme: dark;
  --b2: 23.0416% 0 0;
  --b3: 21.3072% 0 0;
  --bc: 84.9552% 0 0;
  --sc: 89.196% 0.0496 305.03;
  --nc: 84.8742% 0.009322 65.681484;
  --inc: 90.923% 0.043042 262.880917;
  --suc: 12.541% 0.033982 149.213788;
  --wac: 13.3168% 0.031484 58.31834;
  --erc: 13.144% 0.0398 27.33;
  --rounded-box: 1rem;
  --rounded-btn: 0.5rem;
  --rounded-badge: 1.9rem;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  --tab-radius: 0.5rem;
  --p: 77.48% 0.204 60.62;
  --pc: 19.6935% 0.004671 196.779412;
  --s: 45.98% 0.248 305.03;
  --a: 64.8% 0.223 136.073479;
  --ac: 0% 0 0;
  --n: 24.371% 0.046608 65.681484;
  --b1: 24.7759% 0 0;
  --in: 54.615% 0.215208 262.880917;
  --su: 62.7052% 0.169912 149.213788;
  --wa: 66.584% 0.157422 58.31834;
  --er: 65.72% 0.199 27.33;
}

[data-theme=garden] {
  color-scheme: light;
  --b2: 86.4453% 0.002011 17.197414;
  --b3: 79.9386% 0.00186 17.197414;
  --in: 72.06% 0.191 231.6;
  --su: 64.8% 0.150 160;
  --wa: 84.71% 0.199 83.87;
  --er: 71.76% 0.221 22.18;
  --sc: 89.699% 0.022197 355.095988;
  --ac: 11.2547% 0.010859 154.390187;
  --inc: 0% 0 0;
  --suc: 0% 0 0;
  --wac: 0% 0 0;
  --erc: 0% 0 0;
  --rounded-box: 1rem;
  --rounded-btn: 0.5rem;
  --rounded-badge: 1.9rem;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  --tab-radius: 0.5rem;
  --p: 62.45% 0.278 3.83636;
  --pc: 100% 0 0;
  --s: 48.4952% 0.110985 355.095988;
  --a: 56.2735% 0.054297 154.390187;
  --n: 24.1559% 0.049362 89.070594;
  --nc: 92.9519% 0.002163 17.197414;
  --b1: 92.9519% 0.002163 17.197414;
  --bc: 16.9617% 0.001664 17.32068;
}

[data-theme=forest] {
  color-scheme: dark;
  --b2: 17.522% 0.007709 17.911578;
  --b3: 16.2032% 0.007129 17.911578;
  --in: 72.06% 0.191 231.6;
  --su: 64.8% 0.150 160;
  --wa: 84.71% 0.199 83.87;
  --er: 71.76% 0.221 22.18;
  --bc: 83.7682% 0.001658 17.911578;
  --sc: 13.9553% 0.027077 168.327128;
  --ac: 14.1257% 0.02389 185.713193;
  --nc: 86.1397% 0.007806 171.364646;
  --inc: 0% 0 0;
  --suc: 0% 0 0;
  --wac: 0% 0 0;
  --erc: 0% 0 0;
  --rounded-box: 1rem;
  --rounded-badge: 1.9rem;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  --tab-radius: 0.5rem;
  --p: 68.6283% 0.185567 148.958922;
  --pc: 0% 0 0;
  --s: 69.7764% 0.135385 168.327128;
  --a: 70.6285% 0.119451 185.713193;
  --n: 30.6985% 0.039032 171.364646;
  --b1: 18.8409% 0.00829 17.911578;
  --rounded-btn: 1.9rem;
}

[data-theme=aqua] {
  color-scheme: dark;
  --b2: 45.3464% 0.118611 261.181672;
  --b3: 41.9333% 0.109683 261.181672;
  --bc: 89.7519% 0.025508 261.181672;
  --sc: 12.1365% 0.02175 309.782946;
  --ac: 18.6854% 0.020445 94.555431;
  --nc: 12.2124% 0.023402 243.760661;
  --inc: 90.923% 0.043042 262.880917;
  --suc: 12.541% 0.033982 149.213788;
  --wac: 13.3168% 0.031484 58.31834;
  --erc: 14.79% 0.038 27.33;
  --rounded-box: 1rem;
  --rounded-btn: 0.5rem;
  --rounded-badge: 1.9rem;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  --tab-radius: 0.5rem;
  --p: 85.6617% 0.14498 198.6458;
  --pc: 40.1249% 0.068266 197.603872;
  --s: 60.6827% 0.108752 309.782946;
  --a: 93.4269% 0.102225 94.555431;
  --n: 61.0622% 0.117009 243.760661;
  --b1: 48.7596% 0.127539 261.181672;
  --in: 54.615% 0.215208 262.880917;
  --su: 62.7052% 0.169912 149.213788;
  --wa: 66.584% 0.157422 58.31834;
  --er: 73.95% 0.19 27.33;
}

[data-theme=lofi] {
  color-scheme: light;
  --inc: 15.908% 0.0206 205.9;
  --suc: 18.026% 0.0306 164.14;
  --wac: 17.674% 0.027 79.94;
  --erc: 15.732% 0.03 28.47;
  --border-btn: 1px;
  --tab-border: 1px;
  --p: 15.9066% 0 0;
  --pc: 100% 0 0;
  --s: 21.455% 0.001566 17.278957;
  --sc: 100% 0 0;
  --a: 26.8618% 0 0;
  --ac: 100% 0 0;
  --n: 0% 0 0;
  --nc: 100% 0 0;
  --b1: 100% 0 0;
  --b2: 96.1151% 0 0;
  --b3: 92.268% 0.001082 17.17934;
  --bc: 0% 0 0;
  --in: 79.54% 0.103 205.9;
  --su: 90.13% 0.153 164.14;
  --wa: 88.37% 0.135 79.94;
  --er: 78.66% 0.15 28.47;
  --rounded-box: 0.25rem;
  --rounded-btn: 0.125rem;
  --rounded-badge: 0.125rem;
  --tab-radius: 0.125rem;
  --animation-btn: 0;
  --animation-input: 0;
  --btn-focus-scale: 1;
}

[data-theme=pastel] {
  color-scheme: light;
  --in: 72.06% 0.191 231.6;
  --su: 64.8% 0.150 160;
  --wa: 84.71% 0.199 83.87;
  --er: 71.76% 0.221 22.18;
  --bc: 20% 0 0;
  --pc: 16.6166% 0.006979 316.8737;
  --sc: 17.6153% 0.009839 8.688364;
  --ac: 17.8419% 0.012056 170.923263;
  --nc: 14.2681% 0.014702 228.183906;
  --inc: 0% 0 0;
  --suc: 0% 0 0;
  --wac: 0% 0 0;
  --erc: 0% 0 0;
  --rounded-box: 1rem;
  --rounded-badge: 1.9rem;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  --p: 83.0828% 0.034896 316.8737;
  --s: 88.0763% 0.049197 8.688364;
  --a: 89.2096% 0.06028 170.923263;
  --n: 71.3406% 0.07351 228.183906;
  --b1: 100% 0 0;
  --b2: 98.4625% 0.001706 247.838921;
  --b3: 87.1681% 0.009339 258.338227;
  --rounded-btn: 1.9rem;
  --tab-radius: 0.7rem;
}

[data-theme=fantasy] {
  color-scheme: light;
  --b2: 93% 0 0;
  --b3: 86% 0 0;
  --in: 72.06% 0.191 231.6;
  --su: 64.8% 0.150 160;
  --wa: 84.71% 0.199 83.87;
  --er: 71.76% 0.221 22.18;
  --pc: 87.49% 0.0378 325.02;
  --sc: 90.784% 0.0324 241.36;
  --ac: 15.196% 0.0408 56.72;
  --nc: 85.5616% 0.005919 256.847952;
  --inc: 0% 0 0;
  --suc: 0% 0 0;
  --wac: 0% 0 0;
  --erc: 0% 0 0;
  --rounded-box: 1rem;
  --rounded-btn: 0.5rem;
  --rounded-badge: 1.9rem;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  --tab-radius: 0.5rem;
  --p: 37.45% 0.189 325.02;
  --s: 53.92% 0.162 241.36;
  --a: 75.98% 0.204 56.72;
  --n: 27.8078% 0.029596 256.847952;
  --b1: 100% 0 0;
  --bc: 27.8078% 0.029596 256.847952;
}

[data-theme=wireframe] {
  color-scheme: light;
  --bc: 20% 0 0;
  --pc: 15.6521% 0 0;
  --sc: 15.6521% 0 0;
  --ac: 15.6521% 0 0;
  --nc: 18.8014% 0 0;
  --inc: 89.0403% 0.062643 264.052021;
  --suc: 90.395% 0.035372 142.495339;
  --wac: 14.1626% 0.019994 108.702381;
  --erc: 12.5591% 0.051537 29.233885;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  font-family: Chalkboard,comic sans ms,'sans-serif';
  --p: 78.2604% 0 0;
  --s: 78.2604% 0 0;
  --a: 78.2604% 0 0;
  --n: 94.007% 0 0;
  --b1: 100% 0 0;
  --b2: 94.9119% 0 0;
  --b3: 89.7547% 0 0;
  --in: 45.2014% 0.313214 264.052021;
  --su: 51.9752% 0.176858 142.495339;
  --wa: 70.8131% 0.099969 108.702381;
  --er: 62.7955% 0.257683 29.233885;
  --rounded-box: 0.2rem;
  --rounded-btn: 0.2rem;
  --rounded-badge: 0.2rem;
  --tab-radius: 0.2rem;
}

[data-theme=black] {
  color-scheme: dark;
  --pc: 86.736% 0 0;
  --sc: 86.736% 0 0;
  --ac: 86.736% 0 0;
  --nc: 86.736% 0 0;
  --inc: 89.0403% 0.062643 264.052021;
  --suc: 90.395% 0.035372 142.495339;
  --wac: 19.3597% 0.042201 109.769232;
  --erc: 12.5591% 0.051537 29.233885;
  --border-btn: 1px;
  --tab-border: 1px;
  --p: 33.6799% 0 0;
  --s: 33.6799% 0 0;
  --a: 33.6799% 0 0;
  --b1: 0% 0 0;
  --b2: 19.1251% 0 0;
  --b3: 26.8618% 0 0;
  --bc: 87.6096% 0 0;
  --n: 33.6799% 0 0;
  --in: 45.2014% 0.313214 264.052021;
  --su: 51.9752% 0.176858 142.495339;
  --wa: 96.7983% 0.211006 109.769232;
  --er: 62.7955% 0.257683 29.233885;
  --rounded-box: 0;
  --rounded-btn: 0;
  --rounded-badge: 0;
  --animation-btn: 0;
  --animation-input: 0;
  --btn-focus-scale: 1;
  --tab-radius: 0;
}

[data-theme=luxury] {
  color-scheme: dark;
  --pc: 20% 0 0;
  --sc: 85.5163% 0.012821 261.069149;
  --ac: 87.3349% 0.010348 338.82597;
  --inc: 15.8122% 0.024356 237.133883;
  --suc: 15.6239% 0.038579 132.154381;
  --wac: 17.2255% 0.027305 102.89115;
  --erc: 14.3506% 0.035271 22.568916;
  --rounded-box: 1rem;
  --rounded-btn: 0.5rem;
  --rounded-badge: 1.9rem;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  --tab-radius: 0.5rem;
  --p: 100% 0 0;
  --s: 27.5815% 0.064106 261.069149;
  --a: 36.6744% 0.051741 338.82597;
  --n: 24.27% 0.057015 59.825019;
  --nc: 93.2033% 0.089631 90.861683;
  --b1: 14.0765% 0.004386 285.822869;
  --b2: 20.2191% 0.004211 308.22937;
  --b3: 29.8961% 0.003818 308.318612;
  --bc: 75.6879% 0.123666 76.890484;
  --in: 79.0612% 0.121778 237.133883;
  --su: 78.1197% 0.192894 132.154381;
  --wa: 86.1274% 0.136524 102.89115;
  --er: 71.7531% 0.176357 22.568916;
}

[data-theme=dracula] {
  color-scheme: dark;
  --b2: 26.8053% 0.020556 277.508664;
  --b3: 24.7877% 0.019009 277.508664;
  --pc: 15.0922% 0.036614 346.812432;
  --sc: 14.8405% 0.029709 301.883095;
  --ac: 16.6785% 0.024826 66.558491;
  --nc: 87.8891% 0.006515 275.524078;
  --inc: 17.6526% 0.018676 212.846491;
  --suc: 17.4199% 0.043903 148.024881;
  --wac: 19.1068% 0.026849 112.757109;
  --erc: 13.6441% 0.041266 24.430965;
  --rounded-box: 1rem;
  --rounded-btn: 0.5rem;
  --rounded-badge: 1.9rem;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  --tab-radius: 0.5rem;
  --p: 75.4611% 0.18307 346.812432;
  --s: 74.2023% 0.148546 301.883095;
  --a: 83.3927% 0.124132 66.558491;
  --n: 39.4456% 0.032576 275.524078;
  --b1: 28.8229% 0.022103 277.508664;
  --bc: 97.7477% 0.007913 106.545019;
  --in: 88.263% 0.09338 212.846491;
  --su: 87.0995% 0.219516 148.024881;
  --wa: 95.5338% 0.134246 112.757109;
  --er: 68.2204% 0.206328 24.430965;
}

[data-theme=cmyk] {
  color-scheme: light;
  --b2: 93% 0 0;
  --b3: 86% 0 0;
  --bc: 20% 0 0;
  --pc: 14.3544% 0.02666 239.443325;
  --sc: 12.8953% 0.040552 359.339283;
  --ac: 18.8458% 0.037948 105.306968;
  --nc: 84.3557% 0 0;
  --inc: 13.6952% 0.0189 217.284104;
  --suc: 89.3898% 0.032505 321.406278;
  --wac: 14.2473% 0.031969 52.023412;
  --erc: 12.4027% 0.041677 28.717543;
  --rounded-box: 1rem;
  --rounded-btn: 0.5rem;
  --rounded-badge: 1.9rem;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  --tab-radius: 0.5rem;
  --p: 71.7722% 0.133298 239.443325;
  --s: 64.4766% 0.202758 359.339283;
  --a: 94.2289% 0.189741 105.306968;
  --n: 21.7787% 0 0;
  --b1: 100% 0 0;
  --in: 68.4759% 0.094499 217.284104;
  --su: 46.949% 0.162524 321.406278;
  --wa: 71.2364% 0.159843 52.023412;
  --er: 62.0133% 0.208385 28.717543;
}

[data-theme=autumn] {
  color-scheme: light;
  --b2: 89.1077% 0 0;
  --b3: 82.4006% 0 0;
  --bc: 19.1629% 0 0;
  --pc: 88.1446% 0.032232 17.530175;
  --sc: 12.3353% 0.033821 23.865865;
  --ac: 14.6851% 0.018999 60.729616;
  --nc: 90.8734% 0.007475 51.902819;
  --inc: 13.8449% 0.019596 207.284192;
  --suc: 12.199% 0.016032 174.616213;
  --wac: 14.0163% 0.032982 56.844303;
  --erc: 90.614% 0.0482 24.16;
  --rounded-box: 1rem;
  --rounded-btn: 0.5rem;
  --rounded-badge: 1.9rem;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  --tab-radius: 0.5rem;
  --p: 40.7232% 0.16116 17.530175;
  --s: 61.6763% 0.169105 23.865865;
  --a: 73.4253% 0.094994 60.729616;
  --n: 54.3672% 0.037374 51.902819;
  --b1: 95.8147% 0 0;
  --in: 69.2245% 0.097979 207.284192;
  --su: 60.9951% 0.080159 174.616213;
  --wa: 70.0817% 0.164909 56.844303;
  --er: 53.07% 0.241 24.16;
}

[data-theme=business] {
  color-scheme: dark;
  --b2: 22.6487% 0 0;
  --b3: 20.944% 0 0;
  --bc: 84.8707% 0 0;
  --pc: 88.3407% 0.019811 251.473931;
  --sc: 12.8185% 0.005481 229.389418;
  --ac: 13.4542% 0.033545 35.791525;
  --nc: 85.4882% 0.00265 253.041249;
  --inc: 12.5233% 0.028702 240.033697;
  --suc: 14.0454% 0.018919 156.59611;
  --wac: 15.4965% 0.023141 81.519177;
  --erc: 90.3221% 0.029356 29.674507;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  --tab-radius: 0.5rem;
  --p: 41.7036% 0.099057 251.473931;
  --s: 64.0924% 0.027405 229.389418;
  --a: 67.271% 0.167726 35.791525;
  --n: 27.441% 0.01325 253.041249;
  --b1: 24.3535% 0 0;
  --in: 62.6163% 0.143511 240.033697;
  --su: 70.2268% 0.094594 156.59611;
  --wa: 77.4824% 0.115704 81.519177;
  --er: 51.6105% 0.14678 29.674507;
  --rounded-box: 0.25rem;
  --rounded-btn: .125rem;
  --rounded-badge: .125rem;
}

[data-theme=acid] {
  color-scheme: light;
  --b2: 91.6146% 0 0;
  --b3: 84.7189% 0 0;
  --bc: 19.7021% 0 0;
  --pc: 14.38% 0.0714 330.759573;
  --sc: 14.674% 0.0448 48.250878;
  --ac: 18.556% 0.0528 122.962951;
  --nc: 84.262% 0.0256 278.68;
  --inc: 12.144% 0.0454 252.05;
  --suc: 17.144% 0.0532 158.53;
  --wac: 18.202% 0.0424 100.5;
  --erc: 12.968% 0.0586 29.349188;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  --p: 71.9% 0.357 330.759573;
  --s: 73.37% 0.224 48.250878;
  --a: 92.78% 0.264 122.962951;
  --n: 21.31% 0.128 278.68;
  --b1: 98.5104% 0 0;
  --in: 60.72% 0.227 252.05;
  --su: 85.72% 0.266 158.53;
  --wa: 91.01% 0.212 100.5;
  --er: 64.84% 0.293 29.349188;
  --rounded-box: 1.25rem;
  --rounded-btn: 1rem;
  --rounded-badge: 1rem;
  --tab-radius: 0.7rem;
}

[data-theme=lemonade] {
  color-scheme: light;
  --b2: 91.8003% 0.0186 123.72;
  --b3: 84.8906% 0.0172 123.72;
  --bc: 19.742% 0.004 123.72;
  --pc: 11.784% 0.0398 134.6;
  --sc: 15.55% 0.0392 111.09;
  --ac: 17.078% 0.0402 100.73;
  --nc: 86.196% 0.015 108.6;
  --inc: 17.238% 0.0094 224.14;
  --suc: 17.238% 0.0094 157.85;
  --wac: 17.238% 0.0094 102.15;
  --erc: 17.238% 0.0094 25.85;
  --rounded-box: 1rem;
  --rounded-btn: 0.5rem;
  --rounded-badge: 1.9rem;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  --tab-radius: 0.5rem;
  --p: 58.92% 0.199 134.6;
  --s: 77.75% 0.196 111.09;
  --a: 85.39% 0.201 100.73;
  --n: 30.98% 0.075 108.6;
  --b1: 98.71% 0.02 123.72;
  --in: 86.19% 0.047 224.14;
  --su: 86.19% 0.047 157.85;
  --wa: 86.19% 0.047 102.15;
  --er: 86.19% 0.047 25.85;
}

[data-theme=night] {
  color-scheme: dark;
  --b2: 19.3144% 0.037037 265.754874;
  --b3: 17.8606% 0.034249 265.754874;
  --bc: 84.1536% 0.007965 265.754874;
  --pc: 15.0703% 0.027798 232.66148;
  --sc: 13.6023% 0.031661 276.934902;
  --ac: 14.4721% 0.035244 350.048739;
  --nc: 85.5899% 0.00737 260.030984;
  --suc: 15.6904% 0.026506 181.911977;
  --wac: 16.6486% 0.027912 82.95003;
  --erc: 14.3572% 0.034051 13.11834;
  --rounded-box: 1rem;
  --rounded-btn: 0.5rem;
  --rounded-badge: 1.9rem;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  --tab-radius: 0.5rem;
  --p: 75.3513% 0.138989 232.66148;
  --s: 68.0113% 0.158303 276.934902;
  --a: 72.3603% 0.176218 350.048739;
  --n: 27.9495% 0.036848 260.030984;
  --b1: 20.7682% 0.039824 265.754874;
  --in: 68.4553% 0.148062 237.25135;
  --inc: 0% 0 0;
  --su: 78.452% 0.132529 181.911977;
  --wa: 83.2428% 0.139558 82.95003;
  --er: 71.7858% 0.170255 13.11834;
}

[data-theme=coffee] {
  color-scheme: dark;
  --b2: 20.1585% 0.021457 329.708637;
  --b3: 18.6412% 0.019842 329.708637;
  --pc: 14.3993% 0.024765 62.756393;
  --sc: 86.893% 0.00597 199.19444;
  --ac: 88.5243% 0.014881 224.389184;
  --nc: 83.3022% 0.003149 326.261446;
  --inc: 15.898% 0.012774 184.558367;
  --suc: 14.9445% 0.014491 131.116276;
  --wac: 17.6301% 0.028162 87.722413;
  --erc: 15.4637% 0.025644 31.871922;
  --rounded-box: 1rem;
  --rounded-btn: 0.5rem;
  --rounded-badge: 1.9rem;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  --tab-radius: 0.5rem;
  --p: 71.9967% 0.123825 62.756393;
  --s: 34.465% 0.029849 199.19444;
  --a: 42.6213% 0.074405 224.389184;
  --n: 16.5109% 0.015743 326.261446;
  --b1: 21.6758% 0.023072 329.708637;
  --bc: 72.3547% 0.092794 79.129387;
  --in: 79.4902% 0.063869 184.558367;
  --su: 74.7224% 0.072456 131.116276;
  --wa: 88.1503% 0.140812 87.722413;
  --er: 77.3187% 0.12822 31.871922;
}

[data-theme=winter] {
  color-scheme: light;
  --pc: 91.372% 0.051 257.57;
  --sc: 88.5103% 0.03222 282.339433;
  --ac: 11.988% 0.038303 335.171434;
  --nc: 83.9233% 0.012704 257.651965;
  --inc: 17.6255% 0.017178 214.515264;
  --suc: 16.0988% 0.015404 197.823719;
  --wac: 17.8345% 0.009167 71.47031;
  --erc: 14.6185% 0.022037 20.076293;
  --rounded-box: 1rem;
  --rounded-btn: 0.5rem;
  --rounded-badge: 1.9rem;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  --tab-radius: 0.5rem;
  --p: 56.86% 0.255 257.57;
  --s: 42.5516% 0.161098 282.339433;
  --a: 59.9398% 0.191515 335.171434;
  --n: 19.6166% 0.063518 257.651965;
  --b1: 100% 0 0;
  --b2: 97.4663% 0.011947 259.822565;
  --b3: 93.2686% 0.016223 262.751375;
  --bc: 41.8869% 0.053885 255.824911;
  --in: 88.1275% 0.085888 214.515264;
  --su: 80.4941% 0.077019 197.823719;
  --wa: 89.1725% 0.045833 71.47031;
  --er: 73.0926% 0.110185 20.076293;
}

[data-theme=dim] {
  color-scheme: dark;
  --pc: 17.2267% 0.028331 139.549991;
  --sc: 14.6752% 0.033181 35.353059;
  --ac: 14.8459% 0.026728 311.37924;
  --inc: 17.2157% 0.028409 206.182959;
  --suc: 17.2343% 0.028437 166.534048;
  --wac: 17.2327% 0.028447 94.818679;
  --erc: 16.4838% 0.019914 33.756357;
  --rounded-box: 1rem;
  --rounded-btn: 0.5rem;
  --rounded-badge: 1.9rem;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  --tab-radius: 0.5rem;
  --p: 86.1335% 0.141656 139.549991;
  --s: 73.3759% 0.165904 35.353059;
  --a: 74.2296% 0.133641 311.37924;
  --n: 24.7311% 0.020483 264.094728;
  --nc: 82.9011% 0.031335 222.959324;
  --b1: 30.8577% 0.023243 264.149498;
  --b2: 28.0368% 0.01983 264.182074;
  --b3: 26.3469% 0.018403 262.177739;
  --bc: 82.9011% 0.031335 222.959324;
  --in: 86.0785% 0.142046 206.182959;
  --su: 86.1717% 0.142187 166.534048;
  --wa: 86.1634% 0.142236 94.818679;
  --er: 82.4189% 0.09957 33.756357;
}

[data-theme=nord] {
  color-scheme: light;
  --pc: 11.8872% 0.015449 254.027774;
  --sc: 13.9303% 0.011822 248.687186;
  --ac: 15.4929% 0.01245 217.469017;
  --inc: 13.8414% 0.012499 332.664922;
  --suc: 15.3654% 0.01498 131.063061;
  --wac: 17.0972% 0.017847 84.093335;
  --erc: 12.122% 0.024119 15.341883;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  --p: 59.4359% 0.077246 254.027774;
  --s: 69.6516% 0.059108 248.687186;
  --a: 77.4643% 0.062249 217.469017;
  --n: 45.229% 0.035214 264.1312;
  --nc: 89.9258% 0.016374 262.749256;
  --b1: 95.1276% 0.007445 260.731539;
  --b2: 93.2996% 0.010389 261.788485;
  --b3: 89.9258% 0.016374 262.749256;
  --bc: 32.4374% 0.022945 264.182036;
  --in: 69.2072% 0.062496 332.664922;
  --su: 76.827% 0.074899 131.063061;
  --wa: 85.4862% 0.089234 84.093335;
  --er: 60.61% 0.120594 15.341883;
  --rounded-box: 0.4rem;
  --rounded-btn: 0.2rem;
  --rounded-badge: 0.4rem;
  --tab-radius: 0.2rem;
}

[data-theme=sunset] {
  color-scheme: dark;
  --pc: 14.9408% 0.031656 39.94703;
  --sc: 14.5075% 0.035531 2.72034;
  --ac: 14.2589% 0.033336 299.844533;
  --inc: 17.1119% 0.017054 206.015183;
  --suc: 17.1122% 0.017172 144.77874;
  --wac: 17.1139% 0.016961 74.427797;
  --erc: 17.1023% 0.015778 16.886379;
  --animation-btn: 0.25s;
  --animation-input: .2s;
  --btn-focus-scale: 0.95;
  --border-btn: 1px;
  --tab-border: 1px;
  --p: 74.7039% 0.158278 39.94703;
  --s: 72.5375% 0.177654 2.72034;
  --a: 71.2947% 0.166678 299.844533;
  --n: 26% 0.019 237.69;
  --nc: 70% 0.019 237.69;
  --b1: 22% 0.019 237.69;
  --b2: 20% 0.019 237.69;
  --b3: 18% 0.019 237.69;
  --bc: 77.3835% 0.043586 245.096534;
  --in: 85.5596% 0.085271 206.015183;
  --su: 85.5609% 0.08586 144.77874;
  --wa: 85.5695% 0.084806 74.427797;
  --er: 85.5116% 0.07889 16.886379;
  --rounded-box: 1.2rem;
  --rounded-btn: 0.8rem;
  --rounded-badge: 0.4rem;
  --tab-radius: 0.7rem;
}

*, ::before, ::after {
  --tw-border-spacing-x: 0;
  --tw-border-spacing-y: 0;
  --tw-translate-x: 0;
  --tw-translate-y: 0;
  --tw-rotate: 0;
  --tw-skew-x: 0;
  --tw-skew-y: 0;
  --tw-scale-x: 1;
  --tw-scale-y: 1;
  --tw-pan-x:  ;
  --tw-pan-y:  ;
  --tw-pinch-zoom:  ;
  --tw-scroll-snap-strictness: proximity;
  --tw-gradient-from-position:  ;
  --tw-gradient-via-position:  ;
  --tw-gradient-to-position:  ;
  --tw-ordinal:  ;
  --tw-slashed-zero:  ;
  --tw-numeric-figure:  ;
  --tw-numeric-spacing:  ;
  --tw-numeric-fraction:  ;
  --tw-ring-inset:  ;
  --tw-ring-offset-width: 0px;
  --tw-ring-offset-color: #fff;
  --tw-ring-color: rgb(59 130 246 / 0.5);
  --tw-ring-offset-shadow: 0 0 #0000;
  --tw-ring-shadow: 0 0 #0000;
  --tw-shadow: 0 0 #0000;
  --tw-shadow-colored: 0 0 #0000;
  --tw-blur:  ;
  --tw-brightness:  ;
  --tw-contrast:  ;
  --tw-grayscale:  ;
  --tw-hue-rotate:  ;
  --tw-invert:  ;
  --tw-saturate:  ;
  --tw-sepia:  ;
  --tw-drop-shadow:  ;
  --tw-backdrop-blur:  ;
  --tw-backdrop-brightness:  ;
  --tw-backdrop-contrast:  ;
  --tw-backdrop-grayscale:  ;
  --tw-backdrop-hue-rotate:  ;
  --tw-backdrop-invert:  ;
  --tw-backdrop-opacity:  ;
  --tw-backdrop-saturate:  ;
  --tw-backdrop-sepia:  ;
  --tw-contain-size:  ;
  --tw-contain-layout:  ;
  --tw-contain-paint:  ;
  --tw-contain-style:  ;
}

::backdrop {
  --tw-border-spacing-x: 0;
  --tw-border-spacing-y: 0;
  --tw-translate-x: 0;
  --tw-translate-y: 0;
  --tw-rotate: 0;
  --tw-skew-x: 0;
  --tw-skew-y: 0;
  --tw-scale-x: 1;
  --tw-scale-y: 1;
  --tw-pan-x:  ;
  --tw-pan-y:  ;
  --tw-pinch-zoom:  ;
  --tw-scroll-snap-strictness: proximity;
  --tw-gradient-from-position:  ;
  --tw-gradient-via-position:  ;
  --tw-gradient-to-position:  ;
  --tw-ordinal:  ;
  --tw-slashed-zero:  ;
  --tw-numeric-figure:  ;
  --tw-numeric-spacing:  ;
  --tw-numeric-fraction:  ;
  --tw-ring-inset:  ;
  --tw-ring-offset-width: 0px;
  --tw-ring-offset-color: #fff;
  --tw-ring-color: rgb(59 130 246 / 0.5);
  --tw-ring-offset-shadow: 0 0 #0000;
  --tw-ring-shadow: 0 0 #0000;
  --tw-shadow: 0 0 #0000;
  --tw-shadow-colored: 0 0 #0000;
  --tw-blur:  ;
  --tw-brightness:  ;
  --tw-contrast:  ;
  --tw-grayscale:  ;
  --tw-hue-rotate:  ;
  --tw-invert:  ;
  --tw-saturate:  ;
  --tw-sepia:  ;
  --tw-drop-shadow:  ;
  --tw-backdrop-blur:  ;
  --tw-backdrop-brightness:  ;
  --tw-backdrop-contrast:  ;
  --tw-backdrop-grayscale:  ;
  --tw-backdrop-hue-rotate:  ;
  --tw-backdrop-invert:  ;
  --tw-backdrop-opacity:  ;
  --tw-backdrop-saturate:  ;
  --tw-backdrop-sepia:  ;
  --tw-contain-size:  ;
  --tw-contain-layout:  ;
  --tw-contain-paint:  ;
  --tw-contain-style:  ;
}

.container {
  width: 100%;
}

@media (min-width: 640px) {
  .container {
    max-width: 640px;
  }
}

@media (min-width: 768px) {
  .container {
    max-width: 768px;
  }
}

@media (min-width: 1024px) {
  .container {
    max-width: 1024px;
  }
}

@media (min-width: 1280px) {
  .container {
    max-width: 1280px;
  }
}

@media (min-width: 1536px) {
  .container {
    max-width: 1536px;
  }
}

.alert {
  display: grid;
  width: 100%;
  grid-auto-flow: row;
  align-content: flex-start;
  align-items: center;
  justify-items: center;
  gap: 1rem;
  text-align: center;
  border-radius: var(--rounded-box, 1rem);
  border-width: 1px;
  --tw-border-opacity: 1;
  border-color: var(--fallback-b2,oklch(var(--b2)/var(--tw-border-opacity)));
  padding: 1rem;
  --tw-text-opacity: 1;
  color: var(--fallback-bc,oklch(var(--bc)/var(--tw-text-opacity)));
  --alert-bg: var(--fallback-b2,oklch(var(--b2)/1));
  --alert-bg-mix: var(--fallback-b1,oklch(var(--b1)/1));
  background-color: var(--alert-bg);
}

@media (min-width: 640px) {
  .alert {
    grid-auto-flow: column;
    grid-template-columns: auto minmax(auto,1fr);
    justify-items: start;
    text-align: start;
  }
}

.avatar.placeholder > div {
  display: flex;
  align-items: center;
  justify-content: center;
}

.badge {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-backdrop-filter;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-backdrop-filter;
  transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);
  transition-timing-function: cubic-bezier(0, 0, 0.2, 1);
  transition-duration: 200ms;
  height: 1.25rem;
  font-size: 0.875rem;
  line-height: 1.25rem;
  width: -moz-fit-content;
  width: fit-content;
  padding-left: 0.563rem;
  padding-right: 0.563rem;
  border-radius: var(--rounded-badge, 1.9rem);
  border-width: 1px;
  --tw-border-opacity: 1;
  border-color: var(--fallback-b2,oklch(var(--b2)/var(--tw-border-opacity)));
  --tw-bg-opacity: 1;
  background-color: var(--fallback-b1,oklch(var(--b1)/var(--tw-bg-opacity)));
  --tw-text-opacity: 1;
  color: var(--fallback-bc,oklch(var(--bc)/var(--tw-text-opacity)));
}

@media (hover:hover) {
  .checkbox-accent:hover {
    --tw-border-opacity: 1;
    border-color: var(--fallback-a,oklch(var(--a)/var(--tw-border-opacity)));
  }

  .label a:hover {
    --tw-text-opacity: 1;
    color: var(--fallback-bc,oklch(var(--bc)/var(--tw-text-opacity)));
  }
}

.btn {
  display: inline-flex;
  height: 3rem;
  min-height: 3rem;
  flex-shrink: 0;
  cursor: pointer;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
  flex-wrap: wrap;
  align-items: center;
  justify-content: center;
  border-radius: var(--rounded-btn, 0.5rem);
  border-color: transparent;
  border-color: oklch(var(--btn-color, var(--b2)) / var(--tw-border-opacity));
  padding-left: 1rem;
  padding-right: 1rem;
  text-align: center;
  font-size: 0.875rem;
  line-height: 1em;
  gap: 0.5rem;
  font-weight: 600;
  text-decoration-line: none;
  transition-duration: 200ms;
  transition-timing-function: cubic-bezier(0, 0, 0.2, 1);
  border-width: var(--border-btn, 1px);
  transition-property: color, background-color, border-color, opacity, box-shadow, transform;
  --tw-text-opacity: 1;
  color: var(--fallback-bc,oklch(var(--bc)/var(--tw-text-opacity)));
  --tw-shadow: 0 1px 2px 0 rgb(0 0 0 / 0.05);
  --tw-shadow-colored: 0 1px 2px 0 var(--tw-shadow-color);
  box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);
  outline-color: var(--fallback-bc,oklch(var(--bc)/1));
  background-color: oklch(var(--btn-color, var(--b2)) / var(--tw-bg-opacity));
  --tw-bg-opacity: 1;
  --tw-border-opacity: 1;
}

.btn-disabled,
  .btn[disabled],
  .btn:disabled {
  pointer-events: none;
}

:where(.btn:is(input[type="checkbox"])),
:where(.btn:is(input[type="radio"])) {
  width: auto;
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
}

.btn:is(input[type="checkbox"]):after,
.btn:is(input[type="radio"]):after {
  --tw-content: attr(aria-label);
  content: var(--tw-content);
}

.checkbox {
  flex-shrink: 0;
  --chkbg: var(--fallback-bc,oklch(var(--bc)/1));
  --chkfg: var(--fallback-b1,oklch(var(--b1)/1));
  height: 1.5rem;
  width: 1.5rem;
  cursor: pointer;
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  border-radius: var(--rounded-btn, 0.5rem);
  border-width: 1px;
  border-color: var(--fallback-bc,oklch(var(--bc)/var(--tw-border-opacity)));
  --tw-border-opacity: 0.2;
}

.divider {
  display: flex;
  flex-direction: row;
  align-items: center;
  align-self: stretch;
  margin-top: 1rem;
  margin-bottom: 1rem;
  height: 1rem;
  white-space: nowrap;
}

.divider:before,
  .divider:after {
  height: 0.125rem;
  width: 100%;
  flex-grow: 1;
  --tw-content: '';
  content: var(--tw-content);
  background-color: var(--fallback-bc,oklch(var(--bc)/0.1));
}

@media (hover: hover) {
  .btn:hover {
    --tw-border-opacity: 1;
    border-color: var(--fallback-b3,oklch(var(--b3)/var(--tw-border-opacity)));
    --tw-bg-opacity: 1;
    background-color: var(--fallback-b3,oklch(var(--b3)/var(--tw-bg-opacity)));
  }

  @supports (color: color-mix(in oklab, black, black)) {
    .btn:hover {
      background-color: color-mix(
            in oklab,
            oklch(var(--btn-color, var(--b2)) / var(--tw-bg-opacity, 1)) 90%,
            black
          );
      border-color: color-mix(
            in oklab,
            oklch(var(--btn-color, var(--b2)) / var(--tw-border-opacity, 1)) 90%,
            black
          );
    }
  }

  @supports not (color: oklch(0% 0 0)) {
    .btn:hover {
      background-color: var(--btn-color, var(--fallback-b2));
      border-color: var(--btn-color, var(--fallback-b2));
    }
  }

  .btn.glass:hover {
    --glass-opacity: 25%;
    --glass-border-opacity: 15%;
  }

  .btn-outline.btn-primary:hover {
    --tw-text-opacity: 1;
    color: var(--fallback-pc,oklch(var(--pc)/var(--tw-text-opacity)));
  }

  @supports (color: color-mix(in oklab, black, black)) {
    .btn-outline.btn-primary:hover {
      background-color: color-mix(in oklab, var(--fallback-p,oklch(var(--p)/1)) 90%, black);
      border-color: color-mix(in oklab, var(--fallback-p,oklch(var(--p)/1)) 90%, black);
    }
  }

  .btn-outline.btn-secondary:hover {
    --tw-text-opacity: 1;
    color: var(--fallback-sc,oklch(var(--sc)/var(--tw-text-opacity)));
  }

  @supports (color: color-mix(in oklab, black, black)) {
    .btn-outline.btn-secondary:hover {
      background-color: color-mix(in oklab, var(--fallback-s,oklch(var(--s)/1)) 90%, black);
      border-color: color-mix(in oklab, var(--fallback-s,oklch(var(--s)/1)) 90%, black);
    }
  }

  .btn-outline.btn-warning:hover {
    --tw-text-opacity: 1;
    color: var(--fallback-wac,oklch(var(--wac)/var(--tw-text-opacity)));
  }

  @supports (color: color-mix(in oklab, black, black)) {
    .btn-outline.btn-warning:hover {
      background-color: color-mix(in oklab, var(--fallback-wa,oklch(var(--wa)/1)) 90%, black);
      border-color: color-mix(in oklab, var(--fallback-wa,oklch(var(--wa)/1)) 90%, black);
    }
  }

  .btn-disabled:hover,
    .btn[disabled]:hover,
    .btn:disabled:hover {
    --tw-border-opacity: 0;
    background-color: var(--fallback-n,oklch(var(--n)/var(--tw-bg-opacity)));
    --tw-bg-opacity: 0.2;
    color: var(--fallback-bc,oklch(var(--bc)/var(--tw-text-opacity)));
    --tw-text-opacity: 0.2;
  }

  @supports (color: color-mix(in oklab, black, black)) {
    .btn:is(input[type="checkbox"]:checked):hover, .btn:is(input[type="radio"]:checked):hover {
      background-color: color-mix(in oklab, var(--fallback-p,oklch(var(--p)/1)) 90%, black);
      border-color: color-mix(in oklab, var(--fallback-p,oklch(var(--p)/1)) 90%, black);
    }
  }
}

.form-control {
  display: flex;
  flex-direction: column;
}

.label {
  display: flex;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
  align-items: center;
  justify-content: space-between;
  padding-left: 0.25rem;
  padding-right: 0.25rem;
  padding-top: 0.5rem;
  padding-bottom: 0.5rem;
}

.input {
  flex-shrink: 1;
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  height: 3rem;
  padding-left: 1rem;
  padding-right: 1rem;
  font-size: 1rem;
  line-height: 2;
  line-height: 1.5rem;
  border-radius: var(--rounded-btn, 0.5rem);
  border-width: 1px;
  border-color: transparent;
  --tw-bg-opacity: 1;
  background-color: var(--fallback-b1,oklch(var(--b1)/var(--tw-bg-opacity)));
}

.input[type="number"]::-webkit-inner-spin-button,
.input-md[type="number"]::-webkit-inner-spin-button {
  margin-top: -1rem;
  margin-bottom: -1rem;
  margin-inline-end: -1rem;
}

.link {
  cursor: pointer;
  text-decoration-line: underline;
}

:where(.menu li) .badge {
  justify-self: end;
}

.radio {
  flex-shrink: 0;
  --chkbg: var(--bc);
  height: 1.5rem;
  width: 1.5rem;
  cursor: pointer;
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  border-radius: 9999px;
  border-width: 1px;
  border-color: var(--fallback-bc,oklch(var(--bc)/var(--tw-border-opacity)));
  --tw-border-opacity: 0.2;
}

.steps .step {
  display: grid;
  grid-template-columns: repeat(1, minmax(0, 1fr));
  grid-template-columns: auto;
  grid-template-rows: repeat(2, minmax(0, 1fr));
  grid-template-rows: 40px 1fr;
  place-items: center;
  text-align: center;
  min-width: 4rem;
}

.badge-primary {
  --tw-border-opacity: 1;
  border-color: var(--fallback-p,oklch(var(--p)/var(--tw-border-opacity)));
  --tw-bg-opacity: 1;
  background-color: var(--fallback-p,oklch(var(--p)/var(--tw-bg-opacity)));
  --tw-text-opacity: 1;
  color: var(--fallback-pc,oklch(var(--pc)/var(--tw-text-opacity)));
}

.badge-secondary {
  --tw-border-opacity: 1;
  border-color: var(--fallback-s,oklch(var(--s)/var(--tw-border-opacity)));
  --tw-bg-opacity: 1;
  background-color: var(--fallback-s,oklch(var(--s)/var(--tw-bg-opacity)));
  --tw-text-opacity: 1;
  color: var(--fallback-sc,oklch(var(--sc)/var(--tw-text-opacity)));
}

.badge-outline {
  border-color: currentColor;
  --tw-border-opacity: 0.5;
  background-color: transparent;
  color: currentColor;
}

.badge-outline.badge-neutral {
  --tw-text-opacity: 1;
  color: var(--fallback-n,oklch(var(--n)/var(--tw-text-opacity)));
}

.badge-outline.badge-primary {
  --tw-text-opacity: 1;
  color: var(--fallback-p,oklch(var(--p)/var(--tw-text-opacity)));
}

.badge-outline.badge-secondary {
  --tw-text-opacity: 1;
  color: var(--fallback-s,oklch(var(--s)/var(--tw-text-opacity)));
}

.badge-outline.badge-accent {
  --tw-text-opacity: 1;
  color: var(--fallback-a,oklch(var(--a)/var(--tw-text-opacity)));
}

.badge-outline.badge-info {
  --tw-text-opacity: 1;
  color: var(--fallback-in,oklch(var(--in)/var(--tw-text-opacity)));
}

.badge-outline.badge-success {
  --tw-text-opacity: 1;
  color: var(--fallback-su,oklch(var(--su)/var(--tw-text-opacity)));
}

.badge-outline.badge-warning {
  --tw-text-opacity: 1;
  color: var(--fallback-wa,oklch(var(--wa)/var(--tw-text-opacity)));
}

.badge-outline.badge-error {
  --tw-text-opacity: 1;
  color: var(--fallback-er,oklch(var(--er)/var(--tw-text-opacity)));
}

.btm-nav > * .label {
  font-size: 1rem;
  line-height: 1.5rem;
}

@media (prefers-reduced-motion: no-preference) {
  .btn {
    animation: button-pop var(--animation-btn, 0.25s) ease-out;
  }
}

.btn:active:hover,
  .btn:active:focus {
  animation: button-pop 0s ease-out;
  transform: scale(var(--btn-focus-scale, 0.97));
}

@supports not (color: oklch(0% 0 0)) {
  .btn {
    background-color: var(--btn-color, var(--fallback-b2));
    border-color: var(--btn-color, var(--fallback-b2));
  }

  .btn-primary {
    --btn-color: var(--fallback-p);
  }

  .btn-secondary {
    --btn-color: var(--fallback-s);
  }

  .btn-neutral {
    --btn-color: var(--fallback-n);
  }

  .btn-warning {
    --btn-color: var(--fallback-wa);
  }
}

@supports (color: color-mix(in oklab, black, black)) {
  .btn-outline.btn-primary.btn-active {
    background-color: color-mix(in oklab, var(--fallback-p,oklch(var(--p)/1)) 90%, black);
    border-color: color-mix(in oklab, var(--fallback-p,oklch(var(--p)/1)) 90%, black);
  }

  .btn-outline.btn-secondary.btn-active {
    background-color: color-mix(in oklab, var(--fallback-s,oklch(var(--s)/1)) 90%, black);
    border-color: color-mix(in oklab, var(--fallback-s,oklch(var(--s)/1)) 90%, black);
  }

  .btn-outline.btn-warning.btn-active {
    background-color: color-mix(in oklab, var(--fallback-wa,oklch(var(--wa)/1)) 90%, black);
    border-color: color-mix(in oklab, var(--fallback-wa,oklch(var(--wa)/1)) 90%, black);
  }
}

.btn:focus-visible {
  outline-style: solid;
  outline-width: 2px;
  outline-offset: 2px;
}

.btn-primary {
  --tw-text-opacity: 1;
  color: var(--fallback-pc,oklch(var(--pc)/var(--tw-text-opacity)));
  outline-color: var(--fallback-p,oklch(var(--p)/1));
}

@supports (color: oklch(0% 0 0)) {
  .btn-primary {
    --btn-color: var(--p);
  }

  .btn-secondary {
    --btn-color: var(--s);
  }

  .btn-neutral {
    --btn-color: var(--n);
  }

  .btn-warning {
    --btn-color: var(--wa);
  }
}

.btn-secondary {
  --tw-text-opacity: 1;
  color: var(--fallback-sc,oklch(var(--sc)/var(--tw-text-opacity)));
  outline-color: var(--fallback-s,oklch(var(--s)/1));
}

.btn-neutral {
  --tw-text-opacity: 1;
  color: var(--fallback-nc,oklch(var(--nc)/var(--tw-text-opacity)));
  outline-color: var(--fallback-n,oklch(var(--n)/1));
}

.btn-warning {
  --tw-text-opacity: 1;
  color: var(--fallback-wac,oklch(var(--wac)/var(--tw-text-opacity)));
  outline-color: var(--fallback-wa,oklch(var(--wa)/1));
}

.btn.glass {
  --tw-shadow: 0 0 #0000;
  --tw-shadow-colored: 0 0 #0000;
  box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);
  outline-color: currentColor;
}

.btn.glass.btn-active {
  --glass-opacity: 25%;
  --glass-border-opacity: 15%;
}

.btn-outline.btn-primary {
  --tw-text-opacity: 1;
  color: var(--fallback-p,oklch(var(--p)/var(--tw-text-opacity)));
}

.btn-outline.btn-primary.btn-active {
  --tw-text-opacity: 1;
  color: var(--fallback-pc,oklch(var(--pc)/var(--tw-text-opacity)));
}

.btn-outline.btn-secondary {
  --tw-text-opacity: 1;
  color: var(--fallback-s,oklch(var(--s)/var(--tw-text-opacity)));
}

.btn-outline.btn-secondary.btn-active {
  --tw-text-opacity: 1;
  color: var(--fallback-sc,oklch(var(--sc)/var(--tw-text-opacity)));
}

.btn-outline.btn-warning {
  --tw-text-opacity: 1;
  color: var(--fallback-wa,oklch(var(--wa)/var(--tw-text-opacity)));
}

.btn-outline.btn-warning.btn-active {
  --tw-text-opacity: 1;
  color: var(--fallback-wac,oklch(var(--wac)/var(--tw-text-opacity)));
}

.btn.btn-disabled,
  .btn[disabled],
  .btn:disabled {
  --tw-border-opacity: 0;
  background-color: var(--fallback-n,oklch(var(--n)/var(--tw-bg-opacity)));
  --tw-bg-opacity: 0.2;
  color: var(--fallback-bc,oklch(var(--bc)/var(--tw-text-opacity)));
  --tw-text-opacity: 0.2;
}

.btn:is(input[type="checkbox"]:checked),
.btn:is(input[type="radio"]:checked) {
  --tw-border-opacity: 1;
  border-color: var(--fallback-p,oklch(var(--p)/var(--tw-border-opacity)));
  --tw-bg-opacity: 1;
  background-color: var(--fallback-p,oklch(var(--p)/var(--tw-bg-opacity)));
  --tw-text-opacity: 1;
  color: var(--fallback-pc,oklch(var(--pc)/var(--tw-text-opacity)));
}

.btn:is(input[type="checkbox"]:checked):focus-visible, .btn:is(input[type="radio"]:checked):focus-visible {
  outline-color: var(--fallback-p,oklch(var(--p)/1));
}

@keyframes button-pop {
  0% {
    transform: scale(var(--btn-focus-scale, 0.98));
  }

  40% {
    transform: scale(1.02);
  }

  100% {
    transform: scale(1);
  }
}

.checkbox:focus {
  box-shadow: none;
}

.checkbox:focus-visible {
  outline-style: solid;
  outline-width: 2px;
  outline-offset: 2px;
  outline-color: var(--fallback-bc,oklch(var(--bc)/1));
}

.checkbox:disabled {
  border-width: 0px;
  cursor: not-allowed;
  border-color: transparent;
  --tw-bg-opacity: 1;
  background-color: var(--fallback-bc,oklch(var(--bc)/var(--tw-bg-opacity)));
  opacity: 0.2;
}

.checkbox:checked,
  .checkbox[aria-checked="true"] {
  background-repeat: no-repeat;
  animation: checkmark var(--animation-input, 0.2s) ease-out;
  background-color: var(--chkbg);
  background-image: linear-gradient(-45deg, transparent 65%, var(--chkbg) 65.99%),
      linear-gradient(45deg, transparent 75%, var(--chkbg) 75.99%),
      linear-gradient(-45deg, var(--chkbg) 40%, transparent 40.99%),
      linear-gradient(
        45deg,
        var(--chkbg) 30%,
        var(--chkfg) 30.99%,
        var(--chkfg) 40%,
        transparent 40.99%
      ),
      linear-gradient(-45deg, var(--chkfg) 50%, var(--chkbg) 50.99%);
}

.checkbox:indeterminate {
  --tw-bg-opacity: 1;
  background-color: var(--fallback-bc,oklch(var(--bc)/var(--tw-bg-opacity)));
  background-repeat: no-repeat;
  animation: checkmark var(--animation-input, 0.2s) ease-out;
  background-image: linear-gradient(90deg, transparent 80%, var(--chkbg) 80%),
      linear-gradient(-90deg, transparent 80%, var(--chkbg) 80%),
      linear-gradient(0deg, var(--chkbg) 43%, var(--chkfg) 43%, var(--chkfg) 57%, var(--chkbg) 57%);
}

.checkbox-accent {
  --chkbg: var(--fallback-a,oklch(var(--a)/1));
  --chkfg: var(--fallback-ac,oklch(var(--ac)/1));
  --tw-border-opacity: 1;
  border-color: var(--fallback-a,oklch(var(--a)/var(--tw-border-opacity)));
}

.checkbox-accent:focus-visible {
  outline-color: var(--fallback-a,oklch(var(--a)/1));
}

.checkbox-accent:checked,
    .checkbox-accent[aria-checked="true"] {
  --tw-border-opacity: 1;
  border-color: var(--fallback-a,oklch(var(--a)/var(--tw-border-opacity)));
  --tw-bg-opacity: 1;
  background-color: var(--fallback-a,oklch(var(--a)/var(--tw-bg-opacity)));
  --tw-text-opacity: 1;
  color: var(--fallback-ac,oklch(var(--ac)/var(--tw-text-opacity)));
}

@keyframes checkmark {
  0% {
    background-position-y: 5px;
  }

  50% {
    background-position-y: -2px;
  }

  100% {
    background-position-y: 0;
  }
}

.divider:not(:empty) {
  gap: 1rem;
}

.divider-neutral:before,
  .divider-neutral:after {
  --tw-bg-opacity: 1;
  background-color: var(--fallback-n,oklch(var(--n)/var(--tw-bg-opacity)));
}

.label-text {
  font-size: 0.875rem;
  line-height: 1.25rem;
  --tw-text-opacity: 1;
  color: var(--fallback-bc,oklch(var(--bc)/var(--tw-text-opacity)));
}

.input input {
  --tw-bg-opacity: 1;
  background-color: var(--fallback-p,oklch(var(--p)/var(--tw-bg-opacity)));
  background-color: transparent;
}

.input input:focus {
  outline: 2px solid transparent;
  outline-offset: 2px;
}

.input[list]::-webkit-calendar-picker-indicator {
  line-height: 1em;
}

.input-bordered {
  border-color: var(--fallback-bc,oklch(var(--bc)/0.2));
}

.input:focus,
  .input:focus-within {
  box-shadow: none;
  border-color: var(--fallback-bc,oklch(var(--bc)/0.2));
  outline-style: solid;
  outline-width: 2px;
  outline-offset: 2px;
  outline-color: var(--fallback-bc,oklch(var(--bc)/0.2));
}

.input-error {
  --tw-border-opacity: 1;
  border-color: var(--fallback-er,oklch(var(--er)/var(--tw-border-opacity)));
}

.input-error:focus,
    .input-error:focus-within {
  --tw-border-opacity: 1;
  border-color: var(--fallback-er,oklch(var(--er)/var(--tw-border-opacity)));
  outline-color: var(--fallback-er,oklch(var(--er)/1));
}

.input:has(> input[disabled]),
  .input-disabled,
  .input:disabled,
  .input[disabled] {
  cursor: not-allowed;
  --tw-border-opacity: 1;
  border-color: var(--fallback-b2,oklch(var(--b2)/var(--tw-border-opacity)));
  --tw-bg-opacity: 1;
  background-color: var(--fallback-b2,oklch(var(--b2)/var(--tw-bg-opacity)));
  color: var(--fallback-bc,oklch(var(--bc)/0.4));
}

.input:has(> input[disabled])::-moz-placeholder, .input-disabled::-moz-placeholder, .input:disabled::-moz-placeholder, .input[disabled]::-moz-placeholder {
  color: var(--fallback-bc,oklch(var(--bc)/var(--tw-placeholder-opacity)));
  --tw-placeholder-opacity: 0.2;
}

.input:has(> input[disabled])::placeholder,
  .input-disabled::placeholder,
  .input:disabled::placeholder,
  .input[disabled]::placeholder {
  color: var(--fallback-bc,oklch(var(--bc)/var(--tw-placeholder-opacity)));
  --tw-placeholder-opacity: 0.2;
}

.input:has(> input[disabled]) > input[disabled] {
  cursor: not-allowed;
}

.input::-webkit-date-and-time-value {
  text-align: inherit;
}

.link:focus {
  outline: 2px solid transparent;
  outline-offset: 2px;
}

.link:focus-visible {
  outline: 2px solid currentColor;
  outline-offset: 2px;
}

.mockup-browser .mockup-browser-toolbar .input {
  position: relative;
  margin-left: auto;
  margin-right: auto;
  display: block;
  height: 1.75rem;
  width: 24rem;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  --tw-bg-opacity: 1;
  background-color: var(--fallback-b2,oklch(var(--b2)/var(--tw-bg-opacity)));
  padding-left: 2rem;
  direction: ltr;
}

.mockup-browser .mockup-browser-toolbar .input:before {
  content: "";
  position: absolute;
  left: 0.5rem;
  top: 50%;
  aspect-ratio: 1 / 1;
  height: 0.75rem;
  --tw-translate-y: -50%;
  transform: translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y));
  border-radius: 9999px;
  border-width: 2px;
  border-color: currentColor;
  opacity: 0.6;
}

.mockup-browser .mockup-browser-toolbar .input:after {
  content: "";
  position: absolute;
  left: 1.25rem;
  top: 50%;
  height: 0.5rem;
  --tw-translate-y: 25%;
  --tw-rotate: -45deg;
  transform: translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y));
  border-radius: 9999px;
  border-width: 1px;
  border-color: currentColor;
  opacity: 0.6;
}

@keyframes modal-pop {
  0% {
    opacity: 0;
  }
}

@keyframes progress-loading {
  50% {
    background-position-x: -115%;
  }
}

.radio:focus {
  box-shadow: none;
}

.radio:focus-visible {
  outline-style: solid;
  outline-width: 2px;
  outline-offset: 2px;
  outline-color: var(--fallback-bc,oklch(var(--bc)/1));
}

.radio:checked,
  .radio[aria-checked="true"] {
  --tw-bg-opacity: 1;
  background-color: var(--fallback-bc,oklch(var(--bc)/var(--tw-bg-opacity)));
  background-image: none;
  animation: radiomark var(--animation-input, 0.2s) ease-out;
  box-shadow: 0 0 0 4px var(--fallback-b1,oklch(var(--b1)/1)) inset,
      0 0 0 4px var(--fallback-b1,oklch(var(--b1)/1)) inset;
}

.radio:disabled {
  cursor: not-allowed;
  opacity: 0.2;
}

@keyframes radiomark {
  0% {
    box-shadow: 0 0 0 12px var(--fallback-b1,oklch(var(--b1)/1)) inset,
      0 0 0 12px var(--fallback-b1,oklch(var(--b1)/1)) inset;
  }

  50% {
    box-shadow: 0 0 0 3px var(--fallback-b1,oklch(var(--b1)/1)) inset,
      0 0 0 3px var(--fallback-b1,oklch(var(--b1)/1)) inset;
  }

  100% {
    box-shadow: 0 0 0 4px var(--fallback-b1,oklch(var(--b1)/1)) inset,
      0 0 0 4px var(--fallback-b1,oklch(var(--b1)/1)) inset;
  }
}

@keyframes rating-pop {
  0% {
    transform: translateY(-0.125em);
  }

  40% {
    transform: translateY(-0.125em);
  }

  100% {
    transform: translateY(0);
  }
}

@keyframes skeleton {
  from {
    background-position: 150%;
  }

  to {
    background-position: -50%;
  }
}

.steps .step:before {
  top: 0px;
  grid-column-start: 1;
  grid-row-start: 1;
  height: 0.5rem;
  width: 100%;
  transform: translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y));
  --tw-bg-opacity: 1;
  background-color: var(--fallback-b3,oklch(var(--b3)/var(--tw-bg-opacity)));
  --tw-text-opacity: 1;
  color: var(--fallback-bc,oklch(var(--bc)/var(--tw-text-opacity)));
  content: "";
  margin-inline-start: -100%;
}

.steps .step:after {
  content: counter(step);
  counter-increment: step;
  z-index: 1;
  position: relative;
  grid-column-start: 1;
  grid-row-start: 1;
  display: grid;
  height: 2rem;
  width: 2rem;
  place-items: center;
  place-self: center;
  border-radius: 9999px;
  --tw-bg-opacity: 1;
  background-color: var(--fallback-b3,oklch(var(--b3)/var(--tw-bg-opacity)));
  --tw-text-opacity: 1;
  color: var(--fallback-bc,oklch(var(--bc)/var(--tw-text-opacity)));
}

.steps .step:first-child:before {
  content: none;
}

.steps .step[data-content]:after {
  content: attr(data-content);
}

@keyframes toast-pop {
  0% {
    transform: scale(0.9);
    opacity: 0;
  }

  100% {
    transform: scale(1);
    opacity: 1;
  }
}

.steps-horizontal .step {
  display: grid;
  grid-template-columns: repeat(1, minmax(0, 1fr));
  grid-template-rows: repeat(2, minmax(0, 1fr));
  place-items: center;
  text-align: center;
}

.steps-vertical .step {
  display: grid;
  grid-template-columns: repeat(2, minmax(0, 1fr));
  grid-template-rows: repeat(1, minmax(0, 1fr));
}

.steps-horizontal .step {
  grid-template-rows: 40px 1fr;
  grid-template-columns: auto;
  min-width: 4rem;
}

.steps-horizontal .step:before {
  height: 0.5rem;
  width: 100%;
  --tw-translate-x: 0px;
  --tw-translate-y: 0px;
  transform: translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y));
  content: "";
  margin-inline-start: -100%;
}

.steps-horizontal .step:where([dir="rtl"], [dir="rtl"] *):before {
  --tw-translate-x: 0px;
  transform: translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y));
}

.steps-vertical .step {
  gap: 0.5rem;
  grid-template-columns: 40px 1fr;
  grid-template-rows: auto;
  min-height: 4rem;
  justify-items: start;
}

.steps-vertical .step:before {
  height: 100%;
  width: 0.5rem;
  --tw-translate-x: -50%;
  --tw-translate-y: -50%;
  transform: translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y));
  margin-inline-start: 50%;
}

.steps-vertical .step:where([dir="rtl"], [dir="rtl"] *):before {
  --tw-translate-x: 50%;
  transform: translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y));
}

.social-github {
  --tw-bg-opacity: 1;
  background-color: rgb(28 25 23 / var(--tw-bg-opacity));
}

.social-github:hover {
  --tw-bg-opacity: 1;
  background-color: rgb(0 0 0 / var(--tw-bg-opacity));
}

.social-facebook {
  --tw-bg-opacity: 1;
  background-color: rgb(29 78 216 / var(--tw-bg-opacity));
}

.social-facebook:hover {
  --tw-bg-opacity: 1;
  background-color: rgb(30 64 175 / var(--tw-bg-opacity));
}

.social-google {
  --tw-bg-opacity: 1;
  background-color: rgb(185 28 28 / var(--tw-bg-opacity));
}

.social-google:hover {
  --tw-bg-opacity: 1;
  background-color: rgb(153 27 27 / var(--tw-bg-opacity));
}

.social-linkedin {
  --tw-bg-opacity: 1;
  background-color: rgb(8 145 178 / var(--tw-bg-opacity));
}

.social-linkedin:hover {
  --tw-bg-opacity: 1;
  background-color: rgb(14 116 144 / var(--tw-bg-opacity));
}

.social-strava {
  --tw-bg-opacity: 1;
  background-color: rgb(251 146 60 / var(--tw-bg-opacity));
}

.social-strava:hover {
  --tw-bg-opacity: 1;
  background-color: rgb(249 115 22 / var(--tw-bg-opacity));
}

.social-exist {
  --tw-bg-opacity: 1;
  background-color: rgb(107 114 128 / var(--tw-bg-opacity));
}

.social-exist:hover {
  --tw-bg-opacity: 1;
  background-color: rgb(75 85 99 / var(--tw-bg-opacity));
}

.social-wahoo {
  --tw-bg-opacity: 1;
  background-color: rgb(6 182 212 / var(--tw-bg-opacity));
}

.social-wahoo:hover {
  --tw-bg-opacity: 1;
  background-color: rgb(14 116 144 / var(--tw-bg-opacity));
}

.static {
  position: static;
}

.mx-auto {
  margin-left: auto;
  margin-right: auto;
}

.my-1 {
  margin-top: 0.25rem;
  margin-bottom: 0.25rem;
}

.my-2 {
  margin-top: 0.5rem;
  margin-bottom: 0.5rem;
}

.my-3 {
  margin-top: 0.75rem;
  margin-bottom: 0.75rem;
}

.mb-3 {
  margin-bottom: 0.75rem;
}

.ml-1 {
  margin-left: 0.25rem;
}

.ml-2 {
  margin-left: 0.5rem;
}

.mt-1 {
  margin-top: 0.25rem;
}

.mt-3 {
  margin-top: 0.75rem;
}

.mt-5 {
  margin-top: 1.25rem;
}

.block {
  display: block;
}

.flex {
  display: flex;
}

.min-h-screen {
  min-height: 100vh;
}

.w-11\/12 {
  width: 91.666667%;
}

.w-full {
  width: 100%;
}

.max-w-xs {
  max-width: 20rem;
}

.cursor-pointer {
  cursor: pointer;
}

.flex-col {
  flex-direction: column;
}

.items-start {
  align-items: flex-start;
}

.items-center {
  align-items: center;
}

.justify-center {
  justify-content: center;
}

.gap-1 {
  gap: 0.25rem;
}

.gap-1\.5 {
  gap: 0.375rem;
}

.gap-3 {
  gap: 0.75rem;
}

.self-end {
  align-self: flex-end;
}

.rounded {
  border-radius: 0.25rem;
}

.rounded-lg {
  border-radius: 0.5rem;
}

.border {
  border-width: 1px;
}

.bg-accent {
  --tw-bg-opacity: 1;
  background-color: var(--fallback-a,oklch(var(--a)/var(--tw-bg-opacity)));
}

.bg-accent-content {
  --tw-bg-opacity: 1;
  background-color: var(--fallback-ac,oklch(var(--ac)/var(--tw-bg-opacity)));
}

.bg-accent-content\/0 {
  background-color: var(--fallback-ac,oklch(var(--ac)/0));
}

.bg-accent-content\/10 {
  background-color: var(--fallback-ac,oklch(var(--ac)/0.1));
}

.bg-accent-content\/100 {
  background-color: var(--fallback-ac,oklch(var(--ac)/1));
}

.bg-accent-content\/15 {
  background-color: var(--fallback-ac,oklch(var(--ac)/0.15));
}

.bg-accent-content\/20 {
  background-color: var(--fallback-ac,oklch(var(--ac)/0.2));
}

.bg-accent-content\/25 {
  background-color: var(--fallback-ac,oklch(var(--ac)/0.25));
}

.bg-accent-content\/30 {
  background-color: var(--fallback-ac,oklch(var(--ac)/0.3));
}

.bg-accent-content\/35 {
  background-color: var(--fallback-ac,oklch(var(--ac)/0.35));
}

.bg-accent-content\/40 {
  background-color: var(--fallback-ac,oklch(var(--ac)/0.4));
}

.bg-accent-content\/45 {
  background-color: var(--fallback-ac,oklch(var(--ac)/0.45));
}

.bg-accent-content\/5 {
  background-color: var(--fallback-ac,oklch(var(--ac)/0.05));
}

.bg-accent-content\/50 {
  background-color: var(--fallback-ac,oklch(var(--ac)/0.5));
}

.bg-accent-content\/55 {
  background-color: var(--fallback-ac,oklch(var(--ac)/0.55));
}

.bg-accent-content\/60 {
  background-color: var(--fallback-ac,oklch(var(--ac)/0.6));
}

.bg-accent-content\/65 {
  background-color: var(--fallback-ac,oklch(var(--ac)/0.65));
}

.bg-accent-content\/70 {
  background-color: var(--fallback-ac,oklch(var(--ac)/0.7));
}

.bg-accent-content\/75 {
  background-color: var(--fallback-ac,oklch(var(--ac)/0.75));
}

.bg-accent-content\/80 {
  background-color: var(--fallback-ac,oklch(var(--ac)/0.8));
}

.bg-accent-content\/85 {
  background-color: var(--fallback-ac,oklch(var(--ac)/0.85));
}

.bg-accent-content\/90 {
  background-color: var(--fallback-ac,oklch(var(--ac)/0.9));
}

.bg-accent-content\/95 {
  background-color: var(--fallback-ac,oklch(var(--ac)/0.95));
}

.bg-accent\/0 {
  background-color: var(--fallback-a,oklch(var(--a)/0));
}

.bg-accent\/10 {
  background-color: var(--fallback-a,oklch(var(--a)/0.1));
}

.bg-accent\/100 {
  background-color: var(--fallback-a,oklch(var(--a)/1));
}

.bg-accent\/15 {
  background-color: var(--fallback-a,oklch(var(--a)/0.15));
}

.bg-accent\/20 {
  background-color: var(--fallback-a,oklch(var(--a)/0.2));
}

.bg-accent\/25 {
  background-color: var(--fallback-a,oklch(var(--a)/0.25));
}

.bg-accent\/30 {
  background-color: var(--fallback-a,oklch(var(--a)/0.3));
}

.bg-accent\/35 {
  background-color: var(--fallback-a,oklch(var(--a)/0.35));
}

.bg-accent\/40 {
  background-color: var(--fallback-a,oklch(var(--a)/0.4));
}

.bg-accent\/45 {
  background-color: var(--fallback-a,oklch(var(--a)/0.45));
}

.bg-accent\/5 {
  background-color: var(--fallback-a,oklch(var(--a)/0.05));
}

.bg-accent\/50 {
  background-color: var(--fallback-a,oklch(var(--a)/0.5));
}

.bg-accent\/55 {
  background-color: var(--fallback-a,oklch(var(--a)/0.55));
}

.bg-accent\/60 {
  background-color: var(--fallback-a,oklch(var(--a)/0.6));
}

.bg-accent\/65 {
  background-color: var(--fallback-a,oklch(var(--a)/0.65));
}

.bg-accent\/70 {
  background-color: var(--fallback-a,oklch(var(--a)/0.7));
}

.bg-accent\/75 {
  background-color: var(--fallback-a,oklch(var(--a)/0.75));
}

.bg-accent\/80 {
  background-color: var(--fallback-a,oklch(var(--a)/0.8));
}

.bg-accent\/85 {
  background-color: var(--fallback-a,oklch(var(--a)/0.85));
}

.bg-accent\/90 {
  background-color: var(--fallback-a,oklch(var(--a)/0.9));
}

.bg-accent\/95 {
  background-color: var(--fallback-a,oklch(var(--a)/0.95));
}

.bg-amber-100 {
  --tw-bg-opacity: 1;
  background-color: rgb(254 243 199 / var(--tw-bg-opacity));
}

.bg-amber-100\/0 {
  background-color: rgb(254 243 199 / 0);
}

.bg-amber-100\/10 {
  background-color: rgb(254 243 199 / 0.1);
}

.bg-amber-100\/100 {
  background-color: rgb(254 243 199 / 1);
}

.bg-amber-100\/15 {
  background-color: rgb(254 243 199 / 0.15);
}

.bg-amber-100\/20 {
  background-color: rgb(254 243 199 / 0.2);
}

.bg-amber-100\/25 {
  background-color: rgb(254 243 199 / 0.25);
}

.bg-amber-100\/30 {
  background-color: rgb(254 243 199 / 0.3);
}

.bg-amber-100\/35 {
  background-color: rgb(254 243 199 / 0.35);
}

.bg-amber-100\/40 {
  background-color: rgb(254 243 199 / 0.4);
}

.bg-amber-100\/45 {
  background-color: rgb(254 243 199 / 0.45);
}

.bg-amber-100\/5 {
  background-color: rgb(254 243 199 / 0.05);
}

.bg-amber-100\/50 {
  background-color: rgb(254 243 199 / 0.5);
}

.bg-amber-100\/55 {
  background-color: rgb(254 243 199 / 0.55);
}

.bg-amber-100\/60 {
  background-color: rgb(254 243 199 / 0.6);
}

.bg-amber-100\/65 {
  background-color: rgb(254 243 199 / 0.65);
}

.bg-amber-100\/70 {
  background-color: rgb(254 243 199 / 0.7);
}

.bg-amber-100\/75 {
  background-color: rgb(254 243 199 / 0.75);
}

.bg-amber-100\/80 {
  background-color: rgb(254 243 199 / 0.8);
}

.bg-amber-100\/85 {
  background-color: rgb(254 243 199 / 0.85);
}

.bg-amber-100\/90 {
  background-color: rgb(254 243 199 / 0.9);
}

.bg-amber-100\/95 {
  background-color: rgb(254 243 199 / 0.95);
}

.bg-amber-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(253 230 138 / var(--tw-bg-opacity));
}

.bg-amber-200\/0 {
  background-color: rgb(253 230 138 / 0);
}

.bg-amber-200\/10 {
  background-color: rgb(253 230 138 / 0.1);
}

.bg-amber-200\/100 {
  background-color: rgb(253 230 138 / 1);
}

.bg-amber-200\/15 {
  background-color: rgb(253 230 138 / 0.15);
}

.bg-amber-200\/20 {
  background-color: rgb(253 230 138 / 0.2);
}

.bg-amber-200\/25 {
  background-color: rgb(253 230 138 / 0.25);
}

.bg-amber-200\/30 {
  background-color: rgb(253 230 138 / 0.3);
}

.bg-amber-200\/35 {
  background-color: rgb(253 230 138 / 0.35);
}

.bg-amber-200\/40 {
  background-color: rgb(253 230 138 / 0.4);
}

.bg-amber-200\/45 {
  background-color: rgb(253 230 138 / 0.45);
}

.bg-amber-200\/5 {
  background-color: rgb(253 230 138 / 0.05);
}

.bg-amber-200\/50 {
  background-color: rgb(253 230 138 / 0.5);
}

.bg-amber-200\/55 {
  background-color: rgb(253 230 138 / 0.55);
}

.bg-amber-200\/60 {
  background-color: rgb(253 230 138 / 0.6);
}

.bg-amber-200\/65 {
  background-color: rgb(253 230 138 / 0.65);
}

.bg-amber-200\/70 {
  background-color: rgb(253 230 138 / 0.7);
}

.bg-amber-200\/75 {
  background-color: rgb(253 230 138 / 0.75);
}

.bg-amber-200\/80 {
  background-color: rgb(253 230 138 / 0.8);
}

.bg-amber-200\/85 {
  background-color: rgb(253 230 138 / 0.85);
}

.bg-amber-200\/90 {
  background-color: rgb(253 230 138 / 0.9);
}

.bg-amber-200\/95 {
  background-color: rgb(253 230 138 / 0.95);
}

.bg-amber-300 {
  --tw-bg-opacity: 1;
  background-color: rgb(252 211 77 / var(--tw-bg-opacity));
}

.bg-amber-300\/0 {
  background-color: rgb(252 211 77 / 0);
}

.bg-amber-300\/10 {
  background-color: rgb(252 211 77 / 0.1);
}

.bg-amber-300\/100 {
  background-color: rgb(252 211 77 / 1);
}

.bg-amber-300\/15 {
  background-color: rgb(252 211 77 / 0.15);
}

.bg-amber-300\/20 {
  background-color: rgb(252 211 77 / 0.2);
}

.bg-amber-300\/25 {
  background-color: rgb(252 211 77 / 0.25);
}

.bg-amber-300\/30 {
  background-color: rgb(252 211 77 / 0.3);
}

.bg-amber-300\/35 {
  background-color: rgb(252 211 77 / 0.35);
}

.bg-amber-300\/40 {
  background-color: rgb(252 211 77 / 0.4);
}

.bg-amber-300\/45 {
  background-color: rgb(252 211 77 / 0.45);
}

.bg-amber-300\/5 {
  background-color: rgb(252 211 77 / 0.05);
}

.bg-amber-300\/50 {
  background-color: rgb(252 211 77 / 0.5);
}

.bg-amber-300\/55 {
  background-color: rgb(252 211 77 / 0.55);
}

.bg-amber-300\/60 {
  background-color: rgb(252 211 77 / 0.6);
}

.bg-amber-300\/65 {
  background-color: rgb(252 211 77 / 0.65);
}

.bg-amber-300\/70 {
  background-color: rgb(252 211 77 / 0.7);
}

.bg-amber-300\/75 {
  background-color: rgb(252 211 77 / 0.75);
}

.bg-amber-300\/80 {
  background-color: rgb(252 211 77 / 0.8);
}

.bg-amber-300\/85 {
  background-color: rgb(252 211 77 / 0.85);
}

.bg-amber-300\/90 {
  background-color: rgb(252 211 77 / 0.9);
}

.bg-amber-300\/95 {
  background-color: rgb(252 211 77 / 0.95);
}

.bg-amber-400 {
  --tw-bg-opacity: 1;
  background-color: rgb(251 191 36 / var(--tw-bg-opacity));
}

.bg-amber-400\/0 {
  background-color: rgb(251 191 36 / 0);
}

.bg-amber-400\/10 {
  background-color: rgb(251 191 36 / 0.1);
}

.bg-amber-400\/100 {
  background-color: rgb(251 191 36 / 1);
}

.bg-amber-400\/15 {
  background-color: rgb(251 191 36 / 0.15);
}

.bg-amber-400\/20 {
  background-color: rgb(251 191 36 / 0.2);
}

.bg-amber-400\/25 {
  background-color: rgb(251 191 36 / 0.25);
}

.bg-amber-400\/30 {
  background-color: rgb(251 191 36 / 0.3);
}

.bg-amber-400\/35 {
  background-color: rgb(251 191 36 / 0.35);
}

.bg-amber-400\/40 {
  background-color: rgb(251 191 36 / 0.4);
}

.bg-amber-400\/45 {
  background-color: rgb(251 191 36 / 0.45);
}

.bg-amber-400\/5 {
  background-color: rgb(251 191 36 / 0.05);
}

.bg-amber-400\/50 {
  background-color: rgb(251 191 36 / 0.5);
}

.bg-amber-400\/55 {
  background-color: rgb(251 191 36 / 0.55);
}

.bg-amber-400\/60 {
  background-color: rgb(251 191 36 / 0.6);
}

.bg-amber-400\/65 {
  background-color: rgb(251 191 36 / 0.65);
}

.bg-amber-400\/70 {
  background-color: rgb(251 191 36 / 0.7);
}

.bg-amber-400\/75 {
  background-color: rgb(251 191 36 / 0.75);
}

.bg-amber-400\/80 {
  background-color: rgb(251 191 36 / 0.8);
}

.bg-amber-400\/85 {
  background-color: rgb(251 191 36 / 0.85);
}

.bg-amber-400\/90 {
  background-color: rgb(251 191 36 / 0.9);
}

.bg-amber-400\/95 {
  background-color: rgb(251 191 36 / 0.95);
}

.bg-amber-50 {
  --tw-bg-opacity: 1;
  background-color: rgb(255 251 235 / var(--tw-bg-opacity));
}

.bg-amber-50\/0 {
  background-color: rgb(255 251 235 / 0);
}

.bg-amber-50\/10 {
  background-color: rgb(255 251 235 / 0.1);
}

.bg-amber-50\/100 {
  background-color: rgb(255 251 235 / 1);
}

.bg-amber-50\/15 {
  background-color: rgb(255 251 235 / 0.15);
}

.bg-amber-50\/20 {
  background-color: rgb(255 251 235 / 0.2);
}

.bg-amber-50\/25 {
  background-color: rgb(255 251 235 / 0.25);
}

.bg-amber-50\/30 {
  background-color: rgb(255 251 235 / 0.3);
}

.bg-amber-50\/35 {
  background-color: rgb(255 251 235 / 0.35);
}

.bg-amber-50\/40 {
  background-color: rgb(255 251 235 / 0.4);
}

.bg-amber-50\/45 {
  background-color: rgb(255 251 235 / 0.45);
}

.bg-amber-50\/5 {
  background-color: rgb(255 251 235 / 0.05);
}

.bg-amber-50\/50 {
  background-color: rgb(255 251 235 / 0.5);
}

.bg-amber-50\/55 {
  background-color: rgb(255 251 235 / 0.55);
}

.bg-amber-50\/60 {
  background-color: rgb(255 251 235 / 0.6);
}

.bg-amber-50\/65 {
  background-color: rgb(255 251 235 / 0.65);
}

.bg-amber-50\/70 {
  background-color: rgb(255 251 235 / 0.7);
}

.bg-amber-50\/75 {
  background-color: rgb(255 251 235 / 0.75);
}

.bg-amber-50\/80 {
  background-color: rgb(255 251 235 / 0.8);
}

.bg-amber-50\/85 {
  background-color: rgb(255 251 235 / 0.85);
}

.bg-amber-50\/90 {
  background-color: rgb(255 251 235 / 0.9);
}

.bg-amber-50\/95 {
  background-color: rgb(255 251 235 / 0.95);
}

.bg-amber-500 {
  --tw-bg-opacity: 1;
  background-color: rgb(245 158 11 / var(--tw-bg-opacity));
}

.bg-amber-500\/0 {
  background-color: rgb(245 158 11 / 0);
}

.bg-amber-500\/10 {
  background-color: rgb(245 158 11 / 0.1);
}

.bg-amber-500\/100 {
  background-color: rgb(245 158 11 / 1);
}

.bg-amber-500\/15 {
  background-color: rgb(245 158 11 / 0.15);
}

.bg-amber-500\/20 {
  background-color: rgb(245 158 11 / 0.2);
}

.bg-amber-500\/25 {
  background-color: rgb(245 158 11 / 0.25);
}

.bg-amber-500\/30 {
  background-color: rgb(245 158 11 / 0.3);
}

.bg-amber-500\/35 {
  background-color: rgb(245 158 11 / 0.35);
}

.bg-amber-500\/40 {
  background-color: rgb(245 158 11 / 0.4);
}

.bg-amber-500\/45 {
  background-color: rgb(245 158 11 / 0.45);
}

.bg-amber-500\/5 {
  background-color: rgb(245 158 11 / 0.05);
}

.bg-amber-500\/50 {
  background-color: rgb(245 158 11 / 0.5);
}

.bg-amber-500\/55 {
  background-color: rgb(245 158 11 / 0.55);
}

.bg-amber-500\/60 {
  background-color: rgb(245 158 11 / 0.6);
}

.bg-amber-500\/65 {
  background-color: rgb(245 158 11 / 0.65);
}

.bg-amber-500\/70 {
  background-color: rgb(245 158 11 / 0.7);
}

.bg-amber-500\/75 {
  background-color: rgb(245 158 11 / 0.75);
}

.bg-amber-500\/80 {
  background-color: rgb(245 158 11 / 0.8);
}

.bg-amber-500\/85 {
  background-color: rgb(245 158 11 / 0.85);
}

.bg-amber-500\/90 {
  background-color: rgb(245 158 11 / 0.9);
}

.bg-amber-500\/95 {
  background-color: rgb(245 158 11 / 0.95);
}

.bg-amber-600 {
  --tw-bg-opacity: 1;
  background-color: rgb(217 119 6 / var(--tw-bg-opacity));
}

.bg-amber-600\/0 {
  background-color: rgb(217 119 6 / 0);
}

.bg-amber-600\/10 {
  background-color: rgb(217 119 6 / 0.1);
}

.bg-amber-600\/100 {
  background-color: rgb(217 119 6 / 1);
}

.bg-amber-600\/15 {
  background-color: rgb(217 119 6 / 0.15);
}

.bg-amber-600\/20 {
  background-color: rgb(217 119 6 / 0.2);
}

.bg-amber-600\/25 {
  background-color: rgb(217 119 6 / 0.25);
}

.bg-amber-600\/30 {
  background-color: rgb(217 119 6 / 0.3);
}

.bg-amber-600\/35 {
  background-color: rgb(217 119 6 / 0.35);
}

.bg-amber-600\/40 {
  background-color: rgb(217 119 6 / 0.4);
}

.bg-amber-600\/45 {
  background-color: rgb(217 119 6 / 0.45);
}

.bg-amber-600\/5 {
  background-color: rgb(217 119 6 / 0.05);
}

.bg-amber-600\/50 {
  background-color: rgb(217 119 6 / 0.5);
}

.bg-amber-600\/55 {
  background-color: rgb(217 119 6 / 0.55);
}

.bg-amber-600\/60 {
  background-color: rgb(217 119 6 / 0.6);
}

.bg-amber-600\/65 {
  background-color: rgb(217 119 6 / 0.65);
}

.bg-amber-600\/70 {
  background-color: rgb(217 119 6 / 0.7);
}

.bg-amber-600\/75 {
  background-color: rgb(217 119 6 / 0.75);
}

.bg-amber-600\/80 {
  background-color: rgb(217 119 6 / 0.8);
}

.bg-amber-600\/85 {
  background-color: rgb(217 119 6 / 0.85);
}

.bg-amber-600\/90 {
  background-color: rgb(217 119 6 / 0.9);
}

.bg-amber-600\/95 {
  background-color: rgb(217 119 6 / 0.95);
}

.bg-amber-700 {
  --tw-bg-opacity: 1;
  background-color: rgb(180 83 9 / var(--tw-bg-opacity));
}

.bg-amber-700\/0 {
  background-color: rgb(180 83 9 / 0);
}

.bg-amber-700\/10 {
  background-color: rgb(180 83 9 / 0.1);
}

.bg-amber-700\/100 {
  background-color: rgb(180 83 9 / 1);
}

.bg-amber-700\/15 {
  background-color: rgb(180 83 9 / 0.15);
}

.bg-amber-700\/20 {
  background-color: rgb(180 83 9 / 0.2);
}

.bg-amber-700\/25 {
  background-color: rgb(180 83 9 / 0.25);
}

.bg-amber-700\/30 {
  background-color: rgb(180 83 9 / 0.3);
}

.bg-amber-700\/35 {
  background-color: rgb(180 83 9 / 0.35);
}

.bg-amber-700\/40 {
  background-color: rgb(180 83 9 / 0.4);
}

.bg-amber-700\/45 {
  background-color: rgb(180 83 9 / 0.45);
}

.bg-amber-700\/5 {
  background-color: rgb(180 83 9 / 0.05);
}

.bg-amber-700\/50 {
  background-color: rgb(180 83 9 / 0.5);
}

.bg-amber-700\/55 {
  background-color: rgb(180 83 9 / 0.55);
}

.bg-amber-700\/60 {
  background-color: rgb(180 83 9 / 0.6);
}

.bg-amber-700\/65 {
  background-color: rgb(180 83 9 / 0.65);
}

.bg-amber-700\/70 {
  background-color: rgb(180 83 9 / 0.7);
}

.bg-amber-700\/75 {
  background-color: rgb(180 83 9 / 0.75);
}

.bg-amber-700\/80 {
  background-color: rgb(180 83 9 / 0.8);
}

.bg-amber-700\/85 {
  background-color: rgb(180 83 9 / 0.85);
}

.bg-amber-700\/90 {
  background-color: rgb(180 83 9 / 0.9);
}

.bg-amber-700\/95 {
  background-color: rgb(180 83 9 / 0.95);
}

.bg-amber-800 {
  --tw-bg-opacity: 1;
  background-color: rgb(146 64 14 / var(--tw-bg-opacity));
}

.bg-amber-800\/0 {
  background-color: rgb(146 64 14 / 0);
}

.bg-amber-800\/10 {
  background-color: rgb(146 64 14 / 0.1);
}

.bg-amber-800\/100 {
  background-color: rgb(146 64 14 / 1);
}

.bg-amber-800\/15 {
  background-color: rgb(146 64 14 / 0.15);
}

.bg-amber-800\/20 {
  background-color: rgb(146 64 14 / 0.2);
}

.bg-amber-800\/25 {
  background-color: rgb(146 64 14 / 0.25);
}

.bg-amber-800\/30 {
  background-color: rgb(146 64 14 / 0.3);
}

.bg-amber-800\/35 {
  background-color: rgb(146 64 14 / 0.35);
}

.bg-amber-800\/40 {
  background-color: rgb(146 64 14 / 0.4);
}

.bg-amber-800\/45 {
  background-color: rgb(146 64 14 / 0.45);
}

.bg-amber-800\/5 {
  background-color: rgb(146 64 14 / 0.05);
}

.bg-amber-800\/50 {
  background-color: rgb(146 64 14 / 0.5);
}

.bg-amber-800\/55 {
  background-color: rgb(146 64 14 / 0.55);
}

.bg-amber-800\/60 {
  background-color: rgb(146 64 14 / 0.6);
}

.bg-amber-800\/65 {
  background-color: rgb(146 64 14 / 0.65);
}

.bg-amber-800\/70 {
  background-color: rgb(146 64 14 / 0.7);
}

.bg-amber-800\/75 {
  background-color: rgb(146 64 14 / 0.75);
}

.bg-amber-800\/80 {
  background-color: rgb(146 64 14 / 0.8);
}

.bg-amber-800\/85 {
  background-color: rgb(146 64 14 / 0.85);
}

.bg-amber-800\/90 {
  background-color: rgb(146 64 14 / 0.9);
}

.bg-amber-800\/95 {
  background-color: rgb(146 64 14 / 0.95);
}

.bg-amber-900 {
  --tw-bg-opacity: 1;
  background-color: rgb(120 53 15 / var(--tw-bg-opacity));
}

.bg-amber-900\/0 {
  background-color: rgb(120 53 15 / 0);
}

.bg-amber-900\/10 {
  background-color: rgb(120 53 15 / 0.1);
}

.bg-amber-900\/100 {
  background-color: rgb(120 53 15 / 1);
}

.bg-amber-900\/15 {
  background-color: rgb(120 53 15 / 0.15);
}

.bg-amber-900\/20 {
  background-color: rgb(120 53 15 / 0.2);
}

.bg-amber-900\/25 {
  background-color: rgb(120 53 15 / 0.25);
}

.bg-amber-900\/30 {
  background-color: rgb(120 53 15 / 0.3);
}

.bg-amber-900\/35 {
  background-color: rgb(120 53 15 / 0.35);
}

.bg-amber-900\/40 {
  background-color: rgb(120 53 15 / 0.4);
}

.bg-amber-900\/45 {
  background-color: rgb(120 53 15 / 0.45);
}

.bg-amber-900\/5 {
  background-color: rgb(120 53 15 / 0.05);
}

.bg-amber-900\/50 {
  background-color: rgb(120 53 15 / 0.5);
}

.bg-amber-900\/55 {
  background-color: rgb(120 53 15 / 0.55);
}

.bg-amber-900\/60 {
  background-color: rgb(120 53 15 / 0.6);
}

.bg-amber-900\/65 {
  background-color: rgb(120 53 15 / 0.65);
}

.bg-amber-900\/70 {
  background-color: rgb(120 53 15 / 0.7);
}

.bg-amber-900\/75 {
  background-color: rgb(120 53 15 / 0.75);
}

.bg-amber-900\/80 {
  background-color: rgb(120 53 15 / 0.8);
}

.bg-amber-900\/85 {
  background-color: rgb(120 53 15 / 0.85);
}

.bg-amber-900\/90 {
  background-color: rgb(120 53 15 / 0.9);
}

.bg-amber-900\/95 {
  background-color: rgb(120 53 15 / 0.95);
}

.bg-amber-950 {
  --tw-bg-opacity: 1;
  background-color: rgb(69 26 3 / var(--tw-bg-opacity));
}

.bg-amber-950\/0 {
  background-color: rgb(69 26 3 / 0);
}

.bg-amber-950\/10 {
  background-color: rgb(69 26 3 / 0.1);
}

.bg-amber-950\/100 {
  background-color: rgb(69 26 3 / 1);
}

.bg-amber-950\/15 {
  background-color: rgb(69 26 3 / 0.15);
}

.bg-amber-950\/20 {
  background-color: rgb(69 26 3 / 0.2);
}

.bg-amber-950\/25 {
  background-color: rgb(69 26 3 / 0.25);
}

.bg-amber-950\/30 {
  background-color: rgb(69 26 3 / 0.3);
}

.bg-amber-950\/35 {
  background-color: rgb(69 26 3 / 0.35);
}

.bg-amber-950\/40 {
  background-color: rgb(69 26 3 / 0.4);
}

.bg-amber-950\/45 {
  background-color: rgb(69 26 3 / 0.45);
}

.bg-amber-950\/5 {
  background-color: rgb(69 26 3 / 0.05);
}

.bg-amber-950\/50 {
  background-color: rgb(69 26 3 / 0.5);
}

.bg-amber-950\/55 {
  background-color: rgb(69 26 3 / 0.55);
}

.bg-amber-950\/60 {
  background-color: rgb(69 26 3 / 0.6);
}

.bg-amber-950\/65 {
  background-color: rgb(69 26 3 / 0.65);
}

.bg-amber-950\/70 {
  background-color: rgb(69 26 3 / 0.7);
}

.bg-amber-950\/75 {
  background-color: rgb(69 26 3 / 0.75);
}

.bg-amber-950\/80 {
  background-color: rgb(69 26 3 / 0.8);
}

.bg-amber-950\/85 {
  background-color: rgb(69 26 3 / 0.85);
}

.bg-amber-950\/90 {
  background-color: rgb(69 26 3 / 0.9);
}

.bg-amber-950\/95 {
  background-color: rgb(69 26 3 / 0.95);
}

.bg-base-100 {
  --tw-bg-opacity: 1;
  background-color: var(--fallback-b1,oklch(var(--b1)/var(--tw-bg-opacity)));
}

.bg-base-100\/0 {
  background-color: var(--fallback-b1,oklch(var(--b1)/0));
}

.bg-base-100\/10 {
  background-color: var(--fallback-b1,oklch(var(--b1)/0.1));
}

.bg-base-100\/100 {
  background-color: var(--fallback-b1,oklch(var(--b1)/1));
}

.bg-base-100\/15 {
  background-color: var(--fallback-b1,oklch(var(--b1)/0.15));
}

.bg-base-100\/20 {
  background-color: var(--fallback-b1,oklch(var(--b1)/0.2));
}

.bg-base-100\/25 {
  background-color: var(--fallback-b1,oklch(var(--b1)/0.25));
}

.bg-base-100\/30 {
  background-color: var(--fallback-b1,oklch(var(--b1)/0.3));
}

.bg-base-100\/35 {
  background-color: var(--fallback-b1,oklch(var(--b1)/0.35));
}

.bg-base-100\/40 {
  background-color: var(--fallback-b1,oklch(var(--b1)/0.4));
}

.bg-base-100\/45 {
  background-color: var(--fallback-b1,oklch(var(--b1)/0.45));
}

.bg-base-100\/5 {
  background-color: var(--fallback-b1,oklch(var(--b1)/0.05));
}

.bg-base-100\/50 {
  background-color: var(--fallback-b1,oklch(var(--b1)/0.5));
}

.bg-base-100\/55 {
  background-color: var(--fallback-b1,oklch(var(--b1)/0.55));
}

.bg-base-100\/60 {
  background-color: var(--fallback-b1,oklch(var(--b1)/0.6));
}

.bg-base-100\/65 {
  background-color: var(--fallback-b1,oklch(var(--b1)/0.65));
}

.bg-base-100\/70 {
  background-color: var(--fallback-b1,oklch(var(--b1)/0.7));
}

.bg-base-100\/75 {
  background-color: var(--fallback-b1,oklch(var(--b1)/0.75));
}

.bg-base-100\/80 {
  background-color: var(--fallback-b1,oklch(var(--b1)/0.8));
}

.bg-base-100\/85 {
  background-color: var(--fallback-b1,oklch(var(--b1)/0.85));
}

.bg-base-100\/90 {
  background-color: var(--fallback-b1,oklch(var(--b1)/0.9));
}

.bg-base-100\/95 {
  background-color: var(--fallback-b1,oklch(var(--b1)/0.95));
}

.bg-base-200 {
  --tw-bg-opacity: 1;
  background-color: var(--fallback-b2,oklch(var(--b2)/var(--tw-bg-opacity)));
}

.bg-base-200\/0 {
  background-color: var(--fallback-b2,oklch(var(--b2)/0));
}

.bg-base-200\/10 {
  background-color: var(--fallback-b2,oklch(var(--b2)/0.1));
}

.bg-base-200\/100 {
  background-color: var(--fallback-b2,oklch(var(--b2)/1));
}

.bg-base-200\/15 {
  background-color: var(--fallback-b2,oklch(var(--b2)/0.15));
}

.bg-base-200\/20 {
  background-color: var(--fallback-b2,oklch(var(--b2)/0.2));
}

.bg-base-200\/25 {
  background-color: var(--fallback-b2,oklch(var(--b2)/0.25));
}

.bg-base-200\/30 {
  background-color: var(--fallback-b2,oklch(var(--b2)/0.3));
}

.bg-base-200\/35 {
  background-color: var(--fallback-b2,oklch(var(--b2)/0.35));
}

.bg-base-200\/40 {
  background-color: var(--fallback-b2,oklch(var(--b2)/0.4));
}

.bg-base-200\/45 {
  background-color: var(--fallback-b2,oklch(var(--b2)/0.45));
}

.bg-base-200\/5 {
  background-color: var(--fallback-b2,oklch(var(--b2)/0.05));
}

.bg-base-200\/50 {
  background-color: var(--fallback-b2,oklch(var(--b2)/0.5));
}

.bg-base-200\/55 {
  background-color: var(--fallback-b2,oklch(var(--b2)/0.55));
}

.bg-base-200\/60 {
  background-color: var(--fallback-b2,oklch(var(--b2)/0.6));
}

.bg-base-200\/65 {
  background-color: var(--fallback-b2,oklch(var(--b2)/0.65));
}

.bg-base-200\/70 {
  background-color: var(--fallback-b2,oklch(var(--b2)/0.7));
}

.bg-base-200\/75 {
  background-color: var(--fallback-b2,oklch(var(--b2)/0.75));
}

.bg-base-200\/80 {
  background-color: var(--fallback-b2,oklch(var(--b2)/0.8));
}

.bg-base-200\/85 {
  background-color: var(--fallback-b2,oklch(var(--b2)/0.85));
}

.bg-base-200\/90 {
  background-color: var(--fallback-b2,oklch(var(--b2)/0.9));
}

.bg-base-200\/95 {
  background-color: var(--fallback-b2,oklch(var(--b2)/0.95));
}

.bg-base-300 {
  --tw-bg-opacity: 1;
  background-color: var(--fallback-b3,oklch(var(--b3)/var(--tw-bg-opacity)));
}

.bg-base-300\/0 {
  background-color: var(--fallback-b3,oklch(var(--b3)/0));
}

.bg-base-300\/10 {
  background-color: var(--fallback-b3,oklch(var(--b3)/0.1));
}

.bg-base-300\/100 {
  background-color: var(--fallback-b3,oklch(var(--b3)/1));
}

.bg-base-300\/15 {
  background-color: var(--fallback-b3,oklch(var(--b3)/0.15));
}

.bg-base-300\/20 {
  background-color: var(--fallback-b3,oklch(var(--b3)/0.2));
}

.bg-base-300\/25 {
  background-color: var(--fallback-b3,oklch(var(--b3)/0.25));
}

.bg-base-300\/30 {
  background-color: var(--fallback-b3,oklch(var(--b3)/0.3));
}

.bg-base-300\/35 {
  background-color: var(--fallback-b3,oklch(var(--b3)/0.35));
}

.bg-base-300\/40 {
  background-color: var(--fallback-b3,oklch(var(--b3)/0.4));
}

.bg-base-300\/45 {
  background-color: var(--fallback-b3,oklch(var(--b3)/0.45));
}

.bg-base-300\/5 {
  background-color: var(--fallback-b3,oklch(var(--b3)/0.05));
}

.bg-base-300\/50 {
  background-color: var(--fallback-b3,oklch(var(--b3)/0.5));
}

.bg-base-300\/55 {
  background-color: var(--fallback-b3,oklch(var(--b3)/0.55));
}

.bg-base-300\/60 {
  background-color: var(--fallback-b3,oklch(var(--b3)/0.6));
}

.bg-base-300\/65 {
  background-color: var(--fallback-b3,oklch(var(--b3)/0.65));
}

.bg-base-300\/70 {
  background-color: var(--fallback-b3,oklch(var(--b3)/0.7));
}

.bg-base-300\/75 {
  background-color: var(--fallback-b3,oklch(var(--b3)/0.75));
}

.bg-base-300\/80 {
  background-color: var(--fallback-b3,oklch(var(--b3)/0.8));
}

.bg-base-300\/85 {
  background-color: var(--fallback-b3,oklch(var(--b3)/0.85));
}

.bg-base-300\/90 {
  background-color: var(--fallback-b3,oklch(var(--b3)/0.9));
}

.bg-base-300\/95 {
  background-color: var(--fallback-b3,oklch(var(--b3)/0.95));
}

.bg-base-content {
  --tw-bg-opacity: 1;
  background-color: var(--fallback-bc,oklch(var(--bc)/var(--tw-bg-opacity)));
}

.bg-base-content\/0 {
  background-color: var(--fallback-bc,oklch(var(--bc)/0));
}

.bg-base-content\/10 {
  background-color: var(--fallback-bc,oklch(var(--bc)/0.1));
}

.bg-base-content\/100 {
  background-color: var(--fallback-bc,oklch(var(--bc)/1));
}

.bg-base-content\/15 {
  background-color: var(--fallback-bc,oklch(var(--bc)/0.15));
}

.bg-base-content\/20 {
  background-color: var(--fallback-bc,oklch(var(--bc)/0.2));
}

.bg-base-content\/25 {
  background-color: var(--fallback-bc,oklch(var(--bc)/0.25));
}

.bg-base-content\/30 {
  background-color: var(--fallback-bc,oklch(var(--bc)/0.3));
}

.bg-base-content\/35 {
  background-color: var(--fallback-bc,oklch(var(--bc)/0.35));
}

.bg-base-content\/40 {
  background-color: var(--fallback-bc,oklch(var(--bc)/0.4));
}

.bg-base-content\/45 {
  background-color: var(--fallback-bc,oklch(var(--bc)/0.45));
}

.bg-base-content\/5 {
  background-color: var(--fallback-bc,oklch(var(--bc)/0.05));
}

.bg-base-content\/50 {
  background-color: var(--fallback-bc,oklch(var(--bc)/0.5));
}

.bg-base-content\/55 {
  background-color: var(--fallback-bc,oklch(var(--bc)/0.55));
}

.bg-base-content\/60 {
  background-color: var(--fallback-bc,oklch(var(--bc)/0.6));
}

.bg-base-content\/65 {
  background-color: var(--fallback-bc,oklch(var(--bc)/0.65));
}

.bg-base-content\/70 {
  background-color: var(--fallback-bc,oklch(var(--bc)/0.7));
}

.bg-base-content\/75 {
  background-color: var(--fallback-bc,oklch(var(--bc)/0.75));
}

.bg-base-content\/80 {
  background-color: var(--fallback-bc,oklch(var(--bc)/0.8));
}

.bg-base-content\/85 {
  background-color: var(--fallback-bc,oklch(var(--bc)/0.85));
}

.bg-base-content\/90 {
  background-color: var(--fallback-bc,oklch(var(--bc)/0.9));
}

.bg-base-content\/95 {
  background-color: var(--fallback-bc,oklch(var(--bc)/0.95));
}

.bg-black {
  --tw-bg-opacity: 1;
  background-color: rgb(0 0 0 / var(--tw-bg-opacity));
}

.bg-black\/0 {
  background-color: rgb(0 0 0 / 0);
}

.bg-black\/10 {
  background-color: rgb(0 0 0 / 0.1);
}

.bg-black\/100 {
  background-color: rgb(0 0 0 / 1);
}

.bg-black\/15 {
  background-color: rgb(0 0 0 / 0.15);
}

.bg-black\/20 {
  background-color: rgb(0 0 0 / 0.2);
}

.bg-black\/25 {
  background-color: rgb(0 0 0 / 0.25);
}

.bg-black\/30 {
  background-color: rgb(0 0 0 / 0.3);
}

.bg-black\/35 {
  background-color: rgb(0 0 0 / 0.35);
}

.bg-black\/40 {
  background-color: rgb(0 0 0 / 0.4);
}

.bg-black\/45 {
  background-color: rgb(0 0 0 / 0.45);
}

.bg-black\/5 {
  background-color: rgb(0 0 0 / 0.05);
}

.bg-black\/50 {
  background-color: rgb(0 0 0 / 0.5);
}

.bg-black\/55 {
  background-color: rgb(0 0 0 / 0.55);
}

.bg-black\/60 {
  background-color: rgb(0 0 0 / 0.6);
}

.bg-black\/65 {
  background-color: rgb(0 0 0 / 0.65);
}

.bg-black\/70 {
  background-color: rgb(0 0 0 / 0.7);
}

.bg-black\/75 {
  background-color: rgb(0 0 0 / 0.75);
}

.bg-black\/80 {
  background-color: rgb(0 0 0 / 0.8);
}

.bg-black\/85 {
  background-color: rgb(0 0 0 / 0.85);
}

.bg-black\/90 {
  background-color: rgb(0 0 0 / 0.9);
}

.bg-black\/95 {
  background-color: rgb(0 0 0 / 0.95);
}

.bg-blue-100 {
  --tw-bg-opacity: 1;
  background-color: rgb(219 234 254 / var(--tw-bg-opacity));
}

.bg-blue-100\/0 {
  background-color: rgb(219 234 254 / 0);
}

.bg-blue-100\/10 {
  background-color: rgb(219 234 254 / 0.1);
}

.bg-blue-100\/100 {
  background-color: rgb(219 234 254 / 1);
}

.bg-blue-100\/15 {
  background-color: rgb(219 234 254 / 0.15);
}

.bg-blue-100\/20 {
  background-color: rgb(219 234 254 / 0.2);
}

.bg-blue-100\/25 {
  background-color: rgb(219 234 254 / 0.25);
}

.bg-blue-100\/30 {
  background-color: rgb(219 234 254 / 0.3);
}

.bg-blue-100\/35 {
  background-color: rgb(219 234 254 / 0.35);
}

.bg-blue-100\/40 {
  background-color: rgb(219 234 254 / 0.4);
}

.bg-blue-100\/45 {
  background-color: rgb(219 234 254 / 0.45);
}

.bg-blue-100\/5 {
  background-color: rgb(219 234 254 / 0.05);
}

.bg-blue-100\/50 {
  background-color: rgb(219 234 254 / 0.5);
}

.bg-blue-100\/55 {
  background-color: rgb(219 234 254 / 0.55);
}

.bg-blue-100\/60 {
  background-color: rgb(219 234 254 / 0.6);
}

.bg-blue-100\/65 {
  background-color: rgb(219 234 254 / 0.65);
}

.bg-blue-100\/70 {
  background-color: rgb(219 234 254 / 0.7);
}

.bg-blue-100\/75 {
  background-color: rgb(219 234 254 / 0.75);
}

.bg-blue-100\/80 {
  background-color: rgb(219 234 254 / 0.8);
}

.bg-blue-100\/85 {
  background-color: rgb(219 234 254 / 0.85);
}

.bg-blue-100\/90 {
  background-color: rgb(219 234 254 / 0.9);
}

.bg-blue-100\/95 {
  background-color: rgb(219 234 254 / 0.95);
}

.bg-blue-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(191 219 254 / var(--tw-bg-opacity));
}

.bg-blue-200\/0 {
  background-color: rgb(191 219 254 / 0);
}

.bg-blue-200\/10 {
  background-color: rgb(191 219 254 / 0.1);
}

.bg-blue-200\/100 {
  background-color: rgb(191 219 254 / 1);
}

.bg-blue-200\/15 {
  background-color: rgb(191 219 254 / 0.15);
}

.bg-blue-200\/20 {
  background-color: rgb(191 219 254 / 0.2);
}

.bg-blue-200\/25 {
  background-color: rgb(191 219 254 / 0.25);
}

.bg-blue-200\/30 {
  background-color: rgb(191 219 254 / 0.3);
}

.bg-blue-200\/35 {
  background-color: rgb(191 219 254 / 0.35);
}

.bg-blue-200\/40 {
  background-color: rgb(191 219 254 / 0.4);
}

.bg-blue-200\/45 {
  background-color: rgb(191 219 254 / 0.45);
}

.bg-blue-200\/5 {
  background-color: rgb(191 219 254 / 0.05);
}

.bg-blue-200\/50 {
  background-color: rgb(191 219 254 / 0.5);
}

.bg-blue-200\/55 {
  background-color: rgb(191 219 254 / 0.55);
}

.bg-blue-200\/60 {
  background-color: rgb(191 219 254 / 0.6);
}

.bg-blue-200\/65 {
  background-color: rgb(191 219 254 / 0.65);
}

.bg-blue-200\/70 {
  background-color: rgb(191 219 254 / 0.7);
}

.bg-blue-200\/75 {
  background-color: rgb(191 219 254 / 0.75);
}

.bg-blue-200\/80 {
  background-color: rgb(191 219 254 / 0.8);
}

.bg-blue-200\/85 {
  background-color: rgb(191 219 254 / 0.85);
}

.bg-blue-200\/90 {
  background-color: rgb(191 219 254 / 0.9);
}

.bg-blue-200\/95 {
  background-color: rgb(191 219 254 / 0.95);
}

.bg-blue-300 {
  --tw-bg-opacity: 1;
  background-color: rgb(147 197 253 / var(--tw-bg-opacity));
}

.bg-blue-300\/0 {
  background-color: rgb(147 197 253 / 0);
}

.bg-blue-300\/10 {
  background-color: rgb(147 197 253 / 0.1);
}

.bg-blue-300\/100 {
  background-color: rgb(147 197 253 / 1);
}

.bg-blue-300\/15 {
  background-color: rgb(147 197 253 / 0.15);
}

.bg-blue-300\/20 {
  background-color: rgb(147 197 253 / 0.2);
}

.bg-blue-300\/25 {
  background-color: rgb(147 197 253 / 0.25);
}

.bg-blue-300\/30 {
  background-color: rgb(147 197 253 / 0.3);
}

.bg-blue-300\/35 {
  background-color: rgb(147 197 253 / 0.35);
}

.bg-blue-300\/40 {
  background-color: rgb(147 197 253 / 0.4);
}

.bg-blue-300\/45 {
  background-color: rgb(147 197 253 / 0.45);
}

.bg-blue-300\/5 {
  background-color: rgb(147 197 253 / 0.05);
}

.bg-blue-300\/50 {
  background-color: rgb(147 197 253 / 0.5);
}

.bg-blue-300\/55 {
  background-color: rgb(147 197 253 / 0.55);
}

.bg-blue-300\/60 {
  background-color: rgb(147 197 253 / 0.6);
}

.bg-blue-300\/65 {
  background-color: rgb(147 197 253 / 0.65);
}

.bg-blue-300\/70 {
  background-color: rgb(147 197 253 / 0.7);
}

.bg-blue-300\/75 {
  background-color: rgb(147 197 253 / 0.75);
}

.bg-blue-300\/80 {
  background-color: rgb(147 197 253 / 0.8);
}

.bg-blue-300\/85 {
  background-color: rgb(147 197 253 / 0.85);
}

.bg-blue-300\/90 {
  background-color: rgb(147 197 253 / 0.9);
}

.bg-blue-300\/95 {
  background-color: rgb(147 197 253 / 0.95);
}

.bg-blue-400 {
  --tw-bg-opacity: 1;
  background-color: rgb(96 165 250 / var(--tw-bg-opacity));
}

.bg-blue-400\/0 {
  background-color: rgb(96 165 250 / 0);
}

.bg-blue-400\/10 {
  background-color: rgb(96 165 250 / 0.1);
}

.bg-blue-400\/100 {
  background-color: rgb(96 165 250 / 1);
}

.bg-blue-400\/15 {
  background-color: rgb(96 165 250 / 0.15);
}

.bg-blue-400\/20 {
  background-color: rgb(96 165 250 / 0.2);
}

.bg-blue-400\/25 {
  background-color: rgb(96 165 250 / 0.25);
}

.bg-blue-400\/30 {
  background-color: rgb(96 165 250 / 0.3);
}

.bg-blue-400\/35 {
  background-color: rgb(96 165 250 / 0.35);
}

.bg-blue-400\/40 {
  background-color: rgb(96 165 250 / 0.4);
}

.bg-blue-400\/45 {
  background-color: rgb(96 165 250 / 0.45);
}

.bg-blue-400\/5 {
  background-color: rgb(96 165 250 / 0.05);
}

.bg-blue-400\/50 {
  background-color: rgb(96 165 250 / 0.5);
}

.bg-blue-400\/55 {
  background-color: rgb(96 165 250 / 0.55);
}

.bg-blue-400\/60 {
  background-color: rgb(96 165 250 / 0.6);
}

.bg-blue-400\/65 {
  background-color: rgb(96 165 250 / 0.65);
}

.bg-blue-400\/70 {
  background-color: rgb(96 165 250 / 0.7);
}

.bg-blue-400\/75 {
  background-color: rgb(96 165 250 / 0.75);
}

.bg-blue-400\/80 {
  background-color: rgb(96 165 250 / 0.8);
}

.bg-blue-400\/85 {
  background-color: rgb(96 165 250 / 0.85);
}

.bg-blue-400\/90 {
  background-color: rgb(96 165 250 / 0.9);
}

.bg-blue-400\/95 {
  background-color: rgb(96 165 250 / 0.95);
}

.bg-blue-50 {
  --tw-bg-opacity: 1;
  background-color: rgb(239 246 255 / var(--tw-bg-opacity));
}

.bg-blue-50\/0 {
  background-color: rgb(239 246 255 / 0);
}

.bg-blue-50\/10 {
  background-color: rgb(239 246 255 / 0.1);
}

.bg-blue-50\/100 {
  background-color: rgb(239 246 255 / 1);
}

.bg-blue-50\/15 {
  background-color: rgb(239 246 255 / 0.15);
}

.bg-blue-50\/20 {
  background-color: rgb(239 246 255 / 0.2);
}

.bg-blue-50\/25 {
  background-color: rgb(239 246 255 / 0.25);
}

.bg-blue-50\/30 {
  background-color: rgb(239 246 255 / 0.3);
}

.bg-blue-50\/35 {
  background-color: rgb(239 246 255 / 0.35);
}

.bg-blue-50\/40 {
  background-color: rgb(239 246 255 / 0.4);
}

.bg-blue-50\/45 {
  background-color: rgb(239 246 255 / 0.45);
}

.bg-blue-50\/5 {
  background-color: rgb(239 246 255 / 0.05);
}

.bg-blue-50\/50 {
  background-color: rgb(239 246 255 / 0.5);
}

.bg-blue-50\/55 {
  background-color: rgb(239 246 255 / 0.55);
}

.bg-blue-50\/60 {
  background-color: rgb(239 246 255 / 0.6);
}

.bg-blue-50\/65 {
  background-color: rgb(239 246 255 / 0.65);
}

.bg-blue-50\/70 {
  background-color: rgb(239 246 255 / 0.7);
}

.bg-blue-50\/75 {
  background-color: rgb(239 246 255 / 0.75);
}

.bg-blue-50\/80 {
  background-color: rgb(239 246 255 / 0.8);
}

.bg-blue-50\/85 {
  background-color: rgb(239 246 255 / 0.85);
}

.bg-blue-50\/90 {
  background-color: rgb(239 246 255 / 0.9);
}

.bg-blue-50\/95 {
  background-color: rgb(239 246 255 / 0.95);
}

.bg-blue-500 {
  --tw-bg-opacity: 1;
  background-color: rgb(59 130 246 / var(--tw-bg-opacity));
}

.bg-blue-500\/0 {
  background-color: rgb(59 130 246 / 0);
}

.bg-blue-500\/10 {
  background-color: rgb(59 130 246 / 0.1);
}

.bg-blue-500\/100 {
  background-color: rgb(59 130 246 / 1);
}

.bg-blue-500\/15 {
  background-color: rgb(59 130 246 / 0.15);
}

.bg-blue-500\/20 {
  background-color: rgb(59 130 246 / 0.2);
}

.bg-blue-500\/25 {
  background-color: rgb(59 130 246 / 0.25);
}

.bg-blue-500\/30 {
  background-color: rgb(59 130 246 / 0.3);
}

.bg-blue-500\/35 {
  background-color: rgb(59 130 246 / 0.35);
}

.bg-blue-500\/40 {
  background-color: rgb(59 130 246 / 0.4);
}

.bg-blue-500\/45 {
  background-color: rgb(59 130 246 / 0.45);
}

.bg-blue-500\/5 {
  background-color: rgb(59 130 246 / 0.05);
}

.bg-blue-500\/50 {
  background-color: rgb(59 130 246 / 0.5);
}

.bg-blue-500\/55 {
  background-color: rgb(59 130 246 / 0.55);
}

.bg-blue-500\/60 {
  background-color: rgb(59 130 246 / 0.6);
}

.bg-blue-500\/65 {
  background-color: rgb(59 130 246 / 0.65);
}

.bg-blue-500\/70 {
  background-color: rgb(59 130 246 / 0.7);
}

.bg-blue-500\/75 {
  background-color: rgb(59 130 246 / 0.75);
}

.bg-blue-500\/80 {
  background-color: rgb(59 130 246 / 0.8);
}

.bg-blue-500\/85 {
  background-color: rgb(59 130 246 / 0.85);
}

.bg-blue-500\/90 {
  background-color: rgb(59 130 246 / 0.9);
}

.bg-blue-500\/95 {
  background-color: rgb(59 130 246 / 0.95);
}

.bg-blue-600 {
  --tw-bg-opacity: 1;
  background-color: rgb(37 99 235 / var(--tw-bg-opacity));
}

.bg-blue-600\/0 {
  background-color: rgb(37 99 235 / 0);
}

.bg-blue-600\/10 {
  background-color: rgb(37 99 235 / 0.1);
}

.bg-blue-600\/100 {
  background-color: rgb(37 99 235 / 1);
}

.bg-blue-600\/15 {
  background-color: rgb(37 99 235 / 0.15);
}

.bg-blue-600\/20 {
  background-color: rgb(37 99 235 / 0.2);
}

.bg-blue-600\/25 {
  background-color: rgb(37 99 235 / 0.25);
}

.bg-blue-600\/30 {
  background-color: rgb(37 99 235 / 0.3);
}

.bg-blue-600\/35 {
  background-color: rgb(37 99 235 / 0.35);
}

.bg-blue-600\/40 {
  background-color: rgb(37 99 235 / 0.4);
}

.bg-blue-600\/45 {
  background-color: rgb(37 99 235 / 0.45);
}

.bg-blue-600\/5 {
  background-color: rgb(37 99 235 / 0.05);
}

.bg-blue-600\/50 {
  background-color: rgb(37 99 235 / 0.5);
}

.bg-blue-600\/55 {
  background-color: rgb(37 99 235 / 0.55);
}

.bg-blue-600\/60 {
  background-color: rgb(37 99 235 / 0.6);
}

.bg-blue-600\/65 {
  background-color: rgb(37 99 235 / 0.65);
}

.bg-blue-600\/70 {
  background-color: rgb(37 99 235 / 0.7);
}

.bg-blue-600\/75 {
  background-color: rgb(37 99 235 / 0.75);
}

.bg-blue-600\/80 {
  background-color: rgb(37 99 235 / 0.8);
}

.bg-blue-600\/85 {
  background-color: rgb(37 99 235 / 0.85);
}

.bg-blue-600\/90 {
  background-color: rgb(37 99 235 / 0.9);
}

.bg-blue-600\/95 {
  background-color: rgb(37 99 235 / 0.95);
}

.bg-blue-700 {
  --tw-bg-opacity: 1;
  background-color: rgb(29 78 216 / var(--tw-bg-opacity));
}

.bg-blue-700\/0 {
  background-color: rgb(29 78 216 / 0);
}

.bg-blue-700\/10 {
  background-color: rgb(29 78 216 / 0.1);
}

.bg-blue-700\/100 {
  background-color: rgb(29 78 216 / 1);
}

.bg-blue-700\/15 {
  background-color: rgb(29 78 216 / 0.15);
}

.bg-blue-700\/20 {
  background-color: rgb(29 78 216 / 0.2);
}

.bg-blue-700\/25 {
  background-color: rgb(29 78 216 / 0.25);
}

.bg-blue-700\/30 {
  background-color: rgb(29 78 216 / 0.3);
}

.bg-blue-700\/35 {
  background-color: rgb(29 78 216 / 0.35);
}

.bg-blue-700\/40 {
  background-color: rgb(29 78 216 / 0.4);
}

.bg-blue-700\/45 {
  background-color: rgb(29 78 216 / 0.45);
}

.bg-blue-700\/5 {
  background-color: rgb(29 78 216 / 0.05);
}

.bg-blue-700\/50 {
  background-color: rgb(29 78 216 / 0.5);
}

.bg-blue-700\/55 {
  background-color: rgb(29 78 216 / 0.55);
}

.bg-blue-700\/60 {
  background-color: rgb(29 78 216 / 0.6);
}

.bg-blue-700\/65 {
  background-color: rgb(29 78 216 / 0.65);
}

.bg-blue-700\/70 {
  background-color: rgb(29 78 216 / 0.7);
}

.bg-blue-700\/75 {
  background-color: rgb(29 78 216 / 0.75);
}

.bg-blue-700\/80 {
  background-color: rgb(29 78 216 / 0.8);
}

.bg-blue-700\/85 {
  background-color: rgb(29 78 216 / 0.85);
}

.bg-blue-700\/90 {
  background-color: rgb(29 78 216 / 0.9);
}

.bg-blue-700\/95 {
  background-color: rgb(29 78 216 / 0.95);
}

.bg-blue-800 {
  --tw-bg-opacity: 1;
  background-color: rgb(30 64 175 / var(--tw-bg-opacity));
}

.bg-blue-800\/0 {
  background-color: rgb(30 64 175 / 0);
}

.bg-blue-800\/10 {
  background-color: rgb(30 64 175 / 0.1);
}

.bg-blue-800\/100 {
  background-color: rgb(30 64 175 / 1);
}

.bg-blue-800\/15 {
  background-color: rgb(30 64 175 / 0.15);
}

.bg-blue-800\/20 {
  background-color: rgb(30 64 175 / 0.2);
}

.bg-blue-800\/25 {
  background-color: rgb(30 64 175 / 0.25);
}

.bg-blue-800\/30 {
  background-color: rgb(30 64 175 / 0.3);
}

.bg-blue-800\/35 {
  background-color: rgb(30 64 175 / 0.35);
}

.bg-blue-800\/40 {
  background-color: rgb(30 64 175 / 0.4);
}

.bg-blue-800\/45 {
  background-color: rgb(30 64 175 / 0.45);
}

.bg-blue-800\/5 {
  background-color: rgb(30 64 175 / 0.05);
}

.bg-blue-800\/50 {
  background-color: rgb(30 64 175 / 0.5);
}

.bg-blue-800\/55 {
  background-color: rgb(30 64 175 / 0.55);
}

.bg-blue-800\/60 {
  background-color: rgb(30 64 175 / 0.6);
}

.bg-blue-800\/65 {
  background-color: rgb(30 64 175 / 0.65);
}

.bg-blue-800\/70 {
  background-color: rgb(30 64 175 / 0.7);
}

.bg-blue-800\/75 {
  background-color: rgb(30 64 175 / 0.75);
}

.bg-blue-800\/80 {
  background-color: rgb(30 64 175 / 0.8);
}

.bg-blue-800\/85 {
  background-color: rgb(30 64 175 / 0.85);
}

.bg-blue-800\/90 {
  background-color: rgb(30 64 175 / 0.9);
}

.bg-blue-800\/95 {
  background-color: rgb(30 64 175 / 0.95);
}

.bg-blue-900 {
  --tw-bg-opacity: 1;
  background-color: rgb(30 58 138 / var(--tw-bg-opacity));
}

.bg-blue-900\/0 {
  background-color: rgb(30 58 138 / 0);
}

.bg-blue-900\/10 {
  background-color: rgb(30 58 138 / 0.1);
}

.bg-blue-900\/100 {
  background-color: rgb(30 58 138 / 1);
}

.bg-blue-900\/15 {
  background-color: rgb(30 58 138 / 0.15);
}

.bg-blue-900\/20 {
  background-color: rgb(30 58 138 / 0.2);
}

.bg-blue-900\/25 {
  background-color: rgb(30 58 138 / 0.25);
}

.bg-blue-900\/30 {
  background-color: rgb(30 58 138 / 0.3);
}

.bg-blue-900\/35 {
  background-color: rgb(30 58 138 / 0.35);
}

.bg-blue-900\/40 {
  background-color: rgb(30 58 138 / 0.4);
}

.bg-blue-900\/45 {
  background-color: rgb(30 58 138 / 0.45);
}

.bg-blue-900\/5 {
  background-color: rgb(30 58 138 / 0.05);
}

.bg-blue-900\/50 {
  background-color: rgb(30 58 138 / 0.5);
}

.bg-blue-900\/55 {
  background-color: rgb(30 58 138 / 0.55);
}

.bg-blue-900\/60 {
  background-color: rgb(30 58 138 / 0.6);
}

.bg-blue-900\/65 {
  background-color: rgb(30 58 138 / 0.65);
}

.bg-blue-900\/70 {
  background-color: rgb(30 58 138 / 0.7);
}

.bg-blue-900\/75 {
  background-color: rgb(30 58 138 / 0.75);
}

.bg-blue-900\/80 {
  background-color: rgb(30 58 138 / 0.8);
}

.bg-blue-900\/85 {
  background-color: rgb(30 58 138 / 0.85);
}

.bg-blue-900\/90 {
  background-color: rgb(30 58 138 / 0.9);
}

.bg-blue-900\/95 {
  background-color: rgb(30 58 138 / 0.95);
}

.bg-blue-950 {
  --tw-bg-opacity: 1;
  background-color: rgb(23 37 84 / var(--tw-bg-opacity));
}

.bg-blue-950\/0 {
  background-color: rgb(23 37 84 / 0);
}

.bg-blue-950\/10 {
  background-color: rgb(23 37 84 / 0.1);
}

.bg-blue-950\/100 {
  background-color: rgb(23 37 84 / 1);
}

.bg-blue-950\/15 {
  background-color: rgb(23 37 84 / 0.15);
}

.bg-blue-950\/20 {
  background-color: rgb(23 37 84 / 0.2);
}

.bg-blue-950\/25 {
  background-color: rgb(23 37 84 / 0.25);
}

.bg-blue-950\/30 {
  background-color: rgb(23 37 84 / 0.3);
}

.bg-blue-950\/35 {
  background-color: rgb(23 37 84 / 0.35);
}

.bg-blue-950\/40 {
  background-color: rgb(23 37 84 / 0.4);
}

.bg-blue-950\/45 {
  background-color: rgb(23 37 84 / 0.45);
}

.bg-blue-950\/5 {
  background-color: rgb(23 37 84 / 0.05);
}

.bg-blue-950\/50 {
  background-color: rgb(23 37 84 / 0.5);
}

.bg-blue-950\/55 {
  background-color: rgb(23 37 84 / 0.55);
}

.bg-blue-950\/60 {
  background-color: rgb(23 37 84 / 0.6);
}

.bg-blue-950\/65 {
  background-color: rgb(23 37 84 / 0.65);
}

.bg-blue-950\/70 {
  background-color: rgb(23 37 84 / 0.7);
}

.bg-blue-950\/75 {
  background-color: rgb(23 37 84 / 0.75);
}

.bg-blue-950\/80 {
  background-color: rgb(23 37 84 / 0.8);
}

.bg-blue-950\/85 {
  background-color: rgb(23 37 84 / 0.85);
}

.bg-blue-950\/90 {
  background-color: rgb(23 37 84 / 0.9);
}

.bg-blue-950\/95 {
  background-color: rgb(23 37 84 / 0.95);
}

.bg-current {
  background-color: currentColor;
}

.bg-cyan-100 {
  --tw-bg-opacity: 1;
  background-color: rgb(207 250 254 / var(--tw-bg-opacity));
}

.bg-cyan-100\/0 {
  background-color: rgb(207 250 254 / 0);
}

.bg-cyan-100\/10 {
  background-color: rgb(207 250 254 / 0.1);
}

.bg-cyan-100\/100 {
  background-color: rgb(207 250 254 / 1);
}

.bg-cyan-100\/15 {
  background-color: rgb(207 250 254 / 0.15);
}

.bg-cyan-100\/20 {
  background-color: rgb(207 250 254 / 0.2);
}

.bg-cyan-100\/25 {
  background-color: rgb(207 250 254 / 0.25);
}

.bg-cyan-100\/30 {
  background-color: rgb(207 250 254 / 0.3);
}

.bg-cyan-100\/35 {
  background-color: rgb(207 250 254 / 0.35);
}

.bg-cyan-100\/40 {
  background-color: rgb(207 250 254 / 0.4);
}

.bg-cyan-100\/45 {
  background-color: rgb(207 250 254 / 0.45);
}

.bg-cyan-100\/5 {
  background-color: rgb(207 250 254 / 0.05);
}

.bg-cyan-100\/50 {
  background-color: rgb(207 250 254 / 0.5);
}

.bg-cyan-100\/55 {
  background-color: rgb(207 250 254 / 0.55);
}

.bg-cyan-100\/60 {
  background-color: rgb(207 250 254 / 0.6);
}

.bg-cyan-100\/65 {
  background-color: rgb(207 250 254 / 0.65);
}

.bg-cyan-100\/70 {
  background-color: rgb(207 250 254 / 0.7);
}

.bg-cyan-100\/75 {
  background-color: rgb(207 250 254 / 0.75);
}

.bg-cyan-100\/80 {
  background-color: rgb(207 250 254 / 0.8);
}

.bg-cyan-100\/85 {
  background-color: rgb(207 250 254 / 0.85);
}

.bg-cyan-100\/90 {
  background-color: rgb(207 250 254 / 0.9);
}

.bg-cyan-100\/95 {
  background-color: rgb(207 250 254 / 0.95);
}

.bg-cyan-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(165 243 252 / var(--tw-bg-opacity));
}

.bg-cyan-200\/0 {
  background-color: rgb(165 243 252 / 0);
}

.bg-cyan-200\/10 {
  background-color: rgb(165 243 252 / 0.1);
}

.bg-cyan-200\/100 {
  background-color: rgb(165 243 252 / 1);
}

.bg-cyan-200\/15 {
  background-color: rgb(165 243 252 / 0.15);
}

.bg-cyan-200\/20 {
  background-color: rgb(165 243 252 / 0.2);
}

.bg-cyan-200\/25 {
  background-color: rgb(165 243 252 / 0.25);
}

.bg-cyan-200\/30 {
  background-color: rgb(165 243 252 / 0.3);
}

.bg-cyan-200\/35 {
  background-color: rgb(165 243 252 / 0.35);
}

.bg-cyan-200\/40 {
  background-color: rgb(165 243 252 / 0.4);
}

.bg-cyan-200\/45 {
  background-color: rgb(165 243 252 / 0.45);
}

.bg-cyan-200\/5 {
  background-color: rgb(165 243 252 / 0.05);
}

.bg-cyan-200\/50 {
  background-color: rgb(165 243 252 / 0.5);
}

.bg-cyan-200\/55 {
  background-color: rgb(165 243 252 / 0.55);
}

.bg-cyan-200\/60 {
  background-color: rgb(165 243 252 / 0.6);
}

.bg-cyan-200\/65 {
  background-color: rgb(165 243 252 / 0.65);
}

.bg-cyan-200\/70 {
  background-color: rgb(165 243 252 / 0.7);
}

.bg-cyan-200\/75 {
  background-color: rgb(165 243 252 / 0.75);
}

.bg-cyan-200\/80 {
  background-color: rgb(165 243 252 / 0.8);
}

.bg-cyan-200\/85 {
  background-color: rgb(165 243 252 / 0.85);
}

.bg-cyan-200\/90 {
  background-color: rgb(165 243 252 / 0.9);
}

.bg-cyan-200\/95 {
  background-color: rgb(165 243 252 / 0.95);
}

.bg-cyan-300 {
  --tw-bg-opacity: 1;
  background-color: rgb(103 232 249 / var(--tw-bg-opacity));
}

.bg-cyan-300\/0 {
  background-color: rgb(103 232 249 / 0);
}

.bg-cyan-300\/10 {
  background-color: rgb(103 232 249 / 0.1);
}

.bg-cyan-300\/100 {
  background-color: rgb(103 232 249 / 1);
}

.bg-cyan-300\/15 {
  background-color: rgb(103 232 249 / 0.15);
}

.bg-cyan-300\/20 {
  background-color: rgb(103 232 249 / 0.2);
}

.bg-cyan-300\/25 {
  background-color: rgb(103 232 249 / 0.25);
}

.bg-cyan-300\/30 {
  background-color: rgb(103 232 249 / 0.3);
}

.bg-cyan-300\/35 {
  background-color: rgb(103 232 249 / 0.35);
}

.bg-cyan-300\/40 {
  background-color: rgb(103 232 249 / 0.4);
}

.bg-cyan-300\/45 {
  background-color: rgb(103 232 249 / 0.45);
}

.bg-cyan-300\/5 {
  background-color: rgb(103 232 249 / 0.05);
}

.bg-cyan-300\/50 {
  background-color: rgb(103 232 249 / 0.5);
}

.bg-cyan-300\/55 {
  background-color: rgb(103 232 249 / 0.55);
}

.bg-cyan-300\/60 {
  background-color: rgb(103 232 249 / 0.6);
}

.bg-cyan-300\/65 {
  background-color: rgb(103 232 249 / 0.65);
}

.bg-cyan-300\/70 {
  background-color: rgb(103 232 249 / 0.7);
}

.bg-cyan-300\/75 {
  background-color: rgb(103 232 249 / 0.75);
}

.bg-cyan-300\/80 {
  background-color: rgb(103 232 249 / 0.8);
}

.bg-cyan-300\/85 {
  background-color: rgb(103 232 249 / 0.85);
}

.bg-cyan-300\/90 {
  background-color: rgb(103 232 249 / 0.9);
}

.bg-cyan-300\/95 {
  background-color: rgb(103 232 249 / 0.95);
}

.bg-cyan-400 {
  --tw-bg-opacity: 1;
  background-color: rgb(34 211 238 / var(--tw-bg-opacity));
}

.bg-cyan-400\/0 {
  background-color: rgb(34 211 238 / 0);
}

.bg-cyan-400\/10 {
  background-color: rgb(34 211 238 / 0.1);
}

.bg-cyan-400\/100 {
  background-color: rgb(34 211 238 / 1);
}

.bg-cyan-400\/15 {
  background-color: rgb(34 211 238 / 0.15);
}

.bg-cyan-400\/20 {
  background-color: rgb(34 211 238 / 0.2);
}

.bg-cyan-400\/25 {
  background-color: rgb(34 211 238 / 0.25);
}

.bg-cyan-400\/30 {
  background-color: rgb(34 211 238 / 0.3);
}

.bg-cyan-400\/35 {
  background-color: rgb(34 211 238 / 0.35);
}

.bg-cyan-400\/40 {
  background-color: rgb(34 211 238 / 0.4);
}

.bg-cyan-400\/45 {
  background-color: rgb(34 211 238 / 0.45);
}

.bg-cyan-400\/5 {
  background-color: rgb(34 211 238 / 0.05);
}

.bg-cyan-400\/50 {
  background-color: rgb(34 211 238 / 0.5);
}

.bg-cyan-400\/55 {
  background-color: rgb(34 211 238 / 0.55);
}

.bg-cyan-400\/60 {
  background-color: rgb(34 211 238 / 0.6);
}

.bg-cyan-400\/65 {
  background-color: rgb(34 211 238 / 0.65);
}

.bg-cyan-400\/70 {
  background-color: rgb(34 211 238 / 0.7);
}

.bg-cyan-400\/75 {
  background-color: rgb(34 211 238 / 0.75);
}

.bg-cyan-400\/80 {
  background-color: rgb(34 211 238 / 0.8);
}

.bg-cyan-400\/85 {
  background-color: rgb(34 211 238 / 0.85);
}

.bg-cyan-400\/90 {
  background-color: rgb(34 211 238 / 0.9);
}

.bg-cyan-400\/95 {
  background-color: rgb(34 211 238 / 0.95);
}

.bg-cyan-50 {
  --tw-bg-opacity: 1;
  background-color: rgb(236 254 255 / var(--tw-bg-opacity));
}

.bg-cyan-50\/0 {
  background-color: rgb(236 254 255 / 0);
}

.bg-cyan-50\/10 {
  background-color: rgb(236 254 255 / 0.1);
}

.bg-cyan-50\/100 {
  background-color: rgb(236 254 255 / 1);
}

.bg-cyan-50\/15 {
  background-color: rgb(236 254 255 / 0.15);
}

.bg-cyan-50\/20 {
  background-color: rgb(236 254 255 / 0.2);
}

.bg-cyan-50\/25 {
  background-color: rgb(236 254 255 / 0.25);
}

.bg-cyan-50\/30 {
  background-color: rgb(236 254 255 / 0.3);
}

.bg-cyan-50\/35 {
  background-color: rgb(236 254 255 / 0.35);
}

.bg-cyan-50\/40 {
  background-color: rgb(236 254 255 / 0.4);
}

.bg-cyan-50\/45 {
  background-color: rgb(236 254 255 / 0.45);
}

.bg-cyan-50\/5 {
  background-color: rgb(236 254 255 / 0.05);
}

.bg-cyan-50\/50 {
  background-color: rgb(236 254 255 / 0.5);
}

.bg-cyan-50\/55 {
  background-color: rgb(236 254 255 / 0.55);
}

.bg-cyan-50\/60 {
  background-color: rgb(236 254 255 / 0.6);
}

.bg-cyan-50\/65 {
  background-color: rgb(236 254 255 / 0.65);
}

.bg-cyan-50\/70 {
  background-color: rgb(236 254 255 / 0.7);
}

.bg-cyan-50\/75 {
  background-color: rgb(236 254 255 / 0.75);
}

.bg-cyan-50\/80 {
  background-color: rgb(236 254 255 / 0.8);
}

.bg-cyan-50\/85 {
  background-color: rgb(236 254 255 / 0.85);
}

.bg-cyan-50\/90 {
  background-color: rgb(236 254 255 / 0.9);
}

.bg-cyan-50\/95 {
  background-color: rgb(236 254 255 / 0.95);
}

.bg-cyan-500 {
  --tw-bg-opacity: 1;
  background-color: rgb(6 182 212 / var(--tw-bg-opacity));
}

.bg-cyan-500\/0 {
  background-color: rgb(6 182 212 / 0);
}

.bg-cyan-500\/10 {
  background-color: rgb(6 182 212 / 0.1);
}

.bg-cyan-500\/100 {
  background-color: rgb(6 182 212 / 1);
}

.bg-cyan-500\/15 {
  background-color: rgb(6 182 212 / 0.15);
}

.bg-cyan-500\/20 {
  background-color: rgb(6 182 212 / 0.2);
}

.bg-cyan-500\/25 {
  background-color: rgb(6 182 212 / 0.25);
}

.bg-cyan-500\/30 {
  background-color: rgb(6 182 212 / 0.3);
}

.bg-cyan-500\/35 {
  background-color: rgb(6 182 212 / 0.35);
}

.bg-cyan-500\/40 {
  background-color: rgb(6 182 212 / 0.4);
}

.bg-cyan-500\/45 {
  background-color: rgb(6 182 212 / 0.45);
}

.bg-cyan-500\/5 {
  background-color: rgb(6 182 212 / 0.05);
}

.bg-cyan-500\/50 {
  background-color: rgb(6 182 212 / 0.5);
}

.bg-cyan-500\/55 {
  background-color: rgb(6 182 212 / 0.55);
}

.bg-cyan-500\/60 {
  background-color: rgb(6 182 212 / 0.6);
}

.bg-cyan-500\/65 {
  background-color: rgb(6 182 212 / 0.65);
}

.bg-cyan-500\/70 {
  background-color: rgb(6 182 212 / 0.7);
}

.bg-cyan-500\/75 {
  background-color: rgb(6 182 212 / 0.75);
}

.bg-cyan-500\/80 {
  background-color: rgb(6 182 212 / 0.8);
}

.bg-cyan-500\/85 {
  background-color: rgb(6 182 212 / 0.85);
}

.bg-cyan-500\/90 {
  background-color: rgb(6 182 212 / 0.9);
}

.bg-cyan-500\/95 {
  background-color: rgb(6 182 212 / 0.95);
}

.bg-cyan-600 {
  --tw-bg-opacity: 1;
  background-color: rgb(8 145 178 / var(--tw-bg-opacity));
}

.bg-cyan-600\/0 {
  background-color: rgb(8 145 178 / 0);
}

.bg-cyan-600\/10 {
  background-color: rgb(8 145 178 / 0.1);
}

.bg-cyan-600\/100 {
  background-color: rgb(8 145 178 / 1);
}

.bg-cyan-600\/15 {
  background-color: rgb(8 145 178 / 0.15);
}

.bg-cyan-600\/20 {
  background-color: rgb(8 145 178 / 0.2);
}

.bg-cyan-600\/25 {
  background-color: rgb(8 145 178 / 0.25);
}

.bg-cyan-600\/30 {
  background-color: rgb(8 145 178 / 0.3);
}

.bg-cyan-600\/35 {
  background-color: rgb(8 145 178 / 0.35);
}

.bg-cyan-600\/40 {
  background-color: rgb(8 145 178 / 0.4);
}

.bg-cyan-600\/45 {
  background-color: rgb(8 145 178 / 0.45);
}

.bg-cyan-600\/5 {
  background-color: rgb(8 145 178 / 0.05);
}

.bg-cyan-600\/50 {
  background-color: rgb(8 145 178 / 0.5);
}

.bg-cyan-600\/55 {
  background-color: rgb(8 145 178 / 0.55);
}

.bg-cyan-600\/60 {
  background-color: rgb(8 145 178 / 0.6);
}

.bg-cyan-600\/65 {
  background-color: rgb(8 145 178 / 0.65);
}

.bg-cyan-600\/70 {
  background-color: rgb(8 145 178 / 0.7);
}

.bg-cyan-600\/75 {
  background-color: rgb(8 145 178 / 0.75);
}

.bg-cyan-600\/80 {
  background-color: rgb(8 145 178 / 0.8);
}

.bg-cyan-600\/85 {
  background-color: rgb(8 145 178 / 0.85);
}

.bg-cyan-600\/90 {
  background-color: rgb(8 145 178 / 0.9);
}

.bg-cyan-600\/95 {
  background-color: rgb(8 145 178 / 0.95);
}

.bg-cyan-700 {
  --tw-bg-opacity: 1;
  background-color: rgb(14 116 144 / var(--tw-bg-opacity));
}

.bg-cyan-700\/0 {
  background-color: rgb(14 116 144 / 0);
}

.bg-cyan-700\/10 {
  background-color: rgb(14 116 144 / 0.1);
}

.bg-cyan-700\/100 {
  background-color: rgb(14 116 144 / 1);
}

.bg-cyan-700\/15 {
  background-color: rgb(14 116 144 / 0.15);
}

.bg-cyan-700\/20 {
  background-color: rgb(14 116 144 / 0.2);
}

.bg-cyan-700\/25 {
  background-color: rgb(14 116 144 / 0.25);
}

.bg-cyan-700\/30 {
  background-color: rgb(14 116 144 / 0.3);
}

.bg-cyan-700\/35 {
  background-color: rgb(14 116 144 / 0.35);
}

.bg-cyan-700\/40 {
  background-color: rgb(14 116 144 / 0.4);
}

.bg-cyan-700\/45 {
  background-color: rgb(14 116 144 / 0.45);
}

.bg-cyan-700\/5 {
  background-color: rgb(14 116 144 / 0.05);
}

.bg-cyan-700\/50 {
  background-color: rgb(14 116 144 / 0.5);
}

.bg-cyan-700\/55 {
  background-color: rgb(14 116 144 / 0.55);
}

.bg-cyan-700\/60 {
  background-color: rgb(14 116 144 / 0.6);
}

.bg-cyan-700\/65 {
  background-color: rgb(14 116 144 / 0.65);
}

.bg-cyan-700\/70 {
  background-color: rgb(14 116 144 / 0.7);
}

.bg-cyan-700\/75 {
  background-color: rgb(14 116 144 / 0.75);
}

.bg-cyan-700\/80 {
  background-color: rgb(14 116 144 / 0.8);
}

.bg-cyan-700\/85 {
  background-color: rgb(14 116 144 / 0.85);
}

.bg-cyan-700\/90 {
  background-color: rgb(14 116 144 / 0.9);
}

.bg-cyan-700\/95 {
  background-color: rgb(14 116 144 / 0.95);
}

.bg-cyan-800 {
  --tw-bg-opacity: 1;
  background-color: rgb(21 94 117 / var(--tw-bg-opacity));
}

.bg-cyan-800\/0 {
  background-color: rgb(21 94 117 / 0);
}

.bg-cyan-800\/10 {
  background-color: rgb(21 94 117 / 0.1);
}

.bg-cyan-800\/100 {
  background-color: rgb(21 94 117 / 1);
}

.bg-cyan-800\/15 {
  background-color: rgb(21 94 117 / 0.15);
}

.bg-cyan-800\/20 {
  background-color: rgb(21 94 117 / 0.2);
}

.bg-cyan-800\/25 {
  background-color: rgb(21 94 117 / 0.25);
}

.bg-cyan-800\/30 {
  background-color: rgb(21 94 117 / 0.3);
}

.bg-cyan-800\/35 {
  background-color: rgb(21 94 117 / 0.35);
}

.bg-cyan-800\/40 {
  background-color: rgb(21 94 117 / 0.4);
}

.bg-cyan-800\/45 {
  background-color: rgb(21 94 117 / 0.45);
}

.bg-cyan-800\/5 {
  background-color: rgb(21 94 117 / 0.05);
}

.bg-cyan-800\/50 {
  background-color: rgb(21 94 117 / 0.5);
}

.bg-cyan-800\/55 {
  background-color: rgb(21 94 117 / 0.55);
}

.bg-cyan-800\/60 {
  background-color: rgb(21 94 117 / 0.6);
}

.bg-cyan-800\/65 {
  background-color: rgb(21 94 117 / 0.65);
}

.bg-cyan-800\/70 {
  background-color: rgb(21 94 117 / 0.7);
}

.bg-cyan-800\/75 {
  background-color: rgb(21 94 117 / 0.75);
}

.bg-cyan-800\/80 {
  background-color: rgb(21 94 117 / 0.8);
}

.bg-cyan-800\/85 {
  background-color: rgb(21 94 117 / 0.85);
}

.bg-cyan-800\/90 {
  background-color: rgb(21 94 117 / 0.9);
}

.bg-cyan-800\/95 {
  background-color: rgb(21 94 117 / 0.95);
}

.bg-cyan-900 {
  --tw-bg-opacity: 1;
  background-color: rgb(22 78 99 / var(--tw-bg-opacity));
}

.bg-cyan-900\/0 {
  background-color: rgb(22 78 99 / 0);
}

.bg-cyan-900\/10 {
  background-color: rgb(22 78 99 / 0.1);
}

.bg-cyan-900\/100 {
  background-color: rgb(22 78 99 / 1);
}

.bg-cyan-900\/15 {
  background-color: rgb(22 78 99 / 0.15);
}

.bg-cyan-900\/20 {
  background-color: rgb(22 78 99 / 0.2);
}

.bg-cyan-900\/25 {
  background-color: rgb(22 78 99 / 0.25);
}

.bg-cyan-900\/30 {
  background-color: rgb(22 78 99 / 0.3);
}

.bg-cyan-900\/35 {
  background-color: rgb(22 78 99 / 0.35);
}

.bg-cyan-900\/40 {
  background-color: rgb(22 78 99 / 0.4);
}

.bg-cyan-900\/45 {
  background-color: rgb(22 78 99 / 0.45);
}

.bg-cyan-900\/5 {
  background-color: rgb(22 78 99 / 0.05);
}

.bg-cyan-900\/50 {
  background-color: rgb(22 78 99 / 0.5);
}

.bg-cyan-900\/55 {
  background-color: rgb(22 78 99 / 0.55);
}

.bg-cyan-900\/60 {
  background-color: rgb(22 78 99 / 0.6);
}

.bg-cyan-900\/65 {
  background-color: rgb(22 78 99 / 0.65);
}

.bg-cyan-900\/70 {
  background-color: rgb(22 78 99 / 0.7);
}

.bg-cyan-900\/75 {
  background-color: rgb(22 78 99 / 0.75);
}

.bg-cyan-900\/80 {
  background-color: rgb(22 78 99 / 0.8);
}

.bg-cyan-900\/85 {
  background-color: rgb(22 78 99 / 0.85);
}

.bg-cyan-900\/90 {
  background-color: rgb(22 78 99 / 0.9);
}

.bg-cyan-900\/95 {
  background-color: rgb(22 78 99 / 0.95);
}

.bg-cyan-950 {
  --tw-bg-opacity: 1;
  background-color: rgb(8 51 68 / var(--tw-bg-opacity));
}

.bg-cyan-950\/0 {
  background-color: rgb(8 51 68 / 0);
}

.bg-cyan-950\/10 {
  background-color: rgb(8 51 68 / 0.1);
}

.bg-cyan-950\/100 {
  background-color: rgb(8 51 68 / 1);
}

.bg-cyan-950\/15 {
  background-color: rgb(8 51 68 / 0.15);
}

.bg-cyan-950\/20 {
  background-color: rgb(8 51 68 / 0.2);
}

.bg-cyan-950\/25 {
  background-color: rgb(8 51 68 / 0.25);
}

.bg-cyan-950\/30 {
  background-color: rgb(8 51 68 / 0.3);
}

.bg-cyan-950\/35 {
  background-color: rgb(8 51 68 / 0.35);
}

.bg-cyan-950\/40 {
  background-color: rgb(8 51 68 / 0.4);
}

.bg-cyan-950\/45 {
  background-color: rgb(8 51 68 / 0.45);
}

.bg-cyan-950\/5 {
  background-color: rgb(8 51 68 / 0.05);
}

.bg-cyan-950\/50 {
  background-color: rgb(8 51 68 / 0.5);
}

.bg-cyan-950\/55 {
  background-color: rgb(8 51 68 / 0.55);
}

.bg-cyan-950\/60 {
  background-color: rgb(8 51 68 / 0.6);
}

.bg-cyan-950\/65 {
  background-color: rgb(8 51 68 / 0.65);
}

.bg-cyan-950\/70 {
  background-color: rgb(8 51 68 / 0.7);
}

.bg-cyan-950\/75 {
  background-color: rgb(8 51 68 / 0.75);
}

.bg-cyan-950\/80 {
  background-color: rgb(8 51 68 / 0.8);
}

.bg-cyan-950\/85 {
  background-color: rgb(8 51 68 / 0.85);
}

.bg-cyan-950\/90 {
  background-color: rgb(8 51 68 / 0.9);
}

.bg-cyan-950\/95 {
  background-color: rgb(8 51 68 / 0.95);
}

.bg-emerald-100 {
  --tw-bg-opacity: 1;
  background-color: rgb(209 250 229 / var(--tw-bg-opacity));
}

.bg-emerald-100\/0 {
  background-color: rgb(209 250 229 / 0);
}

.bg-emerald-100\/10 {
  background-color: rgb(209 250 229 / 0.1);
}

.bg-emerald-100\/100 {
  background-color: rgb(209 250 229 / 1);
}

.bg-emerald-100\/15 {
  background-color: rgb(209 250 229 / 0.15);
}

.bg-emerald-100\/20 {
  background-color: rgb(209 250 229 / 0.2);
}

.bg-emerald-100\/25 {
  background-color: rgb(209 250 229 / 0.25);
}

.bg-emerald-100\/30 {
  background-color: rgb(209 250 229 / 0.3);
}

.bg-emerald-100\/35 {
  background-color: rgb(209 250 229 / 0.35);
}

.bg-emerald-100\/40 {
  background-color: rgb(209 250 229 / 0.4);
}

.bg-emerald-100\/45 {
  background-color: rgb(209 250 229 / 0.45);
}

.bg-emerald-100\/5 {
  background-color: rgb(209 250 229 / 0.05);
}

.bg-emerald-100\/50 {
  background-color: rgb(209 250 229 / 0.5);
}

.bg-emerald-100\/55 {
  background-color: rgb(209 250 229 / 0.55);
}

.bg-emerald-100\/60 {
  background-color: rgb(209 250 229 / 0.6);
}

.bg-emerald-100\/65 {
  background-color: rgb(209 250 229 / 0.65);
}

.bg-emerald-100\/70 {
  background-color: rgb(209 250 229 / 0.7);
}

.bg-emerald-100\/75 {
  background-color: rgb(209 250 229 / 0.75);
}

.bg-emerald-100\/80 {
  background-color: rgb(209 250 229 / 0.8);
}

.bg-emerald-100\/85 {
  background-color: rgb(209 250 229 / 0.85);
}

.bg-emerald-100\/90 {
  background-color: rgb(209 250 229 / 0.9);
}

.bg-emerald-100\/95 {
  background-color: rgb(209 250 229 / 0.95);
}

.bg-emerald-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(167 243 208 / var(--tw-bg-opacity));
}

.bg-emerald-200\/0 {
  background-color: rgb(167 243 208 / 0);
}

.bg-emerald-200\/10 {
  background-color: rgb(167 243 208 / 0.1);
}

.bg-emerald-200\/100 {
  background-color: rgb(167 243 208 / 1);
}

.bg-emerald-200\/15 {
  background-color: rgb(167 243 208 / 0.15);
}

.bg-emerald-200\/20 {
  background-color: rgb(167 243 208 / 0.2);
}

.bg-emerald-200\/25 {
  background-color: rgb(167 243 208 / 0.25);
}

.bg-emerald-200\/30 {
  background-color: rgb(167 243 208 / 0.3);
}

.bg-emerald-200\/35 {
  background-color: rgb(167 243 208 / 0.35);
}

.bg-emerald-200\/40 {
  background-color: rgb(167 243 208 / 0.4);
}

.bg-emerald-200\/45 {
  background-color: rgb(167 243 208 / 0.45);
}

.bg-emerald-200\/5 {
  background-color: rgb(167 243 208 / 0.05);
}

.bg-emerald-200\/50 {
  background-color: rgb(167 243 208 / 0.5);
}

.bg-emerald-200\/55 {
  background-color: rgb(167 243 208 / 0.55);
}

.bg-emerald-200\/60 {
  background-color: rgb(167 243 208 / 0.6);
}

.bg-emerald-200\/65 {
  background-color: rgb(167 243 208 / 0.65);
}

.bg-emerald-200\/70 {
  background-color: rgb(167 243 208 / 0.7);
}

.bg-emerald-200\/75 {
  background-color: rgb(167 243 208 / 0.75);
}

.bg-emerald-200\/80 {
  background-color: rgb(167 243 208 / 0.8);
}

.bg-emerald-200\/85 {
  background-color: rgb(167 243 208 / 0.85);
}

.bg-emerald-200\/90 {
  background-color: rgb(167 243 208 / 0.9);
}

.bg-emerald-200\/95 {
  background-color: rgb(167 243 208 / 0.95);
}

.bg-emerald-300 {
  --tw-bg-opacity: 1;
  background-color: rgb(110 231 183 / var(--tw-bg-opacity));
}

.bg-emerald-300\/0 {
  background-color: rgb(110 231 183 / 0);
}

.bg-emerald-300\/10 {
  background-color: rgb(110 231 183 / 0.1);
}

.bg-emerald-300\/100 {
  background-color: rgb(110 231 183 / 1);
}

.bg-emerald-300\/15 {
  background-color: rgb(110 231 183 / 0.15);
}

.bg-emerald-300\/20 {
  background-color: rgb(110 231 183 / 0.2);
}

.bg-emerald-300\/25 {
  background-color: rgb(110 231 183 / 0.25);
}

.bg-emerald-300\/30 {
  background-color: rgb(110 231 183 / 0.3);
}

.bg-emerald-300\/35 {
  background-color: rgb(110 231 183 / 0.35);
}

.bg-emerald-300\/40 {
  background-color: rgb(110 231 183 / 0.4);
}

.bg-emerald-300\/45 {
  background-color: rgb(110 231 183 / 0.45);
}

.bg-emerald-300\/5 {
  background-color: rgb(110 231 183 / 0.05);
}

.bg-emerald-300\/50 {
  background-color: rgb(110 231 183 / 0.5);
}

.bg-emerald-300\/55 {
  background-color: rgb(110 231 183 / 0.55);
}

.bg-emerald-300\/60 {
  background-color: rgb(110 231 183 / 0.6);
}

.bg-emerald-300\/65 {
  background-color: rgb(110 231 183 / 0.65);
}

.bg-emerald-300\/70 {
  background-color: rgb(110 231 183 / 0.7);
}

.bg-emerald-300\/75 {
  background-color: rgb(110 231 183 / 0.75);
}

.bg-emerald-300\/80 {
  background-color: rgb(110 231 183 / 0.8);
}

.bg-emerald-300\/85 {
  background-color: rgb(110 231 183 / 0.85);
}

.bg-emerald-300\/90 {
  background-color: rgb(110 231 183 / 0.9);
}

.bg-emerald-300\/95 {
  background-color: rgb(110 231 183 / 0.95);
}

.bg-emerald-400 {
  --tw-bg-opacity: 1;
  background-color: rgb(52 211 153 / var(--tw-bg-opacity));
}

.bg-emerald-400\/0 {
  background-color: rgb(52 211 153 / 0);
}

.bg-emerald-400\/10 {
  background-color: rgb(52 211 153 / 0.1);
}

.bg-emerald-400\/100 {
  background-color: rgb(52 211 153 / 1);
}

.bg-emerald-400\/15 {
  background-color: rgb(52 211 153 / 0.15);
}

.bg-emerald-400\/20 {
  background-color: rgb(52 211 153 / 0.2);
}

.bg-emerald-400\/25 {
  background-color: rgb(52 211 153 / 0.25);
}

.bg-emerald-400\/30 {
  background-color: rgb(52 211 153 / 0.3);
}

.bg-emerald-400\/35 {
  background-color: rgb(52 211 153 / 0.35);
}

.bg-emerald-400\/40 {
  background-color: rgb(52 211 153 / 0.4);
}

.bg-emerald-400\/45 {
  background-color: rgb(52 211 153 / 0.45);
}

.bg-emerald-400\/5 {
  background-color: rgb(52 211 153 / 0.05);
}

.bg-emerald-400\/50 {
  background-color: rgb(52 211 153 / 0.5);
}

.bg-emerald-400\/55 {
  background-color: rgb(52 211 153 / 0.55);
}

.bg-emerald-400\/60 {
  background-color: rgb(52 211 153 / 0.6);
}

.bg-emerald-400\/65 {
  background-color: rgb(52 211 153 / 0.65);
}

.bg-emerald-400\/70 {
  background-color: rgb(52 211 153 / 0.7);
}

.bg-emerald-400\/75 {
  background-color: rgb(52 211 153 / 0.75);
}

.bg-emerald-400\/80 {
  background-color: rgb(52 211 153 / 0.8);
}

.bg-emerald-400\/85 {
  background-color: rgb(52 211 153 / 0.85);
}

.bg-emerald-400\/90 {
  background-color: rgb(52 211 153 / 0.9);
}

.bg-emerald-400\/95 {
  background-color: rgb(52 211 153 / 0.95);
}

.bg-emerald-50 {
  --tw-bg-opacity: 1;
  background-color: rgb(236 253 245 / var(--tw-bg-opacity));
}

.bg-emerald-50\/0 {
  background-color: rgb(236 253 245 / 0);
}

.bg-emerald-50\/10 {
  background-color: rgb(236 253 245 / 0.1);
}

.bg-emerald-50\/100 {
  background-color: rgb(236 253 245 / 1);
}

.bg-emerald-50\/15 {
  background-color: rgb(236 253 245 / 0.15);
}

.bg-emerald-50\/20 {
  background-color: rgb(236 253 245 / 0.2);
}

.bg-emerald-50\/25 {
  background-color: rgb(236 253 245 / 0.25);
}

.bg-emerald-50\/30 {
  background-color: rgb(236 253 245 / 0.3);
}

.bg-emerald-50\/35 {
  background-color: rgb(236 253 245 / 0.35);
}

.bg-emerald-50\/40 {
  background-color: rgb(236 253 245 / 0.4);
}

.bg-emerald-50\/45 {
  background-color: rgb(236 253 245 / 0.45);
}

.bg-emerald-50\/5 {
  background-color: rgb(236 253 245 / 0.05);
}

.bg-emerald-50\/50 {
  background-color: rgb(236 253 245 / 0.5);
}

.bg-emerald-50\/55 {
  background-color: rgb(236 253 245 / 0.55);
}

.bg-emerald-50\/60 {
  background-color: rgb(236 253 245 / 0.6);
}

.bg-emerald-50\/65 {
  background-color: rgb(236 253 245 / 0.65);
}

.bg-emerald-50\/70 {
  background-color: rgb(236 253 245 / 0.7);
}

.bg-emerald-50\/75 {
  background-color: rgb(236 253 245 / 0.75);
}

.bg-emerald-50\/80 {
  background-color: rgb(236 253 245 / 0.8);
}

.bg-emerald-50\/85 {
  background-color: rgb(236 253 245 / 0.85);
}

.bg-emerald-50\/90 {
  background-color: rgb(236 253 245 / 0.9);
}

.bg-emerald-50\/95 {
  background-color: rgb(236 253 245 / 0.95);
}

.bg-emerald-500 {
  --tw-bg-opacity: 1;
  background-color: rgb(16 185 129 / var(--tw-bg-opacity));
}

.bg-emerald-500\/0 {
  background-color: rgb(16 185 129 / 0);
}

.bg-emerald-500\/10 {
  background-color: rgb(16 185 129 / 0.1);
}

.bg-emerald-500\/100 {
  background-color: rgb(16 185 129 / 1);
}

.bg-emerald-500\/15 {
  background-color: rgb(16 185 129 / 0.15);
}

.bg-emerald-500\/20 {
  background-color: rgb(16 185 129 / 0.2);
}

.bg-emerald-500\/25 {
  background-color: rgb(16 185 129 / 0.25);
}

.bg-emerald-500\/30 {
  background-color: rgb(16 185 129 / 0.3);
}

.bg-emerald-500\/35 {
  background-color: rgb(16 185 129 / 0.35);
}

.bg-emerald-500\/40 {
  background-color: rgb(16 185 129 / 0.4);
}

.bg-emerald-500\/45 {
  background-color: rgb(16 185 129 / 0.45);
}

.bg-emerald-500\/5 {
  background-color: rgb(16 185 129 / 0.05);
}

.bg-emerald-500\/50 {
  background-color: rgb(16 185 129 / 0.5);
}

.bg-emerald-500\/55 {
  background-color: rgb(16 185 129 / 0.55);
}

.bg-emerald-500\/60 {
  background-color: rgb(16 185 129 / 0.6);
}

.bg-emerald-500\/65 {
  background-color: rgb(16 185 129 / 0.65);
}

.bg-emerald-500\/70 {
  background-color: rgb(16 185 129 / 0.7);
}

.bg-emerald-500\/75 {
  background-color: rgb(16 185 129 / 0.75);
}

.bg-emerald-500\/80 {
  background-color: rgb(16 185 129 / 0.8);
}

.bg-emerald-500\/85 {
  background-color: rgb(16 185 129 / 0.85);
}

.bg-emerald-500\/90 {
  background-color: rgb(16 185 129 / 0.9);
}

.bg-emerald-500\/95 {
  background-color: rgb(16 185 129 / 0.95);
}

.bg-emerald-600 {
  --tw-bg-opacity: 1;
  background-color: rgb(5 150 105 / var(--tw-bg-opacity));
}

.bg-emerald-600\/0 {
  background-color: rgb(5 150 105 / 0);
}

.bg-emerald-600\/10 {
  background-color: rgb(5 150 105 / 0.1);
}

.bg-emerald-600\/100 {
  background-color: rgb(5 150 105 / 1);
}

.bg-emerald-600\/15 {
  background-color: rgb(5 150 105 / 0.15);
}

.bg-emerald-600\/20 {
  background-color: rgb(5 150 105 / 0.2);
}

.bg-emerald-600\/25 {
  background-color: rgb(5 150 105 / 0.25);
}

.bg-emerald-600\/30 {
  background-color: rgb(5 150 105 / 0.3);
}

.bg-emerald-600\/35 {
  background-color: rgb(5 150 105 / 0.35);
}

.bg-emerald-600\/40 {
  background-color: rgb(5 150 105 / 0.4);
}

.bg-emerald-600\/45 {
  background-color: rgb(5 150 105 / 0.45);
}

.bg-emerald-600\/5 {
  background-color: rgb(5 150 105 / 0.05);
}

.bg-emerald-600\/50 {
  background-color: rgb(5 150 105 / 0.5);
}

.bg-emerald-600\/55 {
  background-color: rgb(5 150 105 / 0.55);
}

.bg-emerald-600\/60 {
  background-color: rgb(5 150 105 / 0.6);
}

.bg-emerald-600\/65 {
  background-color: rgb(5 150 105 / 0.65);
}

.bg-emerald-600\/70 {
  background-color: rgb(5 150 105 / 0.7);
}

.bg-emerald-600\/75 {
  background-color: rgb(5 150 105 / 0.75);
}

.bg-emerald-600\/80 {
  background-color: rgb(5 150 105 / 0.8);
}

.bg-emerald-600\/85 {
  background-color: rgb(5 150 105 / 0.85);
}

.bg-emerald-600\/90 {
  background-color: rgb(5 150 105 / 0.9);
}

.bg-emerald-600\/95 {
  background-color: rgb(5 150 105 / 0.95);
}

.bg-emerald-700 {
  --tw-bg-opacity: 1;
  background-color: rgb(4 120 87 / var(--tw-bg-opacity));
}

.bg-emerald-700\/0 {
  background-color: rgb(4 120 87 / 0);
}

.bg-emerald-700\/10 {
  background-color: rgb(4 120 87 / 0.1);
}

.bg-emerald-700\/100 {
  background-color: rgb(4 120 87 / 1);
}

.bg-emerald-700\/15 {
  background-color: rgb(4 120 87 / 0.15);
}

.bg-emerald-700\/20 {
  background-color: rgb(4 120 87 / 0.2);
}

.bg-emerald-700\/25 {
  background-color: rgb(4 120 87 / 0.25);
}

.bg-emerald-700\/30 {
  background-color: rgb(4 120 87 / 0.3);
}

.bg-emerald-700\/35 {
  background-color: rgb(4 120 87 / 0.35);
}

.bg-emerald-700\/40 {
  background-color: rgb(4 120 87 / 0.4);
}

.bg-emerald-700\/45 {
  background-color: rgb(4 120 87 / 0.45);
}

.bg-emerald-700\/5 {
  background-color: rgb(4 120 87 / 0.05);
}

.bg-emerald-700\/50 {
  background-color: rgb(4 120 87 / 0.5);
}

.bg-emerald-700\/55 {
  background-color: rgb(4 120 87 / 0.55);
}

.bg-emerald-700\/60 {
  background-color: rgb(4 120 87 / 0.6);
}

.bg-emerald-700\/65 {
  background-color: rgb(4 120 87 / 0.65);
}

.bg-emerald-700\/70 {
  background-color: rgb(4 120 87 / 0.7);
}

.bg-emerald-700\/75 {
  background-color: rgb(4 120 87 / 0.75);
}

.bg-emerald-700\/80 {
  background-color: rgb(4 120 87 / 0.8);
}

.bg-emerald-700\/85 {
  background-color: rgb(4 120 87 / 0.85);
}

.bg-emerald-700\/90 {
  background-color: rgb(4 120 87 / 0.9);
}

.bg-emerald-700\/95 {
  background-color: rgb(4 120 87 / 0.95);
}

.bg-emerald-800 {
  --tw-bg-opacity: 1;
  background-color: rgb(6 95 70 / var(--tw-bg-opacity));
}

.bg-emerald-800\/0 {
  background-color: rgb(6 95 70 / 0);
}

.bg-emerald-800\/10 {
  background-color: rgb(6 95 70 / 0.1);
}

.bg-emerald-800\/100 {
  background-color: rgb(6 95 70 / 1);
}

.bg-emerald-800\/15 {
  background-color: rgb(6 95 70 / 0.15);
}

.bg-emerald-800\/20 {
  background-color: rgb(6 95 70 / 0.2);
}

.bg-emerald-800\/25 {
  background-color: rgb(6 95 70 / 0.25);
}

.bg-emerald-800\/30 {
  background-color: rgb(6 95 70 / 0.3);
}

.bg-emerald-800\/35 {
  background-color: rgb(6 95 70 / 0.35);
}

.bg-emerald-800\/40 {
  background-color: rgb(6 95 70 / 0.4);
}

.bg-emerald-800\/45 {
  background-color: rgb(6 95 70 / 0.45);
}

.bg-emerald-800\/5 {
  background-color: rgb(6 95 70 / 0.05);
}

.bg-emerald-800\/50 {
  background-color: rgb(6 95 70 / 0.5);
}

.bg-emerald-800\/55 {
  background-color: rgb(6 95 70 / 0.55);
}

.bg-emerald-800\/60 {
  background-color: rgb(6 95 70 / 0.6);
}

.bg-emerald-800\/65 {
  background-color: rgb(6 95 70 / 0.65);
}

.bg-emerald-800\/70 {
  background-color: rgb(6 95 70 / 0.7);
}

.bg-emerald-800\/75 {
  background-color: rgb(6 95 70 / 0.75);
}

.bg-emerald-800\/80 {
  background-color: rgb(6 95 70 / 0.8);
}

.bg-emerald-800\/85 {
  background-color: rgb(6 95 70 / 0.85);
}

.bg-emerald-800\/90 {
  background-color: rgb(6 95 70 / 0.9);
}

.bg-emerald-800\/95 {
  background-color: rgb(6 95 70 / 0.95);
}

.bg-emerald-900 {
  --tw-bg-opacity: 1;
  background-color: rgb(6 78 59 / var(--tw-bg-opacity));
}

.bg-emerald-900\/0 {
  background-color: rgb(6 78 59 / 0);
}

.bg-emerald-900\/10 {
  background-color: rgb(6 78 59 / 0.1);
}

.bg-emerald-900\/100 {
  background-color: rgb(6 78 59 / 1);
}

.bg-emerald-900\/15 {
  background-color: rgb(6 78 59 / 0.15);
}

.bg-emerald-900\/20 {
  background-color: rgb(6 78 59 / 0.2);
}

.bg-emerald-900\/25 {
  background-color: rgb(6 78 59 / 0.25);
}

.bg-emerald-900\/30 {
  background-color: rgb(6 78 59 / 0.3);
}

.bg-emerald-900\/35 {
  background-color: rgb(6 78 59 / 0.35);
}

.bg-emerald-900\/40 {
  background-color: rgb(6 78 59 / 0.4);
}

.bg-emerald-900\/45 {
  background-color: rgb(6 78 59 / 0.45);
}

.bg-emerald-900\/5 {
  background-color: rgb(6 78 59 / 0.05);
}

.bg-emerald-900\/50 {
  background-color: rgb(6 78 59 / 0.5);
}

.bg-emerald-900\/55 {
  background-color: rgb(6 78 59 / 0.55);
}

.bg-emerald-900\/60 {
  background-color: rgb(6 78 59 / 0.6);
}

.bg-emerald-900\/65 {
  background-color: rgb(6 78 59 / 0.65);
}

.bg-emerald-900\/70 {
  background-color: rgb(6 78 59 / 0.7);
}

.bg-emerald-900\/75 {
  background-color: rgb(6 78 59 / 0.75);
}

.bg-emerald-900\/80 {
  background-color: rgb(6 78 59 / 0.8);
}

.bg-emerald-900\/85 {
  background-color: rgb(6 78 59 / 0.85);
}

.bg-emerald-900\/90 {
  background-color: rgb(6 78 59 / 0.9);
}

.bg-emerald-900\/95 {
  background-color: rgb(6 78 59 / 0.95);
}

.bg-emerald-950 {
  --tw-bg-opacity: 1;
  background-color: rgb(2 44 34 / var(--tw-bg-opacity));
}

.bg-emerald-950\/0 {
  background-color: rgb(2 44 34 / 0);
}

.bg-emerald-950\/10 {
  background-color: rgb(2 44 34 / 0.1);
}

.bg-emerald-950\/100 {
  background-color: rgb(2 44 34 / 1);
}

.bg-emerald-950\/15 {
  background-color: rgb(2 44 34 / 0.15);
}

.bg-emerald-950\/20 {
  background-color: rgb(2 44 34 / 0.2);
}

.bg-emerald-950\/25 {
  background-color: rgb(2 44 34 / 0.25);
}

.bg-emerald-950\/30 {
  background-color: rgb(2 44 34 / 0.3);
}

.bg-emerald-950\/35 {
  background-color: rgb(2 44 34 / 0.35);
}

.bg-emerald-950\/40 {
  background-color: rgb(2 44 34 / 0.4);
}

.bg-emerald-950\/45 {
  background-color: rgb(2 44 34 / 0.45);
}

.bg-emerald-950\/5 {
  background-color: rgb(2 44 34 / 0.05);
}

.bg-emerald-950\/50 {
  background-color: rgb(2 44 34 / 0.5);
}

.bg-emerald-950\/55 {
  background-color: rgb(2 44 34 / 0.55);
}

.bg-emerald-950\/60 {
  background-color: rgb(2 44 34 / 0.6);
}

.bg-emerald-950\/65 {
  background-color: rgb(2 44 34 / 0.65);
}

.bg-emerald-950\/70 {
  background-color: rgb(2 44 34 / 0.7);
}

.bg-emerald-950\/75 {
  background-color: rgb(2 44 34 / 0.75);
}

.bg-emerald-950\/80 {
  background-color: rgb(2 44 34 / 0.8);
}

.bg-emerald-950\/85 {
  background-color: rgb(2 44 34 / 0.85);
}

.bg-emerald-950\/90 {
  background-color: rgb(2 44 34 / 0.9);
}

.bg-emerald-950\/95 {
  background-color: rgb(2 44 34 / 0.95);
}

.bg-error {
  --tw-bg-opacity: 1;
  background-color: var(--fallback-er,oklch(var(--er)/var(--tw-bg-opacity)));
}

.bg-error-content {
  --tw-bg-opacity: 1;
  background-color: var(--fallback-erc,oklch(var(--erc)/var(--tw-bg-opacity)));
}

.bg-error-content\/0 {
  background-color: var(--fallback-erc,oklch(var(--erc)/0));
}

.bg-error-content\/10 {
  background-color: var(--fallback-erc,oklch(var(--erc)/0.1));
}

.bg-error-content\/100 {
  background-color: var(--fallback-erc,oklch(var(--erc)/1));
}

.bg-error-content\/15 {
  background-color: var(--fallback-erc,oklch(var(--erc)/0.15));
}

.bg-error-content\/20 {
  background-color: var(--fallback-erc,oklch(var(--erc)/0.2));
}

.bg-error-content\/25 {
  background-color: var(--fallback-erc,oklch(var(--erc)/0.25));
}

.bg-error-content\/30 {
  background-color: var(--fallback-erc,oklch(var(--erc)/0.3));
}

.bg-error-content\/35 {
  background-color: var(--fallback-erc,oklch(var(--erc)/0.35));
}

.bg-error-content\/40 {
  background-color: var(--fallback-erc,oklch(var(--erc)/0.4));
}

.bg-error-content\/45 {
  background-color: var(--fallback-erc,oklch(var(--erc)/0.45));
}

.bg-error-content\/5 {
  background-color: var(--fallback-erc,oklch(var(--erc)/0.05));
}

.bg-error-content\/50 {
  background-color: var(--fallback-erc,oklch(var(--erc)/0.5));
}

.bg-error-content\/55 {
  background-color: var(--fallback-erc,oklch(var(--erc)/0.55));
}

.bg-error-content\/60 {
  background-color: var(--fallback-erc,oklch(var(--erc)/0.6));
}

.bg-error-content\/65 {
  background-color: var(--fallback-erc,oklch(var(--erc)/0.65));
}

.bg-error-content\/70 {
  background-color: var(--fallback-erc,oklch(var(--erc)/0.7));
}

.bg-error-content\/75 {
  background-color: var(--fallback-erc,oklch(var(--erc)/0.75));
}

.bg-error-content\/80 {
  background-color: var(--fallback-erc,oklch(var(--erc)/0.8));
}

.bg-error-content\/85 {
  background-color: var(--fallback-erc,oklch(var(--erc)/0.85));
}

.bg-error-content\/90 {
  background-color: var(--fallback-erc,oklch(var(--erc)/0.9));
}

.bg-error-content\/95 {
  background-color: var(--fallback-erc,oklch(var(--erc)/0.95));
}

.bg-error\/0 {
  background-color: var(--fallback-er,oklch(var(--er)/0));
}

.bg-error\/10 {
  background-color: var(--fallback-er,oklch(var(--er)/0.1));
}

.bg-error\/100 {
  background-color: var(--fallback-er,oklch(var(--er)/1));
}

.bg-error\/15 {
  background-color: var(--fallback-er,oklch(var(--er)/0.15));
}

.bg-error\/20 {
  background-color: var(--fallback-er,oklch(var(--er)/0.2));
}

.bg-error\/25 {
  background-color: var(--fallback-er,oklch(var(--er)/0.25));
}

.bg-error\/30 {
  background-color: var(--fallback-er,oklch(var(--er)/0.3));
}

.bg-error\/35 {
  background-color: var(--fallback-er,oklch(var(--er)/0.35));
}

.bg-error\/40 {
  background-color: var(--fallback-er,oklch(var(--er)/0.4));
}

.bg-error\/45 {
  background-color: var(--fallback-er,oklch(var(--er)/0.45));
}

.bg-error\/5 {
  background-color: var(--fallback-er,oklch(var(--er)/0.05));
}

.bg-error\/50 {
  background-color: var(--fallback-er,oklch(var(--er)/0.5));
}

.bg-error\/55 {
  background-color: var(--fallback-er,oklch(var(--er)/0.55));
}

.bg-error\/60 {
  background-color: var(--fallback-er,oklch(var(--er)/0.6));
}

.bg-error\/65 {
  background-color: var(--fallback-er,oklch(var(--er)/0.65));
}

.bg-error\/70 {
  background-color: var(--fallback-er,oklch(var(--er)/0.7));
}

.bg-error\/75 {
  background-color: var(--fallback-er,oklch(var(--er)/0.75));
}

.bg-error\/80 {
  background-color: var(--fallback-er,oklch(var(--er)/0.8));
}

.bg-error\/85 {
  background-color: var(--fallback-er,oklch(var(--er)/0.85));
}

.bg-error\/90 {
  background-color: var(--fallback-er,oklch(var(--er)/0.9));
}

.bg-error\/95 {
  background-color: var(--fallback-er,oklch(var(--er)/0.95));
}

.bg-fuchsia-100 {
  --tw-bg-opacity: 1;
  background-color: rgb(250 232 255 / var(--tw-bg-opacity));
}

.bg-fuchsia-100\/0 {
  background-color: rgb(250 232 255 / 0);
}

.bg-fuchsia-100\/10 {
  background-color: rgb(250 232 255 / 0.1);
}

.bg-fuchsia-100\/100 {
  background-color: rgb(250 232 255 / 1);
}

.bg-fuchsia-100\/15 {
  background-color: rgb(250 232 255 / 0.15);
}

.bg-fuchsia-100\/20 {
  background-color: rgb(250 232 255 / 0.2);
}

.bg-fuchsia-100\/25 {
  background-color: rgb(250 232 255 / 0.25);
}

.bg-fuchsia-100\/30 {
  background-color: rgb(250 232 255 / 0.3);
}

.bg-fuchsia-100\/35 {
  background-color: rgb(250 232 255 / 0.35);
}

.bg-fuchsia-100\/40 {
  background-color: rgb(250 232 255 / 0.4);
}

.bg-fuchsia-100\/45 {
  background-color: rgb(250 232 255 / 0.45);
}

.bg-fuchsia-100\/5 {
  background-color: rgb(250 232 255 / 0.05);
}

.bg-fuchsia-100\/50 {
  background-color: rgb(250 232 255 / 0.5);
}

.bg-fuchsia-100\/55 {
  background-color: rgb(250 232 255 / 0.55);
}

.bg-fuchsia-100\/60 {
  background-color: rgb(250 232 255 / 0.6);
}

.bg-fuchsia-100\/65 {
  background-color: rgb(250 232 255 / 0.65);
}

.bg-fuchsia-100\/70 {
  background-color: rgb(250 232 255 / 0.7);
}

.bg-fuchsia-100\/75 {
  background-color: rgb(250 232 255 / 0.75);
}

.bg-fuchsia-100\/80 {
  background-color: rgb(250 232 255 / 0.8);
}

.bg-fuchsia-100\/85 {
  background-color: rgb(250 232 255 / 0.85);
}

.bg-fuchsia-100\/90 {
  background-color: rgb(250 232 255 / 0.9);
}

.bg-fuchsia-100\/95 {
  background-color: rgb(250 232 255 / 0.95);
}

.bg-fuchsia-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(245 208 254 / var(--tw-bg-opacity));
}

.bg-fuchsia-200\/0 {
  background-color: rgb(245 208 254 / 0);
}

.bg-fuchsia-200\/10 {
  background-color: rgb(245 208 254 / 0.1);
}

.bg-fuchsia-200\/100 {
  background-color: rgb(245 208 254 / 1);
}

.bg-fuchsia-200\/15 {
  background-color: rgb(245 208 254 / 0.15);
}

.bg-fuchsia-200\/20 {
  background-color: rgb(245 208 254 / 0.2);
}

.bg-fuchsia-200\/25 {
  background-color: rgb(245 208 254 / 0.25);
}

.bg-fuchsia-200\/30 {
  background-color: rgb(245 208 254 / 0.3);
}

.bg-fuchsia-200\/35 {
  background-color: rgb(245 208 254 / 0.35);
}

.bg-fuchsia-200\/40 {
  background-color: rgb(245 208 254 / 0.4);
}

.bg-fuchsia-200\/45 {
  background-color: rgb(245 208 254 / 0.45);
}

.bg-fuchsia-200\/5 {
  background-color: rgb(245 208 254 / 0.05);
}

.bg-fuchsia-200\/50 {
  background-color: rgb(245 208 254 / 0.5);
}

.bg-fuchsia-200\/55 {
  background-color: rgb(245 208 254 / 0.55);
}

.bg-fuchsia-200\/60 {
  background-color: rgb(245 208 254 / 0.6);
}

.bg-fuchsia-200\/65 {
  background-color: rgb(245 208 254 / 0.65);
}

.bg-fuchsia-200\/70 {
  background-color: rgb(245 208 254 / 0.7);
}

.bg-fuchsia-200\/75 {
  background-color: rgb(245 208 254 / 0.75);
}

.bg-fuchsia-200\/80 {
  background-color: rgb(245 208 254 / 0.8);
}

.bg-fuchsia-200\/85 {
  background-color: rgb(245 208 254 / 0.85);
}

.bg-fuchsia-200\/90 {
  background-color: rgb(245 208 254 / 0.9);
}

.bg-fuchsia-200\/95 {
  background-color: rgb(245 208 254 / 0.95);
}

.bg-fuchsia-300 {
  --tw-bg-opacity: 1;
  background-color: rgb(240 171 252 / var(--tw-bg-opacity));
}

.bg-fuchsia-300\/0 {
  background-color: rgb(240 171 252 / 0);
}

.bg-fuchsia-300\/10 {
  background-color: rgb(240 171 252 / 0.1);
}

.bg-fuchsia-300\/100 {
  background-color: rgb(240 171 252 / 1);
}

.bg-fuchsia-300\/15 {
  background-color: rgb(240 171 252 / 0.15);
}

.bg-fuchsia-300\/20 {
  background-color: rgb(240 171 252 / 0.2);
}

.bg-fuchsia-300\/25 {
  background-color: rgb(240 171 252 / 0.25);
}

.bg-fuchsia-300\/30 {
  background-color: rgb(240 171 252 / 0.3);
}

.bg-fuchsia-300\/35 {
  background-color: rgb(240 171 252 / 0.35);
}

.bg-fuchsia-300\/40 {
  background-color: rgb(240 171 252 / 0.4);
}

.bg-fuchsia-300\/45 {
  background-color: rgb(240 171 252 / 0.45);
}

.bg-fuchsia-300\/5 {
  background-color: rgb(240 171 252 / 0.05);
}

.bg-fuchsia-300\/50 {
  background-color: rgb(240 171 252 / 0.5);
}

.bg-fuchsia-300\/55 {
  background-color: rgb(240 171 252 / 0.55);
}

.bg-fuchsia-300\/60 {
  background-color: rgb(240 171 252 / 0.6);
}

.bg-fuchsia-300\/65 {
  background-color: rgb(240 171 252 / 0.65);
}

.bg-fuchsia-300\/70 {
  background-color: rgb(240 171 252 / 0.7);
}

.bg-fuchsia-300\/75 {
  background-color: rgb(240 171 252 / 0.75);
}

.bg-fuchsia-300\/80 {
  background-color: rgb(240 171 252 / 0.8);
}

.bg-fuchsia-300\/85 {
  background-color: rgb(240 171 252 / 0.85);
}

.bg-fuchsia-300\/90 {
  background-color: rgb(240 171 252 / 0.9);
}

.bg-fuchsia-300\/95 {
  background-color: rgb(240 171 252 / 0.95);
}

.bg-fuchsia-400 {
  --tw-bg-opacity: 1;
  background-color: rgb(232 121 249 / var(--tw-bg-opacity));
}

.bg-fuchsia-400\/0 {
  background-color: rgb(232 121 249 / 0);
}

.bg-fuchsia-400\/10 {
  background-color: rgb(232 121 249 / 0.1);
}

.bg-fuchsia-400\/100 {
  background-color: rgb(232 121 249 / 1);
}

.bg-fuchsia-400\/15 {
  background-color: rgb(232 121 249 / 0.15);
}

.bg-fuchsia-400\/20 {
  background-color: rgb(232 121 249 / 0.2);
}

.bg-fuchsia-400\/25 {
  background-color: rgb(232 121 249 / 0.25);
}

.bg-fuchsia-400\/30 {
  background-color: rgb(232 121 249 / 0.3);
}

.bg-fuchsia-400\/35 {
  background-color: rgb(232 121 249 / 0.35);
}

.bg-fuchsia-400\/40 {
  background-color: rgb(232 121 249 / 0.4);
}

.bg-fuchsia-400\/45 {
  background-color: rgb(232 121 249 / 0.45);
}

.bg-fuchsia-400\/5 {
  background-color: rgb(232 121 249 / 0.05);
}

.bg-fuchsia-400\/50 {
  background-color: rgb(232 121 249 / 0.5);
}

.bg-fuchsia-400\/55 {
  background-color: rgb(232 121 249 / 0.55);
}

.bg-fuchsia-400\/60 {
  background-color: rgb(232 121 249 / 0.6);
}

.bg-fuchsia-400\/65 {
  background-color: rgb(232 121 249 / 0.65);
}

.bg-fuchsia-400\/70 {
  background-color: rgb(232 121 249 / 0.7);
}

.bg-fuchsia-400\/75 {
  background-color: rgb(232 121 249 / 0.75);
}

.bg-fuchsia-400\/80 {
  background-color: rgb(232 121 249 / 0.8);
}

.bg-fuchsia-400\/85 {
  background-color: rgb(232 121 249 / 0.85);
}

.bg-fuchsia-400\/90 {
  background-color: rgb(232 121 249 / 0.9);
}

.bg-fuchsia-400\/95 {
  background-color: rgb(232 121 249 / 0.95);
}

.bg-fuchsia-50 {
  --tw-bg-opacity: 1;
  background-color: rgb(253 244 255 / var(--tw-bg-opacity));
}

.bg-fuchsia-50\/0 {
  background-color: rgb(253 244 255 / 0);
}

.bg-fuchsia-50\/10 {
  background-color: rgb(253 244 255 / 0.1);
}

.bg-fuchsia-50\/100 {
  background-color: rgb(253 244 255 / 1);
}

.bg-fuchsia-50\/15 {
  background-color: rgb(253 244 255 / 0.15);
}

.bg-fuchsia-50\/20 {
  background-color: rgb(253 244 255 / 0.2);
}

.bg-fuchsia-50\/25 {
  background-color: rgb(253 244 255 / 0.25);
}

.bg-fuchsia-50\/30 {
  background-color: rgb(253 244 255 / 0.3);
}

.bg-fuchsia-50\/35 {
  background-color: rgb(253 244 255 / 0.35);
}

.bg-fuchsia-50\/40 {
  background-color: rgb(253 244 255 / 0.4);
}

.bg-fuchsia-50\/45 {
  background-color: rgb(253 244 255 / 0.45);
}

.bg-fuchsia-50\/5 {
  background-color: rgb(253 244 255 / 0.05);
}

.bg-fuchsia-50\/50 {
  background-color: rgb(253 244 255 / 0.5);
}

.bg-fuchsia-50\/55 {
  background-color: rgb(253 244 255 / 0.55);
}

.bg-fuchsia-50\/60 {
  background-color: rgb(253 244 255 / 0.6);
}

.bg-fuchsia-50\/65 {
  background-color: rgb(253 244 255 / 0.65);
}

.bg-fuchsia-50\/70 {
  background-color: rgb(253 244 255 / 0.7);
}

.bg-fuchsia-50\/75 {
  background-color: rgb(253 244 255 / 0.75);
}

.bg-fuchsia-50\/80 {
  background-color: rgb(253 244 255 / 0.8);
}

.bg-fuchsia-50\/85 {
  background-color: rgb(253 244 255 / 0.85);
}

.bg-fuchsia-50\/90 {
  background-color: rgb(253 244 255 / 0.9);
}

.bg-fuchsia-50\/95 {
  background-color: rgb(253 244 255 / 0.95);
}

.bg-fuchsia-500 {
  --tw-bg-opacity: 1;
  background-color: rgb(217 70 239 / var(--tw-bg-opacity));
}

.bg-fuchsia-500\/0 {
  background-color: rgb(217 70 239 / 0);
}

.bg-fuchsia-500\/10 {
  background-color: rgb(217 70 239 / 0.1);
}

.bg-fuchsia-500\/100 {
  background-color: rgb(217 70 239 / 1);
}

.bg-fuchsia-500\/15 {
  background-color: rgb(217 70 239 / 0.15);
}

.bg-fuchsia-500\/20 {
  background-color: rgb(217 70 239 / 0.2);
}

.bg-fuchsia-500\/25 {
  background-color: rgb(217 70 239 / 0.25);
}

.bg-fuchsia-500\/30 {
  background-color: rgb(217 70 239 / 0.3);
}

.bg-fuchsia-500\/35 {
  background-color: rgb(217 70 239 / 0.35);
}

.bg-fuchsia-500\/40 {
  background-color: rgb(217 70 239 / 0.4);
}

.bg-fuchsia-500\/45 {
  background-color: rgb(217 70 239 / 0.45);
}

.bg-fuchsia-500\/5 {
  background-color: rgb(217 70 239 / 0.05);
}

.bg-fuchsia-500\/50 {
  background-color: rgb(217 70 239 / 0.5);
}

.bg-fuchsia-500\/55 {
  background-color: rgb(217 70 239 / 0.55);
}

.bg-fuchsia-500\/60 {
  background-color: rgb(217 70 239 / 0.6);
}

.bg-fuchsia-500\/65 {
  background-color: rgb(217 70 239 / 0.65);
}

.bg-fuchsia-500\/70 {
  background-color: rgb(217 70 239 / 0.7);
}

.bg-fuchsia-500\/75 {
  background-color: rgb(217 70 239 / 0.75);
}

.bg-fuchsia-500\/80 {
  background-color: rgb(217 70 239 / 0.8);
}

.bg-fuchsia-500\/85 {
  background-color: rgb(217 70 239 / 0.85);
}

.bg-fuchsia-500\/90 {
  background-color: rgb(217 70 239 / 0.9);
}

.bg-fuchsia-500\/95 {
  background-color: rgb(217 70 239 / 0.95);
}

.bg-fuchsia-600 {
  --tw-bg-opacity: 1;
  background-color: rgb(192 38 211 / var(--tw-bg-opacity));
}

.bg-fuchsia-600\/0 {
  background-color: rgb(192 38 211 / 0);
}

.bg-fuchsia-600\/10 {
  background-color: rgb(192 38 211 / 0.1);
}

.bg-fuchsia-600\/100 {
  background-color: rgb(192 38 211 / 1);
}

.bg-fuchsia-600\/15 {
  background-color: rgb(192 38 211 / 0.15);
}

.bg-fuchsia-600\/20 {
  background-color: rgb(192 38 211 / 0.2);
}

.bg-fuchsia-600\/25 {
  background-color: rgb(192 38 211 / 0.25);
}

.bg-fuchsia-600\/30 {
  background-color: rgb(192 38 211 / 0.3);
}

.bg-fuchsia-600\/35 {
  background-color: rgb(192 38 211 / 0.35);
}

.bg-fuchsia-600\/40 {
  background-color: rgb(192 38 211 / 0.4);
}

.bg-fuchsia-600\/45 {
  background-color: rgb(192 38 211 / 0.45);
}

.bg-fuchsia-600\/5 {
  background-color: rgb(192 38 211 / 0.05);
}

.bg-fuchsia-600\/50 {
  background-color: rgb(192 38 211 / 0.5);
}

.bg-fuchsia-600\/55 {
  background-color: rgb(192 38 211 / 0.55);
}

.bg-fuchsia-600\/60 {
  background-color: rgb(192 38 211 / 0.6);
}

.bg-fuchsia-600\/65 {
  background-color: rgb(192 38 211 / 0.65);
}

.bg-fuchsia-600\/70 {
  background-color: rgb(192 38 211 / 0.7);
}

.bg-fuchsia-600\/75 {
  background-color: rgb(192 38 211 / 0.75);
}

.bg-fuchsia-600\/80 {
  background-color: rgb(192 38 211 / 0.8);
}

.bg-fuchsia-600\/85 {
  background-color: rgb(192 38 211 / 0.85);
}

.bg-fuchsia-600\/90 {
  background-color: rgb(192 38 211 / 0.9);
}

.bg-fuchsia-600\/95 {
  background-color: rgb(192 38 211 / 0.95);
}

.bg-fuchsia-700 {
  --tw-bg-opacity: 1;
  background-color: rgb(162 28 175 / var(--tw-bg-opacity));
}

.bg-fuchsia-700\/0 {
  background-color: rgb(162 28 175 / 0);
}

.bg-fuchsia-700\/10 {
  background-color: rgb(162 28 175 / 0.1);
}

.bg-fuchsia-700\/100 {
  background-color: rgb(162 28 175 / 1);
}

.bg-fuchsia-700\/15 {
  background-color: rgb(162 28 175 / 0.15);
}

.bg-fuchsia-700\/20 {
  background-color: rgb(162 28 175 / 0.2);
}

.bg-fuchsia-700\/25 {
  background-color: rgb(162 28 175 / 0.25);
}

.bg-fuchsia-700\/30 {
  background-color: rgb(162 28 175 / 0.3);
}

.bg-fuchsia-700\/35 {
  background-color: rgb(162 28 175 / 0.35);
}

.bg-fuchsia-700\/40 {
  background-color: rgb(162 28 175 / 0.4);
}

.bg-fuchsia-700\/45 {
  background-color: rgb(162 28 175 / 0.45);
}

.bg-fuchsia-700\/5 {
  background-color: rgb(162 28 175 / 0.05);
}

.bg-fuchsia-700\/50 {
  background-color: rgb(162 28 175 / 0.5);
}

.bg-fuchsia-700\/55 {
  background-color: rgb(162 28 175 / 0.55);
}

.bg-fuchsia-700\/60 {
  background-color: rgb(162 28 175 / 0.6);
}

.bg-fuchsia-700\/65 {
  background-color: rgb(162 28 175 / 0.65);
}

.bg-fuchsia-700\/70 {
  background-color: rgb(162 28 175 / 0.7);
}

.bg-fuchsia-700\/75 {
  background-color: rgb(162 28 175 / 0.75);
}

.bg-fuchsia-700\/80 {
  background-color: rgb(162 28 175 / 0.8);
}

.bg-fuchsia-700\/85 {
  background-color: rgb(162 28 175 / 0.85);
}

.bg-fuchsia-700\/90 {
  background-color: rgb(162 28 175 / 0.9);
}

.bg-fuchsia-700\/95 {
  background-color: rgb(162 28 175 / 0.95);
}

.bg-fuchsia-800 {
  --tw-bg-opacity: 1;
  background-color: rgb(134 25 143 / var(--tw-bg-opacity));
}

.bg-fuchsia-800\/0 {
  background-color: rgb(134 25 143 / 0);
}

.bg-fuchsia-800\/10 {
  background-color: rgb(134 25 143 / 0.1);
}

.bg-fuchsia-800\/100 {
  background-color: rgb(134 25 143 / 1);
}

.bg-fuchsia-800\/15 {
  background-color: rgb(134 25 143 / 0.15);
}

.bg-fuchsia-800\/20 {
  background-color: rgb(134 25 143 / 0.2);
}

.bg-fuchsia-800\/25 {
  background-color: rgb(134 25 143 / 0.25);
}

.bg-fuchsia-800\/30 {
  background-color: rgb(134 25 143 / 0.3);
}

.bg-fuchsia-800\/35 {
  background-color: rgb(134 25 143 / 0.35);
}

.bg-fuchsia-800\/40 {
  background-color: rgb(134 25 143 / 0.4);
}

.bg-fuchsia-800\/45 {
  background-color: rgb(134 25 143 / 0.45);
}

.bg-fuchsia-800\/5 {
  background-color: rgb(134 25 143 / 0.05);
}

.bg-fuchsia-800\/50 {
  background-color: rgb(134 25 143 / 0.5);
}

.bg-fuchsia-800\/55 {
  background-color: rgb(134 25 143 / 0.55);
}

.bg-fuchsia-800\/60 {
  background-color: rgb(134 25 143 / 0.6);
}

.bg-fuchsia-800\/65 {
  background-color: rgb(134 25 143 / 0.65);
}

.bg-fuchsia-800\/70 {
  background-color: rgb(134 25 143 / 0.7);
}

.bg-fuchsia-800\/75 {
  background-color: rgb(134 25 143 / 0.75);
}

.bg-fuchsia-800\/80 {
  background-color: rgb(134 25 143 / 0.8);
}

.bg-fuchsia-800\/85 {
  background-color: rgb(134 25 143 / 0.85);
}

.bg-fuchsia-800\/90 {
  background-color: rgb(134 25 143 / 0.9);
}

.bg-fuchsia-800\/95 {
  background-color: rgb(134 25 143 / 0.95);
}

.bg-fuchsia-900 {
  --tw-bg-opacity: 1;
  background-color: rgb(112 26 117 / var(--tw-bg-opacity));
}

.bg-fuchsia-900\/0 {
  background-color: rgb(112 26 117 / 0);
}

.bg-fuchsia-900\/10 {
  background-color: rgb(112 26 117 / 0.1);
}

.bg-fuchsia-900\/100 {
  background-color: rgb(112 26 117 / 1);
}

.bg-fuchsia-900\/15 {
  background-color: rgb(112 26 117 / 0.15);
}

.bg-fuchsia-900\/20 {
  background-color: rgb(112 26 117 / 0.2);
}

.bg-fuchsia-900\/25 {
  background-color: rgb(112 26 117 / 0.25);
}

.bg-fuchsia-900\/30 {
  background-color: rgb(112 26 117 / 0.3);
}

.bg-fuchsia-900\/35 {
  background-color: rgb(112 26 117 / 0.35);
}

.bg-fuchsia-900\/40 {
  background-color: rgb(112 26 117 / 0.4);
}

.bg-fuchsia-900\/45 {
  background-color: rgb(112 26 117 / 0.45);
}

.bg-fuchsia-900\/5 {
  background-color: rgb(112 26 117 / 0.05);
}

.bg-fuchsia-900\/50 {
  background-color: rgb(112 26 117 / 0.5);
}

.bg-fuchsia-900\/55 {
  background-color: rgb(112 26 117 / 0.55);
}

.bg-fuchsia-900\/60 {
  background-color: rgb(112 26 117 / 0.6);
}

.bg-fuchsia-900\/65 {
  background-color: rgb(112 26 117 / 0.65);
}

.bg-fuchsia-900\/70 {
  background-color: rgb(112 26 117 / 0.7);
}

.bg-fuchsia-900\/75 {
  background-color: rgb(112 26 117 / 0.75);
}

.bg-fuchsia-900\/80 {
  background-color: rgb(112 26 117 / 0.8);
}

.bg-fuchsia-900\/85 {
  background-color: rgb(112 26 117 / 0.85);
}

.bg-fuchsia-900\/90 {
  background-color: rgb(112 26 117 / 0.9);
}

.bg-fuchsia-900\/95 {
  background-color: rgb(112 26 117 / 0.95);
}

.bg-fuchsia-950 {
  --tw-bg-opacity: 1;
  background-color: rgb(74 4 78 / var(--tw-bg-opacity));
}

.bg-fuchsia-950\/0 {
  background-color: rgb(74 4 78 / 0);
}

.bg-fuchsia-950\/10 {
  background-color: rgb(74 4 78 / 0.1);
}

.bg-fuchsia-950\/100 {
  background-color: rgb(74 4 78 / 1);
}

.bg-fuchsia-950\/15 {
  background-color: rgb(74 4 78 / 0.15);
}

.bg-fuchsia-950\/20 {
  background-color: rgb(74 4 78 / 0.2);
}

.bg-fuchsia-950\/25 {
  background-color: rgb(74 4 78 / 0.25);
}

.bg-fuchsia-950\/30 {
  background-color: rgb(74 4 78 / 0.3);
}

.bg-fuchsia-950\/35 {
  background-color: rgb(74 4 78 / 0.35);
}

.bg-fuchsia-950\/40 {
  background-color: rgb(74 4 78 / 0.4);
}

.bg-fuchsia-950\/45 {
  background-color: rgb(74 4 78 / 0.45);
}

.bg-fuchsia-950\/5 {
  background-color: rgb(74 4 78 / 0.05);
}

.bg-fuchsia-950\/50 {
  background-color: rgb(74 4 78 / 0.5);
}

.bg-fuchsia-950\/55 {
  background-color: rgb(74 4 78 / 0.55);
}

.bg-fuchsia-950\/60 {
  background-color: rgb(74 4 78 / 0.6);
}

.bg-fuchsia-950\/65 {
  background-color: rgb(74 4 78 / 0.65);
}

.bg-fuchsia-950\/70 {
  background-color: rgb(74 4 78 / 0.7);
}

.bg-fuchsia-950\/75 {
  background-color: rgb(74 4 78 / 0.75);
}

.bg-fuchsia-950\/80 {
  background-color: rgb(74 4 78 / 0.8);
}

.bg-fuchsia-950\/85 {
  background-color: rgb(74 4 78 / 0.85);
}

.bg-fuchsia-950\/90 {
  background-color: rgb(74 4 78 / 0.9);
}

.bg-fuchsia-950\/95 {
  background-color: rgb(74 4 78 / 0.95);
}

.bg-gray-100 {
  --tw-bg-opacity: 1;
  background-color: rgb(243 244 246 / var(--tw-bg-opacity));
}

.bg-gray-100\/0 {
  background-color: rgb(243 244 246 / 0);
}

.bg-gray-100\/10 {
  background-color: rgb(243 244 246 / 0.1);
}

.bg-gray-100\/100 {
  background-color: rgb(243 244 246 / 1);
}

.bg-gray-100\/15 {
  background-color: rgb(243 244 246 / 0.15);
}

.bg-gray-100\/20 {
  background-color: rgb(243 244 246 / 0.2);
}

.bg-gray-100\/25 {
  background-color: rgb(243 244 246 / 0.25);
}

.bg-gray-100\/30 {
  background-color: rgb(243 244 246 / 0.3);
}

.bg-gray-100\/35 {
  background-color: rgb(243 244 246 / 0.35);
}

.bg-gray-100\/40 {
  background-color: rgb(243 244 246 / 0.4);
}

.bg-gray-100\/45 {
  background-color: rgb(243 244 246 / 0.45);
}

.bg-gray-100\/5 {
  background-color: rgb(243 244 246 / 0.05);
}

.bg-gray-100\/50 {
  background-color: rgb(243 244 246 / 0.5);
}

.bg-gray-100\/55 {
  background-color: rgb(243 244 246 / 0.55);
}

.bg-gray-100\/60 {
  background-color: rgb(243 244 246 / 0.6);
}

.bg-gray-100\/65 {
  background-color: rgb(243 244 246 / 0.65);
}

.bg-gray-100\/70 {
  background-color: rgb(243 244 246 / 0.7);
}

.bg-gray-100\/75 {
  background-color: rgb(243 244 246 / 0.75);
}

.bg-gray-100\/80 {
  background-color: rgb(243 244 246 / 0.8);
}

.bg-gray-100\/85 {
  background-color: rgb(243 244 246 / 0.85);
}

.bg-gray-100\/90 {
  background-color: rgb(243 244 246 / 0.9);
}

.bg-gray-100\/95 {
  background-color: rgb(243 244 246 / 0.95);
}

.bg-gray-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(229 231 235 / var(--tw-bg-opacity));
}

.bg-gray-200\/0 {
  background-color: rgb(229 231 235 / 0);
}

.bg-gray-200\/10 {
  background-color: rgb(229 231 235 / 0.1);
}

.bg-gray-200\/100 {
  background-color: rgb(229 231 235 / 1);
}

.bg-gray-200\/15 {
  background-color: rgb(229 231 235 / 0.15);
}

.bg-gray-200\/20 {
  background-color: rgb(229 231 235 / 0.2);
}

.bg-gray-200\/25 {
  background-color: rgb(229 231 235 / 0.25);
}

.bg-gray-200\/30 {
  background-color: rgb(229 231 235 / 0.3);
}

.bg-gray-200\/35 {
  background-color: rgb(229 231 235 / 0.35);
}

.bg-gray-200\/40 {
  background-color: rgb(229 231 235 / 0.4);
}

.bg-gray-200\/45 {
  background-color: rgb(229 231 235 / 0.45);
}

.bg-gray-200\/5 {
  background-color: rgb(229 231 235 / 0.05);
}

.bg-gray-200\/50 {
  background-color: rgb(229 231 235 / 0.5);
}

.bg-gray-200\/55 {
  background-color: rgb(229 231 235 / 0.55);
}

.bg-gray-200\/60 {
  background-color: rgb(229 231 235 / 0.6);
}

.bg-gray-200\/65 {
  background-color: rgb(229 231 235 / 0.65);
}

.bg-gray-200\/70 {
  background-color: rgb(229 231 235 / 0.7);
}

.bg-gray-200\/75 {
  background-color: rgb(229 231 235 / 0.75);
}

.bg-gray-200\/80 {
  background-color: rgb(229 231 235 / 0.8);
}

.bg-gray-200\/85 {
  background-color: rgb(229 231 235 / 0.85);
}

.bg-gray-200\/90 {
  background-color: rgb(229 231 235 / 0.9);
}

.bg-gray-200\/95 {
  background-color: rgb(229 231 235 / 0.95);
}

.bg-gray-300 {
  --tw-bg-opacity: 1;
  background-color: rgb(209 213 219 / var(--tw-bg-opacity));
}

.bg-gray-300\/0 {
  background-color: rgb(209 213 219 / 0);
}

.bg-gray-300\/10 {
  background-color: rgb(209 213 219 / 0.1);
}

.bg-gray-300\/100 {
  background-color: rgb(209 213 219 / 1);
}

.bg-gray-300\/15 {
  background-color: rgb(209 213 219 / 0.15);
}

.bg-gray-300\/20 {
  background-color: rgb(209 213 219 / 0.2);
}

.bg-gray-300\/25 {
  background-color: rgb(209 213 219 / 0.25);
}

.bg-gray-300\/30 {
  background-color: rgb(209 213 219 / 0.3);
}

.bg-gray-300\/35 {
  background-color: rgb(209 213 219 / 0.35);
}

.bg-gray-300\/40 {
  background-color: rgb(209 213 219 / 0.4);
}

.bg-gray-300\/45 {
  background-color: rgb(209 213 219 / 0.45);
}

.bg-gray-300\/5 {
  background-color: rgb(209 213 219 / 0.05);
}

.bg-gray-300\/50 {
  background-color: rgb(209 213 219 / 0.5);
}

.bg-gray-300\/55 {
  background-color: rgb(209 213 219 / 0.55);
}

.bg-gray-300\/60 {
  background-color: rgb(209 213 219 / 0.6);
}

.bg-gray-300\/65 {
  background-color: rgb(209 213 219 / 0.65);
}

.bg-gray-300\/70 {
  background-color: rgb(209 213 219 / 0.7);
}

.bg-gray-300\/75 {
  background-color: rgb(209 213 219 / 0.75);
}

.bg-gray-300\/80 {
  background-color: rgb(209 213 219 / 0.8);
}

.bg-gray-300\/85 {
  background-color: rgb(209 213 219 / 0.85);
}

.bg-gray-300\/90 {
  background-color: rgb(209 213 219 / 0.9);
}

.bg-gray-300\/95 {
  background-color: rgb(209 213 219 / 0.95);
}

.bg-gray-400 {
  --tw-bg-opacity: 1;
  background-color: rgb(156 163 175 / var(--tw-bg-opacity));
}

.bg-gray-400\/0 {
  background-color: rgb(156 163 175 / 0);
}

.bg-gray-400\/10 {
  background-color: rgb(156 163 175 / 0.1);
}

.bg-gray-400\/100 {
  background-color: rgb(156 163 175 / 1);
}

.bg-gray-400\/15 {
  background-color: rgb(156 163 175 / 0.15);
}

.bg-gray-400\/20 {
  background-color: rgb(156 163 175 / 0.2);
}

.bg-gray-400\/25 {
  background-color: rgb(156 163 175 / 0.25);
}

.bg-gray-400\/30 {
  background-color: rgb(156 163 175 / 0.3);
}

.bg-gray-400\/35 {
  background-color: rgb(156 163 175 / 0.35);
}

.bg-gray-400\/40 {
  background-color: rgb(156 163 175 / 0.4);
}

.bg-gray-400\/45 {
  background-color: rgb(156 163 175 / 0.45);
}

.bg-gray-400\/5 {
  background-color: rgb(156 163 175 / 0.05);
}

.bg-gray-400\/50 {
  background-color: rgb(156 163 175 / 0.5);
}

.bg-gray-400\/55 {
  background-color: rgb(156 163 175 / 0.55);
}

.bg-gray-400\/60 {
  background-color: rgb(156 163 175 / 0.6);
}

.bg-gray-400\/65 {
  background-color: rgb(156 163 175 / 0.65);
}

.bg-gray-400\/70 {
  background-color: rgb(156 163 175 / 0.7);
}

.bg-gray-400\/75 {
  background-color: rgb(156 163 175 / 0.75);
}

.bg-gray-400\/80 {
  background-color: rgb(156 163 175 / 0.8);
}

.bg-gray-400\/85 {
  background-color: rgb(156 163 175 / 0.85);
}

.bg-gray-400\/90 {
  background-color: rgb(156 163 175 / 0.9);
}

.bg-gray-400\/95 {
  background-color: rgb(156 163 175 / 0.95);
}

.bg-gray-50 {
  --tw-bg-opacity: 1;
  background-color: rgb(249 250 251 / var(--tw-bg-opacity));
}

.bg-gray-50\/0 {
  background-color: rgb(249 250 251 / 0);
}

.bg-gray-50\/10 {
  background-color: rgb(249 250 251 / 0.1);
}

.bg-gray-50\/100 {
  background-color: rgb(249 250 251 / 1);
}

.bg-gray-50\/15 {
  background-color: rgb(249 250 251 / 0.15);
}

.bg-gray-50\/20 {
  background-color: rgb(249 250 251 / 0.2);
}

.bg-gray-50\/25 {
  background-color: rgb(249 250 251 / 0.25);
}

.bg-gray-50\/30 {
  background-color: rgb(249 250 251 / 0.3);
}

.bg-gray-50\/35 {
  background-color: rgb(249 250 251 / 0.35);
}

.bg-gray-50\/40 {
  background-color: rgb(249 250 251 / 0.4);
}

.bg-gray-50\/45 {
  background-color: rgb(249 250 251 / 0.45);
}

.bg-gray-50\/5 {
  background-color: rgb(249 250 251 / 0.05);
}

.bg-gray-50\/50 {
  background-color: rgb(249 250 251 / 0.5);
}

.bg-gray-50\/55 {
  background-color: rgb(249 250 251 / 0.55);
}

.bg-gray-50\/60 {
  background-color: rgb(249 250 251 / 0.6);
}

.bg-gray-50\/65 {
  background-color: rgb(249 250 251 / 0.65);
}

.bg-gray-50\/70 {
  background-color: rgb(249 250 251 / 0.7);
}

.bg-gray-50\/75 {
  background-color: rgb(249 250 251 / 0.75);
}

.bg-gray-50\/80 {
  background-color: rgb(249 250 251 / 0.8);
}

.bg-gray-50\/85 {
  background-color: rgb(249 250 251 / 0.85);
}

.bg-gray-50\/90 {
  background-color: rgb(249 250 251 / 0.9);
}

.bg-gray-50\/95 {
  background-color: rgb(249 250 251 / 0.95);
}

.bg-gray-500 {
  --tw-bg-opacity: 1;
  background-color: rgb(107 114 128 / var(--tw-bg-opacity));
}

.bg-gray-500\/0 {
  background-color: rgb(107 114 128 / 0);
}

.bg-gray-500\/10 {
  background-color: rgb(107 114 128 / 0.1);
}

.bg-gray-500\/100 {
  background-color: rgb(107 114 128 / 1);
}

.bg-gray-500\/15 {
  background-color: rgb(107 114 128 / 0.15);
}

.bg-gray-500\/20 {
  background-color: rgb(107 114 128 / 0.2);
}

.bg-gray-500\/25 {
  background-color: rgb(107 114 128 / 0.25);
}

.bg-gray-500\/30 {
  background-color: rgb(107 114 128 / 0.3);
}

.bg-gray-500\/35 {
  background-color: rgb(107 114 128 / 0.35);
}

.bg-gray-500\/40 {
  background-color: rgb(107 114 128 / 0.4);
}

.bg-gray-500\/45 {
  background-color: rgb(107 114 128 / 0.45);
}

.bg-gray-500\/5 {
  background-color: rgb(107 114 128 / 0.05);
}

.bg-gray-500\/50 {
  background-color: rgb(107 114 128 / 0.5);
}

.bg-gray-500\/55 {
  background-color: rgb(107 114 128 / 0.55);
}

.bg-gray-500\/60 {
  background-color: rgb(107 114 128 / 0.6);
}

.bg-gray-500\/65 {
  background-color: rgb(107 114 128 / 0.65);
}

.bg-gray-500\/70 {
  background-color: rgb(107 114 128 / 0.7);
}

.bg-gray-500\/75 {
  background-color: rgb(107 114 128 / 0.75);
}

.bg-gray-500\/80 {
  background-color: rgb(107 114 128 / 0.8);
}

.bg-gray-500\/85 {
  background-color: rgb(107 114 128 / 0.85);
}

.bg-gray-500\/90 {
  background-color: rgb(107 114 128 / 0.9);
}

.bg-gray-500\/95 {
  background-color: rgb(107 114 128 / 0.95);
}

.bg-gray-600 {
  --tw-bg-opacity: 1;
  background-color: rgb(75 85 99 / var(--tw-bg-opacity));
}

.bg-gray-600\/0 {
  background-color: rgb(75 85 99 / 0);
}

.bg-gray-600\/10 {
  background-color: rgb(75 85 99 / 0.1);
}

.bg-gray-600\/100 {
  background-color: rgb(75 85 99 / 1);
}

.bg-gray-600\/15 {
  background-color: rgb(75 85 99 / 0.15);
}

.bg-gray-600\/20 {
  background-color: rgb(75 85 99 / 0.2);
}

.bg-gray-600\/25 {
  background-color: rgb(75 85 99 / 0.25);
}

.bg-gray-600\/30 {
  background-color: rgb(75 85 99 / 0.3);
}

.bg-gray-600\/35 {
  background-color: rgb(75 85 99 / 0.35);
}

.bg-gray-600\/40 {
  background-color: rgb(75 85 99 / 0.4);
}

.bg-gray-600\/45 {
  background-color: rgb(75 85 99 / 0.45);
}

.bg-gray-600\/5 {
  background-color: rgb(75 85 99 / 0.05);
}

.bg-gray-600\/50 {
  background-color: rgb(75 85 99 / 0.5);
}

.bg-gray-600\/55 {
  background-color: rgb(75 85 99 / 0.55);
}

.bg-gray-600\/60 {
  background-color: rgb(75 85 99 / 0.6);
}

.bg-gray-600\/65 {
  background-color: rgb(75 85 99 / 0.65);
}

.bg-gray-600\/70 {
  background-color: rgb(75 85 99 / 0.7);
}

.bg-gray-600\/75 {
  background-color: rgb(75 85 99 / 0.75);
}

.bg-gray-600\/80 {
  background-color: rgb(75 85 99 / 0.8);
}

.bg-gray-600\/85 {
  background-color: rgb(75 85 99 / 0.85);
}

.bg-gray-600\/90 {
  background-color: rgb(75 85 99 / 0.9);
}

.bg-gray-600\/95 {
  background-color: rgb(75 85 99 / 0.95);
}

.bg-gray-700 {
  --tw-bg-opacity: 1;
  background-color: rgb(55 65 81 / var(--tw-bg-opacity));
}

.bg-gray-700\/0 {
  background-color: rgb(55 65 81 / 0);
}

.bg-gray-700\/10 {
  background-color: rgb(55 65 81 / 0.1);
}

.bg-gray-700\/100 {
  background-color: rgb(55 65 81 / 1);
}

.bg-gray-700\/15 {
  background-color: rgb(55 65 81 / 0.15);
}

.bg-gray-700\/20 {
  background-color: rgb(55 65 81 / 0.2);
}

.bg-gray-700\/25 {
  background-color: rgb(55 65 81 / 0.25);
}

.bg-gray-700\/30 {
  background-color: rgb(55 65 81 / 0.3);
}

.bg-gray-700\/35 {
  background-color: rgb(55 65 81 / 0.35);
}

.bg-gray-700\/40 {
  background-color: rgb(55 65 81 / 0.4);
}

.bg-gray-700\/45 {
  background-color: rgb(55 65 81 / 0.45);
}

.bg-gray-700\/5 {
  background-color: rgb(55 65 81 / 0.05);
}

.bg-gray-700\/50 {
  background-color: rgb(55 65 81 / 0.5);
}

.bg-gray-700\/55 {
  background-color: rgb(55 65 81 / 0.55);
}

.bg-gray-700\/60 {
  background-color: rgb(55 65 81 / 0.6);
}

.bg-gray-700\/65 {
  background-color: rgb(55 65 81 / 0.65);
}

.bg-gray-700\/70 {
  background-color: rgb(55 65 81 / 0.7);
}

.bg-gray-700\/75 {
  background-color: rgb(55 65 81 / 0.75);
}

.bg-gray-700\/80 {
  background-color: rgb(55 65 81 / 0.8);
}

.bg-gray-700\/85 {
  background-color: rgb(55 65 81 / 0.85);
}

.bg-gray-700\/90 {
  background-color: rgb(55 65 81 / 0.9);
}

.bg-gray-700\/95 {
  background-color: rgb(55 65 81 / 0.95);
}

.bg-gray-800 {
  --tw-bg-opacity: 1;
  background-color: rgb(31 41 55 / var(--tw-bg-opacity));
}

.bg-gray-800\/0 {
  background-color: rgb(31 41 55 / 0);
}

.bg-gray-800\/10 {
  background-color: rgb(31 41 55 / 0.1);
}

.bg-gray-800\/100 {
  background-color: rgb(31 41 55 / 1);
}

.bg-gray-800\/15 {
  background-color: rgb(31 41 55 / 0.15);
}

.bg-gray-800\/20 {
  background-color: rgb(31 41 55 / 0.2);
}

.bg-gray-800\/25 {
  background-color: rgb(31 41 55 / 0.25);
}

.bg-gray-800\/30 {
  background-color: rgb(31 41 55 / 0.3);
}

.bg-gray-800\/35 {
  background-color: rgb(31 41 55 / 0.35);
}

.bg-gray-800\/40 {
  background-color: rgb(31 41 55 / 0.4);
}

.bg-gray-800\/45 {
  background-color: rgb(31 41 55 / 0.45);
}

.bg-gray-800\/5 {
  background-color: rgb(31 41 55 / 0.05);
}

.bg-gray-800\/50 {
  background-color: rgb(31 41 55 / 0.5);
}

.bg-gray-800\/55 {
  background-color: rgb(31 41 55 / 0.55);
}

.bg-gray-800\/60 {
  background-color: rgb(31 41 55 / 0.6);
}

.bg-gray-800\/65 {
  background-color: rgb(31 41 55 / 0.65);
}

.bg-gray-800\/70 {
  background-color: rgb(31 41 55 / 0.7);
}

.bg-gray-800\/75 {
  background-color: rgb(31 41 55 / 0.75);
}

.bg-gray-800\/80 {
  background-color: rgb(31 41 55 / 0.8);
}

.bg-gray-800\/85 {
  background-color: rgb(31 41 55 / 0.85);
}

.bg-gray-800\/90 {
  background-color: rgb(31 41 55 / 0.9);
}

.bg-gray-800\/95 {
  background-color: rgb(31 41 55 / 0.95);
}

.bg-gray-900 {
  --tw-bg-opacity: 1;
  background-color: rgb(17 24 39 / var(--tw-bg-opacity));
}

.bg-gray-900\/0 {
  background-color: rgb(17 24 39 / 0);
}

.bg-gray-900\/10 {
  background-color: rgb(17 24 39 / 0.1);
}

.bg-gray-900\/100 {
  background-color: rgb(17 24 39 / 1);
}

.bg-gray-900\/15 {
  background-color: rgb(17 24 39 / 0.15);
}

.bg-gray-900\/20 {
  background-color: rgb(17 24 39 / 0.2);
}

.bg-gray-900\/25 {
  background-color: rgb(17 24 39 / 0.25);
}

.bg-gray-900\/30 {
  background-color: rgb(17 24 39 / 0.3);
}

.bg-gray-900\/35 {
  background-color: rgb(17 24 39 / 0.35);
}

.bg-gray-900\/40 {
  background-color: rgb(17 24 39 / 0.4);
}

.bg-gray-900\/45 {
  background-color: rgb(17 24 39 / 0.45);
}

.bg-gray-900\/5 {
  background-color: rgb(17 24 39 / 0.05);
}

.bg-gray-900\/50 {
  background-color: rgb(17 24 39 / 0.5);
}

.bg-gray-900\/55 {
  background-color: rgb(17 24 39 / 0.55);
}

.bg-gray-900\/60 {
  background-color: rgb(17 24 39 / 0.6);
}

.bg-gray-900\/65 {
  background-color: rgb(17 24 39 / 0.65);
}

.bg-gray-900\/70 {
  background-color: rgb(17 24 39 / 0.7);
}

.bg-gray-900\/75 {
  background-color: rgb(17 24 39 / 0.75);
}

.bg-gray-900\/80 {
  background-color: rgb(17 24 39 / 0.8);
}

.bg-gray-900\/85 {
  background-color: rgb(17 24 39 / 0.85);
}

.bg-gray-900\/90 {
  background-color: rgb(17 24 39 / 0.9);
}

.bg-gray-900\/95 {
  background-color: rgb(17 24 39 / 0.95);
}

.bg-gray-950 {
  --tw-bg-opacity: 1;
  background-color: rgb(3 7 18 / var(--tw-bg-opacity));
}

.bg-gray-950\/0 {
  background-color: rgb(3 7 18 / 0);
}

.bg-gray-950\/10 {
  background-color: rgb(3 7 18 / 0.1);
}

.bg-gray-950\/100 {
  background-color: rgb(3 7 18 / 1);
}

.bg-gray-950\/15 {
  background-color: rgb(3 7 18 / 0.15);
}

.bg-gray-950\/20 {
  background-color: rgb(3 7 18 / 0.2);
}

.bg-gray-950\/25 {
  background-color: rgb(3 7 18 / 0.25);
}

.bg-gray-950\/30 {
  background-color: rgb(3 7 18 / 0.3);
}

.bg-gray-950\/35 {
  background-color: rgb(3 7 18 / 0.35);
}

.bg-gray-950\/40 {
  background-color: rgb(3 7 18 / 0.4);
}

.bg-gray-950\/45 {
  background-color: rgb(3 7 18 / 0.45);
}

.bg-gray-950\/5 {
  background-color: rgb(3 7 18 / 0.05);
}

.bg-gray-950\/50 {
  background-color: rgb(3 7 18 / 0.5);
}

.bg-gray-950\/55 {
  background-color: rgb(3 7 18 / 0.55);
}

.bg-gray-950\/60 {
  background-color: rgb(3 7 18 / 0.6);
}

.bg-gray-950\/65 {
  background-color: rgb(3 7 18 / 0.65);
}

.bg-gray-950\/70 {
  background-color: rgb(3 7 18 / 0.7);
}

.bg-gray-950\/75 {
  background-color: rgb(3 7 18 / 0.75);
}

.bg-gray-950\/80 {
  background-color: rgb(3 7 18 / 0.8);
}

.bg-gray-950\/85 {
  background-color: rgb(3 7 18 / 0.85);
}

.bg-gray-950\/90 {
  background-color: rgb(3 7 18 / 0.9);
}

.bg-gray-950\/95 {
  background-color: rgb(3 7 18 / 0.95);
}

.bg-green-100 {
  --tw-bg-opacity: 1;
  background-color: rgb(220 252 231 / var(--tw-bg-opacity));
}

.bg-green-100\/0 {
  background-color: rgb(220 252 231 / 0);
}

.bg-green-100\/10 {
  background-color: rgb(220 252 231 / 0.1);
}

.bg-green-100\/100 {
  background-color: rgb(220 252 231 / 1);
}

.bg-green-100\/15 {
  background-color: rgb(220 252 231 / 0.15);
}

.bg-green-100\/20 {
  background-color: rgb(220 252 231 / 0.2);
}

.bg-green-100\/25 {
  background-color: rgb(220 252 231 / 0.25);
}

.bg-green-100\/30 {
  background-color: rgb(220 252 231 / 0.3);
}

.bg-green-100\/35 {
  background-color: rgb(220 252 231 / 0.35);
}

.bg-green-100\/40 {
  background-color: rgb(220 252 231 / 0.4);
}

.bg-green-100\/45 {
  background-color: rgb(220 252 231 / 0.45);
}

.bg-green-100\/5 {
  background-color: rgb(220 252 231 / 0.05);
}

.bg-green-100\/50 {
  background-color: rgb(220 252 231 / 0.5);
}

.bg-green-100\/55 {
  background-color: rgb(220 252 231 / 0.55);
}

.bg-green-100\/60 {
  background-color: rgb(220 252 231 / 0.6);
}

.bg-green-100\/65 {
  background-color: rgb(220 252 231 / 0.65);
}

.bg-green-100\/70 {
  background-color: rgb(220 252 231 / 0.7);
}

.bg-green-100\/75 {
  background-color: rgb(220 252 231 / 0.75);
}

.bg-green-100\/80 {
  background-color: rgb(220 252 231 / 0.8);
}

.bg-green-100\/85 {
  background-color: rgb(220 252 231 / 0.85);
}

.bg-green-100\/90 {
  background-color: rgb(220 252 231 / 0.9);
}

.bg-green-100\/95 {
  background-color: rgb(220 252 231 / 0.95);
}

.bg-green-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(187 247 208 / var(--tw-bg-opacity));
}

.bg-green-200\/0 {
  background-color: rgb(187 247 208 / 0);
}

.bg-green-200\/10 {
  background-color: rgb(187 247 208 / 0.1);
}

.bg-green-200\/100 {
  background-color: rgb(187 247 208 / 1);
}

.bg-green-200\/15 {
  background-color: rgb(187 247 208 / 0.15);
}

.bg-green-200\/20 {
  background-color: rgb(187 247 208 / 0.2);
}

.bg-green-200\/25 {
  background-color: rgb(187 247 208 / 0.25);
}

.bg-green-200\/30 {
  background-color: rgb(187 247 208 / 0.3);
}

.bg-green-200\/35 {
  background-color: rgb(187 247 208 / 0.35);
}

.bg-green-200\/40 {
  background-color: rgb(187 247 208 / 0.4);
}

.bg-green-200\/45 {
  background-color: rgb(187 247 208 / 0.45);
}

.bg-green-200\/5 {
  background-color: rgb(187 247 208 / 0.05);
}

.bg-green-200\/50 {
  background-color: rgb(187 247 208 / 0.5);
}

.bg-green-200\/55 {
  background-color: rgb(187 247 208 / 0.55);
}

.bg-green-200\/60 {
  background-color: rgb(187 247 208 / 0.6);
}

.bg-green-200\/65 {
  background-color: rgb(187 247 208 / 0.65);
}

.bg-green-200\/70 {
  background-color: rgb(187 247 208 / 0.7);
}

.bg-green-200\/75 {
  background-color: rgb(187 247 208 / 0.75);
}

.bg-green-200\/80 {
  background-color: rgb(187 247 208 / 0.8);
}

.bg-green-200\/85 {
  background-color: rgb(187 247 208 / 0.85);
}

.bg-green-200\/90 {
  background-color: rgb(187 247 208 / 0.9);
}

.bg-green-200\/95 {
  background-color: rgb(187 247 208 / 0.95);
}

.bg-green-300 {
  --tw-bg-opacity: 1;
  background-color: rgb(134 239 172 / var(--tw-bg-opacity));
}

.bg-green-300\/0 {
  background-color: rgb(134 239 172 / 0);
}

.bg-green-300\/10 {
  background-color: rgb(134 239 172 / 0.1);
}

.bg-green-300\/100 {
  background-color: rgb(134 239 172 / 1);
}

.bg-green-300\/15 {
  background-color: rgb(134 239 172 / 0.15);
}

.bg-green-300\/20 {
  background-color: rgb(134 239 172 / 0.2);
}

.bg-green-300\/25 {
  background-color: rgb(134 239 172 / 0.25);
}

.bg-green-300\/30 {
  background-color: rgb(134 239 172 / 0.3);
}

.bg-green-300\/35 {
  background-color: rgb(134 239 172 / 0.35);
}

.bg-green-300\/40 {
  background-color: rgb(134 239 172 / 0.4);
}

.bg-green-300\/45 {
  background-color: rgb(134 239 172 / 0.45);
}

.bg-green-300\/5 {
  background-color: rgb(134 239 172 / 0.05);
}

.bg-green-300\/50 {
  background-color: rgb(134 239 172 / 0.5);
}

.bg-green-300\/55 {
  background-color: rgb(134 239 172 / 0.55);
}

.bg-green-300\/60 {
  background-color: rgb(134 239 172 / 0.6);
}

.bg-green-300\/65 {
  background-color: rgb(134 239 172 / 0.65);
}

.bg-green-300\/70 {
  background-color: rgb(134 239 172 / 0.7);
}

.bg-green-300\/75 {
  background-color: rgb(134 239 172 / 0.75);
}

.bg-green-300\/80 {
  background-color: rgb(134 239 172 / 0.8);
}

.bg-green-300\/85 {
  background-color: rgb(134 239 172 / 0.85);
}

.bg-green-300\/90 {
  background-color: rgb(134 239 172 / 0.9);
}

.bg-green-300\/95 {
  background-color: rgb(134 239 172 / 0.95);
}

.bg-green-400 {
  --tw-bg-opacity: 1;
  background-color: rgb(74 222 128 / var(--tw-bg-opacity));
}

.bg-green-400\/0 {
  background-color: rgb(74 222 128 / 0);
}

.bg-green-400\/10 {
  background-color: rgb(74 222 128 / 0.1);
}

.bg-green-400\/100 {
  background-color: rgb(74 222 128 / 1);
}

.bg-green-400\/15 {
  background-color: rgb(74 222 128 / 0.15);
}

.bg-green-400\/20 {
  background-color: rgb(74 222 128 / 0.2);
}

.bg-green-400\/25 {
  background-color: rgb(74 222 128 / 0.25);
}

.bg-green-400\/30 {
  background-color: rgb(74 222 128 / 0.3);
}

.bg-green-400\/35 {
  background-color: rgb(74 222 128 / 0.35);
}

.bg-green-400\/40 {
  background-color: rgb(74 222 128 / 0.4);
}

.bg-green-400\/45 {
  background-color: rgb(74 222 128 / 0.45);
}

.bg-green-400\/5 {
  background-color: rgb(74 222 128 / 0.05);
}

.bg-green-400\/50 {
  background-color: rgb(74 222 128 / 0.5);
}

.bg-green-400\/55 {
  background-color: rgb(74 222 128 / 0.55);
}

.bg-green-400\/60 {
  background-color: rgb(74 222 128 / 0.6);
}

.bg-green-400\/65 {
  background-color: rgb(74 222 128 / 0.65);
}

.bg-green-400\/70 {
  background-color: rgb(74 222 128 / 0.7);
}

.bg-green-400\/75 {
  background-color: rgb(74 222 128 / 0.75);
}

.bg-green-400\/80 {
  background-color: rgb(74 222 128 / 0.8);
}

.bg-green-400\/85 {
  background-color: rgb(74 222 128 / 0.85);
}

.bg-green-400\/90 {
  background-color: rgb(74 222 128 / 0.9);
}

.bg-green-400\/95 {
  background-color: rgb(74 222 128 / 0.95);
}

.bg-green-50 {
  --tw-bg-opacity: 1;
  background-color: rgb(240 253 244 / var(--tw-bg-opacity));
}

.bg-green-50\/0 {
  background-color: rgb(240 253 244 / 0);
}

.bg-green-50\/10 {
  background-color: rgb(240 253 244 / 0.1);
}

.bg-green-50\/100 {
  background-color: rgb(240 253 244 / 1);
}

.bg-green-50\/15 {
  background-color: rgb(240 253 244 / 0.15);
}

.bg-green-50\/20 {
  background-color: rgb(240 253 244 / 0.2);
}

.bg-green-50\/25 {
  background-color: rgb(240 253 244 / 0.25);
}

.bg-green-50\/30 {
  background-color: rgb(240 253 244 / 0.3);
}

.bg-green-50\/35 {
  background-color: rgb(240 253 244 / 0.35);
}

.bg-green-50\/40 {
  background-color: rgb(240 253 244 / 0.4);
}

.bg-green-50\/45 {
  background-color: rgb(240 253 244 / 0.45);
}

.bg-green-50\/5 {
  background-color: rgb(240 253 244 / 0.05);
}

.bg-green-50\/50 {
  background-color: rgb(240 253 244 / 0.5);
}

.bg-green-50\/55 {
  background-color: rgb(240 253 244 / 0.55);
}

.bg-green-50\/60 {
  background-color: rgb(240 253 244 / 0.6);
}

.bg-green-50\/65 {
  background-color: rgb(240 253 244 / 0.65);
}

.bg-green-50\/70 {
  background-color: rgb(240 253 244 / 0.7);
}

.bg-green-50\/75 {
  background-color: rgb(240 253 244 / 0.75);
}

.bg-green-50\/80 {
  background-color: rgb(240 253 244 / 0.8);
}

.bg-green-50\/85 {
  background-color: rgb(240 253 244 / 0.85);
}

.bg-green-50\/90 {
  background-color: rgb(240 253 244 / 0.9);
}

.bg-green-50\/95 {
  background-color: rgb(240 253 244 / 0.95);
}

.bg-green-500 {
  --tw-bg-opacity: 1;
  background-color: rgb(34 197 94 / var(--tw-bg-opacity));
}

.bg-green-500\/0 {
  background-color: rgb(34 197 94 / 0);
}

.bg-green-500\/10 {
  background-color: rgb(34 197 94 / 0.1);
}

.bg-green-500\/100 {
  background-color: rgb(34 197 94 / 1);
}

.bg-green-500\/15 {
  background-color: rgb(34 197 94 / 0.15);
}

.bg-green-500\/20 {
  background-color: rgb(34 197 94 / 0.2);
}

.bg-green-500\/25 {
  background-color: rgb(34 197 94 / 0.25);
}

.bg-green-500\/30 {
  background-color: rgb(34 197 94 / 0.3);
}

.bg-green-500\/35 {
  background-color: rgb(34 197 94 / 0.35);
}

.bg-green-500\/40 {
  background-color: rgb(34 197 94 / 0.4);
}

.bg-green-500\/45 {
  background-color: rgb(34 197 94 / 0.45);
}

.bg-green-500\/5 {
  background-color: rgb(34 197 94 / 0.05);
}

.bg-green-500\/50 {
  background-color: rgb(34 197 94 / 0.5);
}

.bg-green-500\/55 {
  background-color: rgb(34 197 94 / 0.55);
}

.bg-green-500\/60 {
  background-color: rgb(34 197 94 / 0.6);
}

.bg-green-500\/65 {
  background-color: rgb(34 197 94 / 0.65);
}

.bg-green-500\/70 {
  background-color: rgb(34 197 94 / 0.7);
}

.bg-green-500\/75 {
  background-color: rgb(34 197 94 / 0.75);
}

.bg-green-500\/80 {
  background-color: rgb(34 197 94 / 0.8);
}

.bg-green-500\/85 {
  background-color: rgb(34 197 94 / 0.85);
}

.bg-green-500\/90 {
  background-color: rgb(34 197 94 / 0.9);
}

.bg-green-500\/95 {
  background-color: rgb(34 197 94 / 0.95);
}

.bg-green-600 {
  --tw-bg-opacity: 1;
  background-color: rgb(22 163 74 / var(--tw-bg-opacity));
}

.bg-green-600\/0 {
  background-color: rgb(22 163 74 / 0);
}

.bg-green-600\/10 {
  background-color: rgb(22 163 74 / 0.1);
}

.bg-green-600\/100 {
  background-color: rgb(22 163 74 / 1);
}

.bg-green-600\/15 {
  background-color: rgb(22 163 74 / 0.15);
}

.bg-green-600\/20 {
  background-color: rgb(22 163 74 / 0.2);
}

.bg-green-600\/25 {
  background-color: rgb(22 163 74 / 0.25);
}

.bg-green-600\/30 {
  background-color: rgb(22 163 74 / 0.3);
}

.bg-green-600\/35 {
  background-color: rgb(22 163 74 / 0.35);
}

.bg-green-600\/40 {
  background-color: rgb(22 163 74 / 0.4);
}

.bg-green-600\/45 {
  background-color: rgb(22 163 74 / 0.45);
}

.bg-green-600\/5 {
  background-color: rgb(22 163 74 / 0.05);
}

.bg-green-600\/50 {
  background-color: rgb(22 163 74 / 0.5);
}

.bg-green-600\/55 {
  background-color: rgb(22 163 74 / 0.55);
}

.bg-green-600\/60 {
  background-color: rgb(22 163 74 / 0.6);
}

.bg-green-600\/65 {
  background-color: rgb(22 163 74 / 0.65);
}

.bg-green-600\/70 {
  background-color: rgb(22 163 74 / 0.7);
}

.bg-green-600\/75 {
  background-color: rgb(22 163 74 / 0.75);
}

.bg-green-600\/80 {
  background-color: rgb(22 163 74 / 0.8);
}

.bg-green-600\/85 {
  background-color: rgb(22 163 74 / 0.85);
}

.bg-green-600\/90 {
  background-color: rgb(22 163 74 / 0.9);
}

.bg-green-600\/95 {
  background-color: rgb(22 163 74 / 0.95);
}

.bg-green-700 {
  --tw-bg-opacity: 1;
  background-color: rgb(21 128 61 / var(--tw-bg-opacity));
}

.bg-green-700\/0 {
  background-color: rgb(21 128 61 / 0);
}

.bg-green-700\/10 {
  background-color: rgb(21 128 61 / 0.1);
}

.bg-green-700\/100 {
  background-color: rgb(21 128 61 / 1);
}

.bg-green-700\/15 {
  background-color: rgb(21 128 61 / 0.15);
}

.bg-green-700\/20 {
  background-color: rgb(21 128 61 / 0.2);
}

.bg-green-700\/25 {
  background-color: rgb(21 128 61 / 0.25);
}

.bg-green-700\/30 {
  background-color: rgb(21 128 61 / 0.3);
}

.bg-green-700\/35 {
  background-color: rgb(21 128 61 / 0.35);
}

.bg-green-700\/40 {
  background-color: rgb(21 128 61 / 0.4);
}

.bg-green-700\/45 {
  background-color: rgb(21 128 61 / 0.45);
}

.bg-green-700\/5 {
  background-color: rgb(21 128 61 / 0.05);
}

.bg-green-700\/50 {
  background-color: rgb(21 128 61 / 0.5);
}

.bg-green-700\/55 {
  background-color: rgb(21 128 61 / 0.55);
}

.bg-green-700\/60 {
  background-color: rgb(21 128 61 / 0.6);
}

.bg-green-700\/65 {
  background-color: rgb(21 128 61 / 0.65);
}

.bg-green-700\/70 {
  background-color: rgb(21 128 61 / 0.7);
}

.bg-green-700\/75 {
  background-color: rgb(21 128 61 / 0.75);
}

.bg-green-700\/80 {
  background-color: rgb(21 128 61 / 0.8);
}

.bg-green-700\/85 {
  background-color: rgb(21 128 61 / 0.85);
}

.bg-green-700\/90 {
  background-color: rgb(21 128 61 / 0.9);
}

.bg-green-700\/95 {
  background-color: rgb(21 128 61 / 0.95);
}

.bg-green-800 {
  --tw-bg-opacity: 1;
  background-color: rgb(22 101 52 / var(--tw-bg-opacity));
}

.bg-green-800\/0 {
  background-color: rgb(22 101 52 / 0);
}

.bg-green-800\/10 {
  background-color: rgb(22 101 52 / 0.1);
}

.bg-green-800\/100 {
  background-color: rgb(22 101 52 / 1);
}

.bg-green-800\/15 {
  background-color: rgb(22 101 52 / 0.15);
}

.bg-green-800\/20 {
  background-color: rgb(22 101 52 / 0.2);
}

.bg-green-800\/25 {
  background-color: rgb(22 101 52 / 0.25);
}

.bg-green-800\/30 {
  background-color: rgb(22 101 52 / 0.3);
}

.bg-green-800\/35 {
  background-color: rgb(22 101 52 / 0.35);
}

.bg-green-800\/40 {
  background-color: rgb(22 101 52 / 0.4);
}

.bg-green-800\/45 {
  background-color: rgb(22 101 52 / 0.45);
}

.bg-green-800\/5 {
  background-color: rgb(22 101 52 / 0.05);
}

.bg-green-800\/50 {
  background-color: rgb(22 101 52 / 0.5);
}

.bg-green-800\/55 {
  background-color: rgb(22 101 52 / 0.55);
}

.bg-green-800\/60 {
  background-color: rgb(22 101 52 / 0.6);
}

.bg-green-800\/65 {
  background-color: rgb(22 101 52 / 0.65);
}

.bg-green-800\/70 {
  background-color: rgb(22 101 52 / 0.7);
}

.bg-green-800\/75 {
  background-color: rgb(22 101 52 / 0.75);
}

.bg-green-800\/80 {
  background-color: rgb(22 101 52 / 0.8);
}

.bg-green-800\/85 {
  background-color: rgb(22 101 52 / 0.85);
}

.bg-green-800\/90 {
  background-color: rgb(22 101 52 / 0.9);
}

.bg-green-800\/95 {
  background-color: rgb(22 101 52 / 0.95);
}

.bg-green-900 {
  --tw-bg-opacity: 1;
  background-color: rgb(20 83 45 / var(--tw-bg-opacity));
}

.bg-green-900\/0 {
  background-color: rgb(20 83 45 / 0);
}

.bg-green-900\/10 {
  background-color: rgb(20 83 45 / 0.1);
}

.bg-green-900\/100 {
  background-color: rgb(20 83 45 / 1);
}

.bg-green-900\/15 {
  background-color: rgb(20 83 45 / 0.15);
}

.bg-green-900\/20 {
  background-color: rgb(20 83 45 / 0.2);
}

.bg-green-900\/25 {
  background-color: rgb(20 83 45 / 0.25);
}

.bg-green-900\/30 {
  background-color: rgb(20 83 45 / 0.3);
}

.bg-green-900\/35 {
  background-color: rgb(20 83 45 / 0.35);
}

.bg-green-900\/40 {
  background-color: rgb(20 83 45 / 0.4);
}

.bg-green-900\/45 {
  background-color: rgb(20 83 45 / 0.45);
}

.bg-green-900\/5 {
  background-color: rgb(20 83 45 / 0.05);
}

.bg-green-900\/50 {
  background-color: rgb(20 83 45 / 0.5);
}

.bg-green-900\/55 {
  background-color: rgb(20 83 45 / 0.55);
}

.bg-green-900\/60 {
  background-color: rgb(20 83 45 / 0.6);
}

.bg-green-900\/65 {
  background-color: rgb(20 83 45 / 0.65);
}

.bg-green-900\/70 {
  background-color: rgb(20 83 45 / 0.7);
}

.bg-green-900\/75 {
  background-color: rgb(20 83 45 / 0.75);
}

.bg-green-900\/80 {
  background-color: rgb(20 83 45 / 0.8);
}

.bg-green-900\/85 {
  background-color: rgb(20 83 45 / 0.85);
}

.bg-green-900\/90 {
  background-color: rgb(20 83 45 / 0.9);
}

.bg-green-900\/95 {
  background-color: rgb(20 83 45 / 0.95);
}

.bg-green-950 {
  --tw-bg-opacity: 1;
  background-color: rgb(5 46 22 / var(--tw-bg-opacity));
}

.bg-green-950\/0 {
  background-color: rgb(5 46 22 / 0);
}

.bg-green-950\/10 {
  background-color: rgb(5 46 22 / 0.1);
}

.bg-green-950\/100 {
  background-color: rgb(5 46 22 / 1);
}

.bg-green-950\/15 {
  background-color: rgb(5 46 22 / 0.15);
}

.bg-green-950\/20 {
  background-color: rgb(5 46 22 / 0.2);
}

.bg-green-950\/25 {
  background-color: rgb(5 46 22 / 0.25);
}

.bg-green-950\/30 {
  background-color: rgb(5 46 22 / 0.3);
}

.bg-green-950\/35 {
  background-color: rgb(5 46 22 / 0.35);
}

.bg-green-950\/40 {
  background-color: rgb(5 46 22 / 0.4);
}

.bg-green-950\/45 {
  background-color: rgb(5 46 22 / 0.45);
}

.bg-green-950\/5 {
  background-color: rgb(5 46 22 / 0.05);
}

.bg-green-950\/50 {
  background-color: rgb(5 46 22 / 0.5);
}

.bg-green-950\/55 {
  background-color: rgb(5 46 22 / 0.55);
}

.bg-green-950\/60 {
  background-color: rgb(5 46 22 / 0.6);
}

.bg-green-950\/65 {
  background-color: rgb(5 46 22 / 0.65);
}

.bg-green-950\/70 {
  background-color: rgb(5 46 22 / 0.7);
}

.bg-green-950\/75 {
  background-color: rgb(5 46 22 / 0.75);
}

.bg-green-950\/80 {
  background-color: rgb(5 46 22 / 0.8);
}

.bg-green-950\/85 {
  background-color: rgb(5 46 22 / 0.85);
}

.bg-green-950\/90 {
  background-color: rgb(5 46 22 / 0.9);
}

.bg-green-950\/95 {
  background-color: rgb(5 46 22 / 0.95);
}

.bg-indigo-100 {
  --tw-bg-opacity: 1;
  background-color: rgb(224 231 255 / var(--tw-bg-opacity));
}

.bg-indigo-100\/0 {
  background-color: rgb(224 231 255 / 0);
}

.bg-indigo-100\/10 {
  background-color: rgb(224 231 255 / 0.1);
}

.bg-indigo-100\/100 {
  background-color: rgb(224 231 255 / 1);
}

.bg-indigo-100\/15 {
  background-color: rgb(224 231 255 / 0.15);
}

.bg-indigo-100\/20 {
  background-color: rgb(224 231 255 / 0.2);
}

.bg-indigo-100\/25 {
  background-color: rgb(224 231 255 / 0.25);
}

.bg-indigo-100\/30 {
  background-color: rgb(224 231 255 / 0.3);
}

.bg-indigo-100\/35 {
  background-color: rgb(224 231 255 / 0.35);
}

.bg-indigo-100\/40 {
  background-color: rgb(224 231 255 / 0.4);
}

.bg-indigo-100\/45 {
  background-color: rgb(224 231 255 / 0.45);
}

.bg-indigo-100\/5 {
  background-color: rgb(224 231 255 / 0.05);
}

.bg-indigo-100\/50 {
  background-color: rgb(224 231 255 / 0.5);
}

.bg-indigo-100\/55 {
  background-color: rgb(224 231 255 / 0.55);
}

.bg-indigo-100\/60 {
  background-color: rgb(224 231 255 / 0.6);
}

.bg-indigo-100\/65 {
  background-color: rgb(224 231 255 / 0.65);
}

.bg-indigo-100\/70 {
  background-color: rgb(224 231 255 / 0.7);
}

.bg-indigo-100\/75 {
  background-color: rgb(224 231 255 / 0.75);
}

.bg-indigo-100\/80 {
  background-color: rgb(224 231 255 / 0.8);
}

.bg-indigo-100\/85 {
  background-color: rgb(224 231 255 / 0.85);
}

.bg-indigo-100\/90 {
  background-color: rgb(224 231 255 / 0.9);
}

.bg-indigo-100\/95 {
  background-color: rgb(224 231 255 / 0.95);
}

.bg-indigo-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(199 210 254 / var(--tw-bg-opacity));
}

.bg-indigo-200\/0 {
  background-color: rgb(199 210 254 / 0);
}

.bg-indigo-200\/10 {
  background-color: rgb(199 210 254 / 0.1);
}

.bg-indigo-200\/100 {
  background-color: rgb(199 210 254 / 1);
}

.bg-indigo-200\/15 {
  background-color: rgb(199 210 254 / 0.15);
}

.bg-indigo-200\/20 {
  background-color: rgb(199 210 254 / 0.2);
}

.bg-indigo-200\/25 {
  background-color: rgb(199 210 254 / 0.25);
}

.bg-indigo-200\/30 {
  background-color: rgb(199 210 254 / 0.3);
}

.bg-indigo-200\/35 {
  background-color: rgb(199 210 254 / 0.35);
}

.bg-indigo-200\/40 {
  background-color: rgb(199 210 254 / 0.4);
}

.bg-indigo-200\/45 {
  background-color: rgb(199 210 254 / 0.45);
}

.bg-indigo-200\/5 {
  background-color: rgb(199 210 254 / 0.05);
}

.bg-indigo-200\/50 {
  background-color: rgb(199 210 254 / 0.5);
}

.bg-indigo-200\/55 {
  background-color: rgb(199 210 254 / 0.55);
}

.bg-indigo-200\/60 {
  background-color: rgb(199 210 254 / 0.6);
}

.bg-indigo-200\/65 {
  background-color: rgb(199 210 254 / 0.65);
}

.bg-indigo-200\/70 {
  background-color: rgb(199 210 254 / 0.7);
}

.bg-indigo-200\/75 {
  background-color: rgb(199 210 254 / 0.75);
}

.bg-indigo-200\/80 {
  background-color: rgb(199 210 254 / 0.8);
}

.bg-indigo-200\/85 {
  background-color: rgb(199 210 254 / 0.85);
}

.bg-indigo-200\/90 {
  background-color: rgb(199 210 254 / 0.9);
}

.bg-indigo-200\/95 {
  background-color: rgb(199 210 254 / 0.95);
}

.bg-indigo-300 {
  --tw-bg-opacity: 1;
  background-color: rgb(165 180 252 / var(--tw-bg-opacity));
}

.bg-indigo-300\/0 {
  background-color: rgb(165 180 252 / 0);
}

.bg-indigo-300\/10 {
  background-color: rgb(165 180 252 / 0.1);
}

.bg-indigo-300\/100 {
  background-color: rgb(165 180 252 / 1);
}

.bg-indigo-300\/15 {
  background-color: rgb(165 180 252 / 0.15);
}

.bg-indigo-300\/20 {
  background-color: rgb(165 180 252 / 0.2);
}

.bg-indigo-300\/25 {
  background-color: rgb(165 180 252 / 0.25);
}

.bg-indigo-300\/30 {
  background-color: rgb(165 180 252 / 0.3);
}

.bg-indigo-300\/35 {
  background-color: rgb(165 180 252 / 0.35);
}

.bg-indigo-300\/40 {
  background-color: rgb(165 180 252 / 0.4);
}

.bg-indigo-300\/45 {
  background-color: rgb(165 180 252 / 0.45);
}

.bg-indigo-300\/5 {
  background-color: rgb(165 180 252 / 0.05);
}

.bg-indigo-300\/50 {
  background-color: rgb(165 180 252 / 0.5);
}

.bg-indigo-300\/55 {
  background-color: rgb(165 180 252 / 0.55);
}

.bg-indigo-300\/60 {
  background-color: rgb(165 180 252 / 0.6);
}

.bg-indigo-300\/65 {
  background-color: rgb(165 180 252 / 0.65);
}

.bg-indigo-300\/70 {
  background-color: rgb(165 180 252 / 0.7);
}

.bg-indigo-300\/75 {
  background-color: rgb(165 180 252 / 0.75);
}

.bg-indigo-300\/80 {
  background-color: rgb(165 180 252 / 0.8);
}

.bg-indigo-300\/85 {
  background-color: rgb(165 180 252 / 0.85);
}

.bg-indigo-300\/90 {
  background-color: rgb(165 180 252 / 0.9);
}

.bg-indigo-300\/95 {
  background-color: rgb(165 180 252 / 0.95);
}

.bg-indigo-400 {
  --tw-bg-opacity: 1;
  background-color: rgb(129 140 248 / var(--tw-bg-opacity));
}

.bg-indigo-400\/0 {
  background-color: rgb(129 140 248 / 0);
}

.bg-indigo-400\/10 {
  background-color: rgb(129 140 248 / 0.1);
}

.bg-indigo-400\/100 {
  background-color: rgb(129 140 248 / 1);
}

.bg-indigo-400\/15 {
  background-color: rgb(129 140 248 / 0.15);
}

.bg-indigo-400\/20 {
  background-color: rgb(129 140 248 / 0.2);
}

.bg-indigo-400\/25 {
  background-color: rgb(129 140 248 / 0.25);
}

.bg-indigo-400\/30 {
  background-color: rgb(129 140 248 / 0.3);
}

.bg-indigo-400\/35 {
  background-color: rgb(129 140 248 / 0.35);
}

.bg-indigo-400\/40 {
  background-color: rgb(129 140 248 / 0.4);
}

.bg-indigo-400\/45 {
  background-color: rgb(129 140 248 / 0.45);
}

.bg-indigo-400\/5 {
  background-color: rgb(129 140 248 / 0.05);
}

.bg-indigo-400\/50 {
  background-color: rgb(129 140 248 / 0.5);
}

.bg-indigo-400\/55 {
  background-color: rgb(129 140 248 / 0.55);
}

.bg-indigo-400\/60 {
  background-color: rgb(129 140 248 / 0.6);
}

.bg-indigo-400\/65 {
  background-color: rgb(129 140 248 / 0.65);
}

.bg-indigo-400\/70 {
  background-color: rgb(129 140 248 / 0.7);
}

.bg-indigo-400\/75 {
  background-color: rgb(129 140 248 / 0.75);
}

.bg-indigo-400\/80 {
  background-color: rgb(129 140 248 / 0.8);
}

.bg-indigo-400\/85 {
  background-color: rgb(129 140 248 / 0.85);
}

.bg-indigo-400\/90 {
  background-color: rgb(129 140 248 / 0.9);
}

.bg-indigo-400\/95 {
  background-color: rgb(129 140 248 / 0.95);
}

.bg-indigo-50 {
  --tw-bg-opacity: 1;
  background-color: rgb(238 242 255 / var(--tw-bg-opacity));
}

.bg-indigo-50\/0 {
  background-color: rgb(238 242 255 / 0);
}

.bg-indigo-50\/10 {
  background-color: rgb(238 242 255 / 0.1);
}

.bg-indigo-50\/100 {
  background-color: rgb(238 242 255 / 1);
}

.bg-indigo-50\/15 {
  background-color: rgb(238 242 255 / 0.15);
}

.bg-indigo-50\/20 {
  background-color: rgb(238 242 255 / 0.2);
}

.bg-indigo-50\/25 {
  background-color: rgb(238 242 255 / 0.25);
}

.bg-indigo-50\/30 {
  background-color: rgb(238 242 255 / 0.3);
}

.bg-indigo-50\/35 {
  background-color: rgb(238 242 255 / 0.35);
}

.bg-indigo-50\/40 {
  background-color: rgb(238 242 255 / 0.4);
}

.bg-indigo-50\/45 {
  background-color: rgb(238 242 255 / 0.45);
}

.bg-indigo-50\/5 {
  background-color: rgb(238 242 255 / 0.05);
}

.bg-indigo-50\/50 {
  background-color: rgb(238 242 255 / 0.5);
}

.bg-indigo-50\/55 {
  background-color: rgb(238 242 255 / 0.55);
}

.bg-indigo-50\/60 {
  background-color: rgb(238 242 255 / 0.6);
}

.bg-indigo-50\/65 {
  background-color: rgb(238 242 255 / 0.65);
}

.bg-indigo-50\/70 {
  background-color: rgb(238 242 255 / 0.7);
}

.bg-indigo-50\/75 {
  background-color: rgb(238 242 255 / 0.75);
}

.bg-indigo-50\/80 {
  background-color: rgb(238 242 255 / 0.8);
}

.bg-indigo-50\/85 {
  background-color: rgb(238 242 255 / 0.85);
}

.bg-indigo-50\/90 {
  background-color: rgb(238 242 255 / 0.9);
}

.bg-indigo-50\/95 {
  background-color: rgb(238 242 255 / 0.95);
}

.bg-indigo-500 {
  --tw-bg-opacity: 1;
  background-color: rgb(99 102 241 / var(--tw-bg-opacity));
}

.bg-indigo-500\/0 {
  background-color: rgb(99 102 241 / 0);
}

.bg-indigo-500\/10 {
  background-color: rgb(99 102 241 / 0.1);
}

.bg-indigo-500\/100 {
  background-color: rgb(99 102 241 / 1);
}

.bg-indigo-500\/15 {
  background-color: rgb(99 102 241 / 0.15);
}

.bg-indigo-500\/20 {
  background-color: rgb(99 102 241 / 0.2);
}

.bg-indigo-500\/25 {
  background-color: rgb(99 102 241 / 0.25);
}

.bg-indigo-500\/30 {
  background-color: rgb(99 102 241 / 0.3);
}

.bg-indigo-500\/35 {
  background-color: rgb(99 102 241 / 0.35);
}

.bg-indigo-500\/40 {
  background-color: rgb(99 102 241 / 0.4);
}

.bg-indigo-500\/45 {
  background-color: rgb(99 102 241 / 0.45);
}

.bg-indigo-500\/5 {
  background-color: rgb(99 102 241 / 0.05);
}

.bg-indigo-500\/50 {
  background-color: rgb(99 102 241 / 0.5);
}

.bg-indigo-500\/55 {
  background-color: rgb(99 102 241 / 0.55);
}

.bg-indigo-500\/60 {
  background-color: rgb(99 102 241 / 0.6);
}

.bg-indigo-500\/65 {
  background-color: rgb(99 102 241 / 0.65);
}

.bg-indigo-500\/70 {
  background-color: rgb(99 102 241 / 0.7);
}

.bg-indigo-500\/75 {
  background-color: rgb(99 102 241 / 0.75);
}

.bg-indigo-500\/80 {
  background-color: rgb(99 102 241 / 0.8);
}

.bg-indigo-500\/85 {
  background-color: rgb(99 102 241 / 0.85);
}

.bg-indigo-500\/90 {
  background-color: rgb(99 102 241 / 0.9);
}

.bg-indigo-500\/95 {
  background-color: rgb(99 102 241 / 0.95);
}

.bg-indigo-600 {
  --tw-bg-opacity: 1;
  background-color: rgb(79 70 229 / var(--tw-bg-opacity));
}

.bg-indigo-600\/0 {
  background-color: rgb(79 70 229 / 0);
}

.bg-indigo-600\/10 {
  background-color: rgb(79 70 229 / 0.1);
}

.bg-indigo-600\/100 {
  background-color: rgb(79 70 229 / 1);
}

.bg-indigo-600\/15 {
  background-color: rgb(79 70 229 / 0.15);
}

.bg-indigo-600\/20 {
  background-color: rgb(79 70 229 / 0.2);
}

.bg-indigo-600\/25 {
  background-color: rgb(79 70 229 / 0.25);
}

.bg-indigo-600\/30 {
  background-color: rgb(79 70 229 / 0.3);
}

.bg-indigo-600\/35 {
  background-color: rgb(79 70 229 / 0.35);
}

.bg-indigo-600\/40 {
  background-color: rgb(79 70 229 / 0.4);
}

.bg-indigo-600\/45 {
  background-color: rgb(79 70 229 / 0.45);
}

.bg-indigo-600\/5 {
  background-color: rgb(79 70 229 / 0.05);
}

.bg-indigo-600\/50 {
  background-color: rgb(79 70 229 / 0.5);
}

.bg-indigo-600\/55 {
  background-color: rgb(79 70 229 / 0.55);
}

.bg-indigo-600\/60 {
  background-color: rgb(79 70 229 / 0.6);
}

.bg-indigo-600\/65 {
  background-color: rgb(79 70 229 / 0.65);
}

.bg-indigo-600\/70 {
  background-color: rgb(79 70 229 / 0.7);
}

.bg-indigo-600\/75 {
  background-color: rgb(79 70 229 / 0.75);
}

.bg-indigo-600\/80 {
  background-color: rgb(79 70 229 / 0.8);
}

.bg-indigo-600\/85 {
  background-color: rgb(79 70 229 / 0.85);
}

.bg-indigo-600\/90 {
  background-color: rgb(79 70 229 / 0.9);
}

.bg-indigo-600\/95 {
  background-color: rgb(79 70 229 / 0.95);
}

.bg-indigo-700 {
  --tw-bg-opacity: 1;
  background-color: rgb(67 56 202 / var(--tw-bg-opacity));
}

.bg-indigo-700\/0 {
  background-color: rgb(67 56 202 / 0);
}

.bg-indigo-700\/10 {
  background-color: rgb(67 56 202 / 0.1);
}

.bg-indigo-700\/100 {
  background-color: rgb(67 56 202 / 1);
}

.bg-indigo-700\/15 {
  background-color: rgb(67 56 202 / 0.15);
}

.bg-indigo-700\/20 {
  background-color: rgb(67 56 202 / 0.2);
}

.bg-indigo-700\/25 {
  background-color: rgb(67 56 202 / 0.25);
}

.bg-indigo-700\/30 {
  background-color: rgb(67 56 202 / 0.3);
}

.bg-indigo-700\/35 {
  background-color: rgb(67 56 202 / 0.35);
}

.bg-indigo-700\/40 {
  background-color: rgb(67 56 202 / 0.4);
}

.bg-indigo-700\/45 {
  background-color: rgb(67 56 202 / 0.45);
}

.bg-indigo-700\/5 {
  background-color: rgb(67 56 202 / 0.05);
}

.bg-indigo-700\/50 {
  background-color: rgb(67 56 202 / 0.5);
}

.bg-indigo-700\/55 {
  background-color: rgb(67 56 202 / 0.55);
}

.bg-indigo-700\/60 {
  background-color: rgb(67 56 202 / 0.6);
}

.bg-indigo-700\/65 {
  background-color: rgb(67 56 202 / 0.65);
}

.bg-indigo-700\/70 {
  background-color: rgb(67 56 202 / 0.7);
}

.bg-indigo-700\/75 {
  background-color: rgb(67 56 202 / 0.75);
}

.bg-indigo-700\/80 {
  background-color: rgb(67 56 202 / 0.8);
}

.bg-indigo-700\/85 {
  background-color: rgb(67 56 202 / 0.85);
}

.bg-indigo-700\/90 {
  background-color: rgb(67 56 202 / 0.9);
}

.bg-indigo-700\/95 {
  background-color: rgb(67 56 202 / 0.95);
}

.bg-indigo-800 {
  --tw-bg-opacity: 1;
  background-color: rgb(55 48 163 / var(--tw-bg-opacity));
}

.bg-indigo-800\/0 {
  background-color: rgb(55 48 163 / 0);
}

.bg-indigo-800\/10 {
  background-color: rgb(55 48 163 / 0.1);
}

.bg-indigo-800\/100 {
  background-color: rgb(55 48 163 / 1);
}

.bg-indigo-800\/15 {
  background-color: rgb(55 48 163 / 0.15);
}

.bg-indigo-800\/20 {
  background-color: rgb(55 48 163 / 0.2);
}

.bg-indigo-800\/25 {
  background-color: rgb(55 48 163 / 0.25);
}

.bg-indigo-800\/30 {
  background-color: rgb(55 48 163 / 0.3);
}

.bg-indigo-800\/35 {
  background-color: rgb(55 48 163 / 0.35);
}

.bg-indigo-800\/40 {
  background-color: rgb(55 48 163 / 0.4);
}

.bg-indigo-800\/45 {
  background-color: rgb(55 48 163 / 0.45);
}

.bg-indigo-800\/5 {
  background-color: rgb(55 48 163 / 0.05);
}

.bg-indigo-800\/50 {
  background-color: rgb(55 48 163 / 0.5);
}

.bg-indigo-800\/55 {
  background-color: rgb(55 48 163 / 0.55);
}

.bg-indigo-800\/60 {
  background-color: rgb(55 48 163 / 0.6);
}

.bg-indigo-800\/65 {
  background-color: rgb(55 48 163 / 0.65);
}

.bg-indigo-800\/70 {
  background-color: rgb(55 48 163 / 0.7);
}

.bg-indigo-800\/75 {
  background-color: rgb(55 48 163 / 0.75);
}

.bg-indigo-800\/80 {
  background-color: rgb(55 48 163 / 0.8);
}

.bg-indigo-800\/85 {
  background-color: rgb(55 48 163 / 0.85);
}

.bg-indigo-800\/90 {
  background-color: rgb(55 48 163 / 0.9);
}

.bg-indigo-800\/95 {
  background-color: rgb(55 48 163 / 0.95);
}

.bg-indigo-900 {
  --tw-bg-opacity: 1;
  background-color: rgb(49 46 129 / var(--tw-bg-opacity));
}

.bg-indigo-900\/0 {
  background-color: rgb(49 46 129 / 0);
}

.bg-indigo-900\/10 {
  background-color: rgb(49 46 129 / 0.1);
}

.bg-indigo-900\/100 {
  background-color: rgb(49 46 129 / 1);
}

.bg-indigo-900\/15 {
  background-color: rgb(49 46 129 / 0.15);
}

.bg-indigo-900\/20 {
  background-color: rgb(49 46 129 / 0.2);
}

.bg-indigo-900\/25 {
  background-color: rgb(49 46 129 / 0.25);
}

.bg-indigo-900\/30 {
  background-color: rgb(49 46 129 / 0.3);
}

.bg-indigo-900\/35 {
  background-color: rgb(49 46 129 / 0.35);
}

.bg-indigo-900\/40 {
  background-color: rgb(49 46 129 / 0.4);
}

.bg-indigo-900\/45 {
  background-color: rgb(49 46 129 / 0.45);
}

.bg-indigo-900\/5 {
  background-color: rgb(49 46 129 / 0.05);
}

.bg-indigo-900\/50 {
  background-color: rgb(49 46 129 / 0.5);
}

.bg-indigo-900\/55 {
  background-color: rgb(49 46 129 / 0.55);
}

.bg-indigo-900\/60 {
  background-color: rgb(49 46 129 / 0.6);
}

.bg-indigo-900\/65 {
  background-color: rgb(49 46 129 / 0.65);
}

.bg-indigo-900\/70 {
  background-color: rgb(49 46 129 / 0.7);
}

.bg-indigo-900\/75 {
  background-color: rgb(49 46 129 / 0.75);
}

.bg-indigo-900\/80 {
  background-color: rgb(49 46 129 / 0.8);
}

.bg-indigo-900\/85 {
  background-color: rgb(49 46 129 / 0.85);
}

.bg-indigo-900\/90 {
  background-color: rgb(49 46 129 / 0.9);
}

.bg-indigo-900\/95 {
  background-color: rgb(49 46 129 / 0.95);
}

.bg-indigo-950 {
  --tw-bg-opacity: 1;
  background-color: rgb(30 27 75 / var(--tw-bg-opacity));
}

.bg-indigo-950\/0 {
  background-color: rgb(30 27 75 / 0);
}

.bg-indigo-950\/10 {
  background-color: rgb(30 27 75 / 0.1);
}

.bg-indigo-950\/100 {
  background-color: rgb(30 27 75 / 1);
}

.bg-indigo-950\/15 {
  background-color: rgb(30 27 75 / 0.15);
}

.bg-indigo-950\/20 {
  background-color: rgb(30 27 75 / 0.2);
}

.bg-indigo-950\/25 {
  background-color: rgb(30 27 75 / 0.25);
}

.bg-indigo-950\/30 {
  background-color: rgb(30 27 75 / 0.3);
}

.bg-indigo-950\/35 {
  background-color: rgb(30 27 75 / 0.35);
}

.bg-indigo-950\/40 {
  background-color: rgb(30 27 75 / 0.4);
}

.bg-indigo-950\/45 {
  background-color: rgb(30 27 75 / 0.45);
}

.bg-indigo-950\/5 {
  background-color: rgb(30 27 75 / 0.05);
}

.bg-indigo-950\/50 {
  background-color: rgb(30 27 75 / 0.5);
}

.bg-indigo-950\/55 {
  background-color: rgb(30 27 75 / 0.55);
}

.bg-indigo-950\/60 {
  background-color: rgb(30 27 75 / 0.6);
}

.bg-indigo-950\/65 {
  background-color: rgb(30 27 75 / 0.65);
}

.bg-indigo-950\/70 {
  background-color: rgb(30 27 75 / 0.7);
}

.bg-indigo-950\/75 {
  background-color: rgb(30 27 75 / 0.75);
}

.bg-indigo-950\/80 {
  background-color: rgb(30 27 75 / 0.8);
}

.bg-indigo-950\/85 {
  background-color: rgb(30 27 75 / 0.85);
}

.bg-indigo-950\/90 {
  background-color: rgb(30 27 75 / 0.9);
}

.bg-indigo-950\/95 {
  background-color: rgb(30 27 75 / 0.95);
}

.bg-info {
  --tw-bg-opacity: 1;
  background-color: var(--fallback-in,oklch(var(--in)/var(--tw-bg-opacity)));
}

.bg-info-content {
  --tw-bg-opacity: 1;
  background-color: var(--fallback-inc,oklch(var(--inc)/var(--tw-bg-opacity)));
}

.bg-info-content\/0 {
  background-color: var(--fallback-inc,oklch(var(--inc)/0));
}

.bg-info-content\/10 {
  background-color: var(--fallback-inc,oklch(var(--inc)/0.1));
}

.bg-info-content\/100 {
  background-color: var(--fallback-inc,oklch(var(--inc)/1));
}

.bg-info-content\/15 {
  background-color: var(--fallback-inc,oklch(var(--inc)/0.15));
}

.bg-info-content\/20 {
  background-color: var(--fallback-inc,oklch(var(--inc)/0.2));
}

.bg-info-content\/25 {
  background-color: var(--fallback-inc,oklch(var(--inc)/0.25));
}

.bg-info-content\/30 {
  background-color: var(--fallback-inc,oklch(var(--inc)/0.3));
}

.bg-info-content\/35 {
  background-color: var(--fallback-inc,oklch(var(--inc)/0.35));
}

.bg-info-content\/40 {
  background-color: var(--fallback-inc,oklch(var(--inc)/0.4));
}

.bg-info-content\/45 {
  background-color: var(--fallback-inc,oklch(var(--inc)/0.45));
}

.bg-info-content\/5 {
  background-color: var(--fallback-inc,oklch(var(--inc)/0.05));
}

.bg-info-content\/50 {
  background-color: var(--fallback-inc,oklch(var(--inc)/0.5));
}

.bg-info-content\/55 {
  background-color: var(--fallback-inc,oklch(var(--inc)/0.55));
}

.bg-info-content\/60 {
  background-color: var(--fallback-inc,oklch(var(--inc)/0.6));
}

.bg-info-content\/65 {
  background-color: var(--fallback-inc,oklch(var(--inc)/0.65));
}

.bg-info-content\/70 {
  background-color: var(--fallback-inc,oklch(var(--inc)/0.7));
}

.bg-info-content\/75 {
  background-color: var(--fallback-inc,oklch(var(--inc)/0.75));
}

.bg-info-content\/80 {
  background-color: var(--fallback-inc,oklch(var(--inc)/0.8));
}

.bg-info-content\/85 {
  background-color: var(--fallback-inc,oklch(var(--inc)/0.85));
}

.bg-info-content\/90 {
  background-color: var(--fallback-inc,oklch(var(--inc)/0.9));
}

.bg-info-content\/95 {
  background-color: var(--fallback-inc,oklch(var(--inc)/0.95));
}

.bg-info\/0 {
  background-color: var(--fallback-in,oklch(var(--in)/0));
}

.bg-info\/10 {
  background-color: var(--fallback-in,oklch(var(--in)/0.1));
}

.bg-info\/100 {
  background-color: var(--fallback-in,oklch(var(--in)/1));
}

.bg-info\/15 {
  background-color: var(--fallback-in,oklch(var(--in)/0.15));
}

.bg-info\/20 {
  background-color: var(--fallback-in,oklch(var(--in)/0.2));
}

.bg-info\/25 {
  background-color: var(--fallback-in,oklch(var(--in)/0.25));
}

.bg-info\/30 {
  background-color: var(--fallback-in,oklch(var(--in)/0.3));
}

.bg-info\/35 {
  background-color: var(--fallback-in,oklch(var(--in)/0.35));
}

.bg-info\/40 {
  background-color: var(--fallback-in,oklch(var(--in)/0.4));
}

.bg-info\/45 {
  background-color: var(--fallback-in,oklch(var(--in)/0.45));
}

.bg-info\/5 {
  background-color: var(--fallback-in,oklch(var(--in)/0.05));
}

.bg-info\/50 {
  background-color: var(--fallback-in,oklch(var(--in)/0.5));
}

.bg-info\/55 {
  background-color: var(--fallback-in,oklch(var(--in)/0.55));
}

.bg-info\/60 {
  background-color: var(--fallback-in,oklch(var(--in)/0.6));
}

.bg-info\/65 {
  background-color: var(--fallback-in,oklch(var(--in)/0.65));
}

.bg-info\/70 {
  background-color: var(--fallback-in,oklch(var(--in)/0.7));
}

.bg-info\/75 {
  background-color: var(--fallback-in,oklch(var(--in)/0.75));
}

.bg-info\/80 {
  background-color: var(--fallback-in,oklch(var(--in)/0.8));
}

.bg-info\/85 {
  background-color: var(--fallback-in,oklch(var(--in)/0.85));
}

.bg-info\/90 {
  background-color: var(--fallback-in,oklch(var(--in)/0.9));
}

.bg-info\/95 {
  background-color: var(--fallback-in,oklch(var(--in)/0.95));
}

.bg-inherit {
  background-color: inherit;
}

.bg-lime-100 {
  --tw-bg-opacity: 1;
  background-color: rgb(236 252 203 / var(--tw-bg-opacity));
}

.bg-lime-100\/0 {
  background-color: rgb(236 252 203 / 0);
}

.bg-lime-100\/10 {
  background-color: rgb(236 252 203 / 0.1);
}

.bg-lime-100\/100 {
  background-color: rgb(236 252 203 / 1);
}

.bg-lime-100\/15 {
  background-color: rgb(236 252 203 / 0.15);
}

.bg-lime-100\/20 {
  background-color: rgb(236 252 203 / 0.2);
}

.bg-lime-100\/25 {
  background-color: rgb(236 252 203 / 0.25);
}

.bg-lime-100\/30 {
  background-color: rgb(236 252 203 / 0.3);
}

.bg-lime-100\/35 {
  background-color: rgb(236 252 203 / 0.35);
}

.bg-lime-100\/40 {
  background-color: rgb(236 252 203 / 0.4);
}

.bg-lime-100\/45 {
  background-color: rgb(236 252 203 / 0.45);
}

.bg-lime-100\/5 {
  background-color: rgb(236 252 203 / 0.05);
}

.bg-lime-100\/50 {
  background-color: rgb(236 252 203 / 0.5);
}

.bg-lime-100\/55 {
  background-color: rgb(236 252 203 / 0.55);
}

.bg-lime-100\/60 {
  background-color: rgb(236 252 203 / 0.6);
}

.bg-lime-100\/65 {
  background-color: rgb(236 252 203 / 0.65);
}

.bg-lime-100\/70 {
  background-color: rgb(236 252 203 / 0.7);
}

.bg-lime-100\/75 {
  background-color: rgb(236 252 203 / 0.75);
}

.bg-lime-100\/80 {
  background-color: rgb(236 252 203 / 0.8);
}

.bg-lime-100\/85 {
  background-color: rgb(236 252 203 / 0.85);
}

.bg-lime-100\/90 {
  background-color: rgb(236 252 203 / 0.9);
}

.bg-lime-100\/95 {
  background-color: rgb(236 252 203 / 0.95);
}

.bg-lime-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(217 249 157 / var(--tw-bg-opacity));
}

.bg-lime-200\/0 {
  background-color: rgb(217 249 157 / 0);
}

.bg-lime-200\/10 {
  background-color: rgb(217 249 157 / 0.1);
}

.bg-lime-200\/100 {
  background-color: rgb(217 249 157 / 1);
}

.bg-lime-200\/15 {
  background-color: rgb(217 249 157 / 0.15);
}

.bg-lime-200\/20 {
  background-color: rgb(217 249 157 / 0.2);
}

.bg-lime-200\/25 {
  background-color: rgb(217 249 157 / 0.25);
}

.bg-lime-200\/30 {
  background-color: rgb(217 249 157 / 0.3);
}

.bg-lime-200\/35 {
  background-color: rgb(217 249 157 / 0.35);
}

.bg-lime-200\/40 {
  background-color: rgb(217 249 157 / 0.4);
}

.bg-lime-200\/45 {
  background-color: rgb(217 249 157 / 0.45);
}

.bg-lime-200\/5 {
  background-color: rgb(217 249 157 / 0.05);
}

.bg-lime-200\/50 {
  background-color: rgb(217 249 157 / 0.5);
}

.bg-lime-200\/55 {
  background-color: rgb(217 249 157 / 0.55);
}

.bg-lime-200\/60 {
  background-color: rgb(217 249 157 / 0.6);
}

.bg-lime-200\/65 {
  background-color: rgb(217 249 157 / 0.65);
}

.bg-lime-200\/70 {
  background-color: rgb(217 249 157 / 0.7);
}

.bg-lime-200\/75 {
  background-color: rgb(217 249 157 / 0.75);
}

.bg-lime-200\/80 {
  background-color: rgb(217 249 157 / 0.8);
}

.bg-lime-200\/85 {
  background-color: rgb(217 249 157 / 0.85);
}

.bg-lime-200\/90 {
  background-color: rgb(217 249 157 / 0.9);
}

.bg-lime-200\/95 {
  background-color: rgb(217 249 157 / 0.95);
}

.bg-lime-300 {
  --tw-bg-opacity: 1;
  background-color: rgb(190 242 100 / var(--tw-bg-opacity));
}

.bg-lime-300\/0 {
  background-color: rgb(190 242 100 / 0);
}

.bg-lime-300\/10 {
  background-color: rgb(190 242 100 / 0.1);
}

.bg-lime-300\/100 {
  background-color: rgb(190 242 100 / 1);
}

.bg-lime-300\/15 {
  background-color: rgb(190 242 100 / 0.15);
}

.bg-lime-300\/20 {
  background-color: rgb(190 242 100 / 0.2);
}

.bg-lime-300\/25 {
  background-color: rgb(190 242 100 / 0.25);
}

.bg-lime-300\/30 {
  background-color: rgb(190 242 100 / 0.3);
}

.bg-lime-300\/35 {
  background-color: rgb(190 242 100 / 0.35);
}

.bg-lime-300\/40 {
  background-color: rgb(190 242 100 / 0.4);
}

.bg-lime-300\/45 {
  background-color: rgb(190 242 100 / 0.45);
}

.bg-lime-300\/5 {
  background-color: rgb(190 242 100 / 0.05);
}

.bg-lime-300\/50 {
  background-color: rgb(190 242 100 / 0.5);
}

.bg-lime-300\/55 {
  background-color: rgb(190 242 100 / 0.55);
}

.bg-lime-300\/60 {
  background-color: rgb(190 242 100 / 0.6);
}

.bg-lime-300\/65 {
  background-color: rgb(190 242 100 / 0.65);
}

.bg-lime-300\/70 {
  background-color: rgb(190 242 100 / 0.7);
}

.bg-lime-300\/75 {
  background-color: rgb(190 242 100 / 0.75);
}

.bg-lime-300\/80 {
  background-color: rgb(190 242 100 / 0.8);
}

.bg-lime-300\/85 {
  background-color: rgb(190 242 100 / 0.85);
}

.bg-lime-300\/90 {
  background-color: rgb(190 242 100 / 0.9);
}

.bg-lime-300\/95 {
  background-color: rgb(190 242 100 / 0.95);
}

.bg-lime-400 {
  --tw-bg-opacity: 1;
  background-color: rgb(163 230 53 / var(--tw-bg-opacity));
}

.bg-lime-400\/0 {
  background-color: rgb(163 230 53 / 0);
}

.bg-lime-400\/10 {
  background-color: rgb(163 230 53 / 0.1);
}

.bg-lime-400\/100 {
  background-color: rgb(163 230 53 / 1);
}

.bg-lime-400\/15 {
  background-color: rgb(163 230 53 / 0.15);
}

.bg-lime-400\/20 {
  background-color: rgb(163 230 53 / 0.2);
}

.bg-lime-400\/25 {
  background-color: rgb(163 230 53 / 0.25);
}

.bg-lime-400\/30 {
  background-color: rgb(163 230 53 / 0.3);
}

.bg-lime-400\/35 {
  background-color: rgb(163 230 53 / 0.35);
}

.bg-lime-400\/40 {
  background-color: rgb(163 230 53 / 0.4);
}

.bg-lime-400\/45 {
  background-color: rgb(163 230 53 / 0.45);
}

.bg-lime-400\/5 {
  background-color: rgb(163 230 53 / 0.05);
}

.bg-lime-400\/50 {
  background-color: rgb(163 230 53 / 0.5);
}

.bg-lime-400\/55 {
  background-color: rgb(163 230 53 / 0.55);
}

.bg-lime-400\/60 {
  background-color: rgb(163 230 53 / 0.6);
}

.bg-lime-400\/65 {
  background-color: rgb(163 230 53 / 0.65);
}

.bg-lime-400\/70 {
  background-color: rgb(163 230 53 / 0.7);
}

.bg-lime-400\/75 {
  background-color: rgb(163 230 53 / 0.75);
}

.bg-lime-400\/80 {
  background-color: rgb(163 230 53 / 0.8);
}

.bg-lime-400\/85 {
  background-color: rgb(163 230 53 / 0.85);
}

.bg-lime-400\/90 {
  background-color: rgb(163 230 53 / 0.9);
}

.bg-lime-400\/95 {
  background-color: rgb(163 230 53 / 0.95);
}

.bg-lime-50 {
  --tw-bg-opacity: 1;
  background-color: rgb(247 254 231 / var(--tw-bg-opacity));
}

.bg-lime-50\/0 {
  background-color: rgb(247 254 231 / 0);
}

.bg-lime-50\/10 {
  background-color: rgb(247 254 231 / 0.1);
}

.bg-lime-50\/100 {
  background-color: rgb(247 254 231 / 1);
}

.bg-lime-50\/15 {
  background-color: rgb(247 254 231 / 0.15);
}

.bg-lime-50\/20 {
  background-color: rgb(247 254 231 / 0.2);
}

.bg-lime-50\/25 {
  background-color: rgb(247 254 231 / 0.25);
}

.bg-lime-50\/30 {
  background-color: rgb(247 254 231 / 0.3);
}

.bg-lime-50\/35 {
  background-color: rgb(247 254 231 / 0.35);
}

.bg-lime-50\/40 {
  background-color: rgb(247 254 231 / 0.4);
}

.bg-lime-50\/45 {
  background-color: rgb(247 254 231 / 0.45);
}

.bg-lime-50\/5 {
  background-color: rgb(247 254 231 / 0.05);
}

.bg-lime-50\/50 {
  background-color: rgb(247 254 231 / 0.5);
}

.bg-lime-50\/55 {
  background-color: rgb(247 254 231 / 0.55);
}

.bg-lime-50\/60 {
  background-color: rgb(247 254 231 / 0.6);
}

.bg-lime-50\/65 {
  background-color: rgb(247 254 231 / 0.65);
}

.bg-lime-50\/70 {
  background-color: rgb(247 254 231 / 0.7);
}

.bg-lime-50\/75 {
  background-color: rgb(247 254 231 / 0.75);
}

.bg-lime-50\/80 {
  background-color: rgb(247 254 231 / 0.8);
}

.bg-lime-50\/85 {
  background-color: rgb(247 254 231 / 0.85);
}

.bg-lime-50\/90 {
  background-color: rgb(247 254 231 / 0.9);
}

.bg-lime-50\/95 {
  background-color: rgb(247 254 231 / 0.95);
}

.bg-lime-500 {
  --tw-bg-opacity: 1;
  background-color: rgb(132 204 22 / var(--tw-bg-opacity));
}

.bg-lime-500\/0 {
  background-color: rgb(132 204 22 / 0);
}

.bg-lime-500\/10 {
  background-color: rgb(132 204 22 / 0.1);
}

.bg-lime-500\/100 {
  background-color: rgb(132 204 22 / 1);
}

.bg-lime-500\/15 {
  background-color: rgb(132 204 22 / 0.15);
}

.bg-lime-500\/20 {
  background-color: rgb(132 204 22 / 0.2);
}

.bg-lime-500\/25 {
  background-color: rgb(132 204 22 / 0.25);
}

.bg-lime-500\/30 {
  background-color: rgb(132 204 22 / 0.3);
}

.bg-lime-500\/35 {
  background-color: rgb(132 204 22 / 0.35);
}

.bg-lime-500\/40 {
  background-color: rgb(132 204 22 / 0.4);
}

.bg-lime-500\/45 {
  background-color: rgb(132 204 22 / 0.45);
}

.bg-lime-500\/5 {
  background-color: rgb(132 204 22 / 0.05);
}

.bg-lime-500\/50 {
  background-color: rgb(132 204 22 / 0.5);
}

.bg-lime-500\/55 {
  background-color: rgb(132 204 22 / 0.55);
}

.bg-lime-500\/60 {
  background-color: rgb(132 204 22 / 0.6);
}

.bg-lime-500\/65 {
  background-color: rgb(132 204 22 / 0.65);
}

.bg-lime-500\/70 {
  background-color: rgb(132 204 22 / 0.7);
}

.bg-lime-500\/75 {
  background-color: rgb(132 204 22 / 0.75);
}

.bg-lime-500\/80 {
  background-color: rgb(132 204 22 / 0.8);
}

.bg-lime-500\/85 {
  background-color: rgb(132 204 22 / 0.85);
}

.bg-lime-500\/90 {
  background-color: rgb(132 204 22 / 0.9);
}

.bg-lime-500\/95 {
  background-color: rgb(132 204 22 / 0.95);
}

.bg-lime-600 {
  --tw-bg-opacity: 1;
  background-color: rgb(101 163 13 / var(--tw-bg-opacity));
}

.bg-lime-600\/0 {
  background-color: rgb(101 163 13 / 0);
}

.bg-lime-600\/10 {
  background-color: rgb(101 163 13 / 0.1);
}

.bg-lime-600\/100 {
  background-color: rgb(101 163 13 / 1);
}

.bg-lime-600\/15 {
  background-color: rgb(101 163 13 / 0.15);
}

.bg-lime-600\/20 {
  background-color: rgb(101 163 13 / 0.2);
}

.bg-lime-600\/25 {
  background-color: rgb(101 163 13 / 0.25);
}

.bg-lime-600\/30 {
  background-color: rgb(101 163 13 / 0.3);
}

.bg-lime-600\/35 {
  background-color: rgb(101 163 13 / 0.35);
}

.bg-lime-600\/40 {
  background-color: rgb(101 163 13 / 0.4);
}

.bg-lime-600\/45 {
  background-color: rgb(101 163 13 / 0.45);
}

.bg-lime-600\/5 {
  background-color: rgb(101 163 13 / 0.05);
}

.bg-lime-600\/50 {
  background-color: rgb(101 163 13 / 0.5);
}

.bg-lime-600\/55 {
  background-color: rgb(101 163 13 / 0.55);
}

.bg-lime-600\/60 {
  background-color: rgb(101 163 13 / 0.6);
}

.bg-lime-600\/65 {
  background-color: rgb(101 163 13 / 0.65);
}

.bg-lime-600\/70 {
  background-color: rgb(101 163 13 / 0.7);
}

.bg-lime-600\/75 {
  background-color: rgb(101 163 13 / 0.75);
}

.bg-lime-600\/80 {
  background-color: rgb(101 163 13 / 0.8);
}

.bg-lime-600\/85 {
  background-color: rgb(101 163 13 / 0.85);
}

.bg-lime-600\/90 {
  background-color: rgb(101 163 13 / 0.9);
}

.bg-lime-600\/95 {
  background-color: rgb(101 163 13 / 0.95);
}

.bg-lime-700 {
  --tw-bg-opacity: 1;
  background-color: rgb(77 124 15 / var(--tw-bg-opacity));
}

.bg-lime-700\/0 {
  background-color: rgb(77 124 15 / 0);
}

.bg-lime-700\/10 {
  background-color: rgb(77 124 15 / 0.1);
}

.bg-lime-700\/100 {
  background-color: rgb(77 124 15 / 1);
}

.bg-lime-700\/15 {
  background-color: rgb(77 124 15 / 0.15);
}

.bg-lime-700\/20 {
  background-color: rgb(77 124 15 / 0.2);
}

.bg-lime-700\/25 {
  background-color: rgb(77 124 15 / 0.25);
}

.bg-lime-700\/30 {
  background-color: rgb(77 124 15 / 0.3);
}

.bg-lime-700\/35 {
  background-color: rgb(77 124 15 / 0.35);
}

.bg-lime-700\/40 {
  background-color: rgb(77 124 15 / 0.4);
}

.bg-lime-700\/45 {
  background-color: rgb(77 124 15 / 0.45);
}

.bg-lime-700\/5 {
  background-color: rgb(77 124 15 / 0.05);
}

.bg-lime-700\/50 {
  background-color: rgb(77 124 15 / 0.5);
}

.bg-lime-700\/55 {
  background-color: rgb(77 124 15 / 0.55);
}

.bg-lime-700\/60 {
  background-color: rgb(77 124 15 / 0.6);
}

.bg-lime-700\/65 {
  background-color: rgb(77 124 15 / 0.65);
}

.bg-lime-700\/70 {
  background-color: rgb(77 124 15 / 0.7);
}

.bg-lime-700\/75 {
  background-color: rgb(77 124 15 / 0.75);
}

.bg-lime-700\/80 {
  background-color: rgb(77 124 15 / 0.8);
}

.bg-lime-700\/85 {
  background-color: rgb(77 124 15 / 0.85);
}

.bg-lime-700\/90 {
  background-color: rgb(77 124 15 / 0.9);
}

.bg-lime-700\/95 {
  background-color: rgb(77 124 15 / 0.95);
}

.bg-lime-800 {
  --tw-bg-opacity: 1;
  background-color: rgb(63 98 18 / var(--tw-bg-opacity));
}

.bg-lime-800\/0 {
  background-color: rgb(63 98 18 / 0);
}

.bg-lime-800\/10 {
  background-color: rgb(63 98 18 / 0.1);
}

.bg-lime-800\/100 {
  background-color: rgb(63 98 18 / 1);
}

.bg-lime-800\/15 {
  background-color: rgb(63 98 18 / 0.15);
}

.bg-lime-800\/20 {
  background-color: rgb(63 98 18 / 0.2);
}

.bg-lime-800\/25 {
  background-color: rgb(63 98 18 / 0.25);
}

.bg-lime-800\/30 {
  background-color: rgb(63 98 18 / 0.3);
}

.bg-lime-800\/35 {
  background-color: rgb(63 98 18 / 0.35);
}

.bg-lime-800\/40 {
  background-color: rgb(63 98 18 / 0.4);
}

.bg-lime-800\/45 {
  background-color: rgb(63 98 18 / 0.45);
}

.bg-lime-800\/5 {
  background-color: rgb(63 98 18 / 0.05);
}

.bg-lime-800\/50 {
  background-color: rgb(63 98 18 / 0.5);
}

.bg-lime-800\/55 {
  background-color: rgb(63 98 18 / 0.55);
}

.bg-lime-800\/60 {
  background-color: rgb(63 98 18 / 0.6);
}

.bg-lime-800\/65 {
  background-color: rgb(63 98 18 / 0.65);
}

.bg-lime-800\/70 {
  background-color: rgb(63 98 18 / 0.7);
}

.bg-lime-800\/75 {
  background-color: rgb(63 98 18 / 0.75);
}

.bg-lime-800\/80 {
  background-color: rgb(63 98 18 / 0.8);
}

.bg-lime-800\/85 {
  background-color: rgb(63 98 18 / 0.85);
}

.bg-lime-800\/90 {
  background-color: rgb(63 98 18 / 0.9);
}

.bg-lime-800\/95 {
  background-color: rgb(63 98 18 / 0.95);
}

.bg-lime-900 {
  --tw-bg-opacity: 1;
  background-color: rgb(54 83 20 / var(--tw-bg-opacity));
}

.bg-lime-900\/0 {
  background-color: rgb(54 83 20 / 0);
}

.bg-lime-900\/10 {
  background-color: rgb(54 83 20 / 0.1);
}

.bg-lime-900\/100 {
  background-color: rgb(54 83 20 / 1);
}

.bg-lime-900\/15 {
  background-color: rgb(54 83 20 / 0.15);
}

.bg-lime-900\/20 {
  background-color: rgb(54 83 20 / 0.2);
}

.bg-lime-900\/25 {
  background-color: rgb(54 83 20 / 0.25);
}

.bg-lime-900\/30 {
  background-color: rgb(54 83 20 / 0.3);
}

.bg-lime-900\/35 {
  background-color: rgb(54 83 20 / 0.35);
}

.bg-lime-900\/40 {
  background-color: rgb(54 83 20 / 0.4);
}

.bg-lime-900\/45 {
  background-color: rgb(54 83 20 / 0.45);
}

.bg-lime-900\/5 {
  background-color: rgb(54 83 20 / 0.05);
}

.bg-lime-900\/50 {
  background-color: rgb(54 83 20 / 0.5);
}

.bg-lime-900\/55 {
  background-color: rgb(54 83 20 / 0.55);
}

.bg-lime-900\/60 {
  background-color: rgb(54 83 20 / 0.6);
}

.bg-lime-900\/65 {
  background-color: rgb(54 83 20 / 0.65);
}

.bg-lime-900\/70 {
  background-color: rgb(54 83 20 / 0.7);
}

.bg-lime-900\/75 {
  background-color: rgb(54 83 20 / 0.75);
}

.bg-lime-900\/80 {
  background-color: rgb(54 83 20 / 0.8);
}

.bg-lime-900\/85 {
  background-color: rgb(54 83 20 / 0.85);
}

.bg-lime-900\/90 {
  background-color: rgb(54 83 20 / 0.9);
}

.bg-lime-900\/95 {
  background-color: rgb(54 83 20 / 0.95);
}

.bg-lime-950 {
  --tw-bg-opacity: 1;
  background-color: rgb(26 46 5 / var(--tw-bg-opacity));
}

.bg-lime-950\/0 {
  background-color: rgb(26 46 5 / 0);
}

.bg-lime-950\/10 {
  background-color: rgb(26 46 5 / 0.1);
}

.bg-lime-950\/100 {
  background-color: rgb(26 46 5 / 1);
}

.bg-lime-950\/15 {
  background-color: rgb(26 46 5 / 0.15);
}

.bg-lime-950\/20 {
  background-color: rgb(26 46 5 / 0.2);
}

.bg-lime-950\/25 {
  background-color: rgb(26 46 5 / 0.25);
}

.bg-lime-950\/30 {
  background-color: rgb(26 46 5 / 0.3);
}

.bg-lime-950\/35 {
  background-color: rgb(26 46 5 / 0.35);
}

.bg-lime-950\/40 {
  background-color: rgb(26 46 5 / 0.4);
}

.bg-lime-950\/45 {
  background-color: rgb(26 46 5 / 0.45);
}

.bg-lime-950\/5 {
  background-color: rgb(26 46 5 / 0.05);
}

.bg-lime-950\/50 {
  background-color: rgb(26 46 5 / 0.5);
}

.bg-lime-950\/55 {
  background-color: rgb(26 46 5 / 0.55);
}

.bg-lime-950\/60 {
  background-color: rgb(26 46 5 / 0.6);
}

.bg-lime-950\/65 {
  background-color: rgb(26 46 5 / 0.65);
}

.bg-lime-950\/70 {
  background-color: rgb(26 46 5 / 0.7);
}

.bg-lime-950\/75 {
  background-color: rgb(26 46 5 / 0.75);
}

.bg-lime-950\/80 {
  background-color: rgb(26 46 5 / 0.8);
}

.bg-lime-950\/85 {
  background-color: rgb(26 46 5 / 0.85);
}

.bg-lime-950\/90 {
  background-color: rgb(26 46 5 / 0.9);
}

.bg-lime-950\/95 {
  background-color: rgb(26 46 5 / 0.95);
}

.bg-neutral {
  --tw-bg-opacity: 1;
  background-color: var(--fallback-n,oklch(var(--n)/var(--tw-bg-opacity)));
}

.bg-neutral-100 {
  --tw-bg-opacity: 1;
  background-color: rgb(245 245 245 / var(--tw-bg-opacity));
}

.bg-neutral-100\/0 {
  background-color: rgb(245 245 245 / 0);
}

.bg-neutral-100\/10 {
  background-color: rgb(245 245 245 / 0.1);
}

.bg-neutral-100\/100 {
  background-color: rgb(245 245 245 / 1);
}

.bg-neutral-100\/15 {
  background-color: rgb(245 245 245 / 0.15);
}

.bg-neutral-100\/20 {
  background-color: rgb(245 245 245 / 0.2);
}

.bg-neutral-100\/25 {
  background-color: rgb(245 245 245 / 0.25);
}

.bg-neutral-100\/30 {
  background-color: rgb(245 245 245 / 0.3);
}

.bg-neutral-100\/35 {
  background-color: rgb(245 245 245 / 0.35);
}

.bg-neutral-100\/40 {
  background-color: rgb(245 245 245 / 0.4);
}

.bg-neutral-100\/45 {
  background-color: rgb(245 245 245 / 0.45);
}

.bg-neutral-100\/5 {
  background-color: rgb(245 245 245 / 0.05);
}

.bg-neutral-100\/50 {
  background-color: rgb(245 245 245 / 0.5);
}

.bg-neutral-100\/55 {
  background-color: rgb(245 245 245 / 0.55);
}

.bg-neutral-100\/60 {
  background-color: rgb(245 245 245 / 0.6);
}

.bg-neutral-100\/65 {
  background-color: rgb(245 245 245 / 0.65);
}

.bg-neutral-100\/70 {
  background-color: rgb(245 245 245 / 0.7);
}

.bg-neutral-100\/75 {
  background-color: rgb(245 245 245 / 0.75);
}

.bg-neutral-100\/80 {
  background-color: rgb(245 245 245 / 0.8);
}

.bg-neutral-100\/85 {
  background-color: rgb(245 245 245 / 0.85);
}

.bg-neutral-100\/90 {
  background-color: rgb(245 245 245 / 0.9);
}

.bg-neutral-100\/95 {
  background-color: rgb(245 245 245 / 0.95);
}

.bg-neutral-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(229 229 229 / var(--tw-bg-opacity));
}

.bg-neutral-200\/0 {
  background-color: rgb(229 229 229 / 0);
}

.bg-neutral-200\/10 {
  background-color: rgb(229 229 229 / 0.1);
}

.bg-neutral-200\/100 {
  background-color: rgb(229 229 229 / 1);
}

.bg-neutral-200\/15 {
  background-color: rgb(229 229 229 / 0.15);
}

.bg-neutral-200\/20 {
  background-color: rgb(229 229 229 / 0.2);
}

.bg-neutral-200\/25 {
  background-color: rgb(229 229 229 / 0.25);
}

.bg-neutral-200\/30 {
  background-color: rgb(229 229 229 / 0.3);
}

.bg-neutral-200\/35 {
  background-color: rgb(229 229 229 / 0.35);
}

.bg-neutral-200\/40 {
  background-color: rgb(229 229 229 / 0.4);
}

.bg-neutral-200\/45 {
  background-color: rgb(229 229 229 / 0.45);
}

.bg-neutral-200\/5 {
  background-color: rgb(229 229 229 / 0.05);
}

.bg-neutral-200\/50 {
  background-color: rgb(229 229 229 / 0.5);
}

.bg-neutral-200\/55 {
  background-color: rgb(229 229 229 / 0.55);
}

.bg-neutral-200\/60 {
  background-color: rgb(229 229 229 / 0.6);
}

.bg-neutral-200\/65 {
  background-color: rgb(229 229 229 / 0.65);
}

.bg-neutral-200\/70 {
  background-color: rgb(229 229 229 / 0.7);
}

.bg-neutral-200\/75 {
  background-color: rgb(229 229 229 / 0.75);
}

.bg-neutral-200\/80 {
  background-color: rgb(229 229 229 / 0.8);
}

.bg-neutral-200\/85 {
  background-color: rgb(229 229 229 / 0.85);
}

.bg-neutral-200\/90 {
  background-color: rgb(229 229 229 / 0.9);
}

.bg-neutral-200\/95 {
  background-color: rgb(229 229 229 / 0.95);
}

.bg-neutral-300 {
  --tw-bg-opacity: 1;
  background-color: rgb(212 212 212 / var(--tw-bg-opacity));
}

.bg-neutral-300\/0 {
  background-color: rgb(212 212 212 / 0);
}

.bg-neutral-300\/10 {
  background-color: rgb(212 212 212 / 0.1);
}

.bg-neutral-300\/100 {
  background-color: rgb(212 212 212 / 1);
}

.bg-neutral-300\/15 {
  background-color: rgb(212 212 212 / 0.15);
}

.bg-neutral-300\/20 {
  background-color: rgb(212 212 212 / 0.2);
}

.bg-neutral-300\/25 {
  background-color: rgb(212 212 212 / 0.25);
}

.bg-neutral-300\/30 {
  background-color: rgb(212 212 212 / 0.3);
}

.bg-neutral-300\/35 {
  background-color: rgb(212 212 212 / 0.35);
}

.bg-neutral-300\/40 {
  background-color: rgb(212 212 212 / 0.4);
}

.bg-neutral-300\/45 {
  background-color: rgb(212 212 212 / 0.45);
}

.bg-neutral-300\/5 {
  background-color: rgb(212 212 212 / 0.05);
}

.bg-neutral-300\/50 {
  background-color: rgb(212 212 212 / 0.5);
}

.bg-neutral-300\/55 {
  background-color: rgb(212 212 212 / 0.55);
}

.bg-neutral-300\/60 {
  background-color: rgb(212 212 212 / 0.6);
}

.bg-neutral-300\/65 {
  background-color: rgb(212 212 212 / 0.65);
}

.bg-neutral-300\/70 {
  background-color: rgb(212 212 212 / 0.7);
}

.bg-neutral-300\/75 {
  background-color: rgb(212 212 212 / 0.75);
}

.bg-neutral-300\/80 {
  background-color: rgb(212 212 212 / 0.8);
}

.bg-neutral-300\/85 {
  background-color: rgb(212 212 212 / 0.85);
}

.bg-neutral-300\/90 {
  background-color: rgb(212 212 212 / 0.9);
}

.bg-neutral-300\/95 {
  background-color: rgb(212 212 212 / 0.95);
}

.bg-neutral-400 {
  --tw-bg-opacity: 1;
  background-color: rgb(163 163 163 / var(--tw-bg-opacity));
}

.bg-neutral-400\/0 {
  background-color: rgb(163 163 163 / 0);
}

.bg-neutral-400\/10 {
  background-color: rgb(163 163 163 / 0.1);
}

.bg-neutral-400\/100 {
  background-color: rgb(163 163 163 / 1);
}

.bg-neutral-400\/15 {
  background-color: rgb(163 163 163 / 0.15);
}

.bg-neutral-400\/20 {
  background-color: rgb(163 163 163 / 0.2);
}

.bg-neutral-400\/25 {
  background-color: rgb(163 163 163 / 0.25);
}

.bg-neutral-400\/30 {
  background-color: rgb(163 163 163 / 0.3);
}

.bg-neutral-400\/35 {
  background-color: rgb(163 163 163 / 0.35);
}

.bg-neutral-400\/40 {
  background-color: rgb(163 163 163 / 0.4);
}

.bg-neutral-400\/45 {
  background-color: rgb(163 163 163 / 0.45);
}

.bg-neutral-400\/5 {
  background-color: rgb(163 163 163 / 0.05);
}

.bg-neutral-400\/50 {
  background-color: rgb(163 163 163 / 0.5);
}

.bg-neutral-400\/55 {
  background-color: rgb(163 163 163 / 0.55);
}

.bg-neutral-400\/60 {
  background-color: rgb(163 163 163 / 0.6);
}

.bg-neutral-400\/65 {
  background-color: rgb(163 163 163 / 0.65);
}

.bg-neutral-400\/70 {
  background-color: rgb(163 163 163 / 0.7);
}

.bg-neutral-400\/75 {
  background-color: rgb(163 163 163 / 0.75);
}

.bg-neutral-400\/80 {
  background-color: rgb(163 163 163 / 0.8);
}

.bg-neutral-400\/85 {
  background-color: rgb(163 163 163 / 0.85);
}

.bg-neutral-400\/90 {
  background-color: rgb(163 163 163 / 0.9);
}

.bg-neutral-400\/95 {
  background-color: rgb(163 163 163 / 0.95);
}

.bg-neutral-50 {
  --tw-bg-opacity: 1;
  background-color: rgb(250 250 250 / var(--tw-bg-opacity));
}

.bg-neutral-50\/0 {
  background-color: rgb(250 250 250 / 0);
}

.bg-neutral-50\/10 {
  background-color: rgb(250 250 250 / 0.1);
}

.bg-neutral-50\/100 {
  background-color: rgb(250 250 250 / 1);
}

.bg-neutral-50\/15 {
  background-color: rgb(250 250 250 / 0.15);
}

.bg-neutral-50\/20 {
  background-color: rgb(250 250 250 / 0.2);
}

.bg-neutral-50\/25 {
  background-color: rgb(250 250 250 / 0.25);
}

.bg-neutral-50\/30 {
  background-color: rgb(250 250 250 / 0.3);
}

.bg-neutral-50\/35 {
  background-color: rgb(250 250 250 / 0.35);
}

.bg-neutral-50\/40 {
  background-color: rgb(250 250 250 / 0.4);
}

.bg-neutral-50\/45 {
  background-color: rgb(250 250 250 / 0.45);
}

.bg-neutral-50\/5 {
  background-color: rgb(250 250 250 / 0.05);
}

.bg-neutral-50\/50 {
  background-color: rgb(250 250 250 / 0.5);
}

.bg-neutral-50\/55 {
  background-color: rgb(250 250 250 / 0.55);
}

.bg-neutral-50\/60 {
  background-color: rgb(250 250 250 / 0.6);
}

.bg-neutral-50\/65 {
  background-color: rgb(250 250 250 / 0.65);
}

.bg-neutral-50\/70 {
  background-color: rgb(250 250 250 / 0.7);
}

.bg-neutral-50\/75 {
  background-color: rgb(250 250 250 / 0.75);
}

.bg-neutral-50\/80 {
  background-color: rgb(250 250 250 / 0.8);
}

.bg-neutral-50\/85 {
  background-color: rgb(250 250 250 / 0.85);
}

.bg-neutral-50\/90 {
  background-color: rgb(250 250 250 / 0.9);
}

.bg-neutral-50\/95 {
  background-color: rgb(250 250 250 / 0.95);
}

.bg-neutral-500 {
  --tw-bg-opacity: 1;
  background-color: rgb(115 115 115 / var(--tw-bg-opacity));
}

.bg-neutral-500\/0 {
  background-color: rgb(115 115 115 / 0);
}

.bg-neutral-500\/10 {
  background-color: rgb(115 115 115 / 0.1);
}

.bg-neutral-500\/100 {
  background-color: rgb(115 115 115 / 1);
}

.bg-neutral-500\/15 {
  background-color: rgb(115 115 115 / 0.15);
}

.bg-neutral-500\/20 {
  background-color: rgb(115 115 115 / 0.2);
}

.bg-neutral-500\/25 {
  background-color: rgb(115 115 115 / 0.25);
}

.bg-neutral-500\/30 {
  background-color: rgb(115 115 115 / 0.3);
}

.bg-neutral-500\/35 {
  background-color: rgb(115 115 115 / 0.35);
}

.bg-neutral-500\/40 {
  background-color: rgb(115 115 115 / 0.4);
}

.bg-neutral-500\/45 {
  background-color: rgb(115 115 115 / 0.45);
}

.bg-neutral-500\/5 {
  background-color: rgb(115 115 115 / 0.05);
}

.bg-neutral-500\/50 {
  background-color: rgb(115 115 115 / 0.5);
}

.bg-neutral-500\/55 {
  background-color: rgb(115 115 115 / 0.55);
}

.bg-neutral-500\/60 {
  background-color: rgb(115 115 115 / 0.6);
}

.bg-neutral-500\/65 {
  background-color: rgb(115 115 115 / 0.65);
}

.bg-neutral-500\/70 {
  background-color: rgb(115 115 115 / 0.7);
}

.bg-neutral-500\/75 {
  background-color: rgb(115 115 115 / 0.75);
}

.bg-neutral-500\/80 {
  background-color: rgb(115 115 115 / 0.8);
}

.bg-neutral-500\/85 {
  background-color: rgb(115 115 115 / 0.85);
}

.bg-neutral-500\/90 {
  background-color: rgb(115 115 115 / 0.9);
}

.bg-neutral-500\/95 {
  background-color: rgb(115 115 115 / 0.95);
}

.bg-neutral-600 {
  --tw-bg-opacity: 1;
  background-color: rgb(82 82 82 / var(--tw-bg-opacity));
}

.bg-neutral-600\/0 {
  background-color: rgb(82 82 82 / 0);
}

.bg-neutral-600\/10 {
  background-color: rgb(82 82 82 / 0.1);
}

.bg-neutral-600\/100 {
  background-color: rgb(82 82 82 / 1);
}

.bg-neutral-600\/15 {
  background-color: rgb(82 82 82 / 0.15);
}

.bg-neutral-600\/20 {
  background-color: rgb(82 82 82 / 0.2);
}

.bg-neutral-600\/25 {
  background-color: rgb(82 82 82 / 0.25);
}

.bg-neutral-600\/30 {
  background-color: rgb(82 82 82 / 0.3);
}

.bg-neutral-600\/35 {
  background-color: rgb(82 82 82 / 0.35);
}

.bg-neutral-600\/40 {
  background-color: rgb(82 82 82 / 0.4);
}

.bg-neutral-600\/45 {
  background-color: rgb(82 82 82 / 0.45);
}

.bg-neutral-600\/5 {
  background-color: rgb(82 82 82 / 0.05);
}

.bg-neutral-600\/50 {
  background-color: rgb(82 82 82 / 0.5);
}

.bg-neutral-600\/55 {
  background-color: rgb(82 82 82 / 0.55);
}

.bg-neutral-600\/60 {
  background-color: rgb(82 82 82 / 0.6);
}

.bg-neutral-600\/65 {
  background-color: rgb(82 82 82 / 0.65);
}

.bg-neutral-600\/70 {
  background-color: rgb(82 82 82 / 0.7);
}

.bg-neutral-600\/75 {
  background-color: rgb(82 82 82 / 0.75);
}

.bg-neutral-600\/80 {
  background-color: rgb(82 82 82 / 0.8);
}

.bg-neutral-600\/85 {
  background-color: rgb(82 82 82 / 0.85);
}

.bg-neutral-600\/90 {
  background-color: rgb(82 82 82 / 0.9);
}

.bg-neutral-600\/95 {
  background-color: rgb(82 82 82 / 0.95);
}

.bg-neutral-700 {
  --tw-bg-opacity: 1;
  background-color: rgb(64 64 64 / var(--tw-bg-opacity));
}

.bg-neutral-700\/0 {
  background-color: rgb(64 64 64 / 0);
}

.bg-neutral-700\/10 {
  background-color: rgb(64 64 64 / 0.1);
}

.bg-neutral-700\/100 {
  background-color: rgb(64 64 64 / 1);
}

.bg-neutral-700\/15 {
  background-color: rgb(64 64 64 / 0.15);
}

.bg-neutral-700\/20 {
  background-color: rgb(64 64 64 / 0.2);
}

.bg-neutral-700\/25 {
  background-color: rgb(64 64 64 / 0.25);
}

.bg-neutral-700\/30 {
  background-color: rgb(64 64 64 / 0.3);
}

.bg-neutral-700\/35 {
  background-color: rgb(64 64 64 / 0.35);
}

.bg-neutral-700\/40 {
  background-color: rgb(64 64 64 / 0.4);
}

.bg-neutral-700\/45 {
  background-color: rgb(64 64 64 / 0.45);
}

.bg-neutral-700\/5 {
  background-color: rgb(64 64 64 / 0.05);
}

.bg-neutral-700\/50 {
  background-color: rgb(64 64 64 / 0.5);
}

.bg-neutral-700\/55 {
  background-color: rgb(64 64 64 / 0.55);
}

.bg-neutral-700\/60 {
  background-color: rgb(64 64 64 / 0.6);
}

.bg-neutral-700\/65 {
  background-color: rgb(64 64 64 / 0.65);
}

.bg-neutral-700\/70 {
  background-color: rgb(64 64 64 / 0.7);
}

.bg-neutral-700\/75 {
  background-color: rgb(64 64 64 / 0.75);
}

.bg-neutral-700\/80 {
  background-color: rgb(64 64 64 / 0.8);
}

.bg-neutral-700\/85 {
  background-color: rgb(64 64 64 / 0.85);
}

.bg-neutral-700\/90 {
  background-color: rgb(64 64 64 / 0.9);
}

.bg-neutral-700\/95 {
  background-color: rgb(64 64 64 / 0.95);
}

.bg-neutral-800 {
  --tw-bg-opacity: 1;
  background-color: rgb(38 38 38 / var(--tw-bg-opacity));
}

.bg-neutral-800\/0 {
  background-color: rgb(38 38 38 / 0);
}

.bg-neutral-800\/10 {
  background-color: rgb(38 38 38 / 0.1);
}

.bg-neutral-800\/100 {
  background-color: rgb(38 38 38 / 1);
}

.bg-neutral-800\/15 {
  background-color: rgb(38 38 38 / 0.15);
}

.bg-neutral-800\/20 {
  background-color: rgb(38 38 38 / 0.2);
}

.bg-neutral-800\/25 {
  background-color: rgb(38 38 38 / 0.25);
}

.bg-neutral-800\/30 {
  background-color: rgb(38 38 38 / 0.3);
}

.bg-neutral-800\/35 {
  background-color: rgb(38 38 38 / 0.35);
}

.bg-neutral-800\/40 {
  background-color: rgb(38 38 38 / 0.4);
}

.bg-neutral-800\/45 {
  background-color: rgb(38 38 38 / 0.45);
}

.bg-neutral-800\/5 {
  background-color: rgb(38 38 38 / 0.05);
}

.bg-neutral-800\/50 {
  background-color: rgb(38 38 38 / 0.5);
}

.bg-neutral-800\/55 {
  background-color: rgb(38 38 38 / 0.55);
}

.bg-neutral-800\/60 {
  background-color: rgb(38 38 38 / 0.6);
}

.bg-neutral-800\/65 {
  background-color: rgb(38 38 38 / 0.65);
}

.bg-neutral-800\/70 {
  background-color: rgb(38 38 38 / 0.7);
}

.bg-neutral-800\/75 {
  background-color: rgb(38 38 38 / 0.75);
}

.bg-neutral-800\/80 {
  background-color: rgb(38 38 38 / 0.8);
}

.bg-neutral-800\/85 {
  background-color: rgb(38 38 38 / 0.85);
}

.bg-neutral-800\/90 {
  background-color: rgb(38 38 38 / 0.9);
}

.bg-neutral-800\/95 {
  background-color: rgb(38 38 38 / 0.95);
}

.bg-neutral-900 {
  --tw-bg-opacity: 1;
  background-color: rgb(23 23 23 / var(--tw-bg-opacity));
}

.bg-neutral-900\/0 {
  background-color: rgb(23 23 23 / 0);
}

.bg-neutral-900\/10 {
  background-color: rgb(23 23 23 / 0.1);
}

.bg-neutral-900\/100 {
  background-color: rgb(23 23 23 / 1);
}

.bg-neutral-900\/15 {
  background-color: rgb(23 23 23 / 0.15);
}

.bg-neutral-900\/20 {
  background-color: rgb(23 23 23 / 0.2);
}

.bg-neutral-900\/25 {
  background-color: rgb(23 23 23 / 0.25);
}

.bg-neutral-900\/30 {
  background-color: rgb(23 23 23 / 0.3);
}

.bg-neutral-900\/35 {
  background-color: rgb(23 23 23 / 0.35);
}

.bg-neutral-900\/40 {
  background-color: rgb(23 23 23 / 0.4);
}

.bg-neutral-900\/45 {
  background-color: rgb(23 23 23 / 0.45);
}

.bg-neutral-900\/5 {
  background-color: rgb(23 23 23 / 0.05);
}

.bg-neutral-900\/50 {
  background-color: rgb(23 23 23 / 0.5);
}

.bg-neutral-900\/55 {
  background-color: rgb(23 23 23 / 0.55);
}

.bg-neutral-900\/60 {
  background-color: rgb(23 23 23 / 0.6);
}

.bg-neutral-900\/65 {
  background-color: rgb(23 23 23 / 0.65);
}

.bg-neutral-900\/70 {
  background-color: rgb(23 23 23 / 0.7);
}

.bg-neutral-900\/75 {
  background-color: rgb(23 23 23 / 0.75);
}

.bg-neutral-900\/80 {
  background-color: rgb(23 23 23 / 0.8);
}

.bg-neutral-900\/85 {
  background-color: rgb(23 23 23 / 0.85);
}

.bg-neutral-900\/90 {
  background-color: rgb(23 23 23 / 0.9);
}

.bg-neutral-900\/95 {
  background-color: rgb(23 23 23 / 0.95);
}

.bg-neutral-950 {
  --tw-bg-opacity: 1;
  background-color: rgb(10 10 10 / var(--tw-bg-opacity));
}

.bg-neutral-950\/0 {
  background-color: rgb(10 10 10 / 0);
}

.bg-neutral-950\/10 {
  background-color: rgb(10 10 10 / 0.1);
}

.bg-neutral-950\/100 {
  background-color: rgb(10 10 10 / 1);
}

.bg-neutral-950\/15 {
  background-color: rgb(10 10 10 / 0.15);
}

.bg-neutral-950\/20 {
  background-color: rgb(10 10 10 / 0.2);
}

.bg-neutral-950\/25 {
  background-color: rgb(10 10 10 / 0.25);
}

.bg-neutral-950\/30 {
  background-color: rgb(10 10 10 / 0.3);
}

.bg-neutral-950\/35 {
  background-color: rgb(10 10 10 / 0.35);
}

.bg-neutral-950\/40 {
  background-color: rgb(10 10 10 / 0.4);
}

.bg-neutral-950\/45 {
  background-color: rgb(10 10 10 / 0.45);
}

.bg-neutral-950\/5 {
  background-color: rgb(10 10 10 / 0.05);
}

.bg-neutral-950\/50 {
  background-color: rgb(10 10 10 / 0.5);
}

.bg-neutral-950\/55 {
  background-color: rgb(10 10 10 / 0.55);
}

.bg-neutral-950\/60 {
  background-color: rgb(10 10 10 / 0.6);
}

.bg-neutral-950\/65 {
  background-color: rgb(10 10 10 / 0.65);
}

.bg-neutral-950\/70 {
  background-color: rgb(10 10 10 / 0.7);
}

.bg-neutral-950\/75 {
  background-color: rgb(10 10 10 / 0.75);
}

.bg-neutral-950\/80 {
  background-color: rgb(10 10 10 / 0.8);
}

.bg-neutral-950\/85 {
  background-color: rgb(10 10 10 / 0.85);
}

.bg-neutral-950\/90 {
  background-color: rgb(10 10 10 / 0.9);
}

.bg-neutral-950\/95 {
  background-color: rgb(10 10 10 / 0.95);
}

.bg-neutral-content {
  --tw-bg-opacity: 1;
  background-color: var(--fallback-nc,oklch(var(--nc)/var(--tw-bg-opacity)));
}

.bg-neutral-content\/0 {
  background-color: var(--fallback-nc,oklch(var(--nc)/0));
}

.bg-neutral-content\/10 {
  background-color: var(--fallback-nc,oklch(var(--nc)/0.1));
}

.bg-neutral-content\/100 {
  background-color: var(--fallback-nc,oklch(var(--nc)/1));
}

.bg-neutral-content\/15 {
  background-color: var(--fallback-nc,oklch(var(--nc)/0.15));
}

.bg-neutral-content\/20 {
  background-color: var(--fallback-nc,oklch(var(--nc)/0.2));
}

.bg-neutral-content\/25 {
  background-color: var(--fallback-nc,oklch(var(--nc)/0.25));
}

.bg-neutral-content\/30 {
  background-color: var(--fallback-nc,oklch(var(--nc)/0.3));
}

.bg-neutral-content\/35 {
  background-color: var(--fallback-nc,oklch(var(--nc)/0.35));
}

.bg-neutral-content\/40 {
  background-color: var(--fallback-nc,oklch(var(--nc)/0.4));
}

.bg-neutral-content\/45 {
  background-color: var(--fallback-nc,oklch(var(--nc)/0.45));
}

.bg-neutral-content\/5 {
  background-color: var(--fallback-nc,oklch(var(--nc)/0.05));
}

.bg-neutral-content\/50 {
  background-color: var(--fallback-nc,oklch(var(--nc)/0.5));
}

.bg-neutral-content\/55 {
  background-color: var(--fallback-nc,oklch(var(--nc)/0.55));
}

.bg-neutral-content\/60 {
  background-color: var(--fallback-nc,oklch(var(--nc)/0.6));
}

.bg-neutral-content\/65 {
  background-color: var(--fallback-nc,oklch(var(--nc)/0.65));
}

.bg-neutral-content\/70 {
  background-color: var(--fallback-nc,oklch(var(--nc)/0.7));
}

.bg-neutral-content\/75 {
  background-color: var(--fallback-nc,oklch(var(--nc)/0.75));
}

.bg-neutral-content\/80 {
  background-color: var(--fallback-nc,oklch(var(--nc)/0.8));
}

.bg-neutral-content\/85 {
  background-color: var(--fallback-nc,oklch(var(--nc)/0.85));
}

.bg-neutral-content\/90 {
  background-color: var(--fallback-nc,oklch(var(--nc)/0.9));
}

.bg-neutral-content\/95 {
  background-color: var(--fallback-nc,oklch(var(--nc)/0.95));
}

.bg-neutral\/0 {
  background-color: var(--fallback-n,oklch(var(--n)/0));
}

.bg-neutral\/10 {
  background-color: var(--fallback-n,oklch(var(--n)/0.1));
}

.bg-neutral\/100 {
  background-color: var(--fallback-n,oklch(var(--n)/1));
}

.bg-neutral\/15 {
  background-color: var(--fallback-n,oklch(var(--n)/0.15));
}

.bg-neutral\/20 {
  background-color: var(--fallback-n,oklch(var(--n)/0.2));
}

.bg-neutral\/25 {
  background-color: var(--fallback-n,oklch(var(--n)/0.25));
}

.bg-neutral\/30 {
  background-color: var(--fallback-n,oklch(var(--n)/0.3));
}

.bg-neutral\/35 {
  background-color: var(--fallback-n,oklch(var(--n)/0.35));
}

.bg-neutral\/40 {
  background-color: var(--fallback-n,oklch(var(--n)/0.4));
}

.bg-neutral\/45 {
  background-color: var(--fallback-n,oklch(var(--n)/0.45));
}

.bg-neutral\/5 {
  background-color: var(--fallback-n,oklch(var(--n)/0.05));
}

.bg-neutral\/50 {
  background-color: var(--fallback-n,oklch(var(--n)/0.5));
}

.bg-neutral\/55 {
  background-color: var(--fallback-n,oklch(var(--n)/0.55));
}

.bg-neutral\/60 {
  background-color: var(--fallback-n,oklch(var(--n)/0.6));
}

.bg-neutral\/65 {
  background-color: var(--fallback-n,oklch(var(--n)/0.65));
}

.bg-neutral\/70 {
  background-color: var(--fallback-n,oklch(var(--n)/0.7));
}

.bg-neutral\/75 {
  background-color: var(--fallback-n,oklch(var(--n)/0.75));
}

.bg-neutral\/80 {
  background-color: var(--fallback-n,oklch(var(--n)/0.8));
}

.bg-neutral\/85 {
  background-color: var(--fallback-n,oklch(var(--n)/0.85));
}

.bg-neutral\/90 {
  background-color: var(--fallback-n,oklch(var(--n)/0.9));
}

.bg-neutral\/95 {
  background-color: var(--fallback-n,oklch(var(--n)/0.95));
}

.bg-orange-100 {
  --tw-bg-opacity: 1;
  background-color: rgb(255 237 213 / var(--tw-bg-opacity));
}

.bg-orange-100\/0 {
  background-color: rgb(255 237 213 / 0);
}

.bg-orange-100\/10 {
  background-color: rgb(255 237 213 / 0.1);
}

.bg-orange-100\/100 {
  background-color: rgb(255 237 213 / 1);
}

.bg-orange-100\/15 {
  background-color: rgb(255 237 213 / 0.15);
}

.bg-orange-100\/20 {
  background-color: rgb(255 237 213 / 0.2);
}

.bg-orange-100\/25 {
  background-color: rgb(255 237 213 / 0.25);
}

.bg-orange-100\/30 {
  background-color: rgb(255 237 213 / 0.3);
}

.bg-orange-100\/35 {
  background-color: rgb(255 237 213 / 0.35);
}

.bg-orange-100\/40 {
  background-color: rgb(255 237 213 / 0.4);
}

.bg-orange-100\/45 {
  background-color: rgb(255 237 213 / 0.45);
}

.bg-orange-100\/5 {
  background-color: rgb(255 237 213 / 0.05);
}

.bg-orange-100\/50 {
  background-color: rgb(255 237 213 / 0.5);
}

.bg-orange-100\/55 {
  background-color: rgb(255 237 213 / 0.55);
}

.bg-orange-100\/60 {
  background-color: rgb(255 237 213 / 0.6);
}

.bg-orange-100\/65 {
  background-color: rgb(255 237 213 / 0.65);
}

.bg-orange-100\/70 {
  background-color: rgb(255 237 213 / 0.7);
}

.bg-orange-100\/75 {
  background-color: rgb(255 237 213 / 0.75);
}

.bg-orange-100\/80 {
  background-color: rgb(255 237 213 / 0.8);
}

.bg-orange-100\/85 {
  background-color: rgb(255 237 213 / 0.85);
}

.bg-orange-100\/90 {
  background-color: rgb(255 237 213 / 0.9);
}

.bg-orange-100\/95 {
  background-color: rgb(255 237 213 / 0.95);
}

.bg-orange-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(254 215 170 / var(--tw-bg-opacity));
}

.bg-orange-200\/0 {
  background-color: rgb(254 215 170 / 0);
}

.bg-orange-200\/10 {
  background-color: rgb(254 215 170 / 0.1);
}

.bg-orange-200\/100 {
  background-color: rgb(254 215 170 / 1);
}

.bg-orange-200\/15 {
  background-color: rgb(254 215 170 / 0.15);
}

.bg-orange-200\/20 {
  background-color: rgb(254 215 170 / 0.2);
}

.bg-orange-200\/25 {
  background-color: rgb(254 215 170 / 0.25);
}

.bg-orange-200\/30 {
  background-color: rgb(254 215 170 / 0.3);
}

.bg-orange-200\/35 {
  background-color: rgb(254 215 170 / 0.35);
}

.bg-orange-200\/40 {
  background-color: rgb(254 215 170 / 0.4);
}

.bg-orange-200\/45 {
  background-color: rgb(254 215 170 / 0.45);
}

.bg-orange-200\/5 {
  background-color: rgb(254 215 170 / 0.05);
}

.bg-orange-200\/50 {
  background-color: rgb(254 215 170 / 0.5);
}

.bg-orange-200\/55 {
  background-color: rgb(254 215 170 / 0.55);
}

.bg-orange-200\/60 {
  background-color: rgb(254 215 170 / 0.6);
}

.bg-orange-200\/65 {
  background-color: rgb(254 215 170 / 0.65);
}

.bg-orange-200\/70 {
  background-color: rgb(254 215 170 / 0.7);
}

.bg-orange-200\/75 {
  background-color: rgb(254 215 170 / 0.75);
}

.bg-orange-200\/80 {
  background-color: rgb(254 215 170 / 0.8);
}

.bg-orange-200\/85 {
  background-color: rgb(254 215 170 / 0.85);
}

.bg-orange-200\/90 {
  background-color: rgb(254 215 170 / 0.9);
}

.bg-orange-200\/95 {
  background-color: rgb(254 215 170 / 0.95);
}

.bg-orange-300 {
  --tw-bg-opacity: 1;
  background-color: rgb(253 186 116 / var(--tw-bg-opacity));
}

.bg-orange-300\/0 {
  background-color: rgb(253 186 116 / 0);
}

.bg-orange-300\/10 {
  background-color: rgb(253 186 116 / 0.1);
}

.bg-orange-300\/100 {
  background-color: rgb(253 186 116 / 1);
}

.bg-orange-300\/15 {
  background-color: rgb(253 186 116 / 0.15);
}

.bg-orange-300\/20 {
  background-color: rgb(253 186 116 / 0.2);
}

.bg-orange-300\/25 {
  background-color: rgb(253 186 116 / 0.25);
}

.bg-orange-300\/30 {
  background-color: rgb(253 186 116 / 0.3);
}

.bg-orange-300\/35 {
  background-color: rgb(253 186 116 / 0.35);
}

.bg-orange-300\/40 {
  background-color: rgb(253 186 116 / 0.4);
}

.bg-orange-300\/45 {
  background-color: rgb(253 186 116 / 0.45);
}

.bg-orange-300\/5 {
  background-color: rgb(253 186 116 / 0.05);
}

.bg-orange-300\/50 {
  background-color: rgb(253 186 116 / 0.5);
}

.bg-orange-300\/55 {
  background-color: rgb(253 186 116 / 0.55);
}

.bg-orange-300\/60 {
  background-color: rgb(253 186 116 / 0.6);
}

.bg-orange-300\/65 {
  background-color: rgb(253 186 116 / 0.65);
}

.bg-orange-300\/70 {
  background-color: rgb(253 186 116 / 0.7);
}

.bg-orange-300\/75 {
  background-color: rgb(253 186 116 / 0.75);
}

.bg-orange-300\/80 {
  background-color: rgb(253 186 116 / 0.8);
}

.bg-orange-300\/85 {
  background-color: rgb(253 186 116 / 0.85);
}

.bg-orange-300\/90 {
  background-color: rgb(253 186 116 / 0.9);
}

.bg-orange-300\/95 {
  background-color: rgb(253 186 116 / 0.95);
}

.bg-orange-400 {
  --tw-bg-opacity: 1;
  background-color: rgb(251 146 60 / var(--tw-bg-opacity));
}

.bg-orange-400\/0 {
  background-color: rgb(251 146 60 / 0);
}

.bg-orange-400\/10 {
  background-color: rgb(251 146 60 / 0.1);
}

.bg-orange-400\/100 {
  background-color: rgb(251 146 60 / 1);
}

.bg-orange-400\/15 {
  background-color: rgb(251 146 60 / 0.15);
}

.bg-orange-400\/20 {
  background-color: rgb(251 146 60 / 0.2);
}

.bg-orange-400\/25 {
  background-color: rgb(251 146 60 / 0.25);
}

.bg-orange-400\/30 {
  background-color: rgb(251 146 60 / 0.3);
}

.bg-orange-400\/35 {
  background-color: rgb(251 146 60 / 0.35);
}

.bg-orange-400\/40 {
  background-color: rgb(251 146 60 / 0.4);
}

.bg-orange-400\/45 {
  background-color: rgb(251 146 60 / 0.45);
}

.bg-orange-400\/5 {
  background-color: rgb(251 146 60 / 0.05);
}

.bg-orange-400\/50 {
  background-color: rgb(251 146 60 / 0.5);
}

.bg-orange-400\/55 {
  background-color: rgb(251 146 60 / 0.55);
}

.bg-orange-400\/60 {
  background-color: rgb(251 146 60 / 0.6);
}

.bg-orange-400\/65 {
  background-color: rgb(251 146 60 / 0.65);
}

.bg-orange-400\/70 {
  background-color: rgb(251 146 60 / 0.7);
}

.bg-orange-400\/75 {
  background-color: rgb(251 146 60 / 0.75);
}

.bg-orange-400\/80 {
  background-color: rgb(251 146 60 / 0.8);
}

.bg-orange-400\/85 {
  background-color: rgb(251 146 60 / 0.85);
}

.bg-orange-400\/90 {
  background-color: rgb(251 146 60 / 0.9);
}

.bg-orange-400\/95 {
  background-color: rgb(251 146 60 / 0.95);
}

.bg-orange-50 {
  --tw-bg-opacity: 1;
  background-color: rgb(255 247 237 / var(--tw-bg-opacity));
}

.bg-orange-50\/0 {
  background-color: rgb(255 247 237 / 0);
}

.bg-orange-50\/10 {
  background-color: rgb(255 247 237 / 0.1);
}

.bg-orange-50\/100 {
  background-color: rgb(255 247 237 / 1);
}

.bg-orange-50\/15 {
  background-color: rgb(255 247 237 / 0.15);
}

.bg-orange-50\/20 {
  background-color: rgb(255 247 237 / 0.2);
}

.bg-orange-50\/25 {
  background-color: rgb(255 247 237 / 0.25);
}

.bg-orange-50\/30 {
  background-color: rgb(255 247 237 / 0.3);
}

.bg-orange-50\/35 {
  background-color: rgb(255 247 237 / 0.35);
}

.bg-orange-50\/40 {
  background-color: rgb(255 247 237 / 0.4);
}

.bg-orange-50\/45 {
  background-color: rgb(255 247 237 / 0.45);
}

.bg-orange-50\/5 {
  background-color: rgb(255 247 237 / 0.05);
}

.bg-orange-50\/50 {
  background-color: rgb(255 247 237 / 0.5);
}

.bg-orange-50\/55 {
  background-color: rgb(255 247 237 / 0.55);
}

.bg-orange-50\/60 {
  background-color: rgb(255 247 237 / 0.6);
}

.bg-orange-50\/65 {
  background-color: rgb(255 247 237 / 0.65);
}

.bg-orange-50\/70 {
  background-color: rgb(255 247 237 / 0.7);
}

.bg-orange-50\/75 {
  background-color: rgb(255 247 237 / 0.75);
}

.bg-orange-50\/80 {
  background-color: rgb(255 247 237 / 0.8);
}

.bg-orange-50\/85 {
  background-color: rgb(255 247 237 / 0.85);
}

.bg-orange-50\/90 {
  background-color: rgb(255 247 237 / 0.9);
}

.bg-orange-50\/95 {
  background-color: rgb(255 247 237 / 0.95);
}

.bg-orange-500 {
  --tw-bg-opacity: 1;
  background-color: rgb(249 115 22 / var(--tw-bg-opacity));
}

.bg-orange-500\/0 {
  background-color: rgb(249 115 22 / 0);
}

.bg-orange-500\/10 {
  background-color: rgb(249 115 22 / 0.1);
}

.bg-orange-500\/100 {
  background-color: rgb(249 115 22 / 1);
}

.bg-orange-500\/15 {
  background-color: rgb(249 115 22 / 0.15);
}

.bg-orange-500\/20 {
  background-color: rgb(249 115 22 / 0.2);
}

.bg-orange-500\/25 {
  background-color: rgb(249 115 22 / 0.25);
}

.bg-orange-500\/30 {
  background-color: rgb(249 115 22 / 0.3);
}

.bg-orange-500\/35 {
  background-color: rgb(249 115 22 / 0.35);
}

.bg-orange-500\/40 {
  background-color: rgb(249 115 22 / 0.4);
}

.bg-orange-500\/45 {
  background-color: rgb(249 115 22 / 0.45);
}

.bg-orange-500\/5 {
  background-color: rgb(249 115 22 / 0.05);
}

.bg-orange-500\/50 {
  background-color: rgb(249 115 22 / 0.5);
}

.bg-orange-500\/55 {
  background-color: rgb(249 115 22 / 0.55);
}

.bg-orange-500\/60 {
  background-color: rgb(249 115 22 / 0.6);
}

.bg-orange-500\/65 {
  background-color: rgb(249 115 22 / 0.65);
}

.bg-orange-500\/70 {
  background-color: rgb(249 115 22 / 0.7);
}

.bg-orange-500\/75 {
  background-color: rgb(249 115 22 / 0.75);
}

.bg-orange-500\/80 {
  background-color: rgb(249 115 22 / 0.8);
}

.bg-orange-500\/85 {
  background-color: rgb(249 115 22 / 0.85);
}

.bg-orange-500\/90 {
  background-color: rgb(249 115 22 / 0.9);
}

.bg-orange-500\/95 {
  background-color: rgb(249 115 22 / 0.95);
}

.bg-orange-600 {
  --tw-bg-opacity: 1;
  background-color: rgb(234 88 12 / var(--tw-bg-opacity));
}

.bg-orange-600\/0 {
  background-color: rgb(234 88 12 / 0);
}

.bg-orange-600\/10 {
  background-color: rgb(234 88 12 / 0.1);
}

.bg-orange-600\/100 {
  background-color: rgb(234 88 12 / 1);
}

.bg-orange-600\/15 {
  background-color: rgb(234 88 12 / 0.15);
}

.bg-orange-600\/20 {
  background-color: rgb(234 88 12 / 0.2);
}

.bg-orange-600\/25 {
  background-color: rgb(234 88 12 / 0.25);
}

.bg-orange-600\/30 {
  background-color: rgb(234 88 12 / 0.3);
}

.bg-orange-600\/35 {
  background-color: rgb(234 88 12 / 0.35);
}

.bg-orange-600\/40 {
  background-color: rgb(234 88 12 / 0.4);
}

.bg-orange-600\/45 {
  background-color: rgb(234 88 12 / 0.45);
}

.bg-orange-600\/5 {
  background-color: rgb(234 88 12 / 0.05);
}

.bg-orange-600\/50 {
  background-color: rgb(234 88 12 / 0.5);
}

.bg-orange-600\/55 {
  background-color: rgb(234 88 12 / 0.55);
}

.bg-orange-600\/60 {
  background-color: rgb(234 88 12 / 0.6);
}

.bg-orange-600\/65 {
  background-color: rgb(234 88 12 / 0.65);
}

.bg-orange-600\/70 {
  background-color: rgb(234 88 12 / 0.7);
}

.bg-orange-600\/75 {
  background-color: rgb(234 88 12 / 0.75);
}

.bg-orange-600\/80 {
  background-color: rgb(234 88 12 / 0.8);
}

.bg-orange-600\/85 {
  background-color: rgb(234 88 12 / 0.85);
}

.bg-orange-600\/90 {
  background-color: rgb(234 88 12 / 0.9);
}

.bg-orange-600\/95 {
  background-color: rgb(234 88 12 / 0.95);
}

.bg-orange-700 {
  --tw-bg-opacity: 1;
  background-color: rgb(194 65 12 / var(--tw-bg-opacity));
}

.bg-orange-700\/0 {
  background-color: rgb(194 65 12 / 0);
}

.bg-orange-700\/10 {
  background-color: rgb(194 65 12 / 0.1);
}

.bg-orange-700\/100 {
  background-color: rgb(194 65 12 / 1);
}

.bg-orange-700\/15 {
  background-color: rgb(194 65 12 / 0.15);
}

.bg-orange-700\/20 {
  background-color: rgb(194 65 12 / 0.2);
}

.bg-orange-700\/25 {
  background-color: rgb(194 65 12 / 0.25);
}

.bg-orange-700\/30 {
  background-color: rgb(194 65 12 / 0.3);
}

.bg-orange-700\/35 {
  background-color: rgb(194 65 12 / 0.35);
}

.bg-orange-700\/40 {
  background-color: rgb(194 65 12 / 0.4);
}

.bg-orange-700\/45 {
  background-color: rgb(194 65 12 / 0.45);
}

.bg-orange-700\/5 {
  background-color: rgb(194 65 12 / 0.05);
}

.bg-orange-700\/50 {
  background-color: rgb(194 65 12 / 0.5);
}

.bg-orange-700\/55 {
  background-color: rgb(194 65 12 / 0.55);
}

.bg-orange-700\/60 {
  background-color: rgb(194 65 12 / 0.6);
}

.bg-orange-700\/65 {
  background-color: rgb(194 65 12 / 0.65);
}

.bg-orange-700\/70 {
  background-color: rgb(194 65 12 / 0.7);
}

.bg-orange-700\/75 {
  background-color: rgb(194 65 12 / 0.75);
}

.bg-orange-700\/80 {
  background-color: rgb(194 65 12 / 0.8);
}

.bg-orange-700\/85 {
  background-color: rgb(194 65 12 / 0.85);
}

.bg-orange-700\/90 {
  background-color: rgb(194 65 12 / 0.9);
}

.bg-orange-700\/95 {
  background-color: rgb(194 65 12 / 0.95);
}

.bg-orange-800 {
  --tw-bg-opacity: 1;
  background-color: rgb(154 52 18 / var(--tw-bg-opacity));
}

.bg-orange-800\/0 {
  background-color: rgb(154 52 18 / 0);
}

.bg-orange-800\/10 {
  background-color: rgb(154 52 18 / 0.1);
}

.bg-orange-800\/100 {
  background-color: rgb(154 52 18 / 1);
}

.bg-orange-800\/15 {
  background-color: rgb(154 52 18 / 0.15);
}

.bg-orange-800\/20 {
  background-color: rgb(154 52 18 / 0.2);
}

.bg-orange-800\/25 {
  background-color: rgb(154 52 18 / 0.25);
}

.bg-orange-800\/30 {
  background-color: rgb(154 52 18 / 0.3);
}

.bg-orange-800\/35 {
  background-color: rgb(154 52 18 / 0.35);
}

.bg-orange-800\/40 {
  background-color: rgb(154 52 18 / 0.4);
}

.bg-orange-800\/45 {
  background-color: rgb(154 52 18 / 0.45);
}

.bg-orange-800\/5 {
  background-color: rgb(154 52 18 / 0.05);
}

.bg-orange-800\/50 {
  background-color: rgb(154 52 18 / 0.5);
}

.bg-orange-800\/55 {
  background-color: rgb(154 52 18 / 0.55);
}

.bg-orange-800\/60 {
  background-color: rgb(154 52 18 / 0.6);
}

.bg-orange-800\/65 {
  background-color: rgb(154 52 18 / 0.65);
}

.bg-orange-800\/70 {
  background-color: rgb(154 52 18 / 0.7);
}

.bg-orange-800\/75 {
  background-color: rgb(154 52 18 / 0.75);
}

.bg-orange-800\/80 {
  background-color: rgb(154 52 18 / 0.8);
}

.bg-orange-800\/85 {
  background-color: rgb(154 52 18 / 0.85);
}

.bg-orange-800\/90 {
  background-color: rgb(154 52 18 / 0.9);
}

.bg-orange-800\/95 {
  background-color: rgb(154 52 18 / 0.95);
}

.bg-orange-900 {
  --tw-bg-opacity: 1;
  background-color: rgb(124 45 18 / var(--tw-bg-opacity));
}

.bg-orange-900\/0 {
  background-color: rgb(124 45 18 / 0);
}

.bg-orange-900\/10 {
  background-color: rgb(124 45 18 / 0.1);
}

.bg-orange-900\/100 {
  background-color: rgb(124 45 18 / 1);
}

.bg-orange-900\/15 {
  background-color: rgb(124 45 18 / 0.15);
}

.bg-orange-900\/20 {
  background-color: rgb(124 45 18 / 0.2);
}

.bg-orange-900\/25 {
  background-color: rgb(124 45 18 / 0.25);
}

.bg-orange-900\/30 {
  background-color: rgb(124 45 18 / 0.3);
}

.bg-orange-900\/35 {
  background-color: rgb(124 45 18 / 0.35);
}

.bg-orange-900\/40 {
  background-color: rgb(124 45 18 / 0.4);
}

.bg-orange-900\/45 {
  background-color: rgb(124 45 18 / 0.45);
}

.bg-orange-900\/5 {
  background-color: rgb(124 45 18 / 0.05);
}

.bg-orange-900\/50 {
  background-color: rgb(124 45 18 / 0.5);
}

.bg-orange-900\/55 {
  background-color: rgb(124 45 18 / 0.55);
}

.bg-orange-900\/60 {
  background-color: rgb(124 45 18 / 0.6);
}

.bg-orange-900\/65 {
  background-color: rgb(124 45 18 / 0.65);
}

.bg-orange-900\/70 {
  background-color: rgb(124 45 18 / 0.7);
}

.bg-orange-900\/75 {
  background-color: rgb(124 45 18 / 0.75);
}

.bg-orange-900\/80 {
  background-color: rgb(124 45 18 / 0.8);
}

.bg-orange-900\/85 {
  background-color: rgb(124 45 18 / 0.85);
}

.bg-orange-900\/90 {
  background-color: rgb(124 45 18 / 0.9);
}

.bg-orange-900\/95 {
  background-color: rgb(124 45 18 / 0.95);
}

.bg-orange-950 {
  --tw-bg-opacity: 1;
  background-color: rgb(67 20 7 / var(--tw-bg-opacity));
}

.bg-orange-950\/0 {
  background-color: rgb(67 20 7 / 0);
}

.bg-orange-950\/10 {
  background-color: rgb(67 20 7 / 0.1);
}

.bg-orange-950\/100 {
  background-color: rgb(67 20 7 / 1);
}

.bg-orange-950\/15 {
  background-color: rgb(67 20 7 / 0.15);
}

.bg-orange-950\/20 {
  background-color: rgb(67 20 7 / 0.2);
}

.bg-orange-950\/25 {
  background-color: rgb(67 20 7 / 0.25);
}

.bg-orange-950\/30 {
  background-color: rgb(67 20 7 / 0.3);
}

.bg-orange-950\/35 {
  background-color: rgb(67 20 7 / 0.35);
}

.bg-orange-950\/40 {
  background-color: rgb(67 20 7 / 0.4);
}

.bg-orange-950\/45 {
  background-color: rgb(67 20 7 / 0.45);
}

.bg-orange-950\/5 {
  background-color: rgb(67 20 7 / 0.05);
}

.bg-orange-950\/50 {
  background-color: rgb(67 20 7 / 0.5);
}

.bg-orange-950\/55 {
  background-color: rgb(67 20 7 / 0.55);
}

.bg-orange-950\/60 {
  background-color: rgb(67 20 7 / 0.6);
}

.bg-orange-950\/65 {
  background-color: rgb(67 20 7 / 0.65);
}

.bg-orange-950\/70 {
  background-color: rgb(67 20 7 / 0.7);
}

.bg-orange-950\/75 {
  background-color: rgb(67 20 7 / 0.75);
}

.bg-orange-950\/80 {
  background-color: rgb(67 20 7 / 0.8);
}

.bg-orange-950\/85 {
  background-color: rgb(67 20 7 / 0.85);
}

.bg-orange-950\/90 {
  background-color: rgb(67 20 7 / 0.9);
}

.bg-orange-950\/95 {
  background-color: rgb(67 20 7 / 0.95);
}

.bg-pink-100 {
  --tw-bg-opacity: 1;
  background-color: rgb(252 231 243 / var(--tw-bg-opacity));
}

.bg-pink-100\/0 {
  background-color: rgb(252 231 243 / 0);
}

.bg-pink-100\/10 {
  background-color: rgb(252 231 243 / 0.1);
}

.bg-pink-100\/100 {
  background-color: rgb(252 231 243 / 1);
}

.bg-pink-100\/15 {
  background-color: rgb(252 231 243 / 0.15);
}

.bg-pink-100\/20 {
  background-color: rgb(252 231 243 / 0.2);
}

.bg-pink-100\/25 {
  background-color: rgb(252 231 243 / 0.25);
}

.bg-pink-100\/30 {
  background-color: rgb(252 231 243 / 0.3);
}

.bg-pink-100\/35 {
  background-color: rgb(252 231 243 / 0.35);
}

.bg-pink-100\/40 {
  background-color: rgb(252 231 243 / 0.4);
}

.bg-pink-100\/45 {
  background-color: rgb(252 231 243 / 0.45);
}

.bg-pink-100\/5 {
  background-color: rgb(252 231 243 / 0.05);
}

.bg-pink-100\/50 {
  background-color: rgb(252 231 243 / 0.5);
}

.bg-pink-100\/55 {
  background-color: rgb(252 231 243 / 0.55);
}

.bg-pink-100\/60 {
  background-color: rgb(252 231 243 / 0.6);
}

.bg-pink-100\/65 {
  background-color: rgb(252 231 243 / 0.65);
}

.bg-pink-100\/70 {
  background-color: rgb(252 231 243 / 0.7);
}

.bg-pink-100\/75 {
  background-color: rgb(252 231 243 / 0.75);
}

.bg-pink-100\/80 {
  background-color: rgb(252 231 243 / 0.8);
}

.bg-pink-100\/85 {
  background-color: rgb(252 231 243 / 0.85);
}

.bg-pink-100\/90 {
  background-color: rgb(252 231 243 / 0.9);
}

.bg-pink-100\/95 {
  background-color: rgb(252 231 243 / 0.95);
}

.bg-pink-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(251 207 232 / var(--tw-bg-opacity));
}

.bg-pink-200\/0 {
  background-color: rgb(251 207 232 / 0);
}

.bg-pink-200\/10 {
  background-color: rgb(251 207 232 / 0.1);
}

.bg-pink-200\/100 {
  background-color: rgb(251 207 232 / 1);
}

.bg-pink-200\/15 {
  background-color: rgb(251 207 232 / 0.15);
}

.bg-pink-200\/20 {
  background-color: rgb(251 207 232 / 0.2);
}

.bg-pink-200\/25 {
  background-color: rgb(251 207 232 / 0.25);
}

.bg-pink-200\/30 {
  background-color: rgb(251 207 232 / 0.3);
}

.bg-pink-200\/35 {
  background-color: rgb(251 207 232 / 0.35);
}

.bg-pink-200\/40 {
  background-color: rgb(251 207 232 / 0.4);
}

.bg-pink-200\/45 {
  background-color: rgb(251 207 232 / 0.45);
}

.bg-pink-200\/5 {
  background-color: rgb(251 207 232 / 0.05);
}

.bg-pink-200\/50 {
  background-color: rgb(251 207 232 / 0.5);
}

.bg-pink-200\/55 {
  background-color: rgb(251 207 232 / 0.55);
}

.bg-pink-200\/60 {
  background-color: rgb(251 207 232 / 0.6);
}

.bg-pink-200\/65 {
  background-color: rgb(251 207 232 / 0.65);
}

.bg-pink-200\/70 {
  background-color: rgb(251 207 232 / 0.7);
}

.bg-pink-200\/75 {
  background-color: rgb(251 207 232 / 0.75);
}

.bg-pink-200\/80 {
  background-color: rgb(251 207 232 / 0.8);
}

.bg-pink-200\/85 {
  background-color: rgb(251 207 232 / 0.85);
}

.bg-pink-200\/90 {
  background-color: rgb(251 207 232 / 0.9);
}

.bg-pink-200\/95 {
  background-color: rgb(251 207 232 / 0.95);
}

.bg-pink-300 {
  --tw-bg-opacity: 1;
  background-color: rgb(249 168 212 / var(--tw-bg-opacity));
}

.bg-pink-300\/0 {
  background-color: rgb(249 168 212 / 0);
}

.bg-pink-300\/10 {
  background-color: rgb(249 168 212 / 0.1);
}

.bg-pink-300\/100 {
  background-color: rgb(249 168 212 / 1);
}

.bg-pink-300\/15 {
  background-color: rgb(249 168 212 / 0.15);
}

.bg-pink-300\/20 {
  background-color: rgb(249 168 212 / 0.2);
}

.bg-pink-300\/25 {
  background-color: rgb(249 168 212 / 0.25);
}

.bg-pink-300\/30 {
  background-color: rgb(249 168 212 / 0.3);
}

.bg-pink-300\/35 {
  background-color: rgb(249 168 212 / 0.35);
}

.bg-pink-300\/40 {
  background-color: rgb(249 168 212 / 0.4);
}

.bg-pink-300\/45 {
  background-color: rgb(249 168 212 / 0.45);
}

.bg-pink-300\/5 {
  background-color: rgb(249 168 212 / 0.05);
}

.bg-pink-300\/50 {
  background-color: rgb(249 168 212 / 0.5);
}

.bg-pink-300\/55 {
  background-color: rgb(249 168 212 / 0.55);
}

.bg-pink-300\/60 {
  background-color: rgb(249 168 212 / 0.6);
}

.bg-pink-300\/65 {
  background-color: rgb(249 168 212 / 0.65);
}

.bg-pink-300\/70 {
  background-color: rgb(249 168 212 / 0.7);
}

.bg-pink-300\/75 {
  background-color: rgb(249 168 212 / 0.75);
}

.bg-pink-300\/80 {
  background-color: rgb(249 168 212 / 0.8);
}

.bg-pink-300\/85 {
  background-color: rgb(249 168 212 / 0.85);
}

.bg-pink-300\/90 {
  background-color: rgb(249 168 212 / 0.9);
}

.bg-pink-300\/95 {
  background-color: rgb(249 168 212 / 0.95);
}

.bg-pink-400 {
  --tw-bg-opacity: 1;
  background-color: rgb(244 114 182 / var(--tw-bg-opacity));
}

.bg-pink-400\/0 {
  background-color: rgb(244 114 182 / 0);
}

.bg-pink-400\/10 {
  background-color: rgb(244 114 182 / 0.1);
}

.bg-pink-400\/100 {
  background-color: rgb(244 114 182 / 1);
}

.bg-pink-400\/15 {
  background-color: rgb(244 114 182 / 0.15);
}

.bg-pink-400\/20 {
  background-color: rgb(244 114 182 / 0.2);
}

.bg-pink-400\/25 {
  background-color: rgb(244 114 182 / 0.25);
}

.bg-pink-400\/30 {
  background-color: rgb(244 114 182 / 0.3);
}

.bg-pink-400\/35 {
  background-color: rgb(244 114 182 / 0.35);
}

.bg-pink-400\/40 {
  background-color: rgb(244 114 182 / 0.4);
}

.bg-pink-400\/45 {
  background-color: rgb(244 114 182 / 0.45);
}

.bg-pink-400\/5 {
  background-color: rgb(244 114 182 / 0.05);
}

.bg-pink-400\/50 {
  background-color: rgb(244 114 182 / 0.5);
}

.bg-pink-400\/55 {
  background-color: rgb(244 114 182 / 0.55);
}

.bg-pink-400\/60 {
  background-color: rgb(244 114 182 / 0.6);
}

.bg-pink-400\/65 {
  background-color: rgb(244 114 182 / 0.65);
}

.bg-pink-400\/70 {
  background-color: rgb(244 114 182 / 0.7);
}

.bg-pink-400\/75 {
  background-color: rgb(244 114 182 / 0.75);
}

.bg-pink-400\/80 {
  background-color: rgb(244 114 182 / 0.8);
}

.bg-pink-400\/85 {
  background-color: rgb(244 114 182 / 0.85);
}

.bg-pink-400\/90 {
  background-color: rgb(244 114 182 / 0.9);
}

.bg-pink-400\/95 {
  background-color: rgb(244 114 182 / 0.95);
}

.bg-pink-50 {
  --tw-bg-opacity: 1;
  background-color: rgb(253 242 248 / var(--tw-bg-opacity));
}

.bg-pink-50\/0 {
  background-color: rgb(253 242 248 / 0);
}

.bg-pink-50\/10 {
  background-color: rgb(253 242 248 / 0.1);
}

.bg-pink-50\/100 {
  background-color: rgb(253 242 248 / 1);
}

.bg-pink-50\/15 {
  background-color: rgb(253 242 248 / 0.15);
}

.bg-pink-50\/20 {
  background-color: rgb(253 242 248 / 0.2);
}

.bg-pink-50\/25 {
  background-color: rgb(253 242 248 / 0.25);
}

.bg-pink-50\/30 {
  background-color: rgb(253 242 248 / 0.3);
}

.bg-pink-50\/35 {
  background-color: rgb(253 242 248 / 0.35);
}

.bg-pink-50\/40 {
  background-color: rgb(253 242 248 / 0.4);
}

.bg-pink-50\/45 {
  background-color: rgb(253 242 248 / 0.45);
}

.bg-pink-50\/5 {
  background-color: rgb(253 242 248 / 0.05);
}

.bg-pink-50\/50 {
  background-color: rgb(253 242 248 / 0.5);
}

.bg-pink-50\/55 {
  background-color: rgb(253 242 248 / 0.55);
}

.bg-pink-50\/60 {
  background-color: rgb(253 242 248 / 0.6);
}

.bg-pink-50\/65 {
  background-color: rgb(253 242 248 / 0.65);
}

.bg-pink-50\/70 {
  background-color: rgb(253 242 248 / 0.7);
}

.bg-pink-50\/75 {
  background-color: rgb(253 242 248 / 0.75);
}

.bg-pink-50\/80 {
  background-color: rgb(253 242 248 / 0.8);
}

.bg-pink-50\/85 {
  background-color: rgb(253 242 248 / 0.85);
}

.bg-pink-50\/90 {
  background-color: rgb(253 242 248 / 0.9);
}

.bg-pink-50\/95 {
  background-color: rgb(253 242 248 / 0.95);
}

.bg-pink-500 {
  --tw-bg-opacity: 1;
  background-color: rgb(236 72 153 / var(--tw-bg-opacity));
}

.bg-pink-500\/0 {
  background-color: rgb(236 72 153 / 0);
}

.bg-pink-500\/10 {
  background-color: rgb(236 72 153 / 0.1);
}

.bg-pink-500\/100 {
  background-color: rgb(236 72 153 / 1);
}

.bg-pink-500\/15 {
  background-color: rgb(236 72 153 / 0.15);
}

.bg-pink-500\/20 {
  background-color: rgb(236 72 153 / 0.2);
}

.bg-pink-500\/25 {
  background-color: rgb(236 72 153 / 0.25);
}

.bg-pink-500\/30 {
  background-color: rgb(236 72 153 / 0.3);
}

.bg-pink-500\/35 {
  background-color: rgb(236 72 153 / 0.35);
}

.bg-pink-500\/40 {
  background-color: rgb(236 72 153 / 0.4);
}

.bg-pink-500\/45 {
  background-color: rgb(236 72 153 / 0.45);
}

.bg-pink-500\/5 {
  background-color: rgb(236 72 153 / 0.05);
}

.bg-pink-500\/50 {
  background-color: rgb(236 72 153 / 0.5);
}

.bg-pink-500\/55 {
  background-color: rgb(236 72 153 / 0.55);
}

.bg-pink-500\/60 {
  background-color: rgb(236 72 153 / 0.6);
}

.bg-pink-500\/65 {
  background-color: rgb(236 72 153 / 0.65);
}

.bg-pink-500\/70 {
  background-color: rgb(236 72 153 / 0.7);
}

.bg-pink-500\/75 {
  background-color: rgb(236 72 153 / 0.75);
}

.bg-pink-500\/80 {
  background-color: rgb(236 72 153 / 0.8);
}

.bg-pink-500\/85 {
  background-color: rgb(236 72 153 / 0.85);
}

.bg-pink-500\/90 {
  background-color: rgb(236 72 153 / 0.9);
}

.bg-pink-500\/95 {
  background-color: rgb(236 72 153 / 0.95);
}

.bg-pink-600 {
  --tw-bg-opacity: 1;
  background-color: rgb(219 39 119 / var(--tw-bg-opacity));
}

.bg-pink-600\/0 {
  background-color: rgb(219 39 119 / 0);
}

.bg-pink-600\/10 {
  background-color: rgb(219 39 119 / 0.1);
}

.bg-pink-600\/100 {
  background-color: rgb(219 39 119 / 1);
}

.bg-pink-600\/15 {
  background-color: rgb(219 39 119 / 0.15);
}

.bg-pink-600\/20 {
  background-color: rgb(219 39 119 / 0.2);
}

.bg-pink-600\/25 {
  background-color: rgb(219 39 119 / 0.25);
}

.bg-pink-600\/30 {
  background-color: rgb(219 39 119 / 0.3);
}

.bg-pink-600\/35 {
  background-color: rgb(219 39 119 / 0.35);
}

.bg-pink-600\/40 {
  background-color: rgb(219 39 119 / 0.4);
}

.bg-pink-600\/45 {
  background-color: rgb(219 39 119 / 0.45);
}

.bg-pink-600\/5 {
  background-color: rgb(219 39 119 / 0.05);
}

.bg-pink-600\/50 {
  background-color: rgb(219 39 119 / 0.5);
}

.bg-pink-600\/55 {
  background-color: rgb(219 39 119 / 0.55);
}

.bg-pink-600\/60 {
  background-color: rgb(219 39 119 / 0.6);
}

.bg-pink-600\/65 {
  background-color: rgb(219 39 119 / 0.65);
}

.bg-pink-600\/70 {
  background-color: rgb(219 39 119 / 0.7);
}

.bg-pink-600\/75 {
  background-color: rgb(219 39 119 / 0.75);
}

.bg-pink-600\/80 {
  background-color: rgb(219 39 119 / 0.8);
}

.bg-pink-600\/85 {
  background-color: rgb(219 39 119 / 0.85);
}

.bg-pink-600\/90 {
  background-color: rgb(219 39 119 / 0.9);
}

.bg-pink-600\/95 {
  background-color: rgb(219 39 119 / 0.95);
}

.bg-pink-700 {
  --tw-bg-opacity: 1;
  background-color: rgb(190 24 93 / var(--tw-bg-opacity));
}

.bg-pink-700\/0 {
  background-color: rgb(190 24 93 / 0);
}

.bg-pink-700\/10 {
  background-color: rgb(190 24 93 / 0.1);
}

.bg-pink-700\/100 {
  background-color: rgb(190 24 93 / 1);
}

.bg-pink-700\/15 {
  background-color: rgb(190 24 93 / 0.15);
}

.bg-pink-700\/20 {
  background-color: rgb(190 24 93 / 0.2);
}

.bg-pink-700\/25 {
  background-color: rgb(190 24 93 / 0.25);
}

.bg-pink-700\/30 {
  background-color: rgb(190 24 93 / 0.3);
}

.bg-pink-700\/35 {
  background-color: rgb(190 24 93 / 0.35);
}

.bg-pink-700\/40 {
  background-color: rgb(190 24 93 / 0.4);
}

.bg-pink-700\/45 {
  background-color: rgb(190 24 93 / 0.45);
}

.bg-pink-700\/5 {
  background-color: rgb(190 24 93 / 0.05);
}

.bg-pink-700\/50 {
  background-color: rgb(190 24 93 / 0.5);
}

.bg-pink-700\/55 {
  background-color: rgb(190 24 93 / 0.55);
}

.bg-pink-700\/60 {
  background-color: rgb(190 24 93 / 0.6);
}

.bg-pink-700\/65 {
  background-color: rgb(190 24 93 / 0.65);
}

.bg-pink-700\/70 {
  background-color: rgb(190 24 93 / 0.7);
}

.bg-pink-700\/75 {
  background-color: rgb(190 24 93 / 0.75);
}

.bg-pink-700\/80 {
  background-color: rgb(190 24 93 / 0.8);
}

.bg-pink-700\/85 {
  background-color: rgb(190 24 93 / 0.85);
}

.bg-pink-700\/90 {
  background-color: rgb(190 24 93 / 0.9);
}

.bg-pink-700\/95 {
  background-color: rgb(190 24 93 / 0.95);
}

.bg-pink-800 {
  --tw-bg-opacity: 1;
  background-color: rgb(157 23 77 / var(--tw-bg-opacity));
}

.bg-pink-800\/0 {
  background-color: rgb(157 23 77 / 0);
}

.bg-pink-800\/10 {
  background-color: rgb(157 23 77 / 0.1);
}

.bg-pink-800\/100 {
  background-color: rgb(157 23 77 / 1);
}

.bg-pink-800\/15 {
  background-color: rgb(157 23 77 / 0.15);
}

.bg-pink-800\/20 {
  background-color: rgb(157 23 77 / 0.2);
}

.bg-pink-800\/25 {
  background-color: rgb(157 23 77 / 0.25);
}

.bg-pink-800\/30 {
  background-color: rgb(157 23 77 / 0.3);
}

.bg-pink-800\/35 {
  background-color: rgb(157 23 77 / 0.35);
}

.bg-pink-800\/40 {
  background-color: rgb(157 23 77 / 0.4);
}

.bg-pink-800\/45 {
  background-color: rgb(157 23 77 / 0.45);
}

.bg-pink-800\/5 {
  background-color: rgb(157 23 77 / 0.05);
}

.bg-pink-800\/50 {
  background-color: rgb(157 23 77 / 0.5);
}

.bg-pink-800\/55 {
  background-color: rgb(157 23 77 / 0.55);
}

.bg-pink-800\/60 {
  background-color: rgb(157 23 77 / 0.6);
}

.bg-pink-800\/65 {
  background-color: rgb(157 23 77 / 0.65);
}

.bg-pink-800\/70 {
  background-color: rgb(157 23 77 / 0.7);
}

.bg-pink-800\/75 {
  background-color: rgb(157 23 77 / 0.75);
}

.bg-pink-800\/80 {
  background-color: rgb(157 23 77 / 0.8);
}

.bg-pink-800\/85 {
  background-color: rgb(157 23 77 / 0.85);
}

.bg-pink-800\/90 {
  background-color: rgb(157 23 77 / 0.9);
}

.bg-pink-800\/95 {
  background-color: rgb(157 23 77 / 0.95);
}

.bg-pink-900 {
  --tw-bg-opacity: 1;
  background-color: rgb(131 24 67 / var(--tw-bg-opacity));
}

.bg-pink-900\/0 {
  background-color: rgb(131 24 67 / 0);
}

.bg-pink-900\/10 {
  background-color: rgb(131 24 67 / 0.1);
}

.bg-pink-900\/100 {
  background-color: rgb(131 24 67 / 1);
}

.bg-pink-900\/15 {
  background-color: rgb(131 24 67 / 0.15);
}

.bg-pink-900\/20 {
  background-color: rgb(131 24 67 / 0.2);
}

.bg-pink-900\/25 {
  background-color: rgb(131 24 67 / 0.25);
}

.bg-pink-900\/30 {
  background-color: rgb(131 24 67 / 0.3);
}

.bg-pink-900\/35 {
  background-color: rgb(131 24 67 / 0.35);
}

.bg-pink-900\/40 {
  background-color: rgb(131 24 67 / 0.4);
}

.bg-pink-900\/45 {
  background-color: rgb(131 24 67 / 0.45);
}

.bg-pink-900\/5 {
  background-color: rgb(131 24 67 / 0.05);
}

.bg-pink-900\/50 {
  background-color: rgb(131 24 67 / 0.5);
}

.bg-pink-900\/55 {
  background-color: rgb(131 24 67 / 0.55);
}

.bg-pink-900\/60 {
  background-color: rgb(131 24 67 / 0.6);
}

.bg-pink-900\/65 {
  background-color: rgb(131 24 67 / 0.65);
}

.bg-pink-900\/70 {
  background-color: rgb(131 24 67 / 0.7);
}

.bg-pink-900\/75 {
  background-color: rgb(131 24 67 / 0.75);
}

.bg-pink-900\/80 {
  background-color: rgb(131 24 67 / 0.8);
}

.bg-pink-900\/85 {
  background-color: rgb(131 24 67 / 0.85);
}

.bg-pink-900\/90 {
  background-color: rgb(131 24 67 / 0.9);
}

.bg-pink-900\/95 {
  background-color: rgb(131 24 67 / 0.95);
}

.bg-pink-950 {
  --tw-bg-opacity: 1;
  background-color: rgb(80 7 36 / var(--tw-bg-opacity));
}

.bg-pink-950\/0 {
  background-color: rgb(80 7 36 / 0);
}

.bg-pink-950\/10 {
  background-color: rgb(80 7 36 / 0.1);
}

.bg-pink-950\/100 {
  background-color: rgb(80 7 36 / 1);
}

.bg-pink-950\/15 {
  background-color: rgb(80 7 36 / 0.15);
}

.bg-pink-950\/20 {
  background-color: rgb(80 7 36 / 0.2);
}

.bg-pink-950\/25 {
  background-color: rgb(80 7 36 / 0.25);
}

.bg-pink-950\/30 {
  background-color: rgb(80 7 36 / 0.3);
}

.bg-pink-950\/35 {
  background-color: rgb(80 7 36 / 0.35);
}

.bg-pink-950\/40 {
  background-color: rgb(80 7 36 / 0.4);
}

.bg-pink-950\/45 {
  background-color: rgb(80 7 36 / 0.45);
}

.bg-pink-950\/5 {
  background-color: rgb(80 7 36 / 0.05);
}

.bg-pink-950\/50 {
  background-color: rgb(80 7 36 / 0.5);
}

.bg-pink-950\/55 {
  background-color: rgb(80 7 36 / 0.55);
}

.bg-pink-950\/60 {
  background-color: rgb(80 7 36 / 0.6);
}

.bg-pink-950\/65 {
  background-color: rgb(80 7 36 / 0.65);
}

.bg-pink-950\/70 {
  background-color: rgb(80 7 36 / 0.7);
}

.bg-pink-950\/75 {
  background-color: rgb(80 7 36 / 0.75);
}

.bg-pink-950\/80 {
  background-color: rgb(80 7 36 / 0.8);
}

.bg-pink-950\/85 {
  background-color: rgb(80 7 36 / 0.85);
}

.bg-pink-950\/90 {
  background-color: rgb(80 7 36 / 0.9);
}

.bg-pink-950\/95 {
  background-color: rgb(80 7 36 / 0.95);
}

.bg-primary {
  --tw-bg-opacity: 1;
  background-color: var(--fallback-p,oklch(var(--p)/var(--tw-bg-opacity)));
}

.bg-primary-content {
  --tw-bg-opacity: 1;
  background-color: var(--fallback-pc,oklch(var(--pc)/var(--tw-bg-opacity)));
}

.bg-primary-content\/0 {
  background-color: var(--fallback-pc,oklch(var(--pc)/0));
}

.bg-primary-content\/10 {
  background-color: var(--fallback-pc,oklch(var(--pc)/0.1));
}

.bg-primary-content\/100 {
  background-color: var(--fallback-pc,oklch(var(--pc)/1));
}

.bg-primary-content\/15 {
  background-color: var(--fallback-pc,oklch(var(--pc)/0.15));
}

.bg-primary-content\/20 {
  background-color: var(--fallback-pc,oklch(var(--pc)/0.2));
}

.bg-primary-content\/25 {
  background-color: var(--fallback-pc,oklch(var(--pc)/0.25));
}

.bg-primary-content\/30 {
  background-color: var(--fallback-pc,oklch(var(--pc)/0.3));
}

.bg-primary-content\/35 {
  background-color: var(--fallback-pc,oklch(var(--pc)/0.35));
}

.bg-primary-content\/40 {
  background-color: var(--fallback-pc,oklch(var(--pc)/0.4));
}

.bg-primary-content\/45 {
  background-color: var(--fallback-pc,oklch(var(--pc)/0.45));
}

.bg-primary-content\/5 {
  background-color: var(--fallback-pc,oklch(var(--pc)/0.05));
}

.bg-primary-content\/50 {
  background-color: var(--fallback-pc,oklch(var(--pc)/0.5));
}

.bg-primary-content\/55 {
  background-color: var(--fallback-pc,oklch(var(--pc)/0.55));
}

.bg-primary-content\/60 {
  background-color: var(--fallback-pc,oklch(var(--pc)/0.6));
}

.bg-primary-content\/65 {
  background-color: var(--fallback-pc,oklch(var(--pc)/0.65));
}

.bg-primary-content\/70 {
  background-color: var(--fallback-pc,oklch(var(--pc)/0.7));
}

.bg-primary-content\/75 {
  background-color: var(--fallback-pc,oklch(var(--pc)/0.75));
}

.bg-primary-content\/80 {
  background-color: var(--fallback-pc,oklch(var(--pc)/0.8));
}

.bg-primary-content\/85 {
  background-color: var(--fallback-pc,oklch(var(--pc)/0.85));
}

.bg-primary-content\/90 {
  background-color: var(--fallback-pc,oklch(var(--pc)/0.9));
}

.bg-primary-content\/95 {
  background-color: var(--fallback-pc,oklch(var(--pc)/0.95));
}

.bg-primary\/0 {
  background-color: var(--fallback-p,oklch(var(--p)/0));
}

.bg-primary\/10 {
  background-color: var(--fallback-p,oklch(var(--p)/0.1));
}

.bg-primary\/100 {
  background-color: var(--fallback-p,oklch(var(--p)/1));
}

.bg-primary\/15 {
  background-color: var(--fallback-p,oklch(var(--p)/0.15));
}

.bg-primary\/20 {
  background-color: var(--fallback-p,oklch(var(--p)/0.2));
}

.bg-primary\/25 {
  background-color: var(--fallback-p,oklch(var(--p)/0.25));
}

.bg-primary\/30 {
  background-color: var(--fallback-p,oklch(var(--p)/0.3));
}

.bg-primary\/35 {
  background-color: var(--fallback-p,oklch(var(--p)/0.35));
}

.bg-primary\/40 {
  background-color: var(--fallback-p,oklch(var(--p)/0.4));
}

.bg-primary\/45 {
  background-color: var(--fallback-p,oklch(var(--p)/0.45));
}

.bg-primary\/5 {
  background-color: var(--fallback-p,oklch(var(--p)/0.05));
}

.bg-primary\/50 {
  background-color: var(--fallback-p,oklch(var(--p)/0.5));
}

.bg-primary\/55 {
  background-color: var(--fallback-p,oklch(var(--p)/0.55));
}

.bg-primary\/60 {
  background-color: var(--fallback-p,oklch(var(--p)/0.6));
}

.bg-primary\/65 {
  background-color: var(--fallback-p,oklch(var(--p)/0.65));
}

.bg-primary\/70 {
  background-color: var(--fallback-p,oklch(var(--p)/0.7));
}

.bg-primary\/75 {
  background-color: var(--fallback-p,oklch(var(--p)/0.75));
}

.bg-primary\/80 {
  background-color: var(--fallback-p,oklch(var(--p)/0.8));
}

.bg-primary\/85 {
  background-color: var(--fallback-p,oklch(var(--p)/0.85));
}

.bg-primary\/90 {
  background-color: var(--fallback-p,oklch(var(--p)/0.9));
}

.bg-primary\/95 {
  background-color: var(--fallback-p,oklch(var(--p)/0.95));
}

.bg-purple-100 {
  --tw-bg-opacity: 1;
  background-color: rgb(243 232 255 / var(--tw-bg-opacity));
}

.bg-purple-100\/0 {
  background-color: rgb(243 232 255 / 0);
}

.bg-purple-100\/10 {
  background-color: rgb(243 232 255 / 0.1);
}

.bg-purple-100\/100 {
  background-color: rgb(243 232 255 / 1);
}

.bg-purple-100\/15 {
  background-color: rgb(243 232 255 / 0.15);
}

.bg-purple-100\/20 {
  background-color: rgb(243 232 255 / 0.2);
}

.bg-purple-100\/25 {
  background-color: rgb(243 232 255 / 0.25);
}

.bg-purple-100\/30 {
  background-color: rgb(243 232 255 / 0.3);
}

.bg-purple-100\/35 {
  background-color: rgb(243 232 255 / 0.35);
}

.bg-purple-100\/40 {
  background-color: rgb(243 232 255 / 0.4);
}

.bg-purple-100\/45 {
  background-color: rgb(243 232 255 / 0.45);
}

.bg-purple-100\/5 {
  background-color: rgb(243 232 255 / 0.05);
}

.bg-purple-100\/50 {
  background-color: rgb(243 232 255 / 0.5);
}

.bg-purple-100\/55 {
  background-color: rgb(243 232 255 / 0.55);
}

.bg-purple-100\/60 {
  background-color: rgb(243 232 255 / 0.6);
}

.bg-purple-100\/65 {
  background-color: rgb(243 232 255 / 0.65);
}

.bg-purple-100\/70 {
  background-color: rgb(243 232 255 / 0.7);
}

.bg-purple-100\/75 {
  background-color: rgb(243 232 255 / 0.75);
}

.bg-purple-100\/80 {
  background-color: rgb(243 232 255 / 0.8);
}

.bg-purple-100\/85 {
  background-color: rgb(243 232 255 / 0.85);
}

.bg-purple-100\/90 {
  background-color: rgb(243 232 255 / 0.9);
}

.bg-purple-100\/95 {
  background-color: rgb(243 232 255 / 0.95);
}

.bg-purple-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(233 213 255 / var(--tw-bg-opacity));
}

.bg-purple-200\/0 {
  background-color: rgb(233 213 255 / 0);
}

.bg-purple-200\/10 {
  background-color: rgb(233 213 255 / 0.1);
}

.bg-purple-200\/100 {
  background-color: rgb(233 213 255 / 1);
}

.bg-purple-200\/15 {
  background-color: rgb(233 213 255 / 0.15);
}

.bg-purple-200\/20 {
  background-color: rgb(233 213 255 / 0.2);
}

.bg-purple-200\/25 {
  background-color: rgb(233 213 255 / 0.25);
}

.bg-purple-200\/30 {
  background-color: rgb(233 213 255 / 0.3);
}

.bg-purple-200\/35 {
  background-color: rgb(233 213 255 / 0.35);
}

.bg-purple-200\/40 {
  background-color: rgb(233 213 255 / 0.4);
}

.bg-purple-200\/45 {
  background-color: rgb(233 213 255 / 0.45);
}

.bg-purple-200\/5 {
  background-color: rgb(233 213 255 / 0.05);
}

.bg-purple-200\/50 {
  background-color: rgb(233 213 255 / 0.5);
}

.bg-purple-200\/55 {
  background-color: rgb(233 213 255 / 0.55);
}

.bg-purple-200\/60 {
  background-color: rgb(233 213 255 / 0.6);
}

.bg-purple-200\/65 {
  background-color: rgb(233 213 255 / 0.65);
}

.bg-purple-200\/70 {
  background-color: rgb(233 213 255 / 0.7);
}

.bg-purple-200\/75 {
  background-color: rgb(233 213 255 / 0.75);
}

.bg-purple-200\/80 {
  background-color: rgb(233 213 255 / 0.8);
}

.bg-purple-200\/85 {
  background-color: rgb(233 213 255 / 0.85);
}

.bg-purple-200\/90 {
  background-color: rgb(233 213 255 / 0.9);
}

.bg-purple-200\/95 {
  background-color: rgb(233 213 255 / 0.95);
}

.bg-purple-300 {
  --tw-bg-opacity: 1;
  background-color: rgb(216 180 254 / var(--tw-bg-opacity));
}

.bg-purple-300\/0 {
  background-color: rgb(216 180 254 / 0);
}

.bg-purple-300\/10 {
  background-color: rgb(216 180 254 / 0.1);
}

.bg-purple-300\/100 {
  background-color: rgb(216 180 254 / 1);
}

.bg-purple-300\/15 {
  background-color: rgb(216 180 254 / 0.15);
}

.bg-purple-300\/20 {
  background-color: rgb(216 180 254 / 0.2);
}

.bg-purple-300\/25 {
  background-color: rgb(216 180 254 / 0.25);
}

.bg-purple-300\/30 {
  background-color: rgb(216 180 254 / 0.3);
}

.bg-purple-300\/35 {
  background-color: rgb(216 180 254 / 0.35);
}

.bg-purple-300\/40 {
  background-color: rgb(216 180 254 / 0.4);
}

.bg-purple-300\/45 {
  background-color: rgb(216 180 254 / 0.45);
}

.bg-purple-300\/5 {
  background-color: rgb(216 180 254 / 0.05);
}

.bg-purple-300\/50 {
  background-color: rgb(216 180 254 / 0.5);
}

.bg-purple-300\/55 {
  background-color: rgb(216 180 254 / 0.55);
}

.bg-purple-300\/60 {
  background-color: rgb(216 180 254 / 0.6);
}

.bg-purple-300\/65 {
  background-color: rgb(216 180 254 / 0.65);
}

.bg-purple-300\/70 {
  background-color: rgb(216 180 254 / 0.7);
}

.bg-purple-300\/75 {
  background-color: rgb(216 180 254 / 0.75);
}

.bg-purple-300\/80 {
  background-color: rgb(216 180 254 / 0.8);
}

.bg-purple-300\/85 {
  background-color: rgb(216 180 254 / 0.85);
}

.bg-purple-300\/90 {
  background-color: rgb(216 180 254 / 0.9);
}

.bg-purple-300\/95 {
  background-color: rgb(216 180 254 / 0.95);
}

.bg-purple-400 {
  --tw-bg-opacity: 1;
  background-color: rgb(192 132 252 / var(--tw-bg-opacity));
}

.bg-purple-400\/0 {
  background-color: rgb(192 132 252 / 0);
}

.bg-purple-400\/10 {
  background-color: rgb(192 132 252 / 0.1);
}

.bg-purple-400\/100 {
  background-color: rgb(192 132 252 / 1);
}

.bg-purple-400\/15 {
  background-color: rgb(192 132 252 / 0.15);
}

.bg-purple-400\/20 {
  background-color: rgb(192 132 252 / 0.2);
}

.bg-purple-400\/25 {
  background-color: rgb(192 132 252 / 0.25);
}

.bg-purple-400\/30 {
  background-color: rgb(192 132 252 / 0.3);
}

.bg-purple-400\/35 {
  background-color: rgb(192 132 252 / 0.35);
}

.bg-purple-400\/40 {
  background-color: rgb(192 132 252 / 0.4);
}

.bg-purple-400\/45 {
  background-color: rgb(192 132 252 / 0.45);
}

.bg-purple-400\/5 {
  background-color: rgb(192 132 252 / 0.05);
}

.bg-purple-400\/50 {
  background-color: rgb(192 132 252 / 0.5);
}

.bg-purple-400\/55 {
  background-color: rgb(192 132 252 / 0.55);
}

.bg-purple-400\/60 {
  background-color: rgb(192 132 252 / 0.6);
}

.bg-purple-400\/65 {
  background-color: rgb(192 132 252 / 0.65);
}

.bg-purple-400\/70 {
  background-color: rgb(192 132 252 / 0.7);
}

.bg-purple-400\/75 {
  background-color: rgb(192 132 252 / 0.75);
}

.bg-purple-400\/80 {
  background-color: rgb(192 132 252 / 0.8);
}

.bg-purple-400\/85 {
  background-color: rgb(192 132 252 / 0.85);
}

.bg-purple-400\/90 {
  background-color: rgb(192 132 252 / 0.9);
}

.bg-purple-400\/95 {
  background-color: rgb(192 132 252 / 0.95);
}

.bg-purple-50 {
  --tw-bg-opacity: 1;
  background-color: rgb(250 245 255 / var(--tw-bg-opacity));
}

.bg-purple-50\/0 {
  background-color: rgb(250 245 255 / 0);
}

.bg-purple-50\/10 {
  background-color: rgb(250 245 255 / 0.1);
}

.bg-purple-50\/100 {
  background-color: rgb(250 245 255 / 1);
}

.bg-purple-50\/15 {
  background-color: rgb(250 245 255 / 0.15);
}

.bg-purple-50\/20 {
  background-color: rgb(250 245 255 / 0.2);
}

.bg-purple-50\/25 {
  background-color: rgb(250 245 255 / 0.25);
}

.bg-purple-50\/30 {
  background-color: rgb(250 245 255 / 0.3);
}

.bg-purple-50\/35 {
  background-color: rgb(250 245 255 / 0.35);
}

.bg-purple-50\/40 {
  background-color: rgb(250 245 255 / 0.4);
}

.bg-purple-50\/45 {
  background-color: rgb(250 245 255 / 0.45);
}

.bg-purple-50\/5 {
  background-color: rgb(250 245 255 / 0.05);
}

.bg-purple-50\/50 {
  background-color: rgb(250 245 255 / 0.5);
}

.bg-purple-50\/55 {
  background-color: rgb(250 245 255 / 0.55);
}

.bg-purple-50\/60 {
  background-color: rgb(250 245 255 / 0.6);
}

.bg-purple-50\/65 {
  background-color: rgb(250 245 255 / 0.65);
}

.bg-purple-50\/70 {
  background-color: rgb(250 245 255 / 0.7);
}

.bg-purple-50\/75 {
  background-color: rgb(250 245 255 / 0.75);
}

.bg-purple-50\/80 {
  background-color: rgb(250 245 255 / 0.8);
}

.bg-purple-50\/85 {
  background-color: rgb(250 245 255 / 0.85);
}

.bg-purple-50\/90 {
  background-color: rgb(250 245 255 / 0.9);
}

.bg-purple-50\/95 {
  background-color: rgb(250 245 255 / 0.95);
}

.bg-purple-500 {
  --tw-bg-opacity: 1;
  background-color: rgb(168 85 247 / var(--tw-bg-opacity));
}

.bg-purple-500\/0 {
  background-color: rgb(168 85 247 / 0);
}

.bg-purple-500\/10 {
  background-color: rgb(168 85 247 / 0.1);
}

.bg-purple-500\/100 {
  background-color: rgb(168 85 247 / 1);
}

.bg-purple-500\/15 {
  background-color: rgb(168 85 247 / 0.15);
}

.bg-purple-500\/20 {
  background-color: rgb(168 85 247 / 0.2);
}

.bg-purple-500\/25 {
  background-color: rgb(168 85 247 / 0.25);
}

.bg-purple-500\/30 {
  background-color: rgb(168 85 247 / 0.3);
}

.bg-purple-500\/35 {
  background-color: rgb(168 85 247 / 0.35);
}

.bg-purple-500\/40 {
  background-color: rgb(168 85 247 / 0.4);
}

.bg-purple-500\/45 {
  background-color: rgb(168 85 247 / 0.45);
}

.bg-purple-500\/5 {
  background-color: rgb(168 85 247 / 0.05);
}

.bg-purple-500\/50 {
  background-color: rgb(168 85 247 / 0.5);
}

.bg-purple-500\/55 {
  background-color: rgb(168 85 247 / 0.55);
}

.bg-purple-500\/60 {
  background-color: rgb(168 85 247 / 0.6);
}

.bg-purple-500\/65 {
  background-color: rgb(168 85 247 / 0.65);
}

.bg-purple-500\/70 {
  background-color: rgb(168 85 247 / 0.7);
}

.bg-purple-500\/75 {
  background-color: rgb(168 85 247 / 0.75);
}

.bg-purple-500\/80 {
  background-color: rgb(168 85 247 / 0.8);
}

.bg-purple-500\/85 {
  background-color: rgb(168 85 247 / 0.85);
}

.bg-purple-500\/90 {
  background-color: rgb(168 85 247 / 0.9);
}

.bg-purple-500\/95 {
  background-color: rgb(168 85 247 / 0.95);
}

.bg-purple-600 {
  --tw-bg-opacity: 1;
  background-color: rgb(147 51 234 / var(--tw-bg-opacity));
}

.bg-purple-600\/0 {
  background-color: rgb(147 51 234 / 0);
}

.bg-purple-600\/10 {
  background-color: rgb(147 51 234 / 0.1);
}

.bg-purple-600\/100 {
  background-color: rgb(147 51 234 / 1);
}

.bg-purple-600\/15 {
  background-color: rgb(147 51 234 / 0.15);
}

.bg-purple-600\/20 {
  background-color: rgb(147 51 234 / 0.2);
}

.bg-purple-600\/25 {
  background-color: rgb(147 51 234 / 0.25);
}

.bg-purple-600\/30 {
  background-color: rgb(147 51 234 / 0.3);
}

.bg-purple-600\/35 {
  background-color: rgb(147 51 234 / 0.35);
}

.bg-purple-600\/40 {
  background-color: rgb(147 51 234 / 0.4);
}

.bg-purple-600\/45 {
  background-color: rgb(147 51 234 / 0.45);
}

.bg-purple-600\/5 {
  background-color: rgb(147 51 234 / 0.05);
}

.bg-purple-600\/50 {
  background-color: rgb(147 51 234 / 0.5);
}

.bg-purple-600\/55 {
  background-color: rgb(147 51 234 / 0.55);
}

.bg-purple-600\/60 {
  background-color: rgb(147 51 234 / 0.6);
}

.bg-purple-600\/65 {
  background-color: rgb(147 51 234 / 0.65);
}

.bg-purple-600\/70 {
  background-color: rgb(147 51 234 / 0.7);
}

.bg-purple-600\/75 {
  background-color: rgb(147 51 234 / 0.75);
}

.bg-purple-600\/80 {
  background-color: rgb(147 51 234 / 0.8);
}

.bg-purple-600\/85 {
  background-color: rgb(147 51 234 / 0.85);
}

.bg-purple-600\/90 {
  background-color: rgb(147 51 234 / 0.9);
}

.bg-purple-600\/95 {
  background-color: rgb(147 51 234 / 0.95);
}

.bg-purple-700 {
  --tw-bg-opacity: 1;
  background-color: rgb(126 34 206 / var(--tw-bg-opacity));
}

.bg-purple-700\/0 {
  background-color: rgb(126 34 206 / 0);
}

.bg-purple-700\/10 {
  background-color: rgb(126 34 206 / 0.1);
}

.bg-purple-700\/100 {
  background-color: rgb(126 34 206 / 1);
}

.bg-purple-700\/15 {
  background-color: rgb(126 34 206 / 0.15);
}

.bg-purple-700\/20 {
  background-color: rgb(126 34 206 / 0.2);
}

.bg-purple-700\/25 {
  background-color: rgb(126 34 206 / 0.25);
}

.bg-purple-700\/30 {
  background-color: rgb(126 34 206 / 0.3);
}

.bg-purple-700\/35 {
  background-color: rgb(126 34 206 / 0.35);
}

.bg-purple-700\/40 {
  background-color: rgb(126 34 206 / 0.4);
}

.bg-purple-700\/45 {
  background-color: rgb(126 34 206 / 0.45);
}

.bg-purple-700\/5 {
  background-color: rgb(126 34 206 / 0.05);
}

.bg-purple-700\/50 {
  background-color: rgb(126 34 206 / 0.5);
}

.bg-purple-700\/55 {
  background-color: rgb(126 34 206 / 0.55);
}

.bg-purple-700\/60 {
  background-color: rgb(126 34 206 / 0.6);
}

.bg-purple-700\/65 {
  background-color: rgb(126 34 206 / 0.65);
}

.bg-purple-700\/70 {
  background-color: rgb(126 34 206 / 0.7);
}

.bg-purple-700\/75 {
  background-color: rgb(126 34 206 / 0.75);
}

.bg-purple-700\/80 {
  background-color: rgb(126 34 206 / 0.8);
}

.bg-purple-700\/85 {
  background-color: rgb(126 34 206 / 0.85);
}

.bg-purple-700\/90 {
  background-color: rgb(126 34 206 / 0.9);
}

.bg-purple-700\/95 {
  background-color: rgb(126 34 206 / 0.95);
}

.bg-purple-800 {
  --tw-bg-opacity: 1;
  background-color: rgb(107 33 168 / var(--tw-bg-opacity));
}

.bg-purple-800\/0 {
  background-color: rgb(107 33 168 / 0);
}

.bg-purple-800\/10 {
  background-color: rgb(107 33 168 / 0.1);
}

.bg-purple-800\/100 {
  background-color: rgb(107 33 168 / 1);
}

.bg-purple-800\/15 {
  background-color: rgb(107 33 168 / 0.15);
}

.bg-purple-800\/20 {
  background-color: rgb(107 33 168 / 0.2);
}

.bg-purple-800\/25 {
  background-color: rgb(107 33 168 / 0.25);
}

.bg-purple-800\/30 {
  background-color: rgb(107 33 168 / 0.3);
}

.bg-purple-800\/35 {
  background-color: rgb(107 33 168 / 0.35);
}

.bg-purple-800\/40 {
  background-color: rgb(107 33 168 / 0.4);
}

.bg-purple-800\/45 {
  background-color: rgb(107 33 168 / 0.45);
}

.bg-purple-800\/5 {
  background-color: rgb(107 33 168 / 0.05);
}

.bg-purple-800\/50 {
  background-color: rgb(107 33 168 / 0.5);
}

.bg-purple-800\/55 {
  background-color: rgb(107 33 168 / 0.55);
}

.bg-purple-800\/60 {
  background-color: rgb(107 33 168 / 0.6);
}

.bg-purple-800\/65 {
  background-color: rgb(107 33 168 / 0.65);
}

.bg-purple-800\/70 {
  background-color: rgb(107 33 168 / 0.7);
}

.bg-purple-800\/75 {
  background-color: rgb(107 33 168 / 0.75);
}

.bg-purple-800\/80 {
  background-color: rgb(107 33 168 / 0.8);
}

.bg-purple-800\/85 {
  background-color: rgb(107 33 168 / 0.85);
}

.bg-purple-800\/90 {
  background-color: rgb(107 33 168 / 0.9);
}

.bg-purple-800\/95 {
  background-color: rgb(107 33 168 / 0.95);
}

.bg-purple-900 {
  --tw-bg-opacity: 1;
  background-color: rgb(88 28 135 / var(--tw-bg-opacity));
}

.bg-purple-900\/0 {
  background-color: rgb(88 28 135 / 0);
}

.bg-purple-900\/10 {
  background-color: rgb(88 28 135 / 0.1);
}

.bg-purple-900\/100 {
  background-color: rgb(88 28 135 / 1);
}

.bg-purple-900\/15 {
  background-color: rgb(88 28 135 / 0.15);
}

.bg-purple-900\/20 {
  background-color: rgb(88 28 135 / 0.2);
}

.bg-purple-900\/25 {
  background-color: rgb(88 28 135 / 0.25);
}

.bg-purple-900\/30 {
  background-color: rgb(88 28 135 / 0.3);
}

.bg-purple-900\/35 {
  background-color: rgb(88 28 135 / 0.35);
}

.bg-purple-900\/40 {
  background-color: rgb(88 28 135 / 0.4);
}

.bg-purple-900\/45 {
  background-color: rgb(88 28 135 / 0.45);
}

.bg-purple-900\/5 {
  background-color: rgb(88 28 135 / 0.05);
}

.bg-purple-900\/50 {
  background-color: rgb(88 28 135 / 0.5);
}

.bg-purple-900\/55 {
  background-color: rgb(88 28 135 / 0.55);
}

.bg-purple-900\/60 {
  background-color: rgb(88 28 135 / 0.6);
}

.bg-purple-900\/65 {
  background-color: rgb(88 28 135 / 0.65);
}

.bg-purple-900\/70 {
  background-color: rgb(88 28 135 / 0.7);
}

.bg-purple-900\/75 {
  background-color: rgb(88 28 135 / 0.75);
}

.bg-purple-900\/80 {
  background-color: rgb(88 28 135 / 0.8);
}

.bg-purple-900\/85 {
  background-color: rgb(88 28 135 / 0.85);
}

.bg-purple-900\/90 {
  background-color: rgb(88 28 135 / 0.9);
}

.bg-purple-900\/95 {
  background-color: rgb(88 28 135 / 0.95);
}

.bg-purple-950 {
  --tw-bg-opacity: 1;
  background-color: rgb(59 7 100 / var(--tw-bg-opacity));
}

.bg-purple-950\/0 {
  background-color: rgb(59 7 100 / 0);
}

.bg-purple-950\/10 {
  background-color: rgb(59 7 100 / 0.1);
}

.bg-purple-950\/100 {
  background-color: rgb(59 7 100 / 1);
}

.bg-purple-950\/15 {
  background-color: rgb(59 7 100 / 0.15);
}

.bg-purple-950\/20 {
  background-color: rgb(59 7 100 / 0.2);
}

.bg-purple-950\/25 {
  background-color: rgb(59 7 100 / 0.25);
}

.bg-purple-950\/30 {
  background-color: rgb(59 7 100 / 0.3);
}

.bg-purple-950\/35 {
  background-color: rgb(59 7 100 / 0.35);
}

.bg-purple-950\/40 {
  background-color: rgb(59 7 100 / 0.4);
}

.bg-purple-950\/45 {
  background-color: rgb(59 7 100 / 0.45);
}

.bg-purple-950\/5 {
  background-color: rgb(59 7 100 / 0.05);
}

.bg-purple-950\/50 {
  background-color: rgb(59 7 100 / 0.5);
}

.bg-purple-950\/55 {
  background-color: rgb(59 7 100 / 0.55);
}

.bg-purple-950\/60 {
  background-color: rgb(59 7 100 / 0.6);
}

.bg-purple-950\/65 {
  background-color: rgb(59 7 100 / 0.65);
}

.bg-purple-950\/70 {
  background-color: rgb(59 7 100 / 0.7);
}

.bg-purple-950\/75 {
  background-color: rgb(59 7 100 / 0.75);
}

.bg-purple-950\/80 {
  background-color: rgb(59 7 100 / 0.8);
}

.bg-purple-950\/85 {
  background-color: rgb(59 7 100 / 0.85);
}

.bg-purple-950\/90 {
  background-color: rgb(59 7 100 / 0.9);
}

.bg-purple-950\/95 {
  background-color: rgb(59 7 100 / 0.95);
}

.bg-red-100 {
  --tw-bg-opacity: 1;
  background-color: rgb(254 226 226 / var(--tw-bg-opacity));
}

.bg-red-100\/0 {
  background-color: rgb(254 226 226 / 0);
}

.bg-red-100\/10 {
  background-color: rgb(254 226 226 / 0.1);
}

.bg-red-100\/100 {
  background-color: rgb(254 226 226 / 1);
}

.bg-red-100\/15 {
  background-color: rgb(254 226 226 / 0.15);
}

.bg-red-100\/20 {
  background-color: rgb(254 226 226 / 0.2);
}

.bg-red-100\/25 {
  background-color: rgb(254 226 226 / 0.25);
}

.bg-red-100\/30 {
  background-color: rgb(254 226 226 / 0.3);
}

.bg-red-100\/35 {
  background-color: rgb(254 226 226 / 0.35);
}

.bg-red-100\/40 {
  background-color: rgb(254 226 226 / 0.4);
}

.bg-red-100\/45 {
  background-color: rgb(254 226 226 / 0.45);
}

.bg-red-100\/5 {
  background-color: rgb(254 226 226 / 0.05);
}

.bg-red-100\/50 {
  background-color: rgb(254 226 226 / 0.5);
}

.bg-red-100\/55 {
  background-color: rgb(254 226 226 / 0.55);
}

.bg-red-100\/60 {
  background-color: rgb(254 226 226 / 0.6);
}

.bg-red-100\/65 {
  background-color: rgb(254 226 226 / 0.65);
}

.bg-red-100\/70 {
  background-color: rgb(254 226 226 / 0.7);
}

.bg-red-100\/75 {
  background-color: rgb(254 226 226 / 0.75);
}

.bg-red-100\/80 {
  background-color: rgb(254 226 226 / 0.8);
}

.bg-red-100\/85 {
  background-color: rgb(254 226 226 / 0.85);
}

.bg-red-100\/90 {
  background-color: rgb(254 226 226 / 0.9);
}

.bg-red-100\/95 {
  background-color: rgb(254 226 226 / 0.95);
}

.bg-red-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(254 202 202 / var(--tw-bg-opacity));
}

.bg-red-200\/0 {
  background-color: rgb(254 202 202 / 0);
}

.bg-red-200\/10 {
  background-color: rgb(254 202 202 / 0.1);
}

.bg-red-200\/100 {
  background-color: rgb(254 202 202 / 1);
}

.bg-red-200\/15 {
  background-color: rgb(254 202 202 / 0.15);
}

.bg-red-200\/20 {
  background-color: rgb(254 202 202 / 0.2);
}

.bg-red-200\/25 {
  background-color: rgb(254 202 202 / 0.25);
}

.bg-red-200\/30 {
  background-color: rgb(254 202 202 / 0.3);
}

.bg-red-200\/35 {
  background-color: rgb(254 202 202 / 0.35);
}

.bg-red-200\/40 {
  background-color: rgb(254 202 202 / 0.4);
}

.bg-red-200\/45 {
  background-color: rgb(254 202 202 / 0.45);
}

.bg-red-200\/5 {
  background-color: rgb(254 202 202 / 0.05);
}

.bg-red-200\/50 {
  background-color: rgb(254 202 202 / 0.5);
}

.bg-red-200\/55 {
  background-color: rgb(254 202 202 / 0.55);
}

.bg-red-200\/60 {
  background-color: rgb(254 202 202 / 0.6);
}

.bg-red-200\/65 {
  background-color: rgb(254 202 202 / 0.65);
}

.bg-red-200\/70 {
  background-color: rgb(254 202 202 / 0.7);
}

.bg-red-200\/75 {
  background-color: rgb(254 202 202 / 0.75);
}

.bg-red-200\/80 {
  background-color: rgb(254 202 202 / 0.8);
}

.bg-red-200\/85 {
  background-color: rgb(254 202 202 / 0.85);
}

.bg-red-200\/90 {
  background-color: rgb(254 202 202 / 0.9);
}

.bg-red-200\/95 {
  background-color: rgb(254 202 202 / 0.95);
}

.bg-red-300 {
  --tw-bg-opacity: 1;
  background-color: rgb(252 165 165 / var(--tw-bg-opacity));
}

.bg-red-300\/0 {
  background-color: rgb(252 165 165 / 0);
}

.bg-red-300\/10 {
  background-color: rgb(252 165 165 / 0.1);
}

.bg-red-300\/100 {
  background-color: rgb(252 165 165 / 1);
}

.bg-red-300\/15 {
  background-color: rgb(252 165 165 / 0.15);
}

.bg-red-300\/20 {
  background-color: rgb(252 165 165 / 0.2);
}

.bg-red-300\/25 {
  background-color: rgb(252 165 165 / 0.25);
}

.bg-red-300\/30 {
  background-color: rgb(252 165 165 / 0.3);
}

.bg-red-300\/35 {
  background-color: rgb(252 165 165 / 0.35);
}

.bg-red-300\/40 {
  background-color: rgb(252 165 165 / 0.4);
}

.bg-red-300\/45 {
  background-color: rgb(252 165 165 / 0.45);
}

.bg-red-300\/5 {
  background-color: rgb(252 165 165 / 0.05);
}

.bg-red-300\/50 {
  background-color: rgb(252 165 165 / 0.5);
}

.bg-red-300\/55 {
  background-color: rgb(252 165 165 / 0.55);
}

.bg-red-300\/60 {
  background-color: rgb(252 165 165 / 0.6);
}

.bg-red-300\/65 {
  background-color: rgb(252 165 165 / 0.65);
}

.bg-red-300\/70 {
  background-color: rgb(252 165 165 / 0.7);
}

.bg-red-300\/75 {
  background-color: rgb(252 165 165 / 0.75);
}

.bg-red-300\/80 {
  background-color: rgb(252 165 165 / 0.8);
}

.bg-red-300\/85 {
  background-color: rgb(252 165 165 / 0.85);
}

.bg-red-300\/90 {
  background-color: rgb(252 165 165 / 0.9);
}

.bg-red-300\/95 {
  background-color: rgb(252 165 165 / 0.95);
}

.bg-red-400 {
  --tw-bg-opacity: 1;
  background-color: rgb(248 113 113 / var(--tw-bg-opacity));
}

.bg-red-400\/0 {
  background-color: rgb(248 113 113 / 0);
}

.bg-red-400\/10 {
  background-color: rgb(248 113 113 / 0.1);
}

.bg-red-400\/100 {
  background-color: rgb(248 113 113 / 1);
}

.bg-red-400\/15 {
  background-color: rgb(248 113 113 / 0.15);
}

.bg-red-400\/20 {
  background-color: rgb(248 113 113 / 0.2);
}

.bg-red-400\/25 {
  background-color: rgb(248 113 113 / 0.25);
}

.bg-red-400\/30 {
  background-color: rgb(248 113 113 / 0.3);
}

.bg-red-400\/35 {
  background-color: rgb(248 113 113 / 0.35);
}

.bg-red-400\/40 {
  background-color: rgb(248 113 113 / 0.4);
}

.bg-red-400\/45 {
  background-color: rgb(248 113 113 / 0.45);
}

.bg-red-400\/5 {
  background-color: rgb(248 113 113 / 0.05);
}

.bg-red-400\/50 {
  background-color: rgb(248 113 113 / 0.5);
}

.bg-red-400\/55 {
  background-color: rgb(248 113 113 / 0.55);
}

.bg-red-400\/60 {
  background-color: rgb(248 113 113 / 0.6);
}

.bg-red-400\/65 {
  background-color: rgb(248 113 113 / 0.65);
}

.bg-red-400\/70 {
  background-color: rgb(248 113 113 / 0.7);
}

.bg-red-400\/75 {
  background-color: rgb(248 113 113 / 0.75);
}

.bg-red-400\/80 {
  background-color: rgb(248 113 113 / 0.8);
}

.bg-red-400\/85 {
  background-color: rgb(248 113 113 / 0.85);
}

.bg-red-400\/90 {
  background-color: rgb(248 113 113 / 0.9);
}

.bg-red-400\/95 {
  background-color: rgb(248 113 113 / 0.95);
}

.bg-red-50 {
  --tw-bg-opacity: 1;
  background-color: rgb(254 242 242 / var(--tw-bg-opacity));
}

.bg-red-50\/0 {
  background-color: rgb(254 242 242 / 0);
}

.bg-red-50\/10 {
  background-color: rgb(254 242 242 / 0.1);
}

.bg-red-50\/100 {
  background-color: rgb(254 242 242 / 1);
}

.bg-red-50\/15 {
  background-color: rgb(254 242 242 / 0.15);
}

.bg-red-50\/20 {
  background-color: rgb(254 242 242 / 0.2);
}

.bg-red-50\/25 {
  background-color: rgb(254 242 242 / 0.25);
}

.bg-red-50\/30 {
  background-color: rgb(254 242 242 / 0.3);
}

.bg-red-50\/35 {
  background-color: rgb(254 242 242 / 0.35);
}

.bg-red-50\/40 {
  background-color: rgb(254 242 242 / 0.4);
}

.bg-red-50\/45 {
  background-color: rgb(254 242 242 / 0.45);
}

.bg-red-50\/5 {
  background-color: rgb(254 242 242 / 0.05);
}

.bg-red-50\/50 {
  background-color: rgb(254 242 242 / 0.5);
}

.bg-red-50\/55 {
  background-color: rgb(254 242 242 / 0.55);
}

.bg-red-50\/60 {
  background-color: rgb(254 242 242 / 0.6);
}

.bg-red-50\/65 {
  background-color: rgb(254 242 242 / 0.65);
}

.bg-red-50\/70 {
  background-color: rgb(254 242 242 / 0.7);
}

.bg-red-50\/75 {
  background-color: rgb(254 242 242 / 0.75);
}

.bg-red-50\/80 {
  background-color: rgb(254 242 242 / 0.8);
}

.bg-red-50\/85 {
  background-color: rgb(254 242 242 / 0.85);
}

.bg-red-50\/90 {
  background-color: rgb(254 242 242 / 0.9);
}

.bg-red-50\/95 {
  background-color: rgb(254 242 242 / 0.95);
}

.bg-red-500 {
  --tw-bg-opacity: 1;
  background-color: rgb(239 68 68 / var(--tw-bg-opacity));
}

.bg-red-500\/0 {
  background-color: rgb(239 68 68 / 0);
}

.bg-red-500\/10 {
  background-color: rgb(239 68 68 / 0.1);
}

.bg-red-500\/100 {
  background-color: rgb(239 68 68 / 1);
}

.bg-red-500\/15 {
  background-color: rgb(239 68 68 / 0.15);
}

.bg-red-500\/20 {
  background-color: rgb(239 68 68 / 0.2);
}

.bg-red-500\/25 {
  background-color: rgb(239 68 68 / 0.25);
}

.bg-red-500\/30 {
  background-color: rgb(239 68 68 / 0.3);
}

.bg-red-500\/35 {
  background-color: rgb(239 68 68 / 0.35);
}

.bg-red-500\/40 {
  background-color: rgb(239 68 68 / 0.4);
}

.bg-red-500\/45 {
  background-color: rgb(239 68 68 / 0.45);
}

.bg-red-500\/5 {
  background-color: rgb(239 68 68 / 0.05);
}

.bg-red-500\/50 {
  background-color: rgb(239 68 68 / 0.5);
}

.bg-red-500\/55 {
  background-color: rgb(239 68 68 / 0.55);
}

.bg-red-500\/60 {
  background-color: rgb(239 68 68 / 0.6);
}

.bg-red-500\/65 {
  background-color: rgb(239 68 68 / 0.65);
}

.bg-red-500\/70 {
  background-color: rgb(239 68 68 / 0.7);
}

.bg-red-500\/75 {
  background-color: rgb(239 68 68 / 0.75);
}

.bg-red-500\/80 {
  background-color: rgb(239 68 68 / 0.8);
}

.bg-red-500\/85 {
  background-color: rgb(239 68 68 / 0.85);
}

.bg-red-500\/90 {
  background-color: rgb(239 68 68 / 0.9);
}

.bg-red-500\/95 {
  background-color: rgb(239 68 68 / 0.95);
}

.bg-red-600 {
  --tw-bg-opacity: 1;
  background-color: rgb(220 38 38 / var(--tw-bg-opacity));
}

.bg-red-600\/0 {
  background-color: rgb(220 38 38 / 0);
}

.bg-red-600\/10 {
  background-color: rgb(220 38 38 / 0.1);
}

.bg-red-600\/100 {
  background-color: rgb(220 38 38 / 1);
}

.bg-red-600\/15 {
  background-color: rgb(220 38 38 / 0.15);
}

.bg-red-600\/20 {
  background-color: rgb(220 38 38 / 0.2);
}

.bg-red-600\/25 {
  background-color: rgb(220 38 38 / 0.25);
}

.bg-red-600\/30 {
  background-color: rgb(220 38 38 / 0.3);
}

.bg-red-600\/35 {
  background-color: rgb(220 38 38 / 0.35);
}

.bg-red-600\/40 {
  background-color: rgb(220 38 38 / 0.4);
}

.bg-red-600\/45 {
  background-color: rgb(220 38 38 / 0.45);
}

.bg-red-600\/5 {
  background-color: rgb(220 38 38 / 0.05);
}

.bg-red-600\/50 {
  background-color: rgb(220 38 38 / 0.5);
}

.bg-red-600\/55 {
  background-color: rgb(220 38 38 / 0.55);
}

.bg-red-600\/60 {
  background-color: rgb(220 38 38 / 0.6);
}

.bg-red-600\/65 {
  background-color: rgb(220 38 38 / 0.65);
}

.bg-red-600\/70 {
  background-color: rgb(220 38 38 / 0.7);
}

.bg-red-600\/75 {
  background-color: rgb(220 38 38 / 0.75);
}

.bg-red-600\/80 {
  background-color: rgb(220 38 38 / 0.8);
}

.bg-red-600\/85 {
  background-color: rgb(220 38 38 / 0.85);
}

.bg-red-600\/90 {
  background-color: rgb(220 38 38 / 0.9);
}

.bg-red-600\/95 {
  background-color: rgb(220 38 38 / 0.95);
}

.bg-red-700 {
  --tw-bg-opacity: 1;
  background-color: rgb(185 28 28 / var(--tw-bg-opacity));
}

.bg-red-700\/0 {
  background-color: rgb(185 28 28 / 0);
}

.bg-red-700\/10 {
  background-color: rgb(185 28 28 / 0.1);
}

.bg-red-700\/100 {
  background-color: rgb(185 28 28 / 1);
}

.bg-red-700\/15 {
  background-color: rgb(185 28 28 / 0.15);
}

.bg-red-700\/20 {
  background-color: rgb(185 28 28 / 0.2);
}

.bg-red-700\/25 {
  background-color: rgb(185 28 28 / 0.25);
}

.bg-red-700\/30 {
  background-color: rgb(185 28 28 / 0.3);
}

.bg-red-700\/35 {
  background-color: rgb(185 28 28 / 0.35);
}

.bg-red-700\/40 {
  background-color: rgb(185 28 28 / 0.4);
}

.bg-red-700\/45 {
  background-color: rgb(185 28 28 / 0.45);
}

.bg-red-700\/5 {
  background-color: rgb(185 28 28 / 0.05);
}

.bg-red-700\/50 {
  background-color: rgb(185 28 28 / 0.5);
}

.bg-red-700\/55 {
  background-color: rgb(185 28 28 / 0.55);
}

.bg-red-700\/60 {
  background-color: rgb(185 28 28 / 0.6);
}

.bg-red-700\/65 {
  background-color: rgb(185 28 28 / 0.65);
}

.bg-red-700\/70 {
  background-color: rgb(185 28 28 / 0.7);
}

.bg-red-700\/75 {
  background-color: rgb(185 28 28 / 0.75);
}

.bg-red-700\/80 {
  background-color: rgb(185 28 28 / 0.8);
}

.bg-red-700\/85 {
  background-color: rgb(185 28 28 / 0.85);
}

.bg-red-700\/90 {
  background-color: rgb(185 28 28 / 0.9);
}

.bg-red-700\/95 {
  background-color: rgb(185 28 28 / 0.95);
}

.bg-red-800 {
  --tw-bg-opacity: 1;
  background-color: rgb(153 27 27 / var(--tw-bg-opacity));
}

.bg-red-800\/0 {
  background-color: rgb(153 27 27 / 0);
}

.bg-red-800\/10 {
  background-color: rgb(153 27 27 / 0.1);
}

.bg-red-800\/100 {
  background-color: rgb(153 27 27 / 1);
}

.bg-red-800\/15 {
  background-color: rgb(153 27 27 / 0.15);
}

.bg-red-800\/20 {
  background-color: rgb(153 27 27 / 0.2);
}

.bg-red-800\/25 {
  background-color: rgb(153 27 27 / 0.25);
}

.bg-red-800\/30 {
  background-color: rgb(153 27 27 / 0.3);
}

.bg-red-800\/35 {
  background-color: rgb(153 27 27 / 0.35);
}

.bg-red-800\/40 {
  background-color: rgb(153 27 27 / 0.4);
}

.bg-red-800\/45 {
  background-color: rgb(153 27 27 / 0.45);
}

.bg-red-800\/5 {
  background-color: rgb(153 27 27 / 0.05);
}

.bg-red-800\/50 {
  background-color: rgb(153 27 27 / 0.5);
}

.bg-red-800\/55 {
  background-color: rgb(153 27 27 / 0.55);
}

.bg-red-800\/60 {
  background-color: rgb(153 27 27 / 0.6);
}

.bg-red-800\/65 {
  background-color: rgb(153 27 27 / 0.65);
}

.bg-red-800\/70 {
  background-color: rgb(153 27 27 / 0.7);
}

.bg-red-800\/75 {
  background-color: rgb(153 27 27 / 0.75);
}

.bg-red-800\/80 {
  background-color: rgb(153 27 27 / 0.8);
}

.bg-red-800\/85 {
  background-color: rgb(153 27 27 / 0.85);
}

.bg-red-800\/90 {
  background-color: rgb(153 27 27 / 0.9);
}

.bg-red-800\/95 {
  background-color: rgb(153 27 27 / 0.95);
}

.bg-red-900 {
  --tw-bg-opacity: 1;
  background-color: rgb(127 29 29 / var(--tw-bg-opacity));
}

.bg-red-900\/0 {
  background-color: rgb(127 29 29 / 0);
}

.bg-red-900\/10 {
  background-color: rgb(127 29 29 / 0.1);
}

.bg-red-900\/100 {
  background-color: rgb(127 29 29 / 1);
}

.bg-red-900\/15 {
  background-color: rgb(127 29 29 / 0.15);
}

.bg-red-900\/20 {
  background-color: rgb(127 29 29 / 0.2);
}

.bg-red-900\/25 {
  background-color: rgb(127 29 29 / 0.25);
}

.bg-red-900\/30 {
  background-color: rgb(127 29 29 / 0.3);
}

.bg-red-900\/35 {
  background-color: rgb(127 29 29 / 0.35);
}

.bg-red-900\/40 {
  background-color: rgb(127 29 29 / 0.4);
}

.bg-red-900\/45 {
  background-color: rgb(127 29 29 / 0.45);
}

.bg-red-900\/5 {
  background-color: rgb(127 29 29 / 0.05);
}

.bg-red-900\/50 {
  background-color: rgb(127 29 29 / 0.5);
}

.bg-red-900\/55 {
  background-color: rgb(127 29 29 / 0.55);
}

.bg-red-900\/60 {
  background-color: rgb(127 29 29 / 0.6);
}

.bg-red-900\/65 {
  background-color: rgb(127 29 29 / 0.65);
}

.bg-red-900\/70 {
  background-color: rgb(127 29 29 / 0.7);
}

.bg-red-900\/75 {
  background-color: rgb(127 29 29 / 0.75);
}

.bg-red-900\/80 {
  background-color: rgb(127 29 29 / 0.8);
}

.bg-red-900\/85 {
  background-color: rgb(127 29 29 / 0.85);
}

.bg-red-900\/90 {
  background-color: rgb(127 29 29 / 0.9);
}

.bg-red-900\/95 {
  background-color: rgb(127 29 29 / 0.95);
}

.bg-red-950 {
  --tw-bg-opacity: 1;
  background-color: rgb(69 10 10 / var(--tw-bg-opacity));
}

.bg-red-950\/0 {
  background-color: rgb(69 10 10 / 0);
}

.bg-red-950\/10 {
  background-color: rgb(69 10 10 / 0.1);
}

.bg-red-950\/100 {
  background-color: rgb(69 10 10 / 1);
}

.bg-red-950\/15 {
  background-color: rgb(69 10 10 / 0.15);
}

.bg-red-950\/20 {
  background-color: rgb(69 10 10 / 0.2);
}

.bg-red-950\/25 {
  background-color: rgb(69 10 10 / 0.25);
}

.bg-red-950\/30 {
  background-color: rgb(69 10 10 / 0.3);
}

.bg-red-950\/35 {
  background-color: rgb(69 10 10 / 0.35);
}

.bg-red-950\/40 {
  background-color: rgb(69 10 10 / 0.4);
}

.bg-red-950\/45 {
  background-color: rgb(69 10 10 / 0.45);
}

.bg-red-950\/5 {
  background-color: rgb(69 10 10 / 0.05);
}

.bg-red-950\/50 {
  background-color: rgb(69 10 10 / 0.5);
}

.bg-red-950\/55 {
  background-color: rgb(69 10 10 / 0.55);
}

.bg-red-950\/60 {
  background-color: rgb(69 10 10 / 0.6);
}

.bg-red-950\/65 {
  background-color: rgb(69 10 10 / 0.65);
}

.bg-red-950\/70 {
  background-color: rgb(69 10 10 / 0.7);
}

.bg-red-950\/75 {
  background-color: rgb(69 10 10 / 0.75);
}

.bg-red-950\/80 {
  background-color: rgb(69 10 10 / 0.8);
}

.bg-red-950\/85 {
  background-color: rgb(69 10 10 / 0.85);
}

.bg-red-950\/90 {
  background-color: rgb(69 10 10 / 0.9);
}

.bg-red-950\/95 {
  background-color: rgb(69 10 10 / 0.95);
}

.bg-rose-100 {
  --tw-bg-opacity: 1;
  background-color: rgb(255 228 230 / var(--tw-bg-opacity));
}

.bg-rose-100\/0 {
  background-color: rgb(255 228 230 / 0);
}

.bg-rose-100\/10 {
  background-color: rgb(255 228 230 / 0.1);
}

.bg-rose-100\/100 {
  background-color: rgb(255 228 230 / 1);
}

.bg-rose-100\/15 {
  background-color: rgb(255 228 230 / 0.15);
}

.bg-rose-100\/20 {
  background-color: rgb(255 228 230 / 0.2);
}

.bg-rose-100\/25 {
  background-color: rgb(255 228 230 / 0.25);
}

.bg-rose-100\/30 {
  background-color: rgb(255 228 230 / 0.3);
}

.bg-rose-100\/35 {
  background-color: rgb(255 228 230 / 0.35);
}

.bg-rose-100\/40 {
  background-color: rgb(255 228 230 / 0.4);
}

.bg-rose-100\/45 {
  background-color: rgb(255 228 230 / 0.45);
}

.bg-rose-100\/5 {
  background-color: rgb(255 228 230 / 0.05);
}

.bg-rose-100\/50 {
  background-color: rgb(255 228 230 / 0.5);
}

.bg-rose-100\/55 {
  background-color: rgb(255 228 230 / 0.55);
}

.bg-rose-100\/60 {
  background-color: rgb(255 228 230 / 0.6);
}

.bg-rose-100\/65 {
  background-color: rgb(255 228 230 / 0.65);
}

.bg-rose-100\/70 {
  background-color: rgb(255 228 230 / 0.7);
}

.bg-rose-100\/75 {
  background-color: rgb(255 228 230 / 0.75);
}

.bg-rose-100\/80 {
  background-color: rgb(255 228 230 / 0.8);
}

.bg-rose-100\/85 {
  background-color: rgb(255 228 230 / 0.85);
}

.bg-rose-100\/90 {
  background-color: rgb(255 228 230 / 0.9);
}

.bg-rose-100\/95 {
  background-color: rgb(255 228 230 / 0.95);
}

.bg-rose-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(254 205 211 / var(--tw-bg-opacity));
}

.bg-rose-200\/0 {
  background-color: rgb(254 205 211 / 0);
}

.bg-rose-200\/10 {
  background-color: rgb(254 205 211 / 0.1);
}

.bg-rose-200\/100 {
  background-color: rgb(254 205 211 / 1);
}

.bg-rose-200\/15 {
  background-color: rgb(254 205 211 / 0.15);
}

.bg-rose-200\/20 {
  background-color: rgb(254 205 211 / 0.2);
}

.bg-rose-200\/25 {
  background-color: rgb(254 205 211 / 0.25);
}

.bg-rose-200\/30 {
  background-color: rgb(254 205 211 / 0.3);
}

.bg-rose-200\/35 {
  background-color: rgb(254 205 211 / 0.35);
}

.bg-rose-200\/40 {
  background-color: rgb(254 205 211 / 0.4);
}

.bg-rose-200\/45 {
  background-color: rgb(254 205 211 / 0.45);
}

.bg-rose-200\/5 {
  background-color: rgb(254 205 211 / 0.05);
}

.bg-rose-200\/50 {
  background-color: rgb(254 205 211 / 0.5);
}

.bg-rose-200\/55 {
  background-color: rgb(254 205 211 / 0.55);
}

.bg-rose-200\/60 {
  background-color: rgb(254 205 211 / 0.6);
}

.bg-rose-200\/65 {
  background-color: rgb(254 205 211 / 0.65);
}

.bg-rose-200\/70 {
  background-color: rgb(254 205 211 / 0.7);
}

.bg-rose-200\/75 {
  background-color: rgb(254 205 211 / 0.75);
}

.bg-rose-200\/80 {
  background-color: rgb(254 205 211 / 0.8);
}

.bg-rose-200\/85 {
  background-color: rgb(254 205 211 / 0.85);
}

.bg-rose-200\/90 {
  background-color: rgb(254 205 211 / 0.9);
}

.bg-rose-200\/95 {
  background-color: rgb(254 205 211 / 0.95);
}

.bg-rose-300 {
  --tw-bg-opacity: 1;
  background-color: rgb(253 164 175 / var(--tw-bg-opacity));
}

.bg-rose-300\/0 {
  background-color: rgb(253 164 175 / 0);
}

.bg-rose-300\/10 {
  background-color: rgb(253 164 175 / 0.1);
}

.bg-rose-300\/100 {
  background-color: rgb(253 164 175 / 1);
}

.bg-rose-300\/15 {
  background-color: rgb(253 164 175 / 0.15);
}

.bg-rose-300\/20 {
  background-color: rgb(253 164 175 / 0.2);
}

.bg-rose-300\/25 {
  background-color: rgb(253 164 175 / 0.25);
}

.bg-rose-300\/30 {
  background-color: rgb(253 164 175 / 0.3);
}

.bg-rose-300\/35 {
  background-color: rgb(253 164 175 / 0.35);
}

.bg-rose-300\/40 {
  background-color: rgb(253 164 175 / 0.4);
}

.bg-rose-300\/45 {
  background-color: rgb(253 164 175 / 0.45);
}

.bg-rose-300\/5 {
  background-color: rgb(253 164 175 / 0.05);
}

.bg-rose-300\/50 {
  background-color: rgb(253 164 175 / 0.5);
}

.bg-rose-300\/55 {
  background-color: rgb(253 164 175 / 0.55);
}

.bg-rose-300\/60 {
  background-color: rgb(253 164 175 / 0.6);
}

.bg-rose-300\/65 {
  background-color: rgb(253 164 175 / 0.65);
}

.bg-rose-300\/70 {
  background-color: rgb(253 164 175 / 0.7);
}

.bg-rose-300\/75 {
  background-color: rgb(253 164 175 / 0.75);
}

.bg-rose-300\/80 {
  background-color: rgb(253 164 175 / 0.8);
}

.bg-rose-300\/85 {
  background-color: rgb(253 164 175 / 0.85);
}

.bg-rose-300\/90 {
  background-color: rgb(253 164 175 / 0.9);
}

.bg-rose-300\/95 {
  background-color: rgb(253 164 175 / 0.95);
}

.bg-rose-400 {
  --tw-bg-opacity: 1;
  background-color: rgb(251 113 133 / var(--tw-bg-opacity));
}

.bg-rose-400\/0 {
  background-color: rgb(251 113 133 / 0);
}

.bg-rose-400\/10 {
  background-color: rgb(251 113 133 / 0.1);
}

.bg-rose-400\/100 {
  background-color: rgb(251 113 133 / 1);
}

.bg-rose-400\/15 {
  background-color: rgb(251 113 133 / 0.15);
}

.bg-rose-400\/20 {
  background-color: rgb(251 113 133 / 0.2);
}

.bg-rose-400\/25 {
  background-color: rgb(251 113 133 / 0.25);
}

.bg-rose-400\/30 {
  background-color: rgb(251 113 133 / 0.3);
}

.bg-rose-400\/35 {
  background-color: rgb(251 113 133 / 0.35);
}

.bg-rose-400\/40 {
  background-color: rgb(251 113 133 / 0.4);
}

.bg-rose-400\/45 {
  background-color: rgb(251 113 133 / 0.45);
}

.bg-rose-400\/5 {
  background-color: rgb(251 113 133 / 0.05);
}

.bg-rose-400\/50 {
  background-color: rgb(251 113 133 / 0.5);
}

.bg-rose-400\/55 {
  background-color: rgb(251 113 133 / 0.55);
}

.bg-rose-400\/60 {
  background-color: rgb(251 113 133 / 0.6);
}

.bg-rose-400\/65 {
  background-color: rgb(251 113 133 / 0.65);
}

.bg-rose-400\/70 {
  background-color: rgb(251 113 133 / 0.7);
}

.bg-rose-400\/75 {
  background-color: rgb(251 113 133 / 0.75);
}

.bg-rose-400\/80 {
  background-color: rgb(251 113 133 / 0.8);
}

.bg-rose-400\/85 {
  background-color: rgb(251 113 133 / 0.85);
}

.bg-rose-400\/90 {
  background-color: rgb(251 113 133 / 0.9);
}

.bg-rose-400\/95 {
  background-color: rgb(251 113 133 / 0.95);
}

.bg-rose-50 {
  --tw-bg-opacity: 1;
  background-color: rgb(255 241 242 / var(--tw-bg-opacity));
}

.bg-rose-50\/0 {
  background-color: rgb(255 241 242 / 0);
}

.bg-rose-50\/10 {
  background-color: rgb(255 241 242 / 0.1);
}

.bg-rose-50\/100 {
  background-color: rgb(255 241 242 / 1);
}

.bg-rose-50\/15 {
  background-color: rgb(255 241 242 / 0.15);
}

.bg-rose-50\/20 {
  background-color: rgb(255 241 242 / 0.2);
}

.bg-rose-50\/25 {
  background-color: rgb(255 241 242 / 0.25);
}

.bg-rose-50\/30 {
  background-color: rgb(255 241 242 / 0.3);
}

.bg-rose-50\/35 {
  background-color: rgb(255 241 242 / 0.35);
}

.bg-rose-50\/40 {
  background-color: rgb(255 241 242 / 0.4);
}

.bg-rose-50\/45 {
  background-color: rgb(255 241 242 / 0.45);
}

.bg-rose-50\/5 {
  background-color: rgb(255 241 242 / 0.05);
}

.bg-rose-50\/50 {
  background-color: rgb(255 241 242 / 0.5);
}

.bg-rose-50\/55 {
  background-color: rgb(255 241 242 / 0.55);
}

.bg-rose-50\/60 {
  background-color: rgb(255 241 242 / 0.6);
}

.bg-rose-50\/65 {
  background-color: rgb(255 241 242 / 0.65);
}

.bg-rose-50\/70 {
  background-color: rgb(255 241 242 / 0.7);
}

.bg-rose-50\/75 {
  background-color: rgb(255 241 242 / 0.75);
}

.bg-rose-50\/80 {
  background-color: rgb(255 241 242 / 0.8);
}

.bg-rose-50\/85 {
  background-color: rgb(255 241 242 / 0.85);
}

.bg-rose-50\/90 {
  background-color: rgb(255 241 242 / 0.9);
}

.bg-rose-50\/95 {
  background-color: rgb(255 241 242 / 0.95);
}

.bg-rose-500 {
  --tw-bg-opacity: 1;
  background-color: rgb(244 63 94 / var(--tw-bg-opacity));
}

.bg-rose-500\/0 {
  background-color: rgb(244 63 94 / 0);
}

.bg-rose-500\/10 {
  background-color: rgb(244 63 94 / 0.1);
}

.bg-rose-500\/100 {
  background-color: rgb(244 63 94 / 1);
}

.bg-rose-500\/15 {
  background-color: rgb(244 63 94 / 0.15);
}

.bg-rose-500\/20 {
  background-color: rgb(244 63 94 / 0.2);
}

.bg-rose-500\/25 {
  background-color: rgb(244 63 94 / 0.25);
}

.bg-rose-500\/30 {
  background-color: rgb(244 63 94 / 0.3);
}

.bg-rose-500\/35 {
  background-color: rgb(244 63 94 / 0.35);
}

.bg-rose-500\/40 {
  background-color: rgb(244 63 94 / 0.4);
}

.bg-rose-500\/45 {
  background-color: rgb(244 63 94 / 0.45);
}

.bg-rose-500\/5 {
  background-color: rgb(244 63 94 / 0.05);
}

.bg-rose-500\/50 {
  background-color: rgb(244 63 94 / 0.5);
}

.bg-rose-500\/55 {
  background-color: rgb(244 63 94 / 0.55);
}

.bg-rose-500\/60 {
  background-color: rgb(244 63 94 / 0.6);
}

.bg-rose-500\/65 {
  background-color: rgb(244 63 94 / 0.65);
}

.bg-rose-500\/70 {
  background-color: rgb(244 63 94 / 0.7);
}

.bg-rose-500\/75 {
  background-color: rgb(244 63 94 / 0.75);
}

.bg-rose-500\/80 {
  background-color: rgb(244 63 94 / 0.8);
}

.bg-rose-500\/85 {
  background-color: rgb(244 63 94 / 0.85);
}

.bg-rose-500\/90 {
  background-color: rgb(244 63 94 / 0.9);
}

.bg-rose-500\/95 {
  background-color: rgb(244 63 94 / 0.95);
}

.bg-rose-600 {
  --tw-bg-opacity: 1;
  background-color: rgb(225 29 72 / var(--tw-bg-opacity));
}

.bg-rose-600\/0 {
  background-color: rgb(225 29 72 / 0);
}

.bg-rose-600\/10 {
  background-color: rgb(225 29 72 / 0.1);
}

.bg-rose-600\/100 {
  background-color: rgb(225 29 72 / 1);
}

.bg-rose-600\/15 {
  background-color: rgb(225 29 72 / 0.15);
}

.bg-rose-600\/20 {
  background-color: rgb(225 29 72 / 0.2);
}

.bg-rose-600\/25 {
  background-color: rgb(225 29 72 / 0.25);
}

.bg-rose-600\/30 {
  background-color: rgb(225 29 72 / 0.3);
}

.bg-rose-600\/35 {
  background-color: rgb(225 29 72 / 0.35);
}

.bg-rose-600\/40 {
  background-color: rgb(225 29 72 / 0.4);
}

.bg-rose-600\/45 {
  background-color: rgb(225 29 72 / 0.45);
}

.bg-rose-600\/5 {
  background-color: rgb(225 29 72 / 0.05);
}

.bg-rose-600\/50 {
  background-color: rgb(225 29 72 / 0.5);
}

.bg-rose-600\/55 {
  background-color: rgb(225 29 72 / 0.55);
}

.bg-rose-600\/60 {
  background-color: rgb(225 29 72 / 0.6);
}

.bg-rose-600\/65 {
  background-color: rgb(225 29 72 / 0.65);
}

.bg-rose-600\/70 {
  background-color: rgb(225 29 72 / 0.7);
}

.bg-rose-600\/75 {
  background-color: rgb(225 29 72 / 0.75);
}

.bg-rose-600\/80 {
  background-color: rgb(225 29 72 / 0.8);
}

.bg-rose-600\/85 {
  background-color: rgb(225 29 72 / 0.85);
}

.bg-rose-600\/90 {
  background-color: rgb(225 29 72 / 0.9);
}

.bg-rose-600\/95 {
  background-color: rgb(225 29 72 / 0.95);
}

.bg-rose-700 {
  --tw-bg-opacity: 1;
  background-color: rgb(190 18 60 / var(--tw-bg-opacity));
}

.bg-rose-700\/0 {
  background-color: rgb(190 18 60 / 0);
}

.bg-rose-700\/10 {
  background-color: rgb(190 18 60 / 0.1);
}

.bg-rose-700\/100 {
  background-color: rgb(190 18 60 / 1);
}

.bg-rose-700\/15 {
  background-color: rgb(190 18 60 / 0.15);
}

.bg-rose-700\/20 {
  background-color: rgb(190 18 60 / 0.2);
}

.bg-rose-700\/25 {
  background-color: rgb(190 18 60 / 0.25);
}

.bg-rose-700\/30 {
  background-color: rgb(190 18 60 / 0.3);
}

.bg-rose-700\/35 {
  background-color: rgb(190 18 60 / 0.35);
}

.bg-rose-700\/40 {
  background-color: rgb(190 18 60 / 0.4);
}

.bg-rose-700\/45 {
  background-color: rgb(190 18 60 / 0.45);
}

.bg-rose-700\/5 {
  background-color: rgb(190 18 60 / 0.05);
}

.bg-rose-700\/50 {
  background-color: rgb(190 18 60 / 0.5);
}

.bg-rose-700\/55 {
  background-color: rgb(190 18 60 / 0.55);
}

.bg-rose-700\/60 {
  background-color: rgb(190 18 60 / 0.6);
}

.bg-rose-700\/65 {
  background-color: rgb(190 18 60 / 0.65);
}

.bg-rose-700\/70 {
  background-color: rgb(190 18 60 / 0.7);
}

.bg-rose-700\/75 {
  background-color: rgb(190 18 60 / 0.75);
}

.bg-rose-700\/80 {
  background-color: rgb(190 18 60 / 0.8);
}

.bg-rose-700\/85 {
  background-color: rgb(190 18 60 / 0.85);
}

.bg-rose-700\/90 {
  background-color: rgb(190 18 60 / 0.9);
}

.bg-rose-700\/95 {
  background-color: rgb(190 18 60 / 0.95);
}

.bg-rose-800 {
  --tw-bg-opacity: 1;
  background-color: rgb(159 18 57 / var(--tw-bg-opacity));
}

.bg-rose-800\/0 {
  background-color: rgb(159 18 57 / 0);
}

.bg-rose-800\/10 {
  background-color: rgb(159 18 57 / 0.1);
}

.bg-rose-800\/100 {
  background-color: rgb(159 18 57 / 1);
}

.bg-rose-800\/15 {
  background-color: rgb(159 18 57 / 0.15);
}

.bg-rose-800\/20 {
  background-color: rgb(159 18 57 / 0.2);
}

.bg-rose-800\/25 {
  background-color: rgb(159 18 57 / 0.25);
}

.bg-rose-800\/30 {
  background-color: rgb(159 18 57 / 0.3);
}

.bg-rose-800\/35 {
  background-color: rgb(159 18 57 / 0.35);
}

.bg-rose-800\/40 {
  background-color: rgb(159 18 57 / 0.4);
}

.bg-rose-800\/45 {
  background-color: rgb(159 18 57 / 0.45);
}

.bg-rose-800\/5 {
  background-color: rgb(159 18 57 / 0.05);
}

.bg-rose-800\/50 {
  background-color: rgb(159 18 57 / 0.5);
}

.bg-rose-800\/55 {
  background-color: rgb(159 18 57 / 0.55);
}

.bg-rose-800\/60 {
  background-color: rgb(159 18 57 / 0.6);
}

.bg-rose-800\/65 {
  background-color: rgb(159 18 57 / 0.65);
}

.bg-rose-800\/70 {
  background-color: rgb(159 18 57 / 0.7);
}

.bg-rose-800\/75 {
  background-color: rgb(159 18 57 / 0.75);
}

.bg-rose-800\/80 {
  background-color: rgb(159 18 57 / 0.8);
}

.bg-rose-800\/85 {
  background-color: rgb(159 18 57 / 0.85);
}

.bg-rose-800\/90 {
  background-color: rgb(159 18 57 / 0.9);
}

.bg-rose-800\/95 {
  background-color: rgb(159 18 57 / 0.95);
}

.bg-rose-900 {
  --tw-bg-opacity: 1;
  background-color: rgb(136 19 55 / var(--tw-bg-opacity));
}

.bg-rose-900\/0 {
  background-color: rgb(136 19 55 / 0);
}

.bg-rose-900\/10 {
  background-color: rgb(136 19 55 / 0.1);
}

.bg-rose-900\/100 {
  background-color: rgb(136 19 55 / 1);
}

.bg-rose-900\/15 {
  background-color: rgb(136 19 55 / 0.15);
}

.bg-rose-900\/20 {
  background-color: rgb(136 19 55 / 0.2);
}

.bg-rose-900\/25 {
  background-color: rgb(136 19 55 / 0.25);
}

.bg-rose-900\/30 {
  background-color: rgb(136 19 55 / 0.3);
}

.bg-rose-900\/35 {
  background-color: rgb(136 19 55 / 0.35);
}

.bg-rose-900\/40 {
  background-color: rgb(136 19 55 / 0.4);
}

.bg-rose-900\/45 {
  background-color: rgb(136 19 55 / 0.45);
}

.bg-rose-900\/5 {
  background-color: rgb(136 19 55 / 0.05);
}

.bg-rose-900\/50 {
  background-color: rgb(136 19 55 / 0.5);
}

.bg-rose-900\/55 {
  background-color: rgb(136 19 55 / 0.55);
}

.bg-rose-900\/60 {
  background-color: rgb(136 19 55 / 0.6);
}

.bg-rose-900\/65 {
  background-color: rgb(136 19 55 / 0.65);
}

.bg-rose-900\/70 {
  background-color: rgb(136 19 55 / 0.7);
}

.bg-rose-900\/75 {
  background-color: rgb(136 19 55 / 0.75);
}

.bg-rose-900\/80 {
  background-color: rgb(136 19 55 / 0.8);
}

.bg-rose-900\/85 {
  background-color: rgb(136 19 55 / 0.85);
}

.bg-rose-900\/90 {
  background-color: rgb(136 19 55 / 0.9);
}

.bg-rose-900\/95 {
  background-color: rgb(136 19 55 / 0.95);
}

.bg-rose-950 {
  --tw-bg-opacity: 1;
  background-color: rgb(76 5 25 / var(--tw-bg-opacity));
}

.bg-rose-950\/0 {
  background-color: rgb(76 5 25 / 0);
}

.bg-rose-950\/10 {
  background-color: rgb(76 5 25 / 0.1);
}

.bg-rose-950\/100 {
  background-color: rgb(76 5 25 / 1);
}

.bg-rose-950\/15 {
  background-color: rgb(76 5 25 / 0.15);
}

.bg-rose-950\/20 {
  background-color: rgb(76 5 25 / 0.2);
}

.bg-rose-950\/25 {
  background-color: rgb(76 5 25 / 0.25);
}

.bg-rose-950\/30 {
  background-color: rgb(76 5 25 / 0.3);
}

.bg-rose-950\/35 {
  background-color: rgb(76 5 25 / 0.35);
}

.bg-rose-950\/40 {
  background-color: rgb(76 5 25 / 0.4);
}

.bg-rose-950\/45 {
  background-color: rgb(76 5 25 / 0.45);
}

.bg-rose-950\/5 {
  background-color: rgb(76 5 25 / 0.05);
}

.bg-rose-950\/50 {
  background-color: rgb(76 5 25 / 0.5);
}

.bg-rose-950\/55 {
  background-color: rgb(76 5 25 / 0.55);
}

.bg-rose-950\/60 {
  background-color: rgb(76 5 25 / 0.6);
}

.bg-rose-950\/65 {
  background-color: rgb(76 5 25 / 0.65);
}

.bg-rose-950\/70 {
  background-color: rgb(76 5 25 / 0.7);
}

.bg-rose-950\/75 {
  background-color: rgb(76 5 25 / 0.75);
}

.bg-rose-950\/80 {
  background-color: rgb(76 5 25 / 0.8);
}

.bg-rose-950\/85 {
  background-color: rgb(76 5 25 / 0.85);
}

.bg-rose-950\/90 {
  background-color: rgb(76 5 25 / 0.9);
}

.bg-rose-950\/95 {
  background-color: rgb(76 5 25 / 0.95);
}

.bg-secondary {
  --tw-bg-opacity: 1;
  background-color: var(--fallback-s,oklch(var(--s)/var(--tw-bg-opacity)));
}

.bg-secondary-content {
  --tw-bg-opacity: 1;
  background-color: var(--fallback-sc,oklch(var(--sc)/var(--tw-bg-opacity)));
}

.bg-secondary-content\/0 {
  background-color: var(--fallback-sc,oklch(var(--sc)/0));
}

.bg-secondary-content\/10 {
  background-color: var(--fallback-sc,oklch(var(--sc)/0.1));
}

.bg-secondary-content\/100 {
  background-color: var(--fallback-sc,oklch(var(--sc)/1));
}

.bg-secondary-content\/15 {
  background-color: var(--fallback-sc,oklch(var(--sc)/0.15));
}

.bg-secondary-content\/20 {
  background-color: var(--fallback-sc,oklch(var(--sc)/0.2));
}

.bg-secondary-content\/25 {
  background-color: var(--fallback-sc,oklch(var(--sc)/0.25));
}

.bg-secondary-content\/30 {
  background-color: var(--fallback-sc,oklch(var(--sc)/0.3));
}

.bg-secondary-content\/35 {
  background-color: var(--fallback-sc,oklch(var(--sc)/0.35));
}

.bg-secondary-content\/40 {
  background-color: var(--fallback-sc,oklch(var(--sc)/0.4));
}

.bg-secondary-content\/45 {
  background-color: var(--fallback-sc,oklch(var(--sc)/0.45));
}

.bg-secondary-content\/5 {
  background-color: var(--fallback-sc,oklch(var(--sc)/0.05));
}

.bg-secondary-content\/50 {
  background-color: var(--fallback-sc,oklch(var(--sc)/0.5));
}

.bg-secondary-content\/55 {
  background-color: var(--fallback-sc,oklch(var(--sc)/0.55));
}

.bg-secondary-content\/60 {
  background-color: var(--fallback-sc,oklch(var(--sc)/0.6));
}

.bg-secondary-content\/65 {
  background-color: var(--fallback-sc,oklch(var(--sc)/0.65));
}

.bg-secondary-content\/70 {
  background-color: var(--fallback-sc,oklch(var(--sc)/0.7));
}

.bg-secondary-content\/75 {
  background-color: var(--fallback-sc,oklch(var(--sc)/0.75));
}

.bg-secondary-content\/80 {
  background-color: var(--fallback-sc,oklch(var(--sc)/0.8));
}

.bg-secondary-content\/85 {
  background-color: var(--fallback-sc,oklch(var(--sc)/0.85));
}

.bg-secondary-content\/90 {
  background-color: var(--fallback-sc,oklch(var(--sc)/0.9));
}

.bg-secondary-content\/95 {
  background-color: var(--fallback-sc,oklch(var(--sc)/0.95));
}

.bg-secondary\/0 {
  background-color: var(--fallback-s,oklch(var(--s)/0));
}

.bg-secondary\/10 {
  background-color: var(--fallback-s,oklch(var(--s)/0.1));
}

.bg-secondary\/100 {
  background-color: var(--fallback-s,oklch(var(--s)/1));
}

.bg-secondary\/15 {
  background-color: var(--fallback-s,oklch(var(--s)/0.15));
}

.bg-secondary\/20 {
  background-color: var(--fallback-s,oklch(var(--s)/0.2));
}

.bg-secondary\/25 {
  background-color: var(--fallback-s,oklch(var(--s)/0.25));
}

.bg-secondary\/30 {
  background-color: var(--fallback-s,oklch(var(--s)/0.3));
}

.bg-secondary\/35 {
  background-color: var(--fallback-s,oklch(var(--s)/0.35));
}

.bg-secondary\/40 {
  background-color: var(--fallback-s,oklch(var(--s)/0.4));
}

.bg-secondary\/45 {
  background-color: var(--fallback-s,oklch(var(--s)/0.45));
}

.bg-secondary\/5 {
  background-color: var(--fallback-s,oklch(var(--s)/0.05));
}

.bg-secondary\/50 {
  background-color: var(--fallback-s,oklch(var(--s)/0.5));
}

.bg-secondary\/55 {
  background-color: var(--fallback-s,oklch(var(--s)/0.55));
}

.bg-secondary\/60 {
  background-color: var(--fallback-s,oklch(var(--s)/0.6));
}

.bg-secondary\/65 {
  background-color: var(--fallback-s,oklch(var(--s)/0.65));
}

.bg-secondary\/70 {
  background-color: var(--fallback-s,oklch(var(--s)/0.7));
}

.bg-secondary\/75 {
  background-color: var(--fallback-s,oklch(var(--s)/0.75));
}

.bg-secondary\/80 {
  background-color: var(--fallback-s,oklch(var(--s)/0.8));
}

.bg-secondary\/85 {
  background-color: var(--fallback-s,oklch(var(--s)/0.85));
}

.bg-secondary\/90 {
  background-color: var(--fallback-s,oklch(var(--s)/0.9));
}

.bg-secondary\/95 {
  background-color: var(--fallback-s,oklch(var(--s)/0.95));
}

.bg-sky-100 {
  --tw-bg-opacity: 1;
  background-color: rgb(224 242 254 / var(--tw-bg-opacity));
}

.bg-sky-100\/0 {
  background-color: rgb(224 242 254 / 0);
}

.bg-sky-100\/10 {
  background-color: rgb(224 242 254 / 0.1);
}

.bg-sky-100\/100 {
  background-color: rgb(224 242 254 / 1);
}

.bg-sky-100\/15 {
  background-color: rgb(224 242 254 / 0.15);
}

.bg-sky-100\/20 {
  background-color: rgb(224 242 254 / 0.2);
}

.bg-sky-100\/25 {
  background-color: rgb(224 242 254 / 0.25);
}

.bg-sky-100\/30 {
  background-color: rgb(224 242 254 / 0.3);
}

.bg-sky-100\/35 {
  background-color: rgb(224 242 254 / 0.35);
}

.bg-sky-100\/40 {
  background-color: rgb(224 242 254 / 0.4);
}

.bg-sky-100\/45 {
  background-color: rgb(224 242 254 / 0.45);
}

.bg-sky-100\/5 {
  background-color: rgb(224 242 254 / 0.05);
}

.bg-sky-100\/50 {
  background-color: rgb(224 242 254 / 0.5);
}

.bg-sky-100\/55 {
  background-color: rgb(224 242 254 / 0.55);
}

.bg-sky-100\/60 {
  background-color: rgb(224 242 254 / 0.6);
}

.bg-sky-100\/65 {
  background-color: rgb(224 242 254 / 0.65);
}

.bg-sky-100\/70 {
  background-color: rgb(224 242 254 / 0.7);
}

.bg-sky-100\/75 {
  background-color: rgb(224 242 254 / 0.75);
}

.bg-sky-100\/80 {
  background-color: rgb(224 242 254 / 0.8);
}

.bg-sky-100\/85 {
  background-color: rgb(224 242 254 / 0.85);
}

.bg-sky-100\/90 {
  background-color: rgb(224 242 254 / 0.9);
}

.bg-sky-100\/95 {
  background-color: rgb(224 242 254 / 0.95);
}

.bg-sky-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(186 230 253 / var(--tw-bg-opacity));
}

.bg-sky-200\/0 {
  background-color: rgb(186 230 253 / 0);
}

.bg-sky-200\/10 {
  background-color: rgb(186 230 253 / 0.1);
}

.bg-sky-200\/100 {
  background-color: rgb(186 230 253 / 1);
}

.bg-sky-200\/15 {
  background-color: rgb(186 230 253 / 0.15);
}

.bg-sky-200\/20 {
  background-color: rgb(186 230 253 / 0.2);
}

.bg-sky-200\/25 {
  background-color: rgb(186 230 253 / 0.25);
}

.bg-sky-200\/30 {
  background-color: rgb(186 230 253 / 0.3);
}

.bg-sky-200\/35 {
  background-color: rgb(186 230 253 / 0.35);
}

.bg-sky-200\/40 {
  background-color: rgb(186 230 253 / 0.4);
}

.bg-sky-200\/45 {
  background-color: rgb(186 230 253 / 0.45);
}

.bg-sky-200\/5 {
  background-color: rgb(186 230 253 / 0.05);
}

.bg-sky-200\/50 {
  background-color: rgb(186 230 253 / 0.5);
}

.bg-sky-200\/55 {
  background-color: rgb(186 230 253 / 0.55);
}

.bg-sky-200\/60 {
  background-color: rgb(186 230 253 / 0.6);
}

.bg-sky-200\/65 {
  background-color: rgb(186 230 253 / 0.65);
}

.bg-sky-200\/70 {
  background-color: rgb(186 230 253 / 0.7);
}

.bg-sky-200\/75 {
  background-color: rgb(186 230 253 / 0.75);
}

.bg-sky-200\/80 {
  background-color: rgb(186 230 253 / 0.8);
}

.bg-sky-200\/85 {
  background-color: rgb(186 230 253 / 0.85);
}

.bg-sky-200\/90 {
  background-color: rgb(186 230 253 / 0.9);
}

.bg-sky-200\/95 {
  background-color: rgb(186 230 253 / 0.95);
}

.bg-sky-300 {
  --tw-bg-opacity: 1;
  background-color: rgb(125 211 252 / var(--tw-bg-opacity));
}

.bg-sky-300\/0 {
  background-color: rgb(125 211 252 / 0);
}

.bg-sky-300\/10 {
  background-color: rgb(125 211 252 / 0.1);
}

.bg-sky-300\/100 {
  background-color: rgb(125 211 252 / 1);
}

.bg-sky-300\/15 {
  background-color: rgb(125 211 252 / 0.15);
}

.bg-sky-300\/20 {
  background-color: rgb(125 211 252 / 0.2);
}

.bg-sky-300\/25 {
  background-color: rgb(125 211 252 / 0.25);
}

.bg-sky-300\/30 {
  background-color: rgb(125 211 252 / 0.3);
}

.bg-sky-300\/35 {
  background-color: rgb(125 211 252 / 0.35);
}

.bg-sky-300\/40 {
  background-color: rgb(125 211 252 / 0.4);
}

.bg-sky-300\/45 {
  background-color: rgb(125 211 252 / 0.45);
}

.bg-sky-300\/5 {
  background-color: rgb(125 211 252 / 0.05);
}

.bg-sky-300\/50 {
  background-color: rgb(125 211 252 / 0.5);
}

.bg-sky-300\/55 {
  background-color: rgb(125 211 252 / 0.55);
}

.bg-sky-300\/60 {
  background-color: rgb(125 211 252 / 0.6);
}

.bg-sky-300\/65 {
  background-color: rgb(125 211 252 / 0.65);
}

.bg-sky-300\/70 {
  background-color: rgb(125 211 252 / 0.7);
}

.bg-sky-300\/75 {
  background-color: rgb(125 211 252 / 0.75);
}

.bg-sky-300\/80 {
  background-color: rgb(125 211 252 / 0.8);
}

.bg-sky-300\/85 {
  background-color: rgb(125 211 252 / 0.85);
}

.bg-sky-300\/90 {
  background-color: rgb(125 211 252 / 0.9);
}

.bg-sky-300\/95 {
  background-color: rgb(125 211 252 / 0.95);
}

.bg-sky-400 {
  --tw-bg-opacity: 1;
  background-color: rgb(56 189 248 / var(--tw-bg-opacity));
}

.bg-sky-400\/0 {
  background-color: rgb(56 189 248 / 0);
}

.bg-sky-400\/10 {
  background-color: rgb(56 189 248 / 0.1);
}

.bg-sky-400\/100 {
  background-color: rgb(56 189 248 / 1);
}

.bg-sky-400\/15 {
  background-color: rgb(56 189 248 / 0.15);
}

.bg-sky-400\/20 {
  background-color: rgb(56 189 248 / 0.2);
}

.bg-sky-400\/25 {
  background-color: rgb(56 189 248 / 0.25);
}

.bg-sky-400\/30 {
  background-color: rgb(56 189 248 / 0.3);
}

.bg-sky-400\/35 {
  background-color: rgb(56 189 248 / 0.35);
}

.bg-sky-400\/40 {
  background-color: rgb(56 189 248 / 0.4);
}

.bg-sky-400\/45 {
  background-color: rgb(56 189 248 / 0.45);
}

.bg-sky-400\/5 {
  background-color: rgb(56 189 248 / 0.05);
}

.bg-sky-400\/50 {
  background-color: rgb(56 189 248 / 0.5);
}

.bg-sky-400\/55 {
  background-color: rgb(56 189 248 / 0.55);
}

.bg-sky-400\/60 {
  background-color: rgb(56 189 248 / 0.6);
}

.bg-sky-400\/65 {
  background-color: rgb(56 189 248 / 0.65);
}

.bg-sky-400\/70 {
  background-color: rgb(56 189 248 / 0.7);
}

.bg-sky-400\/75 {
  background-color: rgb(56 189 248 / 0.75);
}

.bg-sky-400\/80 {
  background-color: rgb(56 189 248 / 0.8);
}

.bg-sky-400\/85 {
  background-color: rgb(56 189 248 / 0.85);
}

.bg-sky-400\/90 {
  background-color: rgb(56 189 248 / 0.9);
}

.bg-sky-400\/95 {
  background-color: rgb(56 189 248 / 0.95);
}

.bg-sky-50 {
  --tw-bg-opacity: 1;
  background-color: rgb(240 249 255 / var(--tw-bg-opacity));
}

.bg-sky-50\/0 {
  background-color: rgb(240 249 255 / 0);
}

.bg-sky-50\/10 {
  background-color: rgb(240 249 255 / 0.1);
}

.bg-sky-50\/100 {
  background-color: rgb(240 249 255 / 1);
}

.bg-sky-50\/15 {
  background-color: rgb(240 249 255 / 0.15);
}

.bg-sky-50\/20 {
  background-color: rgb(240 249 255 / 0.2);
}

.bg-sky-50\/25 {
  background-color: rgb(240 249 255 / 0.25);
}

.bg-sky-50\/30 {
  background-color: rgb(240 249 255 / 0.3);
}

.bg-sky-50\/35 {
  background-color: rgb(240 249 255 / 0.35);
}

.bg-sky-50\/40 {
  background-color: rgb(240 249 255 / 0.4);
}

.bg-sky-50\/45 {
  background-color: rgb(240 249 255 / 0.45);
}

.bg-sky-50\/5 {
  background-color: rgb(240 249 255 / 0.05);
}

.bg-sky-50\/50 {
  background-color: rgb(240 249 255 / 0.5);
}

.bg-sky-50\/55 {
  background-color: rgb(240 249 255 / 0.55);
}

.bg-sky-50\/60 {
  background-color: rgb(240 249 255 / 0.6);
}

.bg-sky-50\/65 {
  background-color: rgb(240 249 255 / 0.65);
}

.bg-sky-50\/70 {
  background-color: rgb(240 249 255 / 0.7);
}

.bg-sky-50\/75 {
  background-color: rgb(240 249 255 / 0.75);
}

.bg-sky-50\/80 {
  background-color: rgb(240 249 255 / 0.8);
}

.bg-sky-50\/85 {
  background-color: rgb(240 249 255 / 0.85);
}

.bg-sky-50\/90 {
  background-color: rgb(240 249 255 / 0.9);
}

.bg-sky-50\/95 {
  background-color: rgb(240 249 255 / 0.95);
}

.bg-sky-500 {
  --tw-bg-opacity: 1;
  background-color: rgb(14 165 233 / var(--tw-bg-opacity));
}

.bg-sky-500\/0 {
  background-color: rgb(14 165 233 / 0);
}

.bg-sky-500\/10 {
  background-color: rgb(14 165 233 / 0.1);
}

.bg-sky-500\/100 {
  background-color: rgb(14 165 233 / 1);
}

.bg-sky-500\/15 {
  background-color: rgb(14 165 233 / 0.15);
}

.bg-sky-500\/20 {
  background-color: rgb(14 165 233 / 0.2);
}

.bg-sky-500\/25 {
  background-color: rgb(14 165 233 / 0.25);
}

.bg-sky-500\/30 {
  background-color: rgb(14 165 233 / 0.3);
}

.bg-sky-500\/35 {
  background-color: rgb(14 165 233 / 0.35);
}

.bg-sky-500\/40 {
  background-color: rgb(14 165 233 / 0.4);
}

.bg-sky-500\/45 {
  background-color: rgb(14 165 233 / 0.45);
}

.bg-sky-500\/5 {
  background-color: rgb(14 165 233 / 0.05);
}

.bg-sky-500\/50 {
  background-color: rgb(14 165 233 / 0.5);
}

.bg-sky-500\/55 {
  background-color: rgb(14 165 233 / 0.55);
}

.bg-sky-500\/60 {
  background-color: rgb(14 165 233 / 0.6);
}

.bg-sky-500\/65 {
  background-color: rgb(14 165 233 / 0.65);
}

.bg-sky-500\/70 {
  background-color: rgb(14 165 233 / 0.7);
}

.bg-sky-500\/75 {
  background-color: rgb(14 165 233 / 0.75);
}

.bg-sky-500\/80 {
  background-color: rgb(14 165 233 / 0.8);
}

.bg-sky-500\/85 {
  background-color: rgb(14 165 233 / 0.85);
}

.bg-sky-500\/90 {
  background-color: rgb(14 165 233 / 0.9);
}

.bg-sky-500\/95 {
  background-color: rgb(14 165 233 / 0.95);
}

.bg-sky-600 {
  --tw-bg-opacity: 1;
  background-color: rgb(2 132 199 / var(--tw-bg-opacity));
}

.bg-sky-600\/0 {
  background-color: rgb(2 132 199 / 0);
}

.bg-sky-600\/10 {
  background-color: rgb(2 132 199 / 0.1);
}

.bg-sky-600\/100 {
  background-color: rgb(2 132 199 / 1);
}

.bg-sky-600\/15 {
  background-color: rgb(2 132 199 / 0.15);
}

.bg-sky-600\/20 {
  background-color: rgb(2 132 199 / 0.2);
}

.bg-sky-600\/25 {
  background-color: rgb(2 132 199 / 0.25);
}

.bg-sky-600\/30 {
  background-color: rgb(2 132 199 / 0.3);
}

.bg-sky-600\/35 {
  background-color: rgb(2 132 199 / 0.35);
}

.bg-sky-600\/40 {
  background-color: rgb(2 132 199 / 0.4);
}

.bg-sky-600\/45 {
  background-color: rgb(2 132 199 / 0.45);
}

.bg-sky-600\/5 {
  background-color: rgb(2 132 199 / 0.05);
}

.bg-sky-600\/50 {
  background-color: rgb(2 132 199 / 0.5);
}

.bg-sky-600\/55 {
  background-color: rgb(2 132 199 / 0.55);
}

.bg-sky-600\/60 {
  background-color: rgb(2 132 199 / 0.6);
}

.bg-sky-600\/65 {
  background-color: rgb(2 132 199 / 0.65);
}

.bg-sky-600\/70 {
  background-color: rgb(2 132 199 / 0.7);
}

.bg-sky-600\/75 {
  background-color: rgb(2 132 199 / 0.75);
}

.bg-sky-600\/80 {
  background-color: rgb(2 132 199 / 0.8);
}

.bg-sky-600\/85 {
  background-color: rgb(2 132 199 / 0.85);
}

.bg-sky-600\/90 {
  background-color: rgb(2 132 199 / 0.9);
}

.bg-sky-600\/95 {
  background-color: rgb(2 132 199 / 0.95);
}

.bg-sky-700 {
  --tw-bg-opacity: 1;
  background-color: rgb(3 105 161 / var(--tw-bg-opacity));
}

.bg-sky-700\/0 {
  background-color: rgb(3 105 161 / 0);
}

.bg-sky-700\/10 {
  background-color: rgb(3 105 161 / 0.1);
}

.bg-sky-700\/100 {
  background-color: rgb(3 105 161 / 1);
}

.bg-sky-700\/15 {
  background-color: rgb(3 105 161 / 0.15);
}

.bg-sky-700\/20 {
  background-color: rgb(3 105 161 / 0.2);
}

.bg-sky-700\/25 {
  background-color: rgb(3 105 161 / 0.25);
}

.bg-sky-700\/30 {
  background-color: rgb(3 105 161 / 0.3);
}

.bg-sky-700\/35 {
  background-color: rgb(3 105 161 / 0.35);
}

.bg-sky-700\/40 {
  background-color: rgb(3 105 161 / 0.4);
}

.bg-sky-700\/45 {
  background-color: rgb(3 105 161 / 0.45);
}

.bg-sky-700\/5 {
  background-color: rgb(3 105 161 / 0.05);
}

.bg-sky-700\/50 {
  background-color: rgb(3 105 161 / 0.5);
}

.bg-sky-700\/55 {
  background-color: rgb(3 105 161 / 0.55);
}

.bg-sky-700\/60 {
  background-color: rgb(3 105 161 / 0.6);
}

.bg-sky-700\/65 {
  background-color: rgb(3 105 161 / 0.65);
}

.bg-sky-700\/70 {
  background-color: rgb(3 105 161 / 0.7);
}

.bg-sky-700\/75 {
  background-color: rgb(3 105 161 / 0.75);
}

.bg-sky-700\/80 {
  background-color: rgb(3 105 161 / 0.8);
}

.bg-sky-700\/85 {
  background-color: rgb(3 105 161 / 0.85);
}

.bg-sky-700\/90 {
  background-color: rgb(3 105 161 / 0.9);
}

.bg-sky-700\/95 {
  background-color: rgb(3 105 161 / 0.95);
}

.bg-sky-800 {
  --tw-bg-opacity: 1;
  background-color: rgb(7 89 133 / var(--tw-bg-opacity));
}

.bg-sky-800\/0 {
  background-color: rgb(7 89 133 / 0);
}

.bg-sky-800\/10 {
  background-color: rgb(7 89 133 / 0.1);
}

.bg-sky-800\/100 {
  background-color: rgb(7 89 133 / 1);
}

.bg-sky-800\/15 {
  background-color: rgb(7 89 133 / 0.15);
}

.bg-sky-800\/20 {
  background-color: rgb(7 89 133 / 0.2);
}

.bg-sky-800\/25 {
  background-color: rgb(7 89 133 / 0.25);
}

.bg-sky-800\/30 {
  background-color: rgb(7 89 133 / 0.3);
}

.bg-sky-800\/35 {
  background-color: rgb(7 89 133 / 0.35);
}

.bg-sky-800\/40 {
  background-color: rgb(7 89 133 / 0.4);
}

.bg-sky-800\/45 {
  background-color: rgb(7 89 133 / 0.45);
}

.bg-sky-800\/5 {
  background-color: rgb(7 89 133 / 0.05);
}

.bg-sky-800\/50 {
  background-color: rgb(7 89 133 / 0.5);
}

.bg-sky-800\/55 {
  background-color: rgb(7 89 133 / 0.55);
}

.bg-sky-800\/60 {
  background-color: rgb(7 89 133 / 0.6);
}

.bg-sky-800\/65 {
  background-color: rgb(7 89 133 / 0.65);
}

.bg-sky-800\/70 {
  background-color: rgb(7 89 133 / 0.7);
}

.bg-sky-800\/75 {
  background-color: rgb(7 89 133 / 0.75);
}

.bg-sky-800\/80 {
  background-color: rgb(7 89 133 / 0.8);
}

.bg-sky-800\/85 {
  background-color: rgb(7 89 133 / 0.85);
}

.bg-sky-800\/90 {
  background-color: rgb(7 89 133 / 0.9);
}

.bg-sky-800\/95 {
  background-color: rgb(7 89 133 / 0.95);
}

.bg-sky-900 {
  --tw-bg-opacity: 1;
  background-color: rgb(12 74 110 / var(--tw-bg-opacity));
}

.bg-sky-900\/0 {
  background-color: rgb(12 74 110 / 0);
}

.bg-sky-900\/10 {
  background-color: rgb(12 74 110 / 0.1);
}

.bg-sky-900\/100 {
  background-color: rgb(12 74 110 / 1);
}

.bg-sky-900\/15 {
  background-color: rgb(12 74 110 / 0.15);
}

.bg-sky-900\/20 {
  background-color: rgb(12 74 110 / 0.2);
}

.bg-sky-900\/25 {
  background-color: rgb(12 74 110 / 0.25);
}

.bg-sky-900\/30 {
  background-color: rgb(12 74 110 / 0.3);
}

.bg-sky-900\/35 {
  background-color: rgb(12 74 110 / 0.35);
}

.bg-sky-900\/40 {
  background-color: rgb(12 74 110 / 0.4);
}

.bg-sky-900\/45 {
  background-color: rgb(12 74 110 / 0.45);
}

.bg-sky-900\/5 {
  background-color: rgb(12 74 110 / 0.05);
}

.bg-sky-900\/50 {
  background-color: rgb(12 74 110 / 0.5);
}

.bg-sky-900\/55 {
  background-color: rgb(12 74 110 / 0.55);
}

.bg-sky-900\/60 {
  background-color: rgb(12 74 110 / 0.6);
}

.bg-sky-900\/65 {
  background-color: rgb(12 74 110 / 0.65);
}

.bg-sky-900\/70 {
  background-color: rgb(12 74 110 / 0.7);
}

.bg-sky-900\/75 {
  background-color: rgb(12 74 110 / 0.75);
}

.bg-sky-900\/80 {
  background-color: rgb(12 74 110 / 0.8);
}

.bg-sky-900\/85 {
  background-color: rgb(12 74 110 / 0.85);
}

.bg-sky-900\/90 {
  background-color: rgb(12 74 110 / 0.9);
}

.bg-sky-900\/95 {
  background-color: rgb(12 74 110 / 0.95);
}

.bg-sky-950 {
  --tw-bg-opacity: 1;
  background-color: rgb(8 47 73 / var(--tw-bg-opacity));
}

.bg-sky-950\/0 {
  background-color: rgb(8 47 73 / 0);
}

.bg-sky-950\/10 {
  background-color: rgb(8 47 73 / 0.1);
}

.bg-sky-950\/100 {
  background-color: rgb(8 47 73 / 1);
}

.bg-sky-950\/15 {
  background-color: rgb(8 47 73 / 0.15);
}

.bg-sky-950\/20 {
  background-color: rgb(8 47 73 / 0.2);
}

.bg-sky-950\/25 {
  background-color: rgb(8 47 73 / 0.25);
}

.bg-sky-950\/30 {
  background-color: rgb(8 47 73 / 0.3);
}

.bg-sky-950\/35 {
  background-color: rgb(8 47 73 / 0.35);
}

.bg-sky-950\/40 {
  background-color: rgb(8 47 73 / 0.4);
}

.bg-sky-950\/45 {
  background-color: rgb(8 47 73 / 0.45);
}

.bg-sky-950\/5 {
  background-color: rgb(8 47 73 / 0.05);
}

.bg-sky-950\/50 {
  background-color: rgb(8 47 73 / 0.5);
}

.bg-sky-950\/55 {
  background-color: rgb(8 47 73 / 0.55);
}

.bg-sky-950\/60 {
  background-color: rgb(8 47 73 / 0.6);
}

.bg-sky-950\/65 {
  background-color: rgb(8 47 73 / 0.65);
}

.bg-sky-950\/70 {
  background-color: rgb(8 47 73 / 0.7);
}

.bg-sky-950\/75 {
  background-color: rgb(8 47 73 / 0.75);
}

.bg-sky-950\/80 {
  background-color: rgb(8 47 73 / 0.8);
}

.bg-sky-950\/85 {
  background-color: rgb(8 47 73 / 0.85);
}

.bg-sky-950\/90 {
  background-color: rgb(8 47 73 / 0.9);
}

.bg-sky-950\/95 {
  background-color: rgb(8 47 73 / 0.95);
}

.bg-slate-100 {
  --tw-bg-opacity: 1;
  background-color: rgb(241 245 249 / var(--tw-bg-opacity));
}

.bg-slate-100\/0 {
  background-color: rgb(241 245 249 / 0);
}

.bg-slate-100\/10 {
  background-color: rgb(241 245 249 / 0.1);
}

.bg-slate-100\/100 {
  background-color: rgb(241 245 249 / 1);
}

.bg-slate-100\/15 {
  background-color: rgb(241 245 249 / 0.15);
}

.bg-slate-100\/20 {
  background-color: rgb(241 245 249 / 0.2);
}

.bg-slate-100\/25 {
  background-color: rgb(241 245 249 / 0.25);
}

.bg-slate-100\/30 {
  background-color: rgb(241 245 249 / 0.3);
}

.bg-slate-100\/35 {
  background-color: rgb(241 245 249 / 0.35);
}

.bg-slate-100\/40 {
  background-color: rgb(241 245 249 / 0.4);
}

.bg-slate-100\/45 {
  background-color: rgb(241 245 249 / 0.45);
}

.bg-slate-100\/5 {
  background-color: rgb(241 245 249 / 0.05);
}

.bg-slate-100\/50 {
  background-color: rgb(241 245 249 / 0.5);
}

.bg-slate-100\/55 {
  background-color: rgb(241 245 249 / 0.55);
}

.bg-slate-100\/60 {
  background-color: rgb(241 245 249 / 0.6);
}

.bg-slate-100\/65 {
  background-color: rgb(241 245 249 / 0.65);
}

.bg-slate-100\/70 {
  background-color: rgb(241 245 249 / 0.7);
}

.bg-slate-100\/75 {
  background-color: rgb(241 245 249 / 0.75);
}

.bg-slate-100\/80 {
  background-color: rgb(241 245 249 / 0.8);
}

.bg-slate-100\/85 {
  background-color: rgb(241 245 249 / 0.85);
}

.bg-slate-100\/90 {
  background-color: rgb(241 245 249 / 0.9);
}

.bg-slate-100\/95 {
  background-color: rgb(241 245 249 / 0.95);
}

.bg-slate-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(226 232 240 / var(--tw-bg-opacity));
}

.bg-slate-200\/0 {
  background-color: rgb(226 232 240 / 0);
}

.bg-slate-200\/10 {
  background-color: rgb(226 232 240 / 0.1);
}

.bg-slate-200\/100 {
  background-color: rgb(226 232 240 / 1);
}

.bg-slate-200\/15 {
  background-color: rgb(226 232 240 / 0.15);
}

.bg-slate-200\/20 {
  background-color: rgb(226 232 240 / 0.2);
}

.bg-slate-200\/25 {
  background-color: rgb(226 232 240 / 0.25);
}

.bg-slate-200\/30 {
  background-color: rgb(226 232 240 / 0.3);
}

.bg-slate-200\/35 {
  background-color: rgb(226 232 240 / 0.35);
}

.bg-slate-200\/40 {
  background-color: rgb(226 232 240 / 0.4);
}

.bg-slate-200\/45 {
  background-color: rgb(226 232 240 / 0.45);
}

.bg-slate-200\/5 {
  background-color: rgb(226 232 240 / 0.05);
}

.bg-slate-200\/50 {
  background-color: rgb(226 232 240 / 0.5);
}

.bg-slate-200\/55 {
  background-color: rgb(226 232 240 / 0.55);
}

.bg-slate-200\/60 {
  background-color: rgb(226 232 240 / 0.6);
}

.bg-slate-200\/65 {
  background-color: rgb(226 232 240 / 0.65);
}

.bg-slate-200\/70 {
  background-color: rgb(226 232 240 / 0.7);
}

.bg-slate-200\/75 {
  background-color: rgb(226 232 240 / 0.75);
}

.bg-slate-200\/80 {
  background-color: rgb(226 232 240 / 0.8);
}

.bg-slate-200\/85 {
  background-color: rgb(226 232 240 / 0.85);
}

.bg-slate-200\/90 {
  background-color: rgb(226 232 240 / 0.9);
}

.bg-slate-200\/95 {
  background-color: rgb(226 232 240 / 0.95);
}

.bg-slate-300 {
  --tw-bg-opacity: 1;
  background-color: rgb(203 213 225 / var(--tw-bg-opacity));
}

.bg-slate-300\/0 {
  background-color: rgb(203 213 225 / 0);
}

.bg-slate-300\/10 {
  background-color: rgb(203 213 225 / 0.1);
}

.bg-slate-300\/100 {
  background-color: rgb(203 213 225 / 1);
}

.bg-slate-300\/15 {
  background-color: rgb(203 213 225 / 0.15);
}

.bg-slate-300\/20 {
  background-color: rgb(203 213 225 / 0.2);
}

.bg-slate-300\/25 {
  background-color: rgb(203 213 225 / 0.25);
}

.bg-slate-300\/30 {
  background-color: rgb(203 213 225 / 0.3);
}

.bg-slate-300\/35 {
  background-color: rgb(203 213 225 / 0.35);
}

.bg-slate-300\/40 {
  background-color: rgb(203 213 225 / 0.4);
}

.bg-slate-300\/45 {
  background-color: rgb(203 213 225 / 0.45);
}

.bg-slate-300\/5 {
  background-color: rgb(203 213 225 / 0.05);
}

.bg-slate-300\/50 {
  background-color: rgb(203 213 225 / 0.5);
}

.bg-slate-300\/55 {
  background-color: rgb(203 213 225 / 0.55);
}

.bg-slate-300\/60 {
  background-color: rgb(203 213 225 / 0.6);
}

.bg-slate-300\/65 {
  background-color: rgb(203 213 225 / 0.65);
}

.bg-slate-300\/70 {
  background-color: rgb(203 213 225 / 0.7);
}

.bg-slate-300\/75 {
  background-color: rgb(203 213 225 / 0.75);
}

.bg-slate-300\/80 {
  background-color: rgb(203 213 225 / 0.8);
}

.bg-slate-300\/85 {
  background-color: rgb(203 213 225 / 0.85);
}

.bg-slate-300\/90 {
  background-color: rgb(203 213 225 / 0.9);
}

.bg-slate-300\/95 {
  background-color: rgb(203 213 225 / 0.95);
}

.bg-slate-400 {
  --tw-bg-opacity: 1;
  background-color: rgb(148 163 184 / var(--tw-bg-opacity));
}

.bg-slate-400\/0 {
  background-color: rgb(148 163 184 / 0);
}

.bg-slate-400\/10 {
  background-color: rgb(148 163 184 / 0.1);
}

.bg-slate-400\/100 {
  background-color: rgb(148 163 184 / 1);
}

.bg-slate-400\/15 {
  background-color: rgb(148 163 184 / 0.15);
}

.bg-slate-400\/20 {
  background-color: rgb(148 163 184 / 0.2);
}

.bg-slate-400\/25 {
  background-color: rgb(148 163 184 / 0.25);
}

.bg-slate-400\/30 {
  background-color: rgb(148 163 184 / 0.3);
}

.bg-slate-400\/35 {
  background-color: rgb(148 163 184 / 0.35);
}

.bg-slate-400\/40 {
  background-color: rgb(148 163 184 / 0.4);
}

.bg-slate-400\/45 {
  background-color: rgb(148 163 184 / 0.45);
}

.bg-slate-400\/5 {
  background-color: rgb(148 163 184 / 0.05);
}

.bg-slate-400\/50 {
  background-color: rgb(148 163 184 / 0.5);
}

.bg-slate-400\/55 {
  background-color: rgb(148 163 184 / 0.55);
}

.bg-slate-400\/60 {
  background-color: rgb(148 163 184 / 0.6);
}

.bg-slate-400\/65 {
  background-color: rgb(148 163 184 / 0.65);
}

.bg-slate-400\/70 {
  background-color: rgb(148 163 184 / 0.7);
}

.bg-slate-400\/75 {
  background-color: rgb(148 163 184 / 0.75);
}

.bg-slate-400\/80 {
  background-color: rgb(148 163 184 / 0.8);
}

.bg-slate-400\/85 {
  background-color: rgb(148 163 184 / 0.85);
}

.bg-slate-400\/90 {
  background-color: rgb(148 163 184 / 0.9);
}

.bg-slate-400\/95 {
  background-color: rgb(148 163 184 / 0.95);
}

.bg-slate-50 {
  --tw-bg-opacity: 1;
  background-color: rgb(248 250 252 / var(--tw-bg-opacity));
}

.bg-slate-50\/0 {
  background-color: rgb(248 250 252 / 0);
}

.bg-slate-50\/10 {
  background-color: rgb(248 250 252 / 0.1);
}

.bg-slate-50\/100 {
  background-color: rgb(248 250 252 / 1);
}

.bg-slate-50\/15 {
  background-color: rgb(248 250 252 / 0.15);
}

.bg-slate-50\/20 {
  background-color: rgb(248 250 252 / 0.2);
}

.bg-slate-50\/25 {
  background-color: rgb(248 250 252 / 0.25);
}

.bg-slate-50\/30 {
  background-color: rgb(248 250 252 / 0.3);
}

.bg-slate-50\/35 {
  background-color: rgb(248 250 252 / 0.35);
}

.bg-slate-50\/40 {
  background-color: rgb(248 250 252 / 0.4);
}

.bg-slate-50\/45 {
  background-color: rgb(248 250 252 / 0.45);
}

.bg-slate-50\/5 {
  background-color: rgb(248 250 252 / 0.05);
}

.bg-slate-50\/50 {
  background-color: rgb(248 250 252 / 0.5);
}

.bg-slate-50\/55 {
  background-color: rgb(248 250 252 / 0.55);
}

.bg-slate-50\/60 {
  background-color: rgb(248 250 252 / 0.6);
}

.bg-slate-50\/65 {
  background-color: rgb(248 250 252 / 0.65);
}

.bg-slate-50\/70 {
  background-color: rgb(248 250 252 / 0.7);
}

.bg-slate-50\/75 {
  background-color: rgb(248 250 252 / 0.75);
}

.bg-slate-50\/80 {
  background-color: rgb(248 250 252 / 0.8);
}

.bg-slate-50\/85 {
  background-color: rgb(248 250 252 / 0.85);
}

.bg-slate-50\/90 {
  background-color: rgb(248 250 252 / 0.9);
}

.bg-slate-50\/95 {
  background-color: rgb(248 250 252 / 0.95);
}

.bg-slate-500 {
  --tw-bg-opacity: 1;
  background-color: rgb(100 116 139 / var(--tw-bg-opacity));
}

.bg-slate-500\/0 {
  background-color: rgb(100 116 139 / 0);
}

.bg-slate-500\/10 {
  background-color: rgb(100 116 139 / 0.1);
}

.bg-slate-500\/100 {
  background-color: rgb(100 116 139 / 1);
}

.bg-slate-500\/15 {
  background-color: rgb(100 116 139 / 0.15);
}

.bg-slate-500\/20 {
  background-color: rgb(100 116 139 / 0.2);
}

.bg-slate-500\/25 {
  background-color: rgb(100 116 139 / 0.25);
}

.bg-slate-500\/30 {
  background-color: rgb(100 116 139 / 0.3);
}

.bg-slate-500\/35 {
  background-color: rgb(100 116 139 / 0.35);
}

.bg-slate-500\/40 {
  background-color: rgb(100 116 139 / 0.4);
}

.bg-slate-500\/45 {
  background-color: rgb(100 116 139 / 0.45);
}

.bg-slate-500\/5 {
  background-color: rgb(100 116 139 / 0.05);
}

.bg-slate-500\/50 {
  background-color: rgb(100 116 139 / 0.5);
}

.bg-slate-500\/55 {
  background-color: rgb(100 116 139 / 0.55);
}

.bg-slate-500\/60 {
  background-color: rgb(100 116 139 / 0.6);
}

.bg-slate-500\/65 {
  background-color: rgb(100 116 139 / 0.65);
}

.bg-slate-500\/70 {
  background-color: rgb(100 116 139 / 0.7);
}

.bg-slate-500\/75 {
  background-color: rgb(100 116 139 / 0.75);
}

.bg-slate-500\/80 {
  background-color: rgb(100 116 139 / 0.8);
}

.bg-slate-500\/85 {
  background-color: rgb(100 116 139 / 0.85);
}

.bg-slate-500\/90 {
  background-color: rgb(100 116 139 / 0.9);
}

.bg-slate-500\/95 {
  background-color: rgb(100 116 139 / 0.95);
}

.bg-slate-600 {
  --tw-bg-opacity: 1;
  background-color: rgb(71 85 105 / var(--tw-bg-opacity));
}

.bg-slate-600\/0 {
  background-color: rgb(71 85 105 / 0);
}

.bg-slate-600\/10 {
  background-color: rgb(71 85 105 / 0.1);
}

.bg-slate-600\/100 {
  background-color: rgb(71 85 105 / 1);
}

.bg-slate-600\/15 {
  background-color: rgb(71 85 105 / 0.15);
}

.bg-slate-600\/20 {
  background-color: rgb(71 85 105 / 0.2);
}

.bg-slate-600\/25 {
  background-color: rgb(71 85 105 / 0.25);
}

.bg-slate-600\/30 {
  background-color: rgb(71 85 105 / 0.3);
}

.bg-slate-600\/35 {
  background-color: rgb(71 85 105 / 0.35);
}

.bg-slate-600\/40 {
  background-color: rgb(71 85 105 / 0.4);
}

.bg-slate-600\/45 {
  background-color: rgb(71 85 105 / 0.45);
}

.bg-slate-600\/5 {
  background-color: rgb(71 85 105 / 0.05);
}

.bg-slate-600\/50 {
  background-color: rgb(71 85 105 / 0.5);
}

.bg-slate-600\/55 {
  background-color: rgb(71 85 105 / 0.55);
}

.bg-slate-600\/60 {
  background-color: rgb(71 85 105 / 0.6);
}

.bg-slate-600\/65 {
  background-color: rgb(71 85 105 / 0.65);
}

.bg-slate-600\/70 {
  background-color: rgb(71 85 105 / 0.7);
}

.bg-slate-600\/75 {
  background-color: rgb(71 85 105 / 0.75);
}

.bg-slate-600\/80 {
  background-color: rgb(71 85 105 / 0.8);
}

.bg-slate-600\/85 {
  background-color: rgb(71 85 105 / 0.85);
}

.bg-slate-600\/90 {
  background-color: rgb(71 85 105 / 0.9);
}

.bg-slate-600\/95 {
  background-color: rgb(71 85 105 / 0.95);
}

.bg-slate-700 {
  --tw-bg-opacity: 1;
  background-color: rgb(51 65 85 / var(--tw-bg-opacity));
}

.bg-slate-700\/0 {
  background-color: rgb(51 65 85 / 0);
}

.bg-slate-700\/10 {
  background-color: rgb(51 65 85 / 0.1);
}

.bg-slate-700\/100 {
  background-color: rgb(51 65 85 / 1);
}

.bg-slate-700\/15 {
  background-color: rgb(51 65 85 / 0.15);
}

.bg-slate-700\/20 {
  background-color: rgb(51 65 85 / 0.2);
}

.bg-slate-700\/25 {
  background-color: rgb(51 65 85 / 0.25);
}

.bg-slate-700\/30 {
  background-color: rgb(51 65 85 / 0.3);
}

.bg-slate-700\/35 {
  background-color: rgb(51 65 85 / 0.35);
}

.bg-slate-700\/40 {
  background-color: rgb(51 65 85 / 0.4);
}

.bg-slate-700\/45 {
  background-color: rgb(51 65 85 / 0.45);
}

.bg-slate-700\/5 {
  background-color: rgb(51 65 85 / 0.05);
}

.bg-slate-700\/50 {
  background-color: rgb(51 65 85 / 0.5);
}

.bg-slate-700\/55 {
  background-color: rgb(51 65 85 / 0.55);
}

.bg-slate-700\/60 {
  background-color: rgb(51 65 85 / 0.6);
}

.bg-slate-700\/65 {
  background-color: rgb(51 65 85 / 0.65);
}

.bg-slate-700\/70 {
  background-color: rgb(51 65 85 / 0.7);
}

.bg-slate-700\/75 {
  background-color: rgb(51 65 85 / 0.75);
}

.bg-slate-700\/80 {
  background-color: rgb(51 65 85 / 0.8);
}

.bg-slate-700\/85 {
  background-color: rgb(51 65 85 / 0.85);
}

.bg-slate-700\/90 {
  background-color: rgb(51 65 85 / 0.9);
}

.bg-slate-700\/95 {
  background-color: rgb(51 65 85 / 0.95);
}

.bg-slate-800 {
  --tw-bg-opacity: 1;
  background-color: rgb(30 41 59 / var(--tw-bg-opacity));
}

.bg-slate-800\/0 {
  background-color: rgb(30 41 59 / 0);
}

.bg-slate-800\/10 {
  background-color: rgb(30 41 59 / 0.1);
}

.bg-slate-800\/100 {
  background-color: rgb(30 41 59 / 1);
}

.bg-slate-800\/15 {
  background-color: rgb(30 41 59 / 0.15);
}

.bg-slate-800\/20 {
  background-color: rgb(30 41 59 / 0.2);
}

.bg-slate-800\/25 {
  background-color: rgb(30 41 59 / 0.25);
}

.bg-slate-800\/30 {
  background-color: rgb(30 41 59 / 0.3);
}

.bg-slate-800\/35 {
  background-color: rgb(30 41 59 / 0.35);
}

.bg-slate-800\/40 {
  background-color: rgb(30 41 59 / 0.4);
}

.bg-slate-800\/45 {
  background-color: rgb(30 41 59 / 0.45);
}

.bg-slate-800\/5 {
  background-color: rgb(30 41 59 / 0.05);
}

.bg-slate-800\/50 {
  background-color: rgb(30 41 59 / 0.5);
}

.bg-slate-800\/55 {
  background-color: rgb(30 41 59 / 0.55);
}

.bg-slate-800\/60 {
  background-color: rgb(30 41 59 / 0.6);
}

.bg-slate-800\/65 {
  background-color: rgb(30 41 59 / 0.65);
}

.bg-slate-800\/70 {
  background-color: rgb(30 41 59 / 0.7);
}

.bg-slate-800\/75 {
  background-color: rgb(30 41 59 / 0.75);
}

.bg-slate-800\/80 {
  background-color: rgb(30 41 59 / 0.8);
}

.bg-slate-800\/85 {
  background-color: rgb(30 41 59 / 0.85);
}

.bg-slate-800\/90 {
  background-color: rgb(30 41 59 / 0.9);
}

.bg-slate-800\/95 {
  background-color: rgb(30 41 59 / 0.95);
}

.bg-slate-900 {
  --tw-bg-opacity: 1;
  background-color: rgb(15 23 42 / var(--tw-bg-opacity));
}

.bg-slate-900\/0 {
  background-color: rgb(15 23 42 / 0);
}

.bg-slate-900\/10 {
  background-color: rgb(15 23 42 / 0.1);
}

.bg-slate-900\/100 {
  background-color: rgb(15 23 42 / 1);
}

.bg-slate-900\/15 {
  background-color: rgb(15 23 42 / 0.15);
}

.bg-slate-900\/20 {
  background-color: rgb(15 23 42 / 0.2);
}

.bg-slate-900\/25 {
  background-color: rgb(15 23 42 / 0.25);
}

.bg-slate-900\/30 {
  background-color: rgb(15 23 42 / 0.3);
}

.bg-slate-900\/35 {
  background-color: rgb(15 23 42 / 0.35);
}

.bg-slate-900\/40 {
  background-color: rgb(15 23 42 / 0.4);
}

.bg-slate-900\/45 {
  background-color: rgb(15 23 42 / 0.45);
}

.bg-slate-900\/5 {
  background-color: rgb(15 23 42 / 0.05);
}

.bg-slate-900\/50 {
  background-color: rgb(15 23 42 / 0.5);
}

.bg-slate-900\/55 {
  background-color: rgb(15 23 42 / 0.55);
}

.bg-slate-900\/60 {
  background-color: rgb(15 23 42 / 0.6);
}

.bg-slate-900\/65 {
  background-color: rgb(15 23 42 / 0.65);
}

.bg-slate-900\/70 {
  background-color: rgb(15 23 42 / 0.7);
}

.bg-slate-900\/75 {
  background-color: rgb(15 23 42 / 0.75);
}

.bg-slate-900\/80 {
  background-color: rgb(15 23 42 / 0.8);
}

.bg-slate-900\/85 {
  background-color: rgb(15 23 42 / 0.85);
}

.bg-slate-900\/90 {
  background-color: rgb(15 23 42 / 0.9);
}

.bg-slate-900\/95 {
  background-color: rgb(15 23 42 / 0.95);
}

.bg-slate-950 {
  --tw-bg-opacity: 1;
  background-color: rgb(2 6 23 / var(--tw-bg-opacity));
}

.bg-slate-950\/0 {
  background-color: rgb(2 6 23 / 0);
}

.bg-slate-950\/10 {
  background-color: rgb(2 6 23 / 0.1);
}

.bg-slate-950\/100 {
  background-color: rgb(2 6 23 / 1);
}

.bg-slate-950\/15 {
  background-color: rgb(2 6 23 / 0.15);
}

.bg-slate-950\/20 {
  background-color: rgb(2 6 23 / 0.2);
}

.bg-slate-950\/25 {
  background-color: rgb(2 6 23 / 0.25);
}

.bg-slate-950\/30 {
  background-color: rgb(2 6 23 / 0.3);
}

.bg-slate-950\/35 {
  background-color: rgb(2 6 23 / 0.35);
}

.bg-slate-950\/40 {
  background-color: rgb(2 6 23 / 0.4);
}

.bg-slate-950\/45 {
  background-color: rgb(2 6 23 / 0.45);
}

.bg-slate-950\/5 {
  background-color: rgb(2 6 23 / 0.05);
}

.bg-slate-950\/50 {
  background-color: rgb(2 6 23 / 0.5);
}

.bg-slate-950\/55 {
  background-color: rgb(2 6 23 / 0.55);
}

.bg-slate-950\/60 {
  background-color: rgb(2 6 23 / 0.6);
}

.bg-slate-950\/65 {
  background-color: rgb(2 6 23 / 0.65);
}

.bg-slate-950\/70 {
  background-color: rgb(2 6 23 / 0.7);
}

.bg-slate-950\/75 {
  background-color: rgb(2 6 23 / 0.75);
}

.bg-slate-950\/80 {
  background-color: rgb(2 6 23 / 0.8);
}

.bg-slate-950\/85 {
  background-color: rgb(2 6 23 / 0.85);
}

.bg-slate-950\/90 {
  background-color: rgb(2 6 23 / 0.9);
}

.bg-slate-950\/95 {
  background-color: rgb(2 6 23 / 0.95);
}

.bg-stone-100 {
  --tw-bg-opacity: 1;
  background-color: rgb(245 245 244 / var(--tw-bg-opacity));
}

.bg-stone-100\/0 {
  background-color: rgb(245 245 244 / 0);
}

.bg-stone-100\/10 {
  background-color: rgb(245 245 244 / 0.1);
}

.bg-stone-100\/100 {
  background-color: rgb(245 245 244 / 1);
}

.bg-stone-100\/15 {
  background-color: rgb(245 245 244 / 0.15);
}

.bg-stone-100\/20 {
  background-color: rgb(245 245 244 / 0.2);
}

.bg-stone-100\/25 {
  background-color: rgb(245 245 244 / 0.25);
}

.bg-stone-100\/30 {
  background-color: rgb(245 245 244 / 0.3);
}

.bg-stone-100\/35 {
  background-color: rgb(245 245 244 / 0.35);
}

.bg-stone-100\/40 {
  background-color: rgb(245 245 244 / 0.4);
}

.bg-stone-100\/45 {
  background-color: rgb(245 245 244 / 0.45);
}

.bg-stone-100\/5 {
  background-color: rgb(245 245 244 / 0.05);
}

.bg-stone-100\/50 {
  background-color: rgb(245 245 244 / 0.5);
}

.bg-stone-100\/55 {
  background-color: rgb(245 245 244 / 0.55);
}

.bg-stone-100\/60 {
  background-color: rgb(245 245 244 / 0.6);
}

.bg-stone-100\/65 {
  background-color: rgb(245 245 244 / 0.65);
}

.bg-stone-100\/70 {
  background-color: rgb(245 245 244 / 0.7);
}

.bg-stone-100\/75 {
  background-color: rgb(245 245 244 / 0.75);
}

.bg-stone-100\/80 {
  background-color: rgb(245 245 244 / 0.8);
}

.bg-stone-100\/85 {
  background-color: rgb(245 245 244 / 0.85);
}

.bg-stone-100\/90 {
  background-color: rgb(245 245 244 / 0.9);
}

.bg-stone-100\/95 {
  background-color: rgb(245 245 244 / 0.95);
}

.bg-stone-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(231 229 228 / var(--tw-bg-opacity));
}

.bg-stone-200\/0 {
  background-color: rgb(231 229 228 / 0);
}

.bg-stone-200\/10 {
  background-color: rgb(231 229 228 / 0.1);
}

.bg-stone-200\/100 {
  background-color: rgb(231 229 228 / 1);
}

.bg-stone-200\/15 {
  background-color: rgb(231 229 228 / 0.15);
}

.bg-stone-200\/20 {
  background-color: rgb(231 229 228 / 0.2);
}

.bg-stone-200\/25 {
  background-color: rgb(231 229 228 / 0.25);
}

.bg-stone-200\/30 {
  background-color: rgb(231 229 228 / 0.3);
}

.bg-stone-200\/35 {
  background-color: rgb(231 229 228 / 0.35);
}

.bg-stone-200\/40 {
  background-color: rgb(231 229 228 / 0.4);
}

.bg-stone-200\/45 {
  background-color: rgb(231 229 228 / 0.45);
}

.bg-stone-200\/5 {
  background-color: rgb(231 229 228 / 0.05);
}

.bg-stone-200\/50 {
  background-color: rgb(231 229 228 / 0.5);
}

.bg-stone-200\/55 {
  background-color: rgb(231 229 228 / 0.55);
}

.bg-stone-200\/60 {
  background-color: rgb(231 229 228 / 0.6);
}

.bg-stone-200\/65 {
  background-color: rgb(231 229 228 / 0.65);
}

.bg-stone-200\/70 {
  background-color: rgb(231 229 228 / 0.7);
}

.bg-stone-200\/75 {
  background-color: rgb(231 229 228 / 0.75);
}

.bg-stone-200\/80 {
  background-color: rgb(231 229 228 / 0.8);
}

.bg-stone-200\/85 {
  background-color: rgb(231 229 228 / 0.85);
}

.bg-stone-200\/90 {
  background-color: rgb(231 229 228 / 0.9);
}

.bg-stone-200\/95 {
  background-color: rgb(231 229 228 / 0.95);
}

.bg-stone-300 {
  --tw-bg-opacity: 1;
  background-color: rgb(214 211 209 / var(--tw-bg-opacity));
}

.bg-stone-300\/0 {
  background-color: rgb(214 211 209 / 0);
}

.bg-stone-300\/10 {
  background-color: rgb(214 211 209 / 0.1);
}

.bg-stone-300\/100 {
  background-color: rgb(214 211 209 / 1);
}

.bg-stone-300\/15 {
  background-color: rgb(214 211 209 / 0.15);
}

.bg-stone-300\/20 {
  background-color: rgb(214 211 209 / 0.2);
}

.bg-stone-300\/25 {
  background-color: rgb(214 211 209 / 0.25);
}

.bg-stone-300\/30 {
  background-color: rgb(214 211 209 / 0.3);
}

.bg-stone-300\/35 {
  background-color: rgb(214 211 209 / 0.35);
}

.bg-stone-300\/40 {
  background-color: rgb(214 211 209 / 0.4);
}

.bg-stone-300\/45 {
  background-color: rgb(214 211 209 / 0.45);
}

.bg-stone-300\/5 {
  background-color: rgb(214 211 209 / 0.05);
}

.bg-stone-300\/50 {
  background-color: rgb(214 211 209 / 0.5);
}

.bg-stone-300\/55 {
  background-color: rgb(214 211 209 / 0.55);
}

.bg-stone-300\/60 {
  background-color: rgb(214 211 209 / 0.6);
}

.bg-stone-300\/65 {
  background-color: rgb(214 211 209 / 0.65);
}

.bg-stone-300\/70 {
  background-color: rgb(214 211 209 / 0.7);
}

.bg-stone-300\/75 {
  background-color: rgb(214 211 209 / 0.75);
}

.bg-stone-300\/80 {
  background-color: rgb(214 211 209 / 0.8);
}

.bg-stone-300\/85 {
  background-color: rgb(214 211 209 / 0.85);
}

.bg-stone-300\/90 {
  background-color: rgb(214 211 209 / 0.9);
}

.bg-stone-300\/95 {
  background-color: rgb(214 211 209 / 0.95);
}

.bg-stone-400 {
  --tw-bg-opacity: 1;
  background-color: rgb(168 162 158 / var(--tw-bg-opacity));
}

.bg-stone-400\/0 {
  background-color: rgb(168 162 158 / 0);
}

.bg-stone-400\/10 {
  background-color: rgb(168 162 158 / 0.1);
}

.bg-stone-400\/100 {
  background-color: rgb(168 162 158 / 1);
}

.bg-stone-400\/15 {
  background-color: rgb(168 162 158 / 0.15);
}

.bg-stone-400\/20 {
  background-color: rgb(168 162 158 / 0.2);
}

.bg-stone-400\/25 {
  background-color: rgb(168 162 158 / 0.25);
}

.bg-stone-400\/30 {
  background-color: rgb(168 162 158 / 0.3);
}

.bg-stone-400\/35 {
  background-color: rgb(168 162 158 / 0.35);
}

.bg-stone-400\/40 {
  background-color: rgb(168 162 158 / 0.4);
}

.bg-stone-400\/45 {
  background-color: rgb(168 162 158 / 0.45);
}

.bg-stone-400\/5 {
  background-color: rgb(168 162 158 / 0.05);
}

.bg-stone-400\/50 {
  background-color: rgb(168 162 158 / 0.5);
}

.bg-stone-400\/55 {
  background-color: rgb(168 162 158 / 0.55);
}

.bg-stone-400\/60 {
  background-color: rgb(168 162 158 / 0.6);
}

.bg-stone-400\/65 {
  background-color: rgb(168 162 158 / 0.65);
}

.bg-stone-400\/70 {
  background-color: rgb(168 162 158 / 0.7);
}

.bg-stone-400\/75 {
  background-color: rgb(168 162 158 / 0.75);
}

.bg-stone-400\/80 {
  background-color: rgb(168 162 158 / 0.8);
}

.bg-stone-400\/85 {
  background-color: rgb(168 162 158 / 0.85);
}

.bg-stone-400\/90 {
  background-color: rgb(168 162 158 / 0.9);
}

.bg-stone-400\/95 {
  background-color: rgb(168 162 158 / 0.95);
}

.bg-stone-50 {
  --tw-bg-opacity: 1;
  background-color: rgb(250 250 249 / var(--tw-bg-opacity));
}

.bg-stone-50\/0 {
  background-color: rgb(250 250 249 / 0);
}

.bg-stone-50\/10 {
  background-color: rgb(250 250 249 / 0.1);
}

.bg-stone-50\/100 {
  background-color: rgb(250 250 249 / 1);
}

.bg-stone-50\/15 {
  background-color: rgb(250 250 249 / 0.15);
}

.bg-stone-50\/20 {
  background-color: rgb(250 250 249 / 0.2);
}

.bg-stone-50\/25 {
  background-color: rgb(250 250 249 / 0.25);
}

.bg-stone-50\/30 {
  background-color: rgb(250 250 249 / 0.3);
}

.bg-stone-50\/35 {
  background-color: rgb(250 250 249 / 0.35);
}

.bg-stone-50\/40 {
  background-color: rgb(250 250 249 / 0.4);
}

.bg-stone-50\/45 {
  background-color: rgb(250 250 249 / 0.45);
}

.bg-stone-50\/5 {
  background-color: rgb(250 250 249 / 0.05);
}

.bg-stone-50\/50 {
  background-color: rgb(250 250 249 / 0.5);
}

.bg-stone-50\/55 {
  background-color: rgb(250 250 249 / 0.55);
}

.bg-stone-50\/60 {
  background-color: rgb(250 250 249 / 0.6);
}

.bg-stone-50\/65 {
  background-color: rgb(250 250 249 / 0.65);
}

.bg-stone-50\/70 {
  background-color: rgb(250 250 249 / 0.7);
}

.bg-stone-50\/75 {
  background-color: rgb(250 250 249 / 0.75);
}

.bg-stone-50\/80 {
  background-color: rgb(250 250 249 / 0.8);
}

.bg-stone-50\/85 {
  background-color: rgb(250 250 249 / 0.85);
}

.bg-stone-50\/90 {
  background-color: rgb(250 250 249 / 0.9);
}

.bg-stone-50\/95 {
  background-color: rgb(250 250 249 / 0.95);
}

.bg-stone-500 {
  --tw-bg-opacity: 1;
  background-color: rgb(120 113 108 / var(--tw-bg-opacity));
}

.bg-stone-500\/0 {
  background-color: rgb(120 113 108 / 0);
}

.bg-stone-500\/10 {
  background-color: rgb(120 113 108 / 0.1);
}

.bg-stone-500\/100 {
  background-color: rgb(120 113 108 / 1);
}

.bg-stone-500\/15 {
  background-color: rgb(120 113 108 / 0.15);
}

.bg-stone-500\/20 {
  background-color: rgb(120 113 108 / 0.2);
}

.bg-stone-500\/25 {
  background-color: rgb(120 113 108 / 0.25);
}

.bg-stone-500\/30 {
  background-color: rgb(120 113 108 / 0.3);
}

.bg-stone-500\/35 {
  background-color: rgb(120 113 108 / 0.35);
}

.bg-stone-500\/40 {
  background-color: rgb(120 113 108 / 0.4);
}

.bg-stone-500\/45 {
  background-color: rgb(120 113 108 / 0.45);
}

.bg-stone-500\/5 {
  background-color: rgb(120 113 108 / 0.05);
}

.bg-stone-500\/50 {
  background-color: rgb(120 113 108 / 0.5);
}

.bg-stone-500\/55 {
  background-color: rgb(120 113 108 / 0.55);
}

.bg-stone-500\/60 {
  background-color: rgb(120 113 108 / 0.6);
}

.bg-stone-500\/65 {
  background-color: rgb(120 113 108 / 0.65);
}

.bg-stone-500\/70 {
  background-color: rgb(120 113 108 / 0.7);
}

.bg-stone-500\/75 {
  background-color: rgb(120 113 108 / 0.75);
}

.bg-stone-500\/80 {
  background-color: rgb(120 113 108 / 0.8);
}

.bg-stone-500\/85 {
  background-color: rgb(120 113 108 / 0.85);
}

.bg-stone-500\/90 {
  background-color: rgb(120 113 108 / 0.9);
}

.bg-stone-500\/95 {
  background-color: rgb(120 113 108 / 0.95);
}

.bg-stone-600 {
  --tw-bg-opacity: 1;
  background-color: rgb(87 83 78 / var(--tw-bg-opacity));
}

.bg-stone-600\/0 {
  background-color: rgb(87 83 78 / 0);
}

.bg-stone-600\/10 {
  background-color: rgb(87 83 78 / 0.1);
}

.bg-stone-600\/100 {
  background-color: rgb(87 83 78 / 1);
}

.bg-stone-600\/15 {
  background-color: rgb(87 83 78 / 0.15);
}

.bg-stone-600\/20 {
  background-color: rgb(87 83 78 / 0.2);
}

.bg-stone-600\/25 {
  background-color: rgb(87 83 78 / 0.25);
}

.bg-stone-600\/30 {
  background-color: rgb(87 83 78 / 0.3);
}

.bg-stone-600\/35 {
  background-color: rgb(87 83 78 / 0.35);
}

.bg-stone-600\/40 {
  background-color: rgb(87 83 78 / 0.4);
}

.bg-stone-600\/45 {
  background-color: rgb(87 83 78 / 0.45);
}

.bg-stone-600\/5 {
  background-color: rgb(87 83 78 / 0.05);
}

.bg-stone-600\/50 {
  background-color: rgb(87 83 78 / 0.5);
}

.bg-stone-600\/55 {
  background-color: rgb(87 83 78 / 0.55);
}

.bg-stone-600\/60 {
  background-color: rgb(87 83 78 / 0.6);
}

.bg-stone-600\/65 {
  background-color: rgb(87 83 78 / 0.65);
}

.bg-stone-600\/70 {
  background-color: rgb(87 83 78 / 0.7);
}

.bg-stone-600\/75 {
  background-color: rgb(87 83 78 / 0.75);
}

.bg-stone-600\/80 {
  background-color: rgb(87 83 78 / 0.8);
}

.bg-stone-600\/85 {
  background-color: rgb(87 83 78 / 0.85);
}

.bg-stone-600\/90 {
  background-color: rgb(87 83 78 / 0.9);
}

.bg-stone-600\/95 {
  background-color: rgb(87 83 78 / 0.95);
}

.bg-stone-700 {
  --tw-bg-opacity: 1;
  background-color: rgb(68 64 60 / var(--tw-bg-opacity));
}

.bg-stone-700\/0 {
  background-color: rgb(68 64 60 / 0);
}

.bg-stone-700\/10 {
  background-color: rgb(68 64 60 / 0.1);
}

.bg-stone-700\/100 {
  background-color: rgb(68 64 60 / 1);
}

.bg-stone-700\/15 {
  background-color: rgb(68 64 60 / 0.15);
}

.bg-stone-700\/20 {
  background-color: rgb(68 64 60 / 0.2);
}

.bg-stone-700\/25 {
  background-color: rgb(68 64 60 / 0.25);
}

.bg-stone-700\/30 {
  background-color: rgb(68 64 60 / 0.3);
}

.bg-stone-700\/35 {
  background-color: rgb(68 64 60 / 0.35);
}

.bg-stone-700\/40 {
  background-color: rgb(68 64 60 / 0.4);
}

.bg-stone-700\/45 {
  background-color: rgb(68 64 60 / 0.45);
}

.bg-stone-700\/5 {
  background-color: rgb(68 64 60 / 0.05);
}

.bg-stone-700\/50 {
  background-color: rgb(68 64 60 / 0.5);
}

.bg-stone-700\/55 {
  background-color: rgb(68 64 60 / 0.55);
}

.bg-stone-700\/60 {
  background-color: rgb(68 64 60 / 0.6);
}

.bg-stone-700\/65 {
  background-color: rgb(68 64 60 / 0.65);
}

.bg-stone-700\/70 {
  background-color: rgb(68 64 60 / 0.7);
}

.bg-stone-700\/75 {
  background-color: rgb(68 64 60 / 0.75);
}

.bg-stone-700\/80 {
  background-color: rgb(68 64 60 / 0.8);
}

.bg-stone-700\/85 {
  background-color: rgb(68 64 60 / 0.85);
}

.bg-stone-700\/90 {
  background-color: rgb(68 64 60 / 0.9);
}

.bg-stone-700\/95 {
  background-color: rgb(68 64 60 / 0.95);
}

.bg-stone-800 {
  --tw-bg-opacity: 1;
  background-color: rgb(41 37 36 / var(--tw-bg-opacity));
}

.bg-stone-800\/0 {
  background-color: rgb(41 37 36 / 0);
}

.bg-stone-800\/10 {
  background-color: rgb(41 37 36 / 0.1);
}

.bg-stone-800\/100 {
  background-color: rgb(41 37 36 / 1);
}

.bg-stone-800\/15 {
  background-color: rgb(41 37 36 / 0.15);
}

.bg-stone-800\/20 {
  background-color: rgb(41 37 36 / 0.2);
}

.bg-stone-800\/25 {
  background-color: rgb(41 37 36 / 0.25);
}

.bg-stone-800\/30 {
  background-color: rgb(41 37 36 / 0.3);
}

.bg-stone-800\/35 {
  background-color: rgb(41 37 36 / 0.35);
}

.bg-stone-800\/40 {
  background-color: rgb(41 37 36 / 0.4);
}

.bg-stone-800\/45 {
  background-color: rgb(41 37 36 / 0.45);
}

.bg-stone-800\/5 {
  background-color: rgb(41 37 36 / 0.05);
}

.bg-stone-800\/50 {
  background-color: rgb(41 37 36 / 0.5);
}

.bg-stone-800\/55 {
  background-color: rgb(41 37 36 / 0.55);
}

.bg-stone-800\/60 {
  background-color: rgb(41 37 36 / 0.6);
}

.bg-stone-800\/65 {
  background-color: rgb(41 37 36 / 0.65);
}

.bg-stone-800\/70 {
  background-color: rgb(41 37 36 / 0.7);
}

.bg-stone-800\/75 {
  background-color: rgb(41 37 36 / 0.75);
}

.bg-stone-800\/80 {
  background-color: rgb(41 37 36 / 0.8);
}

.bg-stone-800\/85 {
  background-color: rgb(41 37 36 / 0.85);
}

.bg-stone-800\/90 {
  background-color: rgb(41 37 36 / 0.9);
}

.bg-stone-800\/95 {
  background-color: rgb(41 37 36 / 0.95);
}

.bg-stone-900 {
  --tw-bg-opacity: 1;
  background-color: rgb(28 25 23 / var(--tw-bg-opacity));
}

.bg-stone-900\/0 {
  background-color: rgb(28 25 23 / 0);
}

.bg-stone-900\/10 {
  background-color: rgb(28 25 23 / 0.1);
}

.bg-stone-900\/100 {
  background-color: rgb(28 25 23 / 1);
}

.bg-stone-900\/15 {
  background-color: rgb(28 25 23 / 0.15);
}

.bg-stone-900\/20 {
  background-color: rgb(28 25 23 / 0.2);
}

.bg-stone-900\/25 {
  background-color: rgb(28 25 23 / 0.25);
}

.bg-stone-900\/30 {
  background-color: rgb(28 25 23 / 0.3);
}

.bg-stone-900\/35 {
  background-color: rgb(28 25 23 / 0.35);
}

.bg-stone-900\/40 {
  background-color: rgb(28 25 23 / 0.4);
}

.bg-stone-900\/45 {
  background-color: rgb(28 25 23 / 0.45);
}

.bg-stone-900\/5 {
  background-color: rgb(28 25 23 / 0.05);
}

.bg-stone-900\/50 {
  background-color: rgb(28 25 23 / 0.5);
}

.bg-stone-900\/55 {
  background-color: rgb(28 25 23 / 0.55);
}

.bg-stone-900\/60 {
  background-color: rgb(28 25 23 / 0.6);
}

.bg-stone-900\/65 {
  background-color: rgb(28 25 23 / 0.65);
}

.bg-stone-900\/70 {
  background-color: rgb(28 25 23 / 0.7);
}

.bg-stone-900\/75 {
  background-color: rgb(28 25 23 / 0.75);
}

.bg-stone-900\/80 {
  background-color: rgb(28 25 23 / 0.8);
}

.bg-stone-900\/85 {
  background-color: rgb(28 25 23 / 0.85);
}

.bg-stone-900\/90 {
  background-color: rgb(28 25 23 / 0.9);
}

.bg-stone-900\/95 {
  background-color: rgb(28 25 23 / 0.95);
}

.bg-stone-950 {
  --tw-bg-opacity: 1;
  background-color: rgb(12 10 9 / var(--tw-bg-opacity));
}

.bg-stone-950\/0 {
  background-color: rgb(12 10 9 / 0);
}

.bg-stone-950\/10 {
  background-color: rgb(12 10 9 / 0.1);
}

.bg-stone-950\/100 {
  background-color: rgb(12 10 9 / 1);
}

.bg-stone-950\/15 {
  background-color: rgb(12 10 9 / 0.15);
}

.bg-stone-950\/20 {
  background-color: rgb(12 10 9 / 0.2);
}

.bg-stone-950\/25 {
  background-color: rgb(12 10 9 / 0.25);
}

.bg-stone-950\/30 {
  background-color: rgb(12 10 9 / 0.3);
}

.bg-stone-950\/35 {
  background-color: rgb(12 10 9 / 0.35);
}

.bg-stone-950\/40 {
  background-color: rgb(12 10 9 / 0.4);
}

.bg-stone-950\/45 {
  background-color: rgb(12 10 9 / 0.45);
}

.bg-stone-950\/5 {
  background-color: rgb(12 10 9 / 0.05);
}

.bg-stone-950\/50 {
  background-color: rgb(12 10 9 / 0.5);
}

.bg-stone-950\/55 {
  background-color: rgb(12 10 9 / 0.55);
}

.bg-stone-950\/60 {
  background-color: rgb(12 10 9 / 0.6);
}

.bg-stone-950\/65 {
  background-color: rgb(12 10 9 / 0.65);
}

.bg-stone-950\/70 {
  background-color: rgb(12 10 9 / 0.7);
}

.bg-stone-950\/75 {
  background-color: rgb(12 10 9 / 0.75);
}

.bg-stone-950\/80 {
  background-color: rgb(12 10 9 / 0.8);
}

.bg-stone-950\/85 {
  background-color: rgb(12 10 9 / 0.85);
}

.bg-stone-950\/90 {
  background-color: rgb(12 10 9 / 0.9);
}

.bg-stone-950\/95 {
  background-color: rgb(12 10 9 / 0.95);
}

.bg-success {
  --tw-bg-opacity: 1;
  background-color: var(--fallback-su,oklch(var(--su)/var(--tw-bg-opacity)));
}

.bg-success-content {
  --tw-bg-opacity: 1;
  background-color: var(--fallback-suc,oklch(var(--suc)/var(--tw-bg-opacity)));
}

.bg-success-content\/0 {
  background-color: var(--fallback-suc,oklch(var(--suc)/0));
}

.bg-success-content\/10 {
  background-color: var(--fallback-suc,oklch(var(--suc)/0.1));
}

.bg-success-content\/100 {
  background-color: var(--fallback-suc,oklch(var(--suc)/1));
}

.bg-success-content\/15 {
  background-color: var(--fallback-suc,oklch(var(--suc)/0.15));
}

.bg-success-content\/20 {
  background-color: var(--fallback-suc,oklch(var(--suc)/0.2));
}

.bg-success-content\/25 {
  background-color: var(--fallback-suc,oklch(var(--suc)/0.25));
}

.bg-success-content\/30 {
  background-color: var(--fallback-suc,oklch(var(--suc)/0.3));
}

.bg-success-content\/35 {
  background-color: var(--fallback-suc,oklch(var(--suc)/0.35));
}

.bg-success-content\/40 {
  background-color: var(--fallback-suc,oklch(var(--suc)/0.4));
}

.bg-success-content\/45 {
  background-color: var(--fallback-suc,oklch(var(--suc)/0.45));
}

.bg-success-content\/5 {
  background-color: var(--fallback-suc,oklch(var(--suc)/0.05));
}

.bg-success-content\/50 {
  background-color: var(--fallback-suc,oklch(var(--suc)/0.5));
}

.bg-success-content\/55 {
  background-color: var(--fallback-suc,oklch(var(--suc)/0.55));
}

.bg-success-content\/60 {
  background-color: var(--fallback-suc,oklch(var(--suc)/0.6));
}

.bg-success-content\/65 {
  background-color: var(--fallback-suc,oklch(var(--suc)/0.65));
}

.bg-success-content\/70 {
  background-color: var(--fallback-suc,oklch(var(--suc)/0.7));
}

.bg-success-content\/75 {
  background-color: var(--fallback-suc,oklch(var(--suc)/0.75));
}

.bg-success-content\/80 {
  background-color: var(--fallback-suc,oklch(var(--suc)/0.8));
}

.bg-success-content\/85 {
  background-color: var(--fallback-suc,oklch(var(--suc)/0.85));
}

.bg-success-content\/90 {
  background-color: var(--fallback-suc,oklch(var(--suc)/0.9));
}

.bg-success-content\/95 {
  background-color: var(--fallback-suc,oklch(var(--suc)/0.95));
}

.bg-success\/0 {
  background-color: var(--fallback-su,oklch(var(--su)/0));
}

.bg-success\/10 {
  background-color: var(--fallback-su,oklch(var(--su)/0.1));
}

.bg-success\/100 {
  background-color: var(--fallback-su,oklch(var(--su)/1));
}

.bg-success\/15 {
  background-color: var(--fallback-su,oklch(var(--su)/0.15));
}

.bg-success\/20 {
  background-color: var(--fallback-su,oklch(var(--su)/0.2));
}

.bg-success\/25 {
  background-color: var(--fallback-su,oklch(var(--su)/0.25));
}

.bg-success\/30 {
  background-color: var(--fallback-su,oklch(var(--su)/0.3));
}

.bg-success\/35 {
  background-color: var(--fallback-su,oklch(var(--su)/0.35));
}

.bg-success\/40 {
  background-color: var(--fallback-su,oklch(var(--su)/0.4));
}

.bg-success\/45 {
  background-color: var(--fallback-su,oklch(var(--su)/0.45));
}

.bg-success\/5 {
  background-color: var(--fallback-su,oklch(var(--su)/0.05));
}

.bg-success\/50 {
  background-color: var(--fallback-su,oklch(var(--su)/0.5));
}

.bg-success\/55 {
  background-color: var(--fallback-su,oklch(var(--su)/0.55));
}

.bg-success\/60 {
  background-color: var(--fallback-su,oklch(var(--su)/0.6));
}

.bg-success\/65 {
  background-color: var(--fallback-su,oklch(var(--su)/0.65));
}

.bg-success\/70 {
  background-color: var(--fallback-su,oklch(var(--su)/0.7));
}

.bg-success\/75 {
  background-color: var(--fallback-su,oklch(var(--su)/0.75));
}

.bg-success\/80 {
  background-color: var(--fallback-su,oklch(var(--su)/0.8));
}

.bg-success\/85 {
  background-color: var(--fallback-su,oklch(var(--su)/0.85));
}

.bg-success\/90 {
  background-color: var(--fallback-su,oklch(var(--su)/0.9));
}

.bg-success\/95 {
  background-color: var(--fallback-su,oklch(var(--su)/0.95));
}

.bg-teal-100 {
  --tw-bg-opacity: 1;
  background-color: rgb(204 251 241 / var(--tw-bg-opacity));
}

.bg-teal-100\/0 {
  background-color: rgb(204 251 241 / 0);
}

.bg-teal-100\/10 {
  background-color: rgb(204 251 241 / 0.1);
}

.bg-teal-100\/100 {
  background-color: rgb(204 251 241 / 1);
}

.bg-teal-100\/15 {
  background-color: rgb(204 251 241 / 0.15);
}

.bg-teal-100\/20 {
  background-color: rgb(204 251 241 / 0.2);
}

.bg-teal-100\/25 {
  background-color: rgb(204 251 241 / 0.25);
}

.bg-teal-100\/30 {
  background-color: rgb(204 251 241 / 0.3);
}

.bg-teal-100\/35 {
  background-color: rgb(204 251 241 / 0.35);
}

.bg-teal-100\/40 {
  background-color: rgb(204 251 241 / 0.4);
}

.bg-teal-100\/45 {
  background-color: rgb(204 251 241 / 0.45);
}

.bg-teal-100\/5 {
  background-color: rgb(204 251 241 / 0.05);
}

.bg-teal-100\/50 {
  background-color: rgb(204 251 241 / 0.5);
}

.bg-teal-100\/55 {
  background-color: rgb(204 251 241 / 0.55);
}

.bg-teal-100\/60 {
  background-color: rgb(204 251 241 / 0.6);
}

.bg-teal-100\/65 {
  background-color: rgb(204 251 241 / 0.65);
}

.bg-teal-100\/70 {
  background-color: rgb(204 251 241 / 0.7);
}

.bg-teal-100\/75 {
  background-color: rgb(204 251 241 / 0.75);
}

.bg-teal-100\/80 {
  background-color: rgb(204 251 241 / 0.8);
}

.bg-teal-100\/85 {
  background-color: rgb(204 251 241 / 0.85);
}

.bg-teal-100\/90 {
  background-color: rgb(204 251 241 / 0.9);
}

.bg-teal-100\/95 {
  background-color: rgb(204 251 241 / 0.95);
}

.bg-teal-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(153 246 228 / var(--tw-bg-opacity));
}

.bg-teal-200\/0 {
  background-color: rgb(153 246 228 / 0);
}

.bg-teal-200\/10 {
  background-color: rgb(153 246 228 / 0.1);
}

.bg-teal-200\/100 {
  background-color: rgb(153 246 228 / 1);
}

.bg-teal-200\/15 {
  background-color: rgb(153 246 228 / 0.15);
}

.bg-teal-200\/20 {
  background-color: rgb(153 246 228 / 0.2);
}

.bg-teal-200\/25 {
  background-color: rgb(153 246 228 / 0.25);
}

.bg-teal-200\/30 {
  background-color: rgb(153 246 228 / 0.3);
}

.bg-teal-200\/35 {
  background-color: rgb(153 246 228 / 0.35);
}

.bg-teal-200\/40 {
  background-color: rgb(153 246 228 / 0.4);
}

.bg-teal-200\/45 {
  background-color: rgb(153 246 228 / 0.45);
}

.bg-teal-200\/5 {
  background-color: rgb(153 246 228 / 0.05);
}

.bg-teal-200\/50 {
  background-color: rgb(153 246 228 / 0.5);
}

.bg-teal-200\/55 {
  background-color: rgb(153 246 228 / 0.55);
}

.bg-teal-200\/60 {
  background-color: rgb(153 246 228 / 0.6);
}

.bg-teal-200\/65 {
  background-color: rgb(153 246 228 / 0.65);
}

.bg-teal-200\/70 {
  background-color: rgb(153 246 228 / 0.7);
}

.bg-teal-200\/75 {
  background-color: rgb(153 246 228 / 0.75);
}

.bg-teal-200\/80 {
  background-color: rgb(153 246 228 / 0.8);
}

.bg-teal-200\/85 {
  background-color: rgb(153 246 228 / 0.85);
}

.bg-teal-200\/90 {
  background-color: rgb(153 246 228 / 0.9);
}

.bg-teal-200\/95 {
  background-color: rgb(153 246 228 / 0.95);
}

.bg-teal-300 {
  --tw-bg-opacity: 1;
  background-color: rgb(94 234 212 / var(--tw-bg-opacity));
}

.bg-teal-300\/0 {
  background-color: rgb(94 234 212 / 0);
}

.bg-teal-300\/10 {
  background-color: rgb(94 234 212 / 0.1);
}

.bg-teal-300\/100 {
  background-color: rgb(94 234 212 / 1);
}

.bg-teal-300\/15 {
  background-color: rgb(94 234 212 / 0.15);
}

.bg-teal-300\/20 {
  background-color: rgb(94 234 212 / 0.2);
}

.bg-teal-300\/25 {
  background-color: rgb(94 234 212 / 0.25);
}

.bg-teal-300\/30 {
  background-color: rgb(94 234 212 / 0.3);
}

.bg-teal-300\/35 {
  background-color: rgb(94 234 212 / 0.35);
}

.bg-teal-300\/40 {
  background-color: rgb(94 234 212 / 0.4);
}

.bg-teal-300\/45 {
  background-color: rgb(94 234 212 / 0.45);
}

.bg-teal-300\/5 {
  background-color: rgb(94 234 212 / 0.05);
}

.bg-teal-300\/50 {
  background-color: rgb(94 234 212 / 0.5);
}

.bg-teal-300\/55 {
  background-color: rgb(94 234 212 / 0.55);
}

.bg-teal-300\/60 {
  background-color: rgb(94 234 212 / 0.6);
}

.bg-teal-300\/65 {
  background-color: rgb(94 234 212 / 0.65);
}

.bg-teal-300\/70 {
  background-color: rgb(94 234 212 / 0.7);
}

.bg-teal-300\/75 {
  background-color: rgb(94 234 212 / 0.75);
}

.bg-teal-300\/80 {
  background-color: rgb(94 234 212 / 0.8);
}

.bg-teal-300\/85 {
  background-color: rgb(94 234 212 / 0.85);
}

.bg-teal-300\/90 {
  background-color: rgb(94 234 212 / 0.9);
}

.bg-teal-300\/95 {
  background-color: rgb(94 234 212 / 0.95);
}

.bg-teal-400 {
  --tw-bg-opacity: 1;
  background-color: rgb(45 212 191 / var(--tw-bg-opacity));
}

.bg-teal-400\/0 {
  background-color: rgb(45 212 191 / 0);
}

.bg-teal-400\/10 {
  background-color: rgb(45 212 191 / 0.1);
}

.bg-teal-400\/100 {
  background-color: rgb(45 212 191 / 1);
}

.bg-teal-400\/15 {
  background-color: rgb(45 212 191 / 0.15);
}

.bg-teal-400\/20 {
  background-color: rgb(45 212 191 / 0.2);
}

.bg-teal-400\/25 {
  background-color: rgb(45 212 191 / 0.25);
}

.bg-teal-400\/30 {
  background-color: rgb(45 212 191 / 0.3);
}

.bg-teal-400\/35 {
  background-color: rgb(45 212 191 / 0.35);
}

.bg-teal-400\/40 {
  background-color: rgb(45 212 191 / 0.4);
}

.bg-teal-400\/45 {
  background-color: rgb(45 212 191 / 0.45);
}

.bg-teal-400\/5 {
  background-color: rgb(45 212 191 / 0.05);
}

.bg-teal-400\/50 {
  background-color: rgb(45 212 191 / 0.5);
}

.bg-teal-400\/55 {
  background-color: rgb(45 212 191 / 0.55);
}

.bg-teal-400\/60 {
  background-color: rgb(45 212 191 / 0.6);
}

.bg-teal-400\/65 {
  background-color: rgb(45 212 191 / 0.65);
}

.bg-teal-400\/70 {
  background-color: rgb(45 212 191 / 0.7);
}

.bg-teal-400\/75 {
  background-color: rgb(45 212 191 / 0.75);
}

.bg-teal-400\/80 {
  background-color: rgb(45 212 191 / 0.8);
}

.bg-teal-400\/85 {
  background-color: rgb(45 212 191 / 0.85);
}

.bg-teal-400\/90 {
  background-color: rgb(45 212 191 / 0.9);
}

.bg-teal-400\/95 {
  background-color: rgb(45 212 191 / 0.95);
}

.bg-teal-50 {
  --tw-bg-opacity: 1;
  background-color: rgb(240 253 250 / var(--tw-bg-opacity));
}

.bg-teal-50\/0 {
  background-color: rgb(240 253 250 / 0);
}

.bg-teal-50\/10 {
  background-color: rgb(240 253 250 / 0.1);
}

.bg-teal-50\/100 {
  background-color: rgb(240 253 250 / 1);
}

.bg-teal-50\/15 {
  background-color: rgb(240 253 250 / 0.15);
}

.bg-teal-50\/20 {
  background-color: rgb(240 253 250 / 0.2);
}

.bg-teal-50\/25 {
  background-color: rgb(240 253 250 / 0.25);
}

.bg-teal-50\/30 {
  background-color: rgb(240 253 250 / 0.3);
}

.bg-teal-50\/35 {
  background-color: rgb(240 253 250 / 0.35);
}

.bg-teal-50\/40 {
  background-color: rgb(240 253 250 / 0.4);
}

.bg-teal-50\/45 {
  background-color: rgb(240 253 250 / 0.45);
}

.bg-teal-50\/5 {
  background-color: rgb(240 253 250 / 0.05);
}

.bg-teal-50\/50 {
  background-color: rgb(240 253 250 / 0.5);
}

.bg-teal-50\/55 {
  background-color: rgb(240 253 250 / 0.55);
}

.bg-teal-50\/60 {
  background-color: rgb(240 253 250 / 0.6);
}

.bg-teal-50\/65 {
  background-color: rgb(240 253 250 / 0.65);
}

.bg-teal-50\/70 {
  background-color: rgb(240 253 250 / 0.7);
}

.bg-teal-50\/75 {
  background-color: rgb(240 253 250 / 0.75);
}

.bg-teal-50\/80 {
  background-color: rgb(240 253 250 / 0.8);
}

.bg-teal-50\/85 {
  background-color: rgb(240 253 250 / 0.85);
}

.bg-teal-50\/90 {
  background-color: rgb(240 253 250 / 0.9);
}

.bg-teal-50\/95 {
  background-color: rgb(240 253 250 / 0.95);
}

.bg-teal-500 {
  --tw-bg-opacity: 1;
  background-color: rgb(20 184 166 / var(--tw-bg-opacity));
}

.bg-teal-500\/0 {
  background-color: rgb(20 184 166 / 0);
}

.bg-teal-500\/10 {
  background-color: rgb(20 184 166 / 0.1);
}

.bg-teal-500\/100 {
  background-color: rgb(20 184 166 / 1);
}

.bg-teal-500\/15 {
  background-color: rgb(20 184 166 / 0.15);
}

.bg-teal-500\/20 {
  background-color: rgb(20 184 166 / 0.2);
}

.bg-teal-500\/25 {
  background-color: rgb(20 184 166 / 0.25);
}

.bg-teal-500\/30 {
  background-color: rgb(20 184 166 / 0.3);
}

.bg-teal-500\/35 {
  background-color: rgb(20 184 166 / 0.35);
}

.bg-teal-500\/40 {
  background-color: rgb(20 184 166 / 0.4);
}

.bg-teal-500\/45 {
  background-color: rgb(20 184 166 / 0.45);
}

.bg-teal-500\/5 {
  background-color: rgb(20 184 166 / 0.05);
}

.bg-teal-500\/50 {
  background-color: rgb(20 184 166 / 0.5);
}

.bg-teal-500\/55 {
  background-color: rgb(20 184 166 / 0.55);
}

.bg-teal-500\/60 {
  background-color: rgb(20 184 166 / 0.6);
}

.bg-teal-500\/65 {
  background-color: rgb(20 184 166 / 0.65);
}

.bg-teal-500\/70 {
  background-color: rgb(20 184 166 / 0.7);
}

.bg-teal-500\/75 {
  background-color: rgb(20 184 166 / 0.75);
}

.bg-teal-500\/80 {
  background-color: rgb(20 184 166 / 0.8);
}

.bg-teal-500\/85 {
  background-color: rgb(20 184 166 / 0.85);
}

.bg-teal-500\/90 {
  background-color: rgb(20 184 166 / 0.9);
}

.bg-teal-500\/95 {
  background-color: rgb(20 184 166 / 0.95);
}

.bg-teal-600 {
  --tw-bg-opacity: 1;
  background-color: rgb(13 148 136 / var(--tw-bg-opacity));
}

.bg-teal-600\/0 {
  background-color: rgb(13 148 136 / 0);
}

.bg-teal-600\/10 {
  background-color: rgb(13 148 136 / 0.1);
}

.bg-teal-600\/100 {
  background-color: rgb(13 148 136 / 1);
}

.bg-teal-600\/15 {
  background-color: rgb(13 148 136 / 0.15);
}

.bg-teal-600\/20 {
  background-color: rgb(13 148 136 / 0.2);
}

.bg-teal-600\/25 {
  background-color: rgb(13 148 136 / 0.25);
}

.bg-teal-600\/30 {
  background-color: rgb(13 148 136 / 0.3);
}

.bg-teal-600\/35 {
  background-color: rgb(13 148 136 / 0.35);
}

.bg-teal-600\/40 {
  background-color: rgb(13 148 136 / 0.4);
}

.bg-teal-600\/45 {
  background-color: rgb(13 148 136 / 0.45);
}

.bg-teal-600\/5 {
  background-color: rgb(13 148 136 / 0.05);
}

.bg-teal-600\/50 {
  background-color: rgb(13 148 136 / 0.5);
}

.bg-teal-600\/55 {
  background-color: rgb(13 148 136 / 0.55);
}

.bg-teal-600\/60 {
  background-color: rgb(13 148 136 / 0.6);
}

.bg-teal-600\/65 {
  background-color: rgb(13 148 136 / 0.65);
}

.bg-teal-600\/70 {
  background-color: rgb(13 148 136 / 0.7);
}

.bg-teal-600\/75 {
  background-color: rgb(13 148 136 / 0.75);
}

.bg-teal-600\/80 {
  background-color: rgb(13 148 136 / 0.8);
}

.bg-teal-600\/85 {
  background-color: rgb(13 148 136 / 0.85);
}

.bg-teal-600\/90 {
  background-color: rgb(13 148 136 / 0.9);
}

.bg-teal-600\/95 {
  background-color: rgb(13 148 136 / 0.95);
}

.bg-teal-700 {
  --tw-bg-opacity: 1;
  background-color: rgb(15 118 110 / var(--tw-bg-opacity));
}

.bg-teal-700\/0 {
  background-color: rgb(15 118 110 / 0);
}

.bg-teal-700\/10 {
  background-color: rgb(15 118 110 / 0.1);
}

.bg-teal-700\/100 {
  background-color: rgb(15 118 110 / 1);
}

.bg-teal-700\/15 {
  background-color: rgb(15 118 110 / 0.15);
}

.bg-teal-700\/20 {
  background-color: rgb(15 118 110 / 0.2);
}

.bg-teal-700\/25 {
  background-color: rgb(15 118 110 / 0.25);
}

.bg-teal-700\/30 {
  background-color: rgb(15 118 110 / 0.3);
}

.bg-teal-700\/35 {
  background-color: rgb(15 118 110 / 0.35);
}

.bg-teal-700\/40 {
  background-color: rgb(15 118 110 / 0.4);
}

.bg-teal-700\/45 {
  background-color: rgb(15 118 110 / 0.45);
}

.bg-teal-700\/5 {
  background-color: rgb(15 118 110 / 0.05);
}

.bg-teal-700\/50 {
  background-color: rgb(15 118 110 / 0.5);
}

.bg-teal-700\/55 {
  background-color: rgb(15 118 110 / 0.55);
}

.bg-teal-700\/60 {
  background-color: rgb(15 118 110 / 0.6);
}

.bg-teal-700\/65 {
  background-color: rgb(15 118 110 / 0.65);
}

.bg-teal-700\/70 {
  background-color: rgb(15 118 110 / 0.7);
}

.bg-teal-700\/75 {
  background-color: rgb(15 118 110 / 0.75);
}

.bg-teal-700\/80 {
  background-color: rgb(15 118 110 / 0.8);
}

.bg-teal-700\/85 {
  background-color: rgb(15 118 110 / 0.85);
}

.bg-teal-700\/90 {
  background-color: rgb(15 118 110 / 0.9);
}

.bg-teal-700\/95 {
  background-color: rgb(15 118 110 / 0.95);
}

.bg-teal-800 {
  --tw-bg-opacity: 1;
  background-color: rgb(17 94 89 / var(--tw-bg-opacity));
}

.bg-teal-800\/0 {
  background-color: rgb(17 94 89 / 0);
}

.bg-teal-800\/10 {
  background-color: rgb(17 94 89 / 0.1);
}

.bg-teal-800\/100 {
  background-color: rgb(17 94 89 / 1);
}

.bg-teal-800\/15 {
  background-color: rgb(17 94 89 / 0.15);
}

.bg-teal-800\/20 {
  background-color: rgb(17 94 89 / 0.2);
}

.bg-teal-800\/25 {
  background-color: rgb(17 94 89 / 0.25);
}

.bg-teal-800\/30 {
  background-color: rgb(17 94 89 / 0.3);
}

.bg-teal-800\/35 {
  background-color: rgb(17 94 89 / 0.35);
}

.bg-teal-800\/40 {
  background-color: rgb(17 94 89 / 0.4);
}

.bg-teal-800\/45 {
  background-color: rgb(17 94 89 / 0.45);
}

.bg-teal-800\/5 {
  background-color: rgb(17 94 89 / 0.05);
}

.bg-teal-800\/50 {
  background-color: rgb(17 94 89 / 0.5);
}

.bg-teal-800\/55 {
  background-color: rgb(17 94 89 / 0.55);
}

.bg-teal-800\/60 {
  background-color: rgb(17 94 89 / 0.6);
}

.bg-teal-800\/65 {
  background-color: rgb(17 94 89 / 0.65);
}

.bg-teal-800\/70 {
  background-color: rgb(17 94 89 / 0.7);
}

.bg-teal-800\/75 {
  background-color: rgb(17 94 89 / 0.75);
}

.bg-teal-800\/80 {
  background-color: rgb(17 94 89 / 0.8);
}

.bg-teal-800\/85 {
  background-color: rgb(17 94 89 / 0.85);
}

.bg-teal-800\/90 {
  background-color: rgb(17 94 89 / 0.9);
}

.bg-teal-800\/95 {
  background-color: rgb(17 94 89 / 0.95);
}

.bg-teal-900 {
  --tw-bg-opacity: 1;
  background-color: rgb(19 78 74 / var(--tw-bg-opacity));
}

.bg-teal-900\/0 {
  background-color: rgb(19 78 74 / 0);
}

.bg-teal-900\/10 {
  background-color: rgb(19 78 74 / 0.1);
}

.bg-teal-900\/100 {
  background-color: rgb(19 78 74 / 1);
}

.bg-teal-900\/15 {
  background-color: rgb(19 78 74 / 0.15);
}

.bg-teal-900\/20 {
  background-color: rgb(19 78 74 / 0.2);
}

.bg-teal-900\/25 {
  background-color: rgb(19 78 74 / 0.25);
}

.bg-teal-900\/30 {
  background-color: rgb(19 78 74 / 0.3);
}

.bg-teal-900\/35 {
  background-color: rgb(19 78 74 / 0.35);
}

.bg-teal-900\/40 {
  background-color: rgb(19 78 74 / 0.4);
}

.bg-teal-900\/45 {
  background-color: rgb(19 78 74 / 0.45);
}

.bg-teal-900\/5 {
  background-color: rgb(19 78 74 / 0.05);
}

.bg-teal-900\/50 {
  background-color: rgb(19 78 74 / 0.5);
}

.bg-teal-900\/55 {
  background-color: rgb(19 78 74 / 0.55);
}

.bg-teal-900\/60 {
  background-color: rgb(19 78 74 / 0.6);
}

.bg-teal-900\/65 {
  background-color: rgb(19 78 74 / 0.65);
}

.bg-teal-900\/70 {
  background-color: rgb(19 78 74 / 0.7);
}

.bg-teal-900\/75 {
  background-color: rgb(19 78 74 / 0.75);
}

.bg-teal-900\/80 {
  background-color: rgb(19 78 74 / 0.8);
}

.bg-teal-900\/85 {
  background-color: rgb(19 78 74 / 0.85);
}

.bg-teal-900\/90 {
  background-color: rgb(19 78 74 / 0.9);
}

.bg-teal-900\/95 {
  background-color: rgb(19 78 74 / 0.95);
}

.bg-teal-950 {
  --tw-bg-opacity: 1;
  background-color: rgb(4 47 46 / var(--tw-bg-opacity));
}

.bg-teal-950\/0 {
  background-color: rgb(4 47 46 / 0);
}

.bg-teal-950\/10 {
  background-color: rgb(4 47 46 / 0.1);
}

.bg-teal-950\/100 {
  background-color: rgb(4 47 46 / 1);
}

.bg-teal-950\/15 {
  background-color: rgb(4 47 46 / 0.15);
}

.bg-teal-950\/20 {
  background-color: rgb(4 47 46 / 0.2);
}

.bg-teal-950\/25 {
  background-color: rgb(4 47 46 / 0.25);
}

.bg-teal-950\/30 {
  background-color: rgb(4 47 46 / 0.3);
}

.bg-teal-950\/35 {
  background-color: rgb(4 47 46 / 0.35);
}

.bg-teal-950\/40 {
  background-color: rgb(4 47 46 / 0.4);
}

.bg-teal-950\/45 {
  background-color: rgb(4 47 46 / 0.45);
}

.bg-teal-950\/5 {
  background-color: rgb(4 47 46 / 0.05);
}

.bg-teal-950\/50 {
  background-color: rgb(4 47 46 / 0.5);
}

.bg-teal-950\/55 {
  background-color: rgb(4 47 46 / 0.55);
}

.bg-teal-950\/60 {
  background-color: rgb(4 47 46 / 0.6);
}

.bg-teal-950\/65 {
  background-color: rgb(4 47 46 / 0.65);
}

.bg-teal-950\/70 {
  background-color: rgb(4 47 46 / 0.7);
}

.bg-teal-950\/75 {
  background-color: rgb(4 47 46 / 0.75);
}

.bg-teal-950\/80 {
  background-color: rgb(4 47 46 / 0.8);
}

.bg-teal-950\/85 {
  background-color: rgb(4 47 46 / 0.85);
}

.bg-teal-950\/90 {
  background-color: rgb(4 47 46 / 0.9);
}

.bg-teal-950\/95 {
  background-color: rgb(4 47 46 / 0.95);
}

.bg-transparent {
  background-color: transparent;
}

.bg-transparent\/0 {
  background-color: rgb(0 0 0 / 0);
}

.bg-transparent\/10 {
  background-color: rgb(0 0 0 / 0.1);
}

.bg-transparent\/100 {
  background-color: rgb(0 0 0 / 1);
}

.bg-transparent\/15 {
  background-color: rgb(0 0 0 / 0.15);
}

.bg-transparent\/20 {
  background-color: rgb(0 0 0 / 0.2);
}

.bg-transparent\/25 {
  background-color: rgb(0 0 0 / 0.25);
}

.bg-transparent\/30 {
  background-color: rgb(0 0 0 / 0.3);
}

.bg-transparent\/35 {
  background-color: rgb(0 0 0 / 0.35);
}

.bg-transparent\/40 {
  background-color: rgb(0 0 0 / 0.4);
}

.bg-transparent\/45 {
  background-color: rgb(0 0 0 / 0.45);
}

.bg-transparent\/5 {
  background-color: rgb(0 0 0 / 0.05);
}

.bg-transparent\/50 {
  background-color: rgb(0 0 0 / 0.5);
}

.bg-transparent\/55 {
  background-color: rgb(0 0 0 / 0.55);
}

.bg-transparent\/60 {
  background-color: rgb(0 0 0 / 0.6);
}

.bg-transparent\/65 {
  background-color: rgb(0 0 0 / 0.65);
}

.bg-transparent\/70 {
  background-color: rgb(0 0 0 / 0.7);
}

.bg-transparent\/75 {
  background-color: rgb(0 0 0 / 0.75);
}

.bg-transparent\/80 {
  background-color: rgb(0 0 0 / 0.8);
}

.bg-transparent\/85 {
  background-color: rgb(0 0 0 / 0.85);
}

.bg-transparent\/90 {
  background-color: rgb(0 0 0 / 0.9);
}

.bg-transparent\/95 {
  background-color: rgb(0 0 0 / 0.95);
}

.bg-violet-100 {
  --tw-bg-opacity: 1;
  background-color: rgb(237 233 254 / var(--tw-bg-opacity));
}

.bg-violet-100\/0 {
  background-color: rgb(237 233 254 / 0);
}

.bg-violet-100\/10 {
  background-color: rgb(237 233 254 / 0.1);
}

.bg-violet-100\/100 {
  background-color: rgb(237 233 254 / 1);
}

.bg-violet-100\/15 {
  background-color: rgb(237 233 254 / 0.15);
}

.bg-violet-100\/20 {
  background-color: rgb(237 233 254 / 0.2);
}

.bg-violet-100\/25 {
  background-color: rgb(237 233 254 / 0.25);
}

.bg-violet-100\/30 {
  background-color: rgb(237 233 254 / 0.3);
}

.bg-violet-100\/35 {
  background-color: rgb(237 233 254 / 0.35);
}

.bg-violet-100\/40 {
  background-color: rgb(237 233 254 / 0.4);
}

.bg-violet-100\/45 {
  background-color: rgb(237 233 254 / 0.45);
}

.bg-violet-100\/5 {
  background-color: rgb(237 233 254 / 0.05);
}

.bg-violet-100\/50 {
  background-color: rgb(237 233 254 / 0.5);
}

.bg-violet-100\/55 {
  background-color: rgb(237 233 254 / 0.55);
}

.bg-violet-100\/60 {
  background-color: rgb(237 233 254 / 0.6);
}

.bg-violet-100\/65 {
  background-color: rgb(237 233 254 / 0.65);
}

.bg-violet-100\/70 {
  background-color: rgb(237 233 254 / 0.7);
}

.bg-violet-100\/75 {
  background-color: rgb(237 233 254 / 0.75);
}

.bg-violet-100\/80 {
  background-color: rgb(237 233 254 / 0.8);
}

.bg-violet-100\/85 {
  background-color: rgb(237 233 254 / 0.85);
}

.bg-violet-100\/90 {
  background-color: rgb(237 233 254 / 0.9);
}

.bg-violet-100\/95 {
  background-color: rgb(237 233 254 / 0.95);
}

.bg-violet-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(221 214 254 / var(--tw-bg-opacity));
}

.bg-violet-200\/0 {
  background-color: rgb(221 214 254 / 0);
}

.bg-violet-200\/10 {
  background-color: rgb(221 214 254 / 0.1);
}

.bg-violet-200\/100 {
  background-color: rgb(221 214 254 / 1);
}

.bg-violet-200\/15 {
  background-color: rgb(221 214 254 / 0.15);
}

.bg-violet-200\/20 {
  background-color: rgb(221 214 254 / 0.2);
}

.bg-violet-200\/25 {
  background-color: rgb(221 214 254 / 0.25);
}

.bg-violet-200\/30 {
  background-color: rgb(221 214 254 / 0.3);
}

.bg-violet-200\/35 {
  background-color: rgb(221 214 254 / 0.35);
}

.bg-violet-200\/40 {
  background-color: rgb(221 214 254 / 0.4);
}

.bg-violet-200\/45 {
  background-color: rgb(221 214 254 / 0.45);
}

.bg-violet-200\/5 {
  background-color: rgb(221 214 254 / 0.05);
}

.bg-violet-200\/50 {
  background-color: rgb(221 214 254 / 0.5);
}

.bg-violet-200\/55 {
  background-color: rgb(221 214 254 / 0.55);
}

.bg-violet-200\/60 {
  background-color: rgb(221 214 254 / 0.6);
}

.bg-violet-200\/65 {
  background-color: rgb(221 214 254 / 0.65);
}

.bg-violet-200\/70 {
  background-color: rgb(221 214 254 / 0.7);
}

.bg-violet-200\/75 {
  background-color: rgb(221 214 254 / 0.75);
}

.bg-violet-200\/80 {
  background-color: rgb(221 214 254 / 0.8);
}

.bg-violet-200\/85 {
  background-color: rgb(221 214 254 / 0.85);
}

.bg-violet-200\/90 {
  background-color: rgb(221 214 254 / 0.9);
}

.bg-violet-200\/95 {
  background-color: rgb(221 214 254 / 0.95);
}

.bg-violet-300 {
  --tw-bg-opacity: 1;
  background-color: rgb(196 181 253 / var(--tw-bg-opacity));
}

.bg-violet-300\/0 {
  background-color: rgb(196 181 253 / 0);
}

.bg-violet-300\/10 {
  background-color: rgb(196 181 253 / 0.1);
}

.bg-violet-300\/100 {
  background-color: rgb(196 181 253 / 1);
}

.bg-violet-300\/15 {
  background-color: rgb(196 181 253 / 0.15);
}

.bg-violet-300\/20 {
  background-color: rgb(196 181 253 / 0.2);
}

.bg-violet-300\/25 {
  background-color: rgb(196 181 253 / 0.25);
}

.bg-violet-300\/30 {
  background-color: rgb(196 181 253 / 0.3);
}

.bg-violet-300\/35 {
  background-color: rgb(196 181 253 / 0.35);
}

.bg-violet-300\/40 {
  background-color: rgb(196 181 253 / 0.4);
}

.bg-violet-300\/45 {
  background-color: rgb(196 181 253 / 0.45);
}

.bg-violet-300\/5 {
  background-color: rgb(196 181 253 / 0.05);
}

.bg-violet-300\/50 {
  background-color: rgb(196 181 253 / 0.5);
}

.bg-violet-300\/55 {
  background-color: rgb(196 181 253 / 0.55);
}

.bg-violet-300\/60 {
  background-color: rgb(196 181 253 / 0.6);
}

.bg-violet-300\/65 {
  background-color: rgb(196 181 253 / 0.65);
}

.bg-violet-300\/70 {
  background-color: rgb(196 181 253 / 0.7);
}

.bg-violet-300\/75 {
  background-color: rgb(196 181 253 / 0.75);
}

.bg-violet-300\/80 {
  background-color: rgb(196 181 253 / 0.8);
}

.bg-violet-300\/85 {
  background-color: rgb(196 181 253 / 0.85);
}

.bg-violet-300\/90 {
  background-color: rgb(196 181 253 / 0.9);
}

.bg-violet-300\/95 {
  background-color: rgb(196 181 253 / 0.95);
}

.bg-violet-400 {
  --tw-bg-opacity: 1;
  background-color: rgb(167 139 250 / var(--tw-bg-opacity));
}

.bg-violet-400\/0 {
  background-color: rgb(167 139 250 / 0);
}

.bg-violet-400\/10 {
  background-color: rgb(167 139 250 / 0.1);
}

.bg-violet-400\/100 {
  background-color: rgb(167 139 250 / 1);
}

.bg-violet-400\/15 {
  background-color: rgb(167 139 250 / 0.15);
}

.bg-violet-400\/20 {
  background-color: rgb(167 139 250 / 0.2);
}

.bg-violet-400\/25 {
  background-color: rgb(167 139 250 / 0.25);
}

.bg-violet-400\/30 {
  background-color: rgb(167 139 250 / 0.3);
}

.bg-violet-400\/35 {
  background-color: rgb(167 139 250 / 0.35);
}

.bg-violet-400\/40 {
  background-color: rgb(167 139 250 / 0.4);
}

.bg-violet-400\/45 {
  background-color: rgb(167 139 250 / 0.45);
}

.bg-violet-400\/5 {
  background-color: rgb(167 139 250 / 0.05);
}

.bg-violet-400\/50 {
  background-color: rgb(167 139 250 / 0.5);
}

.bg-violet-400\/55 {
  background-color: rgb(167 139 250 / 0.55);
}

.bg-violet-400\/60 {
  background-color: rgb(167 139 250 / 0.6);
}

.bg-violet-400\/65 {
  background-color: rgb(167 139 250 / 0.65);
}

.bg-violet-400\/70 {
  background-color: rgb(167 139 250 / 0.7);
}

.bg-violet-400\/75 {
  background-color: rgb(167 139 250 / 0.75);
}

.bg-violet-400\/80 {
  background-color: rgb(167 139 250 / 0.8);
}

.bg-violet-400\/85 {
  background-color: rgb(167 139 250 / 0.85);
}

.bg-violet-400\/90 {
  background-color: rgb(167 139 250 / 0.9);
}

.bg-violet-400\/95 {
  background-color: rgb(167 139 250 / 0.95);
}

.bg-violet-50 {
  --tw-bg-opacity: 1;
  background-color: rgb(245 243 255 / var(--tw-bg-opacity));
}

.bg-violet-50\/0 {
  background-color: rgb(245 243 255 / 0);
}

.bg-violet-50\/10 {
  background-color: rgb(245 243 255 / 0.1);
}

.bg-violet-50\/100 {
  background-color: rgb(245 243 255 / 1);
}

.bg-violet-50\/15 {
  background-color: rgb(245 243 255 / 0.15);
}

.bg-violet-50\/20 {
  background-color: rgb(245 243 255 / 0.2);
}

.bg-violet-50\/25 {
  background-color: rgb(245 243 255 / 0.25);
}

.bg-violet-50\/30 {
  background-color: rgb(245 243 255 / 0.3);
}

.bg-violet-50\/35 {
  background-color: rgb(245 243 255 / 0.35);
}

.bg-violet-50\/40 {
  background-color: rgb(245 243 255 / 0.4);
}

.bg-violet-50\/45 {
  background-color: rgb(245 243 255 / 0.45);
}

.bg-violet-50\/5 {
  background-color: rgb(245 243 255 / 0.05);
}

.bg-violet-50\/50 {
  background-color: rgb(245 243 255 / 0.5);
}

.bg-violet-50\/55 {
  background-color: rgb(245 243 255 / 0.55);
}

.bg-violet-50\/60 {
  background-color: rgb(245 243 255 / 0.6);
}

.bg-violet-50\/65 {
  background-color: rgb(245 243 255 / 0.65);
}

.bg-violet-50\/70 {
  background-color: rgb(245 243 255 / 0.7);
}

.bg-violet-50\/75 {
  background-color: rgb(245 243 255 / 0.75);
}

.bg-violet-50\/80 {
  background-color: rgb(245 243 255 / 0.8);
}

.bg-violet-50\/85 {
  background-color: rgb(245 243 255 / 0.85);
}

.bg-violet-50\/90 {
  background-color: rgb(245 243 255 / 0.9);
}

.bg-violet-50\/95 {
  background-color: rgb(245 243 255 / 0.95);
}

.bg-violet-500 {
  --tw-bg-opacity: 1;
  background-color: rgb(139 92 246 / var(--tw-bg-opacity));
}

.bg-violet-500\/0 {
  background-color: rgb(139 92 246 / 0);
}

.bg-violet-500\/10 {
  background-color: rgb(139 92 246 / 0.1);
}

.bg-violet-500\/100 {
  background-color: rgb(139 92 246 / 1);
}

.bg-violet-500\/15 {
  background-color: rgb(139 92 246 / 0.15);
}

.bg-violet-500\/20 {
  background-color: rgb(139 92 246 / 0.2);
}

.bg-violet-500\/25 {
  background-color: rgb(139 92 246 / 0.25);
}

.bg-violet-500\/30 {
  background-color: rgb(139 92 246 / 0.3);
}

.bg-violet-500\/35 {
  background-color: rgb(139 92 246 / 0.35);
}

.bg-violet-500\/40 {
  background-color: rgb(139 92 246 / 0.4);
}

.bg-violet-500\/45 {
  background-color: rgb(139 92 246 / 0.45);
}

.bg-violet-500\/5 {
  background-color: rgb(139 92 246 / 0.05);
}

.bg-violet-500\/50 {
  background-color: rgb(139 92 246 / 0.5);
}

.bg-violet-500\/55 {
  background-color: rgb(139 92 246 / 0.55);
}

.bg-violet-500\/60 {
  background-color: rgb(139 92 246 / 0.6);
}

.bg-violet-500\/65 {
  background-color: rgb(139 92 246 / 0.65);
}

.bg-violet-500\/70 {
  background-color: rgb(139 92 246 / 0.7);
}

.bg-violet-500\/75 {
  background-color: rgb(139 92 246 / 0.75);
}

.bg-violet-500\/80 {
  background-color: rgb(139 92 246 / 0.8);
}

.bg-violet-500\/85 {
  background-color: rgb(139 92 246 / 0.85);
}

.bg-violet-500\/90 {
  background-color: rgb(139 92 246 / 0.9);
}

.bg-violet-500\/95 {
  background-color: rgb(139 92 246 / 0.95);
}

.bg-violet-600 {
  --tw-bg-opacity: 1;
  background-color: rgb(124 58 237 / var(--tw-bg-opacity));
}

.bg-violet-600\/0 {
  background-color: rgb(124 58 237 / 0);
}

.bg-violet-600\/10 {
  background-color: rgb(124 58 237 / 0.1);
}

.bg-violet-600\/100 {
  background-color: rgb(124 58 237 / 1);
}

.bg-violet-600\/15 {
  background-color: rgb(124 58 237 / 0.15);
}

.bg-violet-600\/20 {
  background-color: rgb(124 58 237 / 0.2);
}

.bg-violet-600\/25 {
  background-color: rgb(124 58 237 / 0.25);
}

.bg-violet-600\/30 {
  background-color: rgb(124 58 237 / 0.3);
}

.bg-violet-600\/35 {
  background-color: rgb(124 58 237 / 0.35);
}

.bg-violet-600\/40 {
  background-color: rgb(124 58 237 / 0.4);
}

.bg-violet-600\/45 {
  background-color: rgb(124 58 237 / 0.45);
}

.bg-violet-600\/5 {
  background-color: rgb(124 58 237 / 0.05);
}

.bg-violet-600\/50 {
  background-color: rgb(124 58 237 / 0.5);
}

.bg-violet-600\/55 {
  background-color: rgb(124 58 237 / 0.55);
}

.bg-violet-600\/60 {
  background-color: rgb(124 58 237 / 0.6);
}

.bg-violet-600\/65 {
  background-color: rgb(124 58 237 / 0.65);
}

.bg-violet-600\/70 {
  background-color: rgb(124 58 237 / 0.7);
}

.bg-violet-600\/75 {
  background-color: rgb(124 58 237 / 0.75);
}

.bg-violet-600\/80 {
  background-color: rgb(124 58 237 / 0.8);
}

.bg-violet-600\/85 {
  background-color: rgb(124 58 237 / 0.85);
}

.bg-violet-600\/90 {
  background-color: rgb(124 58 237 / 0.9);
}

.bg-violet-600\/95 {
  background-color: rgb(124 58 237 / 0.95);
}

.bg-violet-700 {
  --tw-bg-opacity: 1;
  background-color: rgb(109 40 217 / var(--tw-bg-opacity));
}

.bg-violet-700\/0 {
  background-color: rgb(109 40 217 / 0);
}

.bg-violet-700\/10 {
  background-color: rgb(109 40 217 / 0.1);
}

.bg-violet-700\/100 {
  background-color: rgb(109 40 217 / 1);
}

.bg-violet-700\/15 {
  background-color: rgb(109 40 217 / 0.15);
}

.bg-violet-700\/20 {
  background-color: rgb(109 40 217 / 0.2);
}

.bg-violet-700\/25 {
  background-color: rgb(109 40 217 / 0.25);
}

.bg-violet-700\/30 {
  background-color: rgb(109 40 217 / 0.3);
}

.bg-violet-700\/35 {
  background-color: rgb(109 40 217 / 0.35);
}

.bg-violet-700\/40 {
  background-color: rgb(109 40 217 / 0.4);
}

.bg-violet-700\/45 {
  background-color: rgb(109 40 217 / 0.45);
}

.bg-violet-700\/5 {
  background-color: rgb(109 40 217 / 0.05);
}

.bg-violet-700\/50 {
  background-color: rgb(109 40 217 / 0.5);
}

.bg-violet-700\/55 {
  background-color: rgb(109 40 217 / 0.55);
}

.bg-violet-700\/60 {
  background-color: rgb(109 40 217 / 0.6);
}

.bg-violet-700\/65 {
  background-color: rgb(109 40 217 / 0.65);
}

.bg-violet-700\/70 {
  background-color: rgb(109 40 217 / 0.7);
}

.bg-violet-700\/75 {
  background-color: rgb(109 40 217 / 0.75);
}

.bg-violet-700\/80 {
  background-color: rgb(109 40 217 / 0.8);
}

.bg-violet-700\/85 {
  background-color: rgb(109 40 217 / 0.85);
}

.bg-violet-700\/90 {
  background-color: rgb(109 40 217 / 0.9);
}

.bg-violet-700\/95 {
  background-color: rgb(109 40 217 / 0.95);
}

.bg-violet-800 {
  --tw-bg-opacity: 1;
  background-color: rgb(91 33 182 / var(--tw-bg-opacity));
}

.bg-violet-800\/0 {
  background-color: rgb(91 33 182 / 0);
}

.bg-violet-800\/10 {
  background-color: rgb(91 33 182 / 0.1);
}

.bg-violet-800\/100 {
  background-color: rgb(91 33 182 / 1);
}

.bg-violet-800\/15 {
  background-color: rgb(91 33 182 / 0.15);
}

.bg-violet-800\/20 {
  background-color: rgb(91 33 182 / 0.2);
}

.bg-violet-800\/25 {
  background-color: rgb(91 33 182 / 0.25);
}

.bg-violet-800\/30 {
  background-color: rgb(91 33 182 / 0.3);
}

.bg-violet-800\/35 {
  background-color: rgb(91 33 182 / 0.35);
}

.bg-violet-800\/40 {
  background-color: rgb(91 33 182 / 0.4);
}

.bg-violet-800\/45 {
  background-color: rgb(91 33 182 / 0.45);
}

.bg-violet-800\/5 {
  background-color: rgb(91 33 182 / 0.05);
}

.bg-violet-800\/50 {
  background-color: rgb(91 33 182 / 0.5);
}

.bg-violet-800\/55 {
  background-color: rgb(91 33 182 / 0.55);
}

.bg-violet-800\/60 {
  background-color: rgb(91 33 182 / 0.6);
}

.bg-violet-800\/65 {
  background-color: rgb(91 33 182 / 0.65);
}

.bg-violet-800\/70 {
  background-color: rgb(91 33 182 / 0.7);
}

.bg-violet-800\/75 {
  background-color: rgb(91 33 182 / 0.75);
}

.bg-violet-800\/80 {
  background-color: rgb(91 33 182 / 0.8);
}

.bg-violet-800\/85 {
  background-color: rgb(91 33 182 / 0.85);
}

.bg-violet-800\/90 {
  background-color: rgb(91 33 182 / 0.9);
}

.bg-violet-800\/95 {
  background-color: rgb(91 33 182 / 0.95);
}

.bg-violet-900 {
  --tw-bg-opacity: 1;
  background-color: rgb(76 29 149 / var(--tw-bg-opacity));
}

.bg-violet-900\/0 {
  background-color: rgb(76 29 149 / 0);
}

.bg-violet-900\/10 {
  background-color: rgb(76 29 149 / 0.1);
}

.bg-violet-900\/100 {
  background-color: rgb(76 29 149 / 1);
}

.bg-violet-900\/15 {
  background-color: rgb(76 29 149 / 0.15);
}

.bg-violet-900\/20 {
  background-color: rgb(76 29 149 / 0.2);
}

.bg-violet-900\/25 {
  background-color: rgb(76 29 149 / 0.25);
}

.bg-violet-900\/30 {
  background-color: rgb(76 29 149 / 0.3);
}

.bg-violet-900\/35 {
  background-color: rgb(76 29 149 / 0.35);
}

.bg-violet-900\/40 {
  background-color: rgb(76 29 149 / 0.4);
}

.bg-violet-900\/45 {
  background-color: rgb(76 29 149 / 0.45);
}

.bg-violet-900\/5 {
  background-color: rgb(76 29 149 / 0.05);
}

.bg-violet-900\/50 {
  background-color: rgb(76 29 149 / 0.5);
}

.bg-violet-900\/55 {
  background-color: rgb(76 29 149 / 0.55);
}

.bg-violet-900\/60 {
  background-color: rgb(76 29 149 / 0.6);
}

.bg-violet-900\/65 {
  background-color: rgb(76 29 149 / 0.65);
}

.bg-violet-900\/70 {
  background-color: rgb(76 29 149 / 0.7);
}

.bg-violet-900\/75 {
  background-color: rgb(76 29 149 / 0.75);
}

.bg-violet-900\/80 {
  background-color: rgb(76 29 149 / 0.8);
}

.bg-violet-900\/85 {
  background-color: rgb(76 29 149 / 0.85);
}

.bg-violet-900\/90 {
  background-color: rgb(76 29 149 / 0.9);
}

.bg-violet-900\/95 {
  background-color: rgb(76 29 149 / 0.95);
}

.bg-violet-950 {
  --tw-bg-opacity: 1;
  background-color: rgb(46 16 101 / var(--tw-bg-opacity));
}

.bg-violet-950\/0 {
  background-color: rgb(46 16 101 / 0);
}

.bg-violet-950\/10 {
  background-color: rgb(46 16 101 / 0.1);
}

.bg-violet-950\/100 {
  background-color: rgb(46 16 101 / 1);
}

.bg-violet-950\/15 {
  background-color: rgb(46 16 101 / 0.15);
}

.bg-violet-950\/20 {
  background-color: rgb(46 16 101 / 0.2);
}

.bg-violet-950\/25 {
  background-color: rgb(46 16 101 / 0.25);
}

.bg-violet-950\/30 {
  background-color: rgb(46 16 101 / 0.3);
}

.bg-violet-950\/35 {
  background-color: rgb(46 16 101 / 0.35);
}

.bg-violet-950\/40 {
  background-color: rgb(46 16 101 / 0.4);
}

.bg-violet-950\/45 {
  background-color: rgb(46 16 101 / 0.45);
}

.bg-violet-950\/5 {
  background-color: rgb(46 16 101 / 0.05);
}

.bg-violet-950\/50 {
  background-color: rgb(46 16 101 / 0.5);
}

.bg-violet-950\/55 {
  background-color: rgb(46 16 101 / 0.55);
}

.bg-violet-950\/60 {
  background-color: rgb(46 16 101 / 0.6);
}

.bg-violet-950\/65 {
  background-color: rgb(46 16 101 / 0.65);
}

.bg-violet-950\/70 {
  background-color: rgb(46 16 101 / 0.7);
}

.bg-violet-950\/75 {
  background-color: rgb(46 16 101 / 0.75);
}

.bg-violet-950\/80 {
  background-color: rgb(46 16 101 / 0.8);
}

.bg-violet-950\/85 {
  background-color: rgb(46 16 101 / 0.85);
}

.bg-violet-950\/90 {
  background-color: rgb(46 16 101 / 0.9);
}

.bg-violet-950\/95 {
  background-color: rgb(46 16 101 / 0.95);
}

.bg-warning {
  --tw-bg-opacity: 1;
  background-color: var(--fallback-wa,oklch(var(--wa)/var(--tw-bg-opacity)));
}

.bg-warning-content {
  --tw-bg-opacity: 1;
  background-color: var(--fallback-wac,oklch(var(--wac)/var(--tw-bg-opacity)));
}

.bg-warning-content\/0 {
  background-color: var(--fallback-wac,oklch(var(--wac)/0));
}

.bg-warning-content\/10 {
  background-color: var(--fallback-wac,oklch(var(--wac)/0.1));
}

.bg-warning-content\/100 {
  background-color: var(--fallback-wac,oklch(var(--wac)/1));
}

.bg-warning-content\/15 {
  background-color: var(--fallback-wac,oklch(var(--wac)/0.15));
}

.bg-warning-content\/20 {
  background-color: var(--fallback-wac,oklch(var(--wac)/0.2));
}

.bg-warning-content\/25 {
  background-color: var(--fallback-wac,oklch(var(--wac)/0.25));
}

.bg-warning-content\/30 {
  background-color: var(--fallback-wac,oklch(var(--wac)/0.3));
}

.bg-warning-content\/35 {
  background-color: var(--fallback-wac,oklch(var(--wac)/0.35));
}

.bg-warning-content\/40 {
  background-color: var(--fallback-wac,oklch(var(--wac)/0.4));
}

.bg-warning-content\/45 {
  background-color: var(--fallback-wac,oklch(var(--wac)/0.45));
}

.bg-warning-content\/5 {
  background-color: var(--fallback-wac,oklch(var(--wac)/0.05));
}

.bg-warning-content\/50 {
  background-color: var(--fallback-wac,oklch(var(--wac)/0.5));
}

.bg-warning-content\/55 {
  background-color: var(--fallback-wac,oklch(var(--wac)/0.55));
}

.bg-warning-content\/60 {
  background-color: var(--fallback-wac,oklch(var(--wac)/0.6));
}

.bg-warning-content\/65 {
  background-color: var(--fallback-wac,oklch(var(--wac)/0.65));
}

.bg-warning-content\/70 {
  background-color: var(--fallback-wac,oklch(var(--wac)/0.7));
}

.bg-warning-content\/75 {
  background-color: var(--fallback-wac,oklch(var(--wac)/0.75));
}

.bg-warning-content\/80 {
  background-color: var(--fallback-wac,oklch(var(--wac)/0.8));
}

.bg-warning-content\/85 {
  background-color: var(--fallback-wac,oklch(var(--wac)/0.85));
}

.bg-warning-content\/90 {
  background-color: var(--fallback-wac,oklch(var(--wac)/0.9));
}

.bg-warning-content\/95 {
  background-color: var(--fallback-wac,oklch(var(--wac)/0.95));
}

.bg-warning\/0 {
  background-color: var(--fallback-wa,oklch(var(--wa)/0));
}

.bg-warning\/10 {
  background-color: var(--fallback-wa,oklch(var(--wa)/0.1));
}

.bg-warning\/100 {
  background-color: var(--fallback-wa,oklch(var(--wa)/1));
}

.bg-warning\/15 {
  background-color: var(--fallback-wa,oklch(var(--wa)/0.15));
}

.bg-warning\/20 {
  background-color: var(--fallback-wa,oklch(var(--wa)/0.2));
}

.bg-warning\/25 {
  background-color: var(--fallback-wa,oklch(var(--wa)/0.25));
}

.bg-warning\/30 {
  background-color: var(--fallback-wa,oklch(var(--wa)/0.3));
}

.bg-warning\/35 {
  background-color: var(--fallback-wa,oklch(var(--wa)/0.35));
}

.bg-warning\/40 {
  background-color: var(--fallback-wa,oklch(var(--wa)/0.4));
}

.bg-warning\/45 {
  background-color: var(--fallback-wa,oklch(var(--wa)/0.45));
}

.bg-warning\/5 {
  background-color: var(--fallback-wa,oklch(var(--wa)/0.05));
}

.bg-warning\/50 {
  background-color: var(--fallback-wa,oklch(var(--wa)/0.5));
}

.bg-warning\/55 {
  background-color: var(--fallback-wa,oklch(var(--wa)/0.55));
}

.bg-warning\/60 {
  background-color: var(--fallback-wa,oklch(var(--wa)/0.6));
}

.bg-warning\/65 {
  background-color: var(--fallback-wa,oklch(var(--wa)/0.65));
}

.bg-warning\/70 {
  background-color: var(--fallback-wa,oklch(var(--wa)/0.7));
}

.bg-warning\/75 {
  background-color: var(--fallback-wa,oklch(var(--wa)/0.75));
}

.bg-warning\/80 {
  background-color: var(--fallback-wa,oklch(var(--wa)/0.8));
}

.bg-warning\/85 {
  background-color: var(--fallback-wa,oklch(var(--wa)/0.85));
}

.bg-warning\/90 {
  background-color: var(--fallback-wa,oklch(var(--wa)/0.9));
}

.bg-warning\/95 {
  background-color: var(--fallback-wa,oklch(var(--wa)/0.95));
}

.bg-white {
  --tw-bg-opacity: 1;
  background-color: rgb(255 255 255 / var(--tw-bg-opacity));
}

.bg-white\/0 {
  background-color: rgb(255 255 255 / 0);
}

.bg-white\/10 {
  background-color: rgb(255 255 255 / 0.1);
}

.bg-white\/100 {
  background-color: rgb(255 255 255 / 1);
}

.bg-white\/15 {
  background-color: rgb(255 255 255 / 0.15);
}

.bg-white\/20 {
  background-color: rgb(255 255 255 / 0.2);
}

.bg-white\/25 {
  background-color: rgb(255 255 255 / 0.25);
}

.bg-white\/30 {
  background-color: rgb(255 255 255 / 0.3);
}

.bg-white\/35 {
  background-color: rgb(255 255 255 / 0.35);
}

.bg-white\/40 {
  background-color: rgb(255 255 255 / 0.4);
}

.bg-white\/45 {
  background-color: rgb(255 255 255 / 0.45);
}

.bg-white\/5 {
  background-color: rgb(255 255 255 / 0.05);
}

.bg-white\/50 {
  background-color: rgb(255 255 255 / 0.5);
}

.bg-white\/55 {
  background-color: rgb(255 255 255 / 0.55);
}

.bg-white\/60 {
  background-color: rgb(255 255 255 / 0.6);
}

.bg-white\/65 {
  background-color: rgb(255 255 255 / 0.65);
}

.bg-white\/70 {
  background-color: rgb(255 255 255 / 0.7);
}

.bg-white\/75 {
  background-color: rgb(255 255 255 / 0.75);
}

.bg-white\/80 {
  background-color: rgb(255 255 255 / 0.8);
}

.bg-white\/85 {
  background-color: rgb(255 255 255 / 0.85);
}

.bg-white\/90 {
  background-color: rgb(255 255 255 / 0.9);
}

.bg-white\/95 {
  background-color: rgb(255 255 255 / 0.95);
}

.bg-yellow-100 {
  --tw-bg-opacity: 1;
  background-color: rgb(254 249 195 / var(--tw-bg-opacity));
}

.bg-yellow-100\/0 {
  background-color: rgb(254 249 195 / 0);
}

.bg-yellow-100\/10 {
  background-color: rgb(254 249 195 / 0.1);
}

.bg-yellow-100\/100 {
  background-color: rgb(254 249 195 / 1);
}

.bg-yellow-100\/15 {
  background-color: rgb(254 249 195 / 0.15);
}

.bg-yellow-100\/20 {
  background-color: rgb(254 249 195 / 0.2);
}

.bg-yellow-100\/25 {
  background-color: rgb(254 249 195 / 0.25);
}

.bg-yellow-100\/30 {
  background-color: rgb(254 249 195 / 0.3);
}

.bg-yellow-100\/35 {
  background-color: rgb(254 249 195 / 0.35);
}

.bg-yellow-100\/40 {
  background-color: rgb(254 249 195 / 0.4);
}

.bg-yellow-100\/45 {
  background-color: rgb(254 249 195 / 0.45);
}

.bg-yellow-100\/5 {
  background-color: rgb(254 249 195 / 0.05);
}

.bg-yellow-100\/50 {
  background-color: rgb(254 249 195 / 0.5);
}

.bg-yellow-100\/55 {
  background-color: rgb(254 249 195 / 0.55);
}

.bg-yellow-100\/60 {
  background-color: rgb(254 249 195 / 0.6);
}

.bg-yellow-100\/65 {
  background-color: rgb(254 249 195 / 0.65);
}

.bg-yellow-100\/70 {
  background-color: rgb(254 249 195 / 0.7);
}

.bg-yellow-100\/75 {
  background-color: rgb(254 249 195 / 0.75);
}

.bg-yellow-100\/80 {
  background-color: rgb(254 249 195 / 0.8);
}

.bg-yellow-100\/85 {
  background-color: rgb(254 249 195 / 0.85);
}

.bg-yellow-100\/90 {
  background-color: rgb(254 249 195 / 0.9);
}

.bg-yellow-100\/95 {
  background-color: rgb(254 249 195 / 0.95);
}

.bg-yellow-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(254 240 138 / var(--tw-bg-opacity));
}

.bg-yellow-200\/0 {
  background-color: rgb(254 240 138 / 0);
}

.bg-yellow-200\/10 {
  background-color: rgb(254 240 138 / 0.1);
}

.bg-yellow-200\/100 {
  background-color: rgb(254 240 138 / 1);
}

.bg-yellow-200\/15 {
  background-color: rgb(254 240 138 / 0.15);
}

.bg-yellow-200\/20 {
  background-color: rgb(254 240 138 / 0.2);
}

.bg-yellow-200\/25 {
  background-color: rgb(254 240 138 / 0.25);
}

.bg-yellow-200\/30 {
  background-color: rgb(254 240 138 / 0.3);
}

.bg-yellow-200\/35 {
  background-color: rgb(254 240 138 / 0.35);
}

.bg-yellow-200\/40 {
  background-color: rgb(254 240 138 / 0.4);
}

.bg-yellow-200\/45 {
  background-color: rgb(254 240 138 / 0.45);
}

.bg-yellow-200\/5 {
  background-color: rgb(254 240 138 / 0.05);
}

.bg-yellow-200\/50 {
  background-color: rgb(254 240 138 / 0.5);
}

.bg-yellow-200\/55 {
  background-color: rgb(254 240 138 / 0.55);
}

.bg-yellow-200\/60 {
  background-color: rgb(254 240 138 / 0.6);
}

.bg-yellow-200\/65 {
  background-color: rgb(254 240 138 / 0.65);
}

.bg-yellow-200\/70 {
  background-color: rgb(254 240 138 / 0.7);
}

.bg-yellow-200\/75 {
  background-color: rgb(254 240 138 / 0.75);
}

.bg-yellow-200\/80 {
  background-color: rgb(254 240 138 / 0.8);
}

.bg-yellow-200\/85 {
  background-color: rgb(254 240 138 / 0.85);
}

.bg-yellow-200\/90 {
  background-color: rgb(254 240 138 / 0.9);
}

.bg-yellow-200\/95 {
  background-color: rgb(254 240 138 / 0.95);
}

.bg-yellow-300 {
  --tw-bg-opacity: 1;
  background-color: rgb(253 224 71 / var(--tw-bg-opacity));
}

.bg-yellow-300\/0 {
  background-color: rgb(253 224 71 / 0);
}

.bg-yellow-300\/10 {
  background-color: rgb(253 224 71 / 0.1);
}

.bg-yellow-300\/100 {
  background-color: rgb(253 224 71 / 1);
}

.bg-yellow-300\/15 {
  background-color: rgb(253 224 71 / 0.15);
}

.bg-yellow-300\/20 {
  background-color: rgb(253 224 71 / 0.2);
}

.bg-yellow-300\/25 {
  background-color: rgb(253 224 71 / 0.25);
}

.bg-yellow-300\/30 {
  background-color: rgb(253 224 71 / 0.3);
}

.bg-yellow-300\/35 {
  background-color: rgb(253 224 71 / 0.35);
}

.bg-yellow-300\/40 {
  background-color: rgb(253 224 71 / 0.4);
}

.bg-yellow-300\/45 {
  background-color: rgb(253 224 71 / 0.45);
}

.bg-yellow-300\/5 {
  background-color: rgb(253 224 71 / 0.05);
}

.bg-yellow-300\/50 {
  background-color: rgb(253 224 71 / 0.5);
}

.bg-yellow-300\/55 {
  background-color: rgb(253 224 71 / 0.55);
}

.bg-yellow-300\/60 {
  background-color: rgb(253 224 71 / 0.6);
}

.bg-yellow-300\/65 {
  background-color: rgb(253 224 71 / 0.65);
}

.bg-yellow-300\/70 {
  background-color: rgb(253 224 71 / 0.7);
}

.bg-yellow-300\/75 {
  background-color: rgb(253 224 71 / 0.75);
}

.bg-yellow-300\/80 {
  background-color: rgb(253 224 71 / 0.8);
}

.bg-yellow-300\/85 {
  background-color: rgb(253 224 71 / 0.85);
}

.bg-yellow-300\/90 {
  background-color: rgb(253 224 71 / 0.9);
}

.bg-yellow-300\/95 {
  background-color: rgb(253 224 71 / 0.95);
}

.bg-yellow-400 {
  --tw-bg-opacity: 1;
  background-color: rgb(250 204 21 / var(--tw-bg-opacity));
}

.bg-yellow-400\/0 {
  background-color: rgb(250 204 21 / 0);
}

.bg-yellow-400\/10 {
  background-color: rgb(250 204 21 / 0.1);
}

.bg-yellow-400\/100 {
  background-color: rgb(250 204 21 / 1);
}

.bg-yellow-400\/15 {
  background-color: rgb(250 204 21 / 0.15);
}

.bg-yellow-400\/20 {
  background-color: rgb(250 204 21 / 0.2);
}

.bg-yellow-400\/25 {
  background-color: rgb(250 204 21 / 0.25);
}

.bg-yellow-400\/30 {
  background-color: rgb(250 204 21 / 0.3);
}

.bg-yellow-400\/35 {
  background-color: rgb(250 204 21 / 0.35);
}

.bg-yellow-400\/40 {
  background-color: rgb(250 204 21 / 0.4);
}

.bg-yellow-400\/45 {
  background-color: rgb(250 204 21 / 0.45);
}

.bg-yellow-400\/5 {
  background-color: rgb(250 204 21 / 0.05);
}

.bg-yellow-400\/50 {
  background-color: rgb(250 204 21 / 0.5);
}

.bg-yellow-400\/55 {
  background-color: rgb(250 204 21 / 0.55);
}

.bg-yellow-400\/60 {
  background-color: rgb(250 204 21 / 0.6);
}

.bg-yellow-400\/65 {
  background-color: rgb(250 204 21 / 0.65);
}

.bg-yellow-400\/70 {
  background-color: rgb(250 204 21 / 0.7);
}

.bg-yellow-400\/75 {
  background-color: rgb(250 204 21 / 0.75);
}

.bg-yellow-400\/80 {
  background-color: rgb(250 204 21 / 0.8);
}

.bg-yellow-400\/85 {
  background-color: rgb(250 204 21 / 0.85);
}

.bg-yellow-400\/90 {
  background-color: rgb(250 204 21 / 0.9);
}

.bg-yellow-400\/95 {
  background-color: rgb(250 204 21 / 0.95);
}

.bg-yellow-50 {
  --tw-bg-opacity: 1;
  background-color: rgb(254 252 232 / var(--tw-bg-opacity));
}

.bg-yellow-50\/0 {
  background-color: rgb(254 252 232 / 0);
}

.bg-yellow-50\/10 {
  background-color: rgb(254 252 232 / 0.1);
}

.bg-yellow-50\/100 {
  background-color: rgb(254 252 232 / 1);
}

.bg-yellow-50\/15 {
  background-color: rgb(254 252 232 / 0.15);
}

.bg-yellow-50\/20 {
  background-color: rgb(254 252 232 / 0.2);
}

.bg-yellow-50\/25 {
  background-color: rgb(254 252 232 / 0.25);
}

.bg-yellow-50\/30 {
  background-color: rgb(254 252 232 / 0.3);
}

.bg-yellow-50\/35 {
  background-color: rgb(254 252 232 / 0.35);
}

.bg-yellow-50\/40 {
  background-color: rgb(254 252 232 / 0.4);
}

.bg-yellow-50\/45 {
  background-color: rgb(254 252 232 / 0.45);
}

.bg-yellow-50\/5 {
  background-color: rgb(254 252 232 / 0.05);
}

.bg-yellow-50\/50 {
  background-color: rgb(254 252 232 / 0.5);
}

.bg-yellow-50\/55 {
  background-color: rgb(254 252 232 / 0.55);
}

.bg-yellow-50\/60 {
  background-color: rgb(254 252 232 / 0.6);
}

.bg-yellow-50\/65 {
  background-color: rgb(254 252 232 / 0.65);
}

.bg-yellow-50\/70 {
  background-color: rgb(254 252 232 / 0.7);
}

.bg-yellow-50\/75 {
  background-color: rgb(254 252 232 / 0.75);
}

.bg-yellow-50\/80 {
  background-color: rgb(254 252 232 / 0.8);
}

.bg-yellow-50\/85 {
  background-color: rgb(254 252 232 / 0.85);
}

.bg-yellow-50\/90 {
  background-color: rgb(254 252 232 / 0.9);
}

.bg-yellow-50\/95 {
  background-color: rgb(254 252 232 / 0.95);
}

.bg-yellow-500 {
  --tw-bg-opacity: 1;
  background-color: rgb(234 179 8 / var(--tw-bg-opacity));
}

.bg-yellow-500\/0 {
  background-color: rgb(234 179 8 / 0);
}

.bg-yellow-500\/10 {
  background-color: rgb(234 179 8 / 0.1);
}

.bg-yellow-500\/100 {
  background-color: rgb(234 179 8 / 1);
}

.bg-yellow-500\/15 {
  background-color: rgb(234 179 8 / 0.15);
}

.bg-yellow-500\/20 {
  background-color: rgb(234 179 8 / 0.2);
}

.bg-yellow-500\/25 {
  background-color: rgb(234 179 8 / 0.25);
}

.bg-yellow-500\/30 {
  background-color: rgb(234 179 8 / 0.3);
}

.bg-yellow-500\/35 {
  background-color: rgb(234 179 8 / 0.35);
}

.bg-yellow-500\/40 {
  background-color: rgb(234 179 8 / 0.4);
}

.bg-yellow-500\/45 {
  background-color: rgb(234 179 8 / 0.45);
}

.bg-yellow-500\/5 {
  background-color: rgb(234 179 8 / 0.05);
}

.bg-yellow-500\/50 {
  background-color: rgb(234 179 8 / 0.5);
}

.bg-yellow-500\/55 {
  background-color: rgb(234 179 8 / 0.55);
}

.bg-yellow-500\/60 {
  background-color: rgb(234 179 8 / 0.6);
}

.bg-yellow-500\/65 {
  background-color: rgb(234 179 8 / 0.65);
}

.bg-yellow-500\/70 {
  background-color: rgb(234 179 8 / 0.7);
}

.bg-yellow-500\/75 {
  background-color: rgb(234 179 8 / 0.75);
}

.bg-yellow-500\/80 {
  background-color: rgb(234 179 8 / 0.8);
}

.bg-yellow-500\/85 {
  background-color: rgb(234 179 8 / 0.85);
}

.bg-yellow-500\/90 {
  background-color: rgb(234 179 8 / 0.9);
}

.bg-yellow-500\/95 {
  background-color: rgb(234 179 8 / 0.95);
}

.bg-yellow-600 {
  --tw-bg-opacity: 1;
  background-color: rgb(202 138 4 / var(--tw-bg-opacity));
}

.bg-yellow-600\/0 {
  background-color: rgb(202 138 4 / 0);
}

.bg-yellow-600\/10 {
  background-color: rgb(202 138 4 / 0.1);
}

.bg-yellow-600\/100 {
  background-color: rgb(202 138 4 / 1);
}

.bg-yellow-600\/15 {
  background-color: rgb(202 138 4 / 0.15);
}

.bg-yellow-600\/20 {
  background-color: rgb(202 138 4 / 0.2);
}

.bg-yellow-600\/25 {
  background-color: rgb(202 138 4 / 0.25);
}

.bg-yellow-600\/30 {
  background-color: rgb(202 138 4 / 0.3);
}

.bg-yellow-600\/35 {
  background-color: rgb(202 138 4 / 0.35);
}

.bg-yellow-600\/40 {
  background-color: rgb(202 138 4 / 0.4);
}

.bg-yellow-600\/45 {
  background-color: rgb(202 138 4 / 0.45);
}

.bg-yellow-600\/5 {
  background-color: rgb(202 138 4 / 0.05);
}

.bg-yellow-600\/50 {
  background-color: rgb(202 138 4 / 0.5);
}

.bg-yellow-600\/55 {
  background-color: rgb(202 138 4 / 0.55);
}

.bg-yellow-600\/60 {
  background-color: rgb(202 138 4 / 0.6);
}

.bg-yellow-600\/65 {
  background-color: rgb(202 138 4 / 0.65);
}

.bg-yellow-600\/70 {
  background-color: rgb(202 138 4 / 0.7);
}

.bg-yellow-600\/75 {
  background-color: rgb(202 138 4 / 0.75);
}

.bg-yellow-600\/80 {
  background-color: rgb(202 138 4 / 0.8);
}

.bg-yellow-600\/85 {
  background-color: rgb(202 138 4 / 0.85);
}

.bg-yellow-600\/90 {
  background-color: rgb(202 138 4 / 0.9);
}

.bg-yellow-600\/95 {
  background-color: rgb(202 138 4 / 0.95);
}

.bg-yellow-700 {
  --tw-bg-opacity: 1;
  background-color: rgb(161 98 7 / var(--tw-bg-opacity));
}

.bg-yellow-700\/0 {
  background-color: rgb(161 98 7 / 0);
}

.bg-yellow-700\/10 {
  background-color: rgb(161 98 7 / 0.1);
}

.bg-yellow-700\/100 {
  background-color: rgb(161 98 7 / 1);
}

.bg-yellow-700\/15 {
  background-color: rgb(161 98 7 / 0.15);
}

.bg-yellow-700\/20 {
  background-color: rgb(161 98 7 / 0.2);
}

.bg-yellow-700\/25 {
  background-color: rgb(161 98 7 / 0.25);
}

.bg-yellow-700\/30 {
  background-color: rgb(161 98 7 / 0.3);
}

.bg-yellow-700\/35 {
  background-color: rgb(161 98 7 / 0.35);
}

.bg-yellow-700\/40 {
  background-color: rgb(161 98 7 / 0.4);
}

.bg-yellow-700\/45 {
  background-color: rgb(161 98 7 / 0.45);
}

.bg-yellow-700\/5 {
  background-color: rgb(161 98 7 / 0.05);
}

.bg-yellow-700\/50 {
  background-color: rgb(161 98 7 / 0.5);
}

.bg-yellow-700\/55 {
  background-color: rgb(161 98 7 / 0.55);
}

.bg-yellow-700\/60 {
  background-color: rgb(161 98 7 / 0.6);
}

.bg-yellow-700\/65 {
  background-color: rgb(161 98 7 / 0.65);
}

.bg-yellow-700\/70 {
  background-color: rgb(161 98 7 / 0.7);
}

.bg-yellow-700\/75 {
  background-color: rgb(161 98 7 / 0.75);
}

.bg-yellow-700\/80 {
  background-color: rgb(161 98 7 / 0.8);
}

.bg-yellow-700\/85 {
  background-color: rgb(161 98 7 / 0.85);
}

.bg-yellow-700\/90 {
  background-color: rgb(161 98 7 / 0.9);
}

.bg-yellow-700\/95 {
  background-color: rgb(161 98 7 / 0.95);
}

.bg-yellow-800 {
  --tw-bg-opacity: 1;
  background-color: rgb(133 77 14 / var(--tw-bg-opacity));
}

.bg-yellow-800\/0 {
  background-color: rgb(133 77 14 / 0);
}

.bg-yellow-800\/10 {
  background-color: rgb(133 77 14 / 0.1);
}

.bg-yellow-800\/100 {
  background-color: rgb(133 77 14 / 1);
}

.bg-yellow-800\/15 {
  background-color: rgb(133 77 14 / 0.15);
}

.bg-yellow-800\/20 {
  background-color: rgb(133 77 14 / 0.2);
}

.bg-yellow-800\/25 {
  background-color: rgb(133 77 14 / 0.25);
}

.bg-yellow-800\/30 {
  background-color: rgb(133 77 14 / 0.3);
}

.bg-yellow-800\/35 {
  background-color: rgb(133 77 14 / 0.35);
}

.bg-yellow-800\/40 {
  background-color: rgb(133 77 14 / 0.4);
}

.bg-yellow-800\/45 {
  background-color: rgb(133 77 14 / 0.45);
}

.bg-yellow-800\/5 {
  background-color: rgb(133 77 14 / 0.05);
}

.bg-yellow-800\/50 {
  background-color: rgb(133 77 14 / 0.5);
}

.bg-yellow-800\/55 {
  background-color: rgb(133 77 14 / 0.55);
}

.bg-yellow-800\/60 {
  background-color: rgb(133 77 14 / 0.6);
}

.bg-yellow-800\/65 {
  background-color: rgb(133 77 14 / 0.65);
}

.bg-yellow-800\/70 {
  background-color: rgb(133 77 14 / 0.7);
}

.bg-yellow-800\/75 {
  background-color: rgb(133 77 14 / 0.75);
}

.bg-yellow-800\/80 {
  background-color: rgb(133 77 14 / 0.8);
}

.bg-yellow-800\/85 {
  background-color: rgb(133 77 14 / 0.85);
}

.bg-yellow-800\/90 {
  background-color: rgb(133 77 14 / 0.9);
}

.bg-yellow-800\/95 {
  background-color: rgb(133 77 14 / 0.95);
}

.bg-yellow-900 {
  --tw-bg-opacity: 1;
  background-color: rgb(113 63 18 / var(--tw-bg-opacity));
}

.bg-yellow-900\/0 {
  background-color: rgb(113 63 18 / 0);
}

.bg-yellow-900\/10 {
  background-color: rgb(113 63 18 / 0.1);
}

.bg-yellow-900\/100 {
  background-color: rgb(113 63 18 / 1);
}

.bg-yellow-900\/15 {
  background-color: rgb(113 63 18 / 0.15);
}

.bg-yellow-900\/20 {
  background-color: rgb(113 63 18 / 0.2);
}

.bg-yellow-900\/25 {
  background-color: rgb(113 63 18 / 0.25);
}

.bg-yellow-900\/30 {
  background-color: rgb(113 63 18 / 0.3);
}

.bg-yellow-900\/35 {
  background-color: rgb(113 63 18 / 0.35);
}

.bg-yellow-900\/40 {
  background-color: rgb(113 63 18 / 0.4);
}

.bg-yellow-900\/45 {
  background-color: rgb(113 63 18 / 0.45);
}

.bg-yellow-900\/5 {
  background-color: rgb(113 63 18 / 0.05);
}

.bg-yellow-900\/50 {
  background-color: rgb(113 63 18 / 0.5);
}

.bg-yellow-900\/55 {
  background-color: rgb(113 63 18 / 0.55);
}

.bg-yellow-900\/60 {
  background-color: rgb(113 63 18 / 0.6);
}

.bg-yellow-900\/65 {
  background-color: rgb(113 63 18 / 0.65);
}

.bg-yellow-900\/70 {
  background-color: rgb(113 63 18 / 0.7);
}

.bg-yellow-900\/75 {
  background-color: rgb(113 63 18 / 0.75);
}

.bg-yellow-900\/80 {
  background-color: rgb(113 63 18 / 0.8);
}

.bg-yellow-900\/85 {
  background-color: rgb(113 63 18 / 0.85);
}

.bg-yellow-900\/90 {
  background-color: rgb(113 63 18 / 0.9);
}

.bg-yellow-900\/95 {
  background-color: rgb(113 63 18 / 0.95);
}

.bg-yellow-950 {
  --tw-bg-opacity: 1;
  background-color: rgb(66 32 6 / var(--tw-bg-opacity));
}

.bg-yellow-950\/0 {
  background-color: rgb(66 32 6 / 0);
}

.bg-yellow-950\/10 {
  background-color: rgb(66 32 6 / 0.1);
}

.bg-yellow-950\/100 {
  background-color: rgb(66 32 6 / 1);
}

.bg-yellow-950\/15 {
  background-color: rgb(66 32 6 / 0.15);
}

.bg-yellow-950\/20 {
  background-color: rgb(66 32 6 / 0.2);
}

.bg-yellow-950\/25 {
  background-color: rgb(66 32 6 / 0.25);
}

.bg-yellow-950\/30 {
  background-color: rgb(66 32 6 / 0.3);
}

.bg-yellow-950\/35 {
  background-color: rgb(66 32 6 / 0.35);
}

.bg-yellow-950\/40 {
  background-color: rgb(66 32 6 / 0.4);
}

.bg-yellow-950\/45 {
  background-color: rgb(66 32 6 / 0.45);
}

.bg-yellow-950\/5 {
  background-color: rgb(66 32 6 / 0.05);
}

.bg-yellow-950\/50 {
  background-color: rgb(66 32 6 / 0.5);
}

.bg-yellow-950\/55 {
  background-color: rgb(66 32 6 / 0.55);
}

.bg-yellow-950\/60 {
  background-color: rgb(66 32 6 / 0.6);
}

.bg-yellow-950\/65 {
  background-color: rgb(66 32 6 / 0.65);
}

.bg-yellow-950\/70 {
  background-color: rgb(66 32 6 / 0.7);
}

.bg-yellow-950\/75 {
  background-color: rgb(66 32 6 / 0.75);
}

.bg-yellow-950\/80 {
  background-color: rgb(66 32 6 / 0.8);
}

.bg-yellow-950\/85 {
  background-color: rgb(66 32 6 / 0.85);
}

.bg-yellow-950\/90 {
  background-color: rgb(66 32 6 / 0.9);
}

.bg-yellow-950\/95 {
  background-color: rgb(66 32 6 / 0.95);
}

.bg-zinc-100 {
  --tw-bg-opacity: 1;
  background-color: rgb(244 244 245 / var(--tw-bg-opacity));
}

.bg-zinc-100\/0 {
  background-color: rgb(244 244 245 / 0);
}

.bg-zinc-100\/10 {
  background-color: rgb(244 244 245 / 0.1);
}

.bg-zinc-100\/100 {
  background-color: rgb(244 244 245 / 1);
}

.bg-zinc-100\/15 {
  background-color: rgb(244 244 245 / 0.15);
}

.bg-zinc-100\/20 {
  background-color: rgb(244 244 245 / 0.2);
}

.bg-zinc-100\/25 {
  background-color: rgb(244 244 245 / 0.25);
}

.bg-zinc-100\/30 {
  background-color: rgb(244 244 245 / 0.3);
}

.bg-zinc-100\/35 {
  background-color: rgb(244 244 245 / 0.35);
}

.bg-zinc-100\/40 {
  background-color: rgb(244 244 245 / 0.4);
}

.bg-zinc-100\/45 {
  background-color: rgb(244 244 245 / 0.45);
}

.bg-zinc-100\/5 {
  background-color: rgb(244 244 245 / 0.05);
}

.bg-zinc-100\/50 {
  background-color: rgb(244 244 245 / 0.5);
}

.bg-zinc-100\/55 {
  background-color: rgb(244 244 245 / 0.55);
}

.bg-zinc-100\/60 {
  background-color: rgb(244 244 245 / 0.6);
}

.bg-zinc-100\/65 {
  background-color: rgb(244 244 245 / 0.65);
}

.bg-zinc-100\/70 {
  background-color: rgb(244 244 245 / 0.7);
}

.bg-zinc-100\/75 {
  background-color: rgb(244 244 245 / 0.75);
}

.bg-zinc-100\/80 {
  background-color: rgb(244 244 245 / 0.8);
}

.bg-zinc-100\/85 {
  background-color: rgb(244 244 245 / 0.85);
}

.bg-zinc-100\/90 {
  background-color: rgb(244 244 245 / 0.9);
}

.bg-zinc-100\/95 {
  background-color: rgb(244 244 245 / 0.95);
}

.bg-zinc-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(228 228 231 / var(--tw-bg-opacity));
}

.bg-zinc-200\/0 {
  background-color: rgb(228 228 231 / 0);
}

.bg-zinc-200\/10 {
  background-color: rgb(228 228 231 / 0.1);
}

.bg-zinc-200\/100 {
  background-color: rgb(228 228 231 / 1);
}

.bg-zinc-200\/15 {
  background-color: rgb(228 228 231 / 0.15);
}

.bg-zinc-200\/20 {
  background-color: rgb(228 228 231 / 0.2);
}

.bg-zinc-200\/25 {
  background-color: rgb(228 228 231 / 0.25);
}

.bg-zinc-200\/30 {
  background-color: rgb(228 228 231 / 0.3);
}

.bg-zinc-200\/35 {
  background-color: rgb(228 228 231 / 0.35);
}

.bg-zinc-200\/40 {
  background-color: rgb(228 228 231 / 0.4);
}

.bg-zinc-200\/45 {
  background-color: rgb(228 228 231 / 0.45);
}

.bg-zinc-200\/5 {
  background-color: rgb(228 228 231 / 0.05);
}

.bg-zinc-200\/50 {
  background-color: rgb(228 228 231 / 0.5);
}

.bg-zinc-200\/55 {
  background-color: rgb(228 228 231 / 0.55);
}

.bg-zinc-200\/60 {
  background-color: rgb(228 228 231 / 0.6);
}

.bg-zinc-200\/65 {
  background-color: rgb(228 228 231 / 0.65);
}

.bg-zinc-200\/70 {
  background-color: rgb(228 228 231 / 0.7);
}

.bg-zinc-200\/75 {
  background-color: rgb(228 228 231 / 0.75);
}

.bg-zinc-200\/80 {
  background-color: rgb(228 228 231 / 0.8);
}

.bg-zinc-200\/85 {
  background-color: rgb(228 228 231 / 0.85);
}

.bg-zinc-200\/90 {
  background-color: rgb(228 228 231 / 0.9);
}

.bg-zinc-200\/95 {
  background-color: rgb(228 228 231 / 0.95);
}

.bg-zinc-300 {
  --tw-bg-opacity: 1;
  background-color: rgb(212 212 216 / var(--tw-bg-opacity));
}

.bg-zinc-300\/0 {
  background-color: rgb(212 212 216 / 0);
}

.bg-zinc-300\/10 {
  background-color: rgb(212 212 216 / 0.1);
}

.bg-zinc-300\/100 {
  background-color: rgb(212 212 216 / 1);
}

.bg-zinc-300\/15 {
  background-color: rgb(212 212 216 / 0.15);
}

.bg-zinc-300\/20 {
  background-color: rgb(212 212 216 / 0.2);
}

.bg-zinc-300\/25 {
  background-color: rgb(212 212 216 / 0.25);
}

.bg-zinc-300\/30 {
  background-color: rgb(212 212 216 / 0.3);
}

.bg-zinc-300\/35 {
  background-color: rgb(212 212 216 / 0.35);
}

.bg-zinc-300\/40 {
  background-color: rgb(212 212 216 / 0.4);
}

.bg-zinc-300\/45 {
  background-color: rgb(212 212 216 / 0.45);
}

.bg-zinc-300\/5 {
  background-color: rgb(212 212 216 / 0.05);
}

.bg-zinc-300\/50 {
  background-color: rgb(212 212 216 / 0.5);
}

.bg-zinc-300\/55 {
  background-color: rgb(212 212 216 / 0.55);
}

.bg-zinc-300\/60 {
  background-color: rgb(212 212 216 / 0.6);
}

.bg-zinc-300\/65 {
  background-color: rgb(212 212 216 / 0.65);
}

.bg-zinc-300\/70 {
  background-color: rgb(212 212 216 / 0.7);
}

.bg-zinc-300\/75 {
  background-color: rgb(212 212 216 / 0.75);
}

.bg-zinc-300\/80 {
  background-color: rgb(212 212 216 / 0.8);
}

.bg-zinc-300\/85 {
  background-color: rgb(212 212 216 / 0.85);
}

.bg-zinc-300\/90 {
  background-color: rgb(212 212 216 / 0.9);
}

.bg-zinc-300\/95 {
  background-color: rgb(212 212 216 / 0.95);
}

.bg-zinc-400 {
  --tw-bg-opacity: 1;
  background-color: rgb(161 161 170 / var(--tw-bg-opacity));
}

.bg-zinc-400\/0 {
  background-color: rgb(161 161 170 / 0);
}

.bg-zinc-400\/10 {
  background-color: rgb(161 161 170 / 0.1);
}

.bg-zinc-400\/100 {
  background-color: rgb(161 161 170 / 1);
}

.bg-zinc-400\/15 {
  background-color: rgb(161 161 170 / 0.15);
}

.bg-zinc-400\/20 {
  background-color: rgb(161 161 170 / 0.2);
}

.bg-zinc-400\/25 {
  background-color: rgb(161 161 170 / 0.25);
}

.bg-zinc-400\/30 {
  background-color: rgb(161 161 170 / 0.3);
}

.bg-zinc-400\/35 {
  background-color: rgb(161 161 170 / 0.35);
}

.bg-zinc-400\/40 {
  background-color: rgb(161 161 170 / 0.4);
}

.bg-zinc-400\/45 {
  background-color: rgb(161 161 170 / 0.45);
}

.bg-zinc-400\/5 {
  background-color: rgb(161 161 170 / 0.05);
}

.bg-zinc-400\/50 {
  background-color: rgb(161 161 170 / 0.5);
}

.bg-zinc-400\/55 {
  background-color: rgb(161 161 170 / 0.55);
}

.bg-zinc-400\/60 {
  background-color: rgb(161 161 170 / 0.6);
}

.bg-zinc-400\/65 {
  background-color: rgb(161 161 170 / 0.65);
}

.bg-zinc-400\/70 {
  background-color: rgb(161 161 170 / 0.7);
}

.bg-zinc-400\/75 {
  background-color: rgb(161 161 170 / 0.75);
}

.bg-zinc-400\/80 {
  background-color: rgb(161 161 170 / 0.8);
}

.bg-zinc-400\/85 {
  background-color: rgb(161 161 170 / 0.85);
}

.bg-zinc-400\/90 {
  background-color: rgb(161 161 170 / 0.9);
}

.bg-zinc-400\/95 {
  background-color: rgb(161 161 170 / 0.95);
}

.bg-zinc-50 {
  --tw-bg-opacity: 1;
  background-color: rgb(250 250 250 / var(--tw-bg-opacity));
}

.bg-zinc-50\/0 {
  background-color: rgb(250 250 250 / 0);
}

.bg-zinc-50\/10 {
  background-color: rgb(250 250 250 / 0.1);
}

.bg-zinc-50\/100 {
  background-color: rgb(250 250 250 / 1);
}

.bg-zinc-50\/15 {
  background-color: rgb(250 250 250 / 0.15);
}

.bg-zinc-50\/20 {
  background-color: rgb(250 250 250 / 0.2);
}

.bg-zinc-50\/25 {
  background-color: rgb(250 250 250 / 0.25);
}

.bg-zinc-50\/30 {
  background-color: rgb(250 250 250 / 0.3);
}

.bg-zinc-50\/35 {
  background-color: rgb(250 250 250 / 0.35);
}

.bg-zinc-50\/40 {
  background-color: rgb(250 250 250 / 0.4);
}

.bg-zinc-50\/45 {
  background-color: rgb(250 250 250 / 0.45);
}

.bg-zinc-50\/5 {
  background-color: rgb(250 250 250 / 0.05);
}

.bg-zinc-50\/50 {
  background-color: rgb(250 250 250 / 0.5);
}

.bg-zinc-50\/55 {
  background-color: rgb(250 250 250 / 0.55);
}

.bg-zinc-50\/60 {
  background-color: rgb(250 250 250 / 0.6);
}

.bg-zinc-50\/65 {
  background-color: rgb(250 250 250 / 0.65);
}

.bg-zinc-50\/70 {
  background-color: rgb(250 250 250 / 0.7);
}

.bg-zinc-50\/75 {
  background-color: rgb(250 250 250 / 0.75);
}

.bg-zinc-50\/80 {
  background-color: rgb(250 250 250 / 0.8);
}

.bg-zinc-50\/85 {
  background-color: rgb(250 250 250 / 0.85);
}

.bg-zinc-50\/90 {
  background-color: rgb(250 250 250 / 0.9);
}

.bg-zinc-50\/95 {
  background-color: rgb(250 250 250 / 0.95);
}

.bg-zinc-500 {
  --tw-bg-opacity: 1;
  background-color: rgb(113 113 122 / var(--tw-bg-opacity));
}

.bg-zinc-500\/0 {
  background-color: rgb(113 113 122 / 0);
}

.bg-zinc-500\/10 {
  background-color: rgb(113 113 122 / 0.1);
}

.bg-zinc-500\/100 {
  background-color: rgb(113 113 122 / 1);
}

.bg-zinc-500\/15 {
  background-color: rgb(113 113 122 / 0.15);
}

.bg-zinc-500\/20 {
  background-color: rgb(113 113 122 / 0.2);
}

.bg-zinc-500\/25 {
  background-color: rgb(113 113 122 / 0.25);
}

.bg-zinc-500\/30 {
  background-color: rgb(113 113 122 / 0.3);
}

.bg-zinc-500\/35 {
  background-color: rgb(113 113 122 / 0.35);
}

.bg-zinc-500\/40 {
  background-color: rgb(113 113 122 / 0.4);
}

.bg-zinc-500\/45 {
  background-color: rgb(113 113 122 / 0.45);
}

.bg-zinc-500\/5 {
  background-color: rgb(113 113 122 / 0.05);
}

.bg-zinc-500\/50 {
  background-color: rgb(113 113 122 / 0.5);
}

.bg-zinc-500\/55 {
  background-color: rgb(113 113 122 / 0.55);
}

.bg-zinc-500\/60 {
  background-color: rgb(113 113 122 / 0.6);
}

.bg-zinc-500\/65 {
  background-color: rgb(113 113 122 / 0.65);
}

.bg-zinc-500\/70 {
  background-color: rgb(113 113 122 / 0.7);
}

.bg-zinc-500\/75 {
  background-color: rgb(113 113 122 / 0.75);
}

.bg-zinc-500\/80 {
  background-color: rgb(113 113 122 / 0.8);
}

.bg-zinc-500\/85 {
  background-color: rgb(113 113 122 / 0.85);
}

.bg-zinc-500\/90 {
  background-color: rgb(113 113 122 / 0.9);
}

.bg-zinc-500\/95 {
  background-color: rgb(113 113 122 / 0.95);
}

.bg-zinc-600 {
  --tw-bg-opacity: 1;
  background-color: rgb(82 82 91 / var(--tw-bg-opacity));
}

.bg-zinc-600\/0 {
  background-color: rgb(82 82 91 / 0);
}

.bg-zinc-600\/10 {
  background-color: rgb(82 82 91 / 0.1);
}

.bg-zinc-600\/100 {
  background-color: rgb(82 82 91 / 1);
}

.bg-zinc-600\/15 {
  background-color: rgb(82 82 91 / 0.15);
}

.bg-zinc-600\/20 {
  background-color: rgb(82 82 91 / 0.2);
}

.bg-zinc-600\/25 {
  background-color: rgb(82 82 91 / 0.25);
}

.bg-zinc-600\/30 {
  background-color: rgb(82 82 91 / 0.3);
}

.bg-zinc-600\/35 {
  background-color: rgb(82 82 91 / 0.35);
}

.bg-zinc-600\/40 {
  background-color: rgb(82 82 91 / 0.4);
}

.bg-zinc-600\/45 {
  background-color: rgb(82 82 91 / 0.45);
}

.bg-zinc-600\/5 {
  background-color: rgb(82 82 91 / 0.05);
}

.bg-zinc-600\/50 {
  background-color: rgb(82 82 91 / 0.5);
}

.bg-zinc-600\/55 {
  background-color: rgb(82 82 91 / 0.55);
}

.bg-zinc-600\/60 {
  background-color: rgb(82 82 91 / 0.6);
}

.bg-zinc-600\/65 {
  background-color: rgb(82 82 91 / 0.65);
}

.bg-zinc-600\/70 {
  background-color: rgb(82 82 91 / 0.7);
}

.bg-zinc-600\/75 {
  background-color: rgb(82 82 91 / 0.75);
}

.bg-zinc-600\/80 {
  background-color: rgb(82 82 91 / 0.8);
}

.bg-zinc-600\/85 {
  background-color: rgb(82 82 91 / 0.85);
}

.bg-zinc-600\/90 {
  background-color: rgb(82 82 91 / 0.9);
}

.bg-zinc-600\/95 {
  background-color: rgb(82 82 91 / 0.95);
}

.bg-zinc-700 {
  --tw-bg-opacity: 1;
  background-color: rgb(63 63 70 / var(--tw-bg-opacity));
}

.bg-zinc-700\/0 {
  background-color: rgb(63 63 70 / 0);
}

.bg-zinc-700\/10 {
  background-color: rgb(63 63 70 / 0.1);
}

.bg-zinc-700\/100 {
  background-color: rgb(63 63 70 / 1);
}

.bg-zinc-700\/15 {
  background-color: rgb(63 63 70 / 0.15);
}

.bg-zinc-700\/20 {
  background-color: rgb(63 63 70 / 0.2);
}

.bg-zinc-700\/25 {
  background-color: rgb(63 63 70 / 0.25);
}

.bg-zinc-700\/30 {
  background-color: rgb(63 63 70 / 0.3);
}

.bg-zinc-700\/35 {
  background-color: rgb(63 63 70 / 0.35);
}

.bg-zinc-700\/40 {
  background-color: rgb(63 63 70 / 0.4);
}

.bg-zinc-700\/45 {
  background-color: rgb(63 63 70 / 0.45);
}

.bg-zinc-700\/5 {
  background-color: rgb(63 63 70 / 0.05);
}

.bg-zinc-700\/50 {
  background-color: rgb(63 63 70 / 0.5);
}

.bg-zinc-700\/55 {
  background-color: rgb(63 63 70 / 0.55);
}

.bg-zinc-700\/60 {
  background-color: rgb(63 63 70 / 0.6);
}

.bg-zinc-700\/65 {
  background-color: rgb(63 63 70 / 0.65);
}

.bg-zinc-700\/70 {
  background-color: rgb(63 63 70 / 0.7);
}

.bg-zinc-700\/75 {
  background-color: rgb(63 63 70 / 0.75);
}

.bg-zinc-700\/80 {
  background-color: rgb(63 63 70 / 0.8);
}

.bg-zinc-700\/85 {
  background-color: rgb(63 63 70 / 0.85);
}

.bg-zinc-700\/90 {
  background-color: rgb(63 63 70 / 0.9);
}

.bg-zinc-700\/95 {
  background-color: rgb(63 63 70 / 0.95);
}

.bg-zinc-800 {
  --tw-bg-opacity: 1;
  background-color: rgb(39 39 42 / var(--tw-bg-opacity));
}

.bg-zinc-800\/0 {
  background-color: rgb(39 39 42 / 0);
}

.bg-zinc-800\/10 {
  background-color: rgb(39 39 42 / 0.1);
}

.bg-zinc-800\/100 {
  background-color: rgb(39 39 42 / 1);
}

.bg-zinc-800\/15 {
  background-color: rgb(39 39 42 / 0.15);
}

.bg-zinc-800\/20 {
  background-color: rgb(39 39 42 / 0.2);
}

.bg-zinc-800\/25 {
  background-color: rgb(39 39 42 / 0.25);
}

.bg-zinc-800\/30 {
  background-color: rgb(39 39 42 / 0.3);
}

.bg-zinc-800\/35 {
  background-color: rgb(39 39 42 / 0.35);
}

.bg-zinc-800\/40 {
  background-color: rgb(39 39 42 / 0.4);
}

.bg-zinc-800\/45 {
  background-color: rgb(39 39 42 / 0.45);
}

.bg-zinc-800\/5 {
  background-color: rgb(39 39 42 / 0.05);
}

.bg-zinc-800\/50 {
  background-color: rgb(39 39 42 / 0.5);
}

.bg-zinc-800\/55 {
  background-color: rgb(39 39 42 / 0.55);
}

.bg-zinc-800\/60 {
  background-color: rgb(39 39 42 / 0.6);
}

.bg-zinc-800\/65 {
  background-color: rgb(39 39 42 / 0.65);
}

.bg-zinc-800\/70 {
  background-color: rgb(39 39 42 / 0.7);
}

.bg-zinc-800\/75 {
  background-color: rgb(39 39 42 / 0.75);
}

.bg-zinc-800\/80 {
  background-color: rgb(39 39 42 / 0.8);
}

.bg-zinc-800\/85 {
  background-color: rgb(39 39 42 / 0.85);
}

.bg-zinc-800\/90 {
  background-color: rgb(39 39 42 / 0.9);
}

.bg-zinc-800\/95 {
  background-color: rgb(39 39 42 / 0.95);
}

.bg-zinc-900 {
  --tw-bg-opacity: 1;
  background-color: rgb(24 24 27 / var(--tw-bg-opacity));
}

.bg-zinc-900\/0 {
  background-color: rgb(24 24 27 / 0);
}

.bg-zinc-900\/10 {
  background-color: rgb(24 24 27 / 0.1);
}

.bg-zinc-900\/100 {
  background-color: rgb(24 24 27 / 1);
}

.bg-zinc-900\/15 {
  background-color: rgb(24 24 27 / 0.15);
}

.bg-zinc-900\/20 {
  background-color: rgb(24 24 27 / 0.2);
}

.bg-zinc-900\/25 {
  background-color: rgb(24 24 27 / 0.25);
}

.bg-zinc-900\/30 {
  background-color: rgb(24 24 27 / 0.3);
}

.bg-zinc-900\/35 {
  background-color: rgb(24 24 27 / 0.35);
}

.bg-zinc-900\/40 {
  background-color: rgb(24 24 27 / 0.4);
}

.bg-zinc-900\/45 {
  background-color: rgb(24 24 27 / 0.45);
}

.bg-zinc-900\/5 {
  background-color: rgb(24 24 27 / 0.05);
}

.bg-zinc-900\/50 {
  background-color: rgb(24 24 27 / 0.5);
}

.bg-zinc-900\/55 {
  background-color: rgb(24 24 27 / 0.55);
}

.bg-zinc-900\/60 {
  background-color: rgb(24 24 27 / 0.6);
}

.bg-zinc-900\/65 {
  background-color: rgb(24 24 27 / 0.65);
}

.bg-zinc-900\/70 {
  background-color: rgb(24 24 27 / 0.7);
}

.bg-zinc-900\/75 {
  background-color: rgb(24 24 27 / 0.75);
}

.bg-zinc-900\/80 {
  background-color: rgb(24 24 27 / 0.8);
}

.bg-zinc-900\/85 {
  background-color: rgb(24 24 27 / 0.85);
}

.bg-zinc-900\/90 {
  background-color: rgb(24 24 27 / 0.9);
}

.bg-zinc-900\/95 {
  background-color: rgb(24 24 27 / 0.95);
}

.bg-zinc-950 {
  --tw-bg-opacity: 1;
  background-color: rgb(9 9 11 / var(--tw-bg-opacity));
}

.bg-zinc-950\/0 {
  background-color: rgb(9 9 11 / 0);
}

.bg-zinc-950\/10 {
  background-color: rgb(9 9 11 / 0.1);
}

.bg-zinc-950\/100 {
  background-color: rgb(9 9 11 / 1);
}

.bg-zinc-950\/15 {
  background-color: rgb(9 9 11 / 0.15);
}

.bg-zinc-950\/20 {
  background-color: rgb(9 9 11 / 0.2);
}

.bg-zinc-950\/25 {
  background-color: rgb(9 9 11 / 0.25);
}

.bg-zinc-950\/30 {
  background-color: rgb(9 9 11 / 0.3);
}

.bg-zinc-950\/35 {
  background-color: rgb(9 9 11 / 0.35);
}

.bg-zinc-950\/40 {
  background-color: rgb(9 9 11 / 0.4);
}

.bg-zinc-950\/45 {
  background-color: rgb(9 9 11 / 0.45);
}

.bg-zinc-950\/5 {
  background-color: rgb(9 9 11 / 0.05);
}

.bg-zinc-950\/50 {
  background-color: rgb(9 9 11 / 0.5);
}

.bg-zinc-950\/55 {
  background-color: rgb(9 9 11 / 0.55);
}

.bg-zinc-950\/60 {
  background-color: rgb(9 9 11 / 0.6);
}

.bg-zinc-950\/65 {
  background-color: rgb(9 9 11 / 0.65);
}

.bg-zinc-950\/70 {
  background-color: rgb(9 9 11 / 0.7);
}

.bg-zinc-950\/75 {
  background-color: rgb(9 9 11 / 0.75);
}

.bg-zinc-950\/80 {
  background-color: rgb(9 9 11 / 0.8);
}

.bg-zinc-950\/85 {
  background-color: rgb(9 9 11 / 0.85);
}

.bg-zinc-950\/90 {
  background-color: rgb(9 9 11 / 0.9);
}

.bg-zinc-950\/95 {
  background-color: rgb(9 9 11 / 0.95);
}

.bg-opacity-0 {
  --tw-bg-opacity: 0;
}

.bg-opacity-10 {
  --tw-bg-opacity: 0.1;
}

.bg-opacity-100 {
  --tw-bg-opacity: 1;
}

.bg-opacity-15 {
  --tw-bg-opacity: 0.15;
}

.bg-opacity-20 {
  --tw-bg-opacity: 0.2;
}

.bg-opacity-25 {
  --tw-bg-opacity: 0.25;
}

.bg-opacity-30 {
  --tw-bg-opacity: 0.3;
}

.bg-opacity-35 {
  --tw-bg-opacity: 0.35;
}

.bg-opacity-40 {
  --tw-bg-opacity: 0.4;
}

.bg-opacity-45 {
  --tw-bg-opacity: 0.45;
}

.bg-opacity-5 {
  --tw-bg-opacity: 0.05;
}

.bg-opacity-50 {
  --tw-bg-opacity: 0.5;
}

.bg-opacity-55 {
  --tw-bg-opacity: 0.55;
}

.bg-opacity-60 {
  --tw-bg-opacity: 0.6;
}

.bg-opacity-65 {
  --tw-bg-opacity: 0.65;
}

.bg-opacity-70 {
  --tw-bg-opacity: 0.7;
}

.bg-opacity-75 {
  --tw-bg-opacity: 0.75;
}

.bg-opacity-80 {
  --tw-bg-opacity: 0.8;
}

.bg-opacity-85 {
  --tw-bg-opacity: 0.85;
}

.bg-opacity-90 {
  --tw-bg-opacity: 0.9;
}

.bg-opacity-95 {
  --tw-bg-opacity: 0.95;
}

.bg-gradient-to-b {
  background-image: linear-gradient(to bottom, var(--tw-gradient-stops));
}

.bg-gradient-to-bl {
  background-image: linear-gradient(to bottom left, var(--tw-gradient-stops));
}

.bg-gradient-to-br {
  background-image: linear-gradient(to bottom right, var(--tw-gradient-stops));
}

.bg-gradient-to-l {
  background-image: linear-gradient(to left, var(--tw-gradient-stops));
}

.bg-gradient-to-r {
  background-image: linear-gradient(to right, var(--tw-gradient-stops));
}

.bg-gradient-to-t {
  background-image: linear-gradient(to top, var(--tw-gradient-stops));
}

.bg-gradient-to-tl {
  background-image: linear-gradient(to top left, var(--tw-gradient-stops));
}

.bg-gradient-to-tr {
  background-image: linear-gradient(to top right, var(--tw-gradient-stops));
}

.bg-none {
  background-image: none;
}

.bg-auto {
  background-size: auto;
}

.bg-contain {
  background-size: contain;
}

.bg-cover {
  background-size: cover;
}

.bg-fixed {
  background-attachment: fixed;
}

.bg-local {
  background-attachment: local;
}

.bg-scroll {
  background-attachment: scroll;
}

.bg-clip-border {
  background-clip: border-box;
}

.bg-clip-padding {
  background-clip: padding-box;
}

.bg-clip-content {
  background-clip: content-box;
}

.bg-clip-text {
  -webkit-background-clip: text;
          background-clip: text;
}

.bg-bottom {
  background-position: bottom;
}

.bg-center {
  background-position: center;
}

.bg-left {
  background-position: left;
}

.bg-left-bottom {
  background-position: left bottom;
}

.bg-left-top {
  background-position: left top;
}

.bg-right {
  background-position: right;
}

.bg-right-bottom {
  background-position: right bottom;
}

.bg-right-top {
  background-position: right top;
}

.bg-top {
  background-position: top;
}

.bg-repeat {
  background-repeat: repeat;
}

.bg-no-repeat {
  background-repeat: no-repeat;
}

.bg-repeat-x {
  background-repeat: repeat-x;
}

.bg-repeat-y {
  background-repeat: repeat-y;
}

.bg-repeat-round {
  background-repeat: round;
}

.bg-repeat-space {
  background-repeat: space;
}

.bg-origin-border {
  background-origin: border-box;
}

.bg-origin-padding {
  background-origin: padding-box;
}

.bg-origin-content {
  background-origin: content-box;
}

.p-10 {
  padding: 2.5rem;
}

.p-3 {
  padding: 0.75rem;
}

.py-3 {
  padding-top: 0.75rem;
  padding-bottom: 0.75rem;
}

.pt-1 {
  padding-top: 0.25rem;
}

.text-2xl {
  font-size: 1.5rem;
  line-height: 2rem;
}

.text-lg {
  font-size: 1.125rem;
  line-height: 1.75rem;
}

.text-sm {
  font-size: 0.875rem;
  line-height: 1.25rem;
}

.text-xs {
  font-size: 0.75rem;
  line-height: 1rem;
}

.font-medium {
  font-weight: 500;
}

.tracking-wide {
  letter-spacing: 0.025em;
}

.text-error {
  --tw-text-opacity: 1;
  color: var(--fallback-er,oklch(var(--er)/var(--tw-text-opacity)));
}

.text-neutral {
  --tw-text-opacity: 1;
  color: var(--fallback-n,oklch(var(--n)/var(--tw-text-opacity)));
}

.text-primary {
  --tw-text-opacity: 1;
  color: var(--fallback-p,oklch(var(--p)/var(--tw-text-opacity)));
}

.text-white {
  --tw-text-opacity: 1;
  color: rgb(255 255 255 / var(--tw-text-opacity));
}

.text-base-300 {
  --tw-text-opacity: 1;
  color: var(--fallback-b3,oklch(var(--b3)/var(--tw-text-opacity)));
}

.bg-blend-normal {
  background-blend-mode: normal;
}

.bg-blend-multiply {
  background-blend-mode: multiply;
}

.bg-blend-screen {
  background-blend-mode: screen;
}

.bg-blend-overlay {
  background-blend-mode: overlay;
}

.bg-blend-darken {
  background-blend-mode: darken;
}

.bg-blend-lighten {
  background-blend-mode: lighten;
}

.bg-blend-color-dodge {
  background-blend-mode: color-dodge;
}

.bg-blend-color-burn {
  background-blend-mode: color-burn;
}

.bg-blend-hard-light {
  background-blend-mode: hard-light;
}

.bg-blend-soft-light {
  background-blend-mode: soft-light;
}

.bg-blend-difference {
  background-blend-mode: difference;
}

.bg-blend-exclusion {
  background-blend-mode: exclusion;
}

.bg-blend-hue {
  background-blend-mode: hue;
}

.bg-blend-saturation {
  background-blend-mode: saturation;
}

.bg-blend-color {
  background-blend-mode: color;
}

.bg-blend-luminosity {
  background-blend-mode: luminosity;
}

.shadow-md {
  --tw-shadow: 0 4px 6px -1px rgb(0 0 0 / 0.1), 0 2px 4px -2px rgb(0 0 0 / 0.1);
  --tw-shadow-colored: 0 4px 6px -1px var(--tw-shadow-color), 0 2px 4px -2px var(--tw-shadow-color);
  box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);
}

.\[\&_a\]\:link a {
  cursor: pointer;
  text-decoration-line: underline;
}

.\[\&_a\]\:link a:focus {
  outline: 2px solid transparent;
  outline-offset: 2px;
}

.\[\&_a\]\:link a:focus-visible {
  outline: 2px solid currentColor;
  outline-offset: 2px;
}

.checked\:bg-primary:checked {
  --tw-bg-opacity: 1;
  background-color: var(--fallback-p,oklch(var(--p)/var(--tw-bg-opacity)));
}

@media (min-width: 640px) {
  .sm\:p-5 {
    padding: 1.25rem;
  }
}

@media (min-width: 768px) {
  .md\:w-6\/12 {
    width: 50%;
  }

  .md\:flex-row {
    flex-direction: row;
  }

  .md\:p-10 {
    padding: 2.5rem;
  }

  .md\:text-base {
    font-size: 1rem;
    line-height: 1.5rem;
  }
}

@media (min-width: 1024px) {
  .lg\:mt-32 {
    margin-top: 8rem;
  }

  .lg\:w-5\/12 {
    width: 41.666667%;
  }
}

@media (min-width: 1280px) {
  .xl\:w-4\/12 {
    width: 33.333333%;
  }
}
